#
# spec file for package kernel-default
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#
# needssslcertforbuild


%define srcversion 4.12
%define patchversion 4.12.14
%define variant %{nil}
%define vanilla_only 0

%include %_sourcedir/kernel-spec-macros

%define build_flavor	default
%define build_default	("%build_flavor" == "default")
%define build_vanilla	("%build_flavor" == "vanilla")

%if ! %build_vanilla
%define src_install_dir /usr/src/linux-%kernelrelease%variant
%else
%define src_install_dir /usr/src/linux-%kernelrelease-vanilla
%endif
%define obj_install_dir /usr/src/linux-%kernelrelease%variant-obj
%define rpm_install_dir %buildroot%obj_install_dir
%define kernel_build_dir %my_builddir/linux-%srcversion/linux-obj

%(chmod +x %_sourcedir/{guards,apply-patches,check-for-config-changes,group-source-files.pl,split-modules,modversions,kabi.pl,mkspec,compute-PATCHVERSION.sh,arch-symbols,log.sh,try-disable-staging-driver,compress-vmlinux.sh,mkspec-dtb,check-module-license})

%global cpu_arch %(%_sourcedir/arch-symbols %_target_cpu)
%define cpu_arch_flavor %cpu_arch/%build_flavor

# Define some CONFIG variables as rpm macros as well. (rpm cannot handle
# defining them all at once.)
%define config_vars CONFIG_MODULES CONFIG_MODULE_SIG CONFIG_KMSG_IDS CONFIG_SUSE_KERNEL_SUPPORTED CONFIG_EFI_STUB
%{expand:%(eval "$(test -n "%cpu_arch_flavor" && tar -xjf %_sourcedir/config.tar.bz2 --to-stdout config/%cpu_arch_flavor)"; for config in %config_vars; do echo "%%global $config ${!config:-n}"; done)}
%define split_extra (%CONFIG_MODULES == "y" && %CONFIG_SUSE_KERNEL_SUPPORTED == "y")

%ifarch %ix86 x86_64
%define install_vdso 1
%else
%define install_vdso 0
%endif

Name:           kernel-default
Summary:        The Standard Kernel
License:        GPL-2.0
Group:          System/Kernel
Version:        4.12.14
%if 0%{?is_kotd}
Release:        lp150.11.4.ga9fee09
%else
Release:        lp150.11.4
%endif
Url:            http://www.kernel.org/
BuildRequires:  bc
BuildRequires:  bison
BuildRequires:  coreutils
BuildRequires:  fdupes
BuildRequires:  flex
# Cannot test %%CONFIG_GCC_PLUGINS here because the buildservice parser
# does not expand %%(...)
%if "%build_flavor" == "syzkaller"
# Needed by scripts/gcc-plugin.sh
BuildRequires:  gcc-c++ gcc-devel
%endif
%if 0%{?suse_version} > 1310
BuildRequires:  hmaccalc
%endif
BuildRequires:  libopenssl-devel
BuildRequires:  modutils
# Used to sign the kernel in the buildservice
BuildRequires:  openssl
BuildRequires:  pesign-obs-integration
# for objtool
BuildRequires:  libelf-devel
Provides:       %name = %version-%source_rel
# bnc#901925
Provides:       %name-%version-%source_rel
Provides:       %{name}_%_target_cpu = %version-%source_rel
Provides:       kernel-base = %version-%source_rel
Provides:       multiversion(kernel)
# In SLE11, kernel-$flavor complemented kernel-$flavor-base. With SLE12,
# kernel-$flavor itself contains all the needed files and kernel-$flavor-base
# is a subset that can replace kernel-$flavor in some scenarios. We need to
# obsolete the -base subpackage from SLE11, so that the base files are not
# owned by multiple packages now. The dependency is not correct wrt openSUSE
# 11.2 - 11.4, but we primarily care about the supported upgrade path.
Obsoletes:      %name-base < 3.1
Recommends: kernel-firmware
# The following is copied to the -base subpackage as well
# BEGIN COMMON DEPS
Requires(pre):  coreutils awk
# For /usr/lib/module-init-tools/weak-modules2
Requires(post): suse-module-tools
# For depmod (modutils is a dependency provided by both module-init-tools and
# kmod-compat)
Requires(post): modutils
# This Requires is wrong, because the post/postun scripts have a
# test -x update-bootloader, having perl-Bootloader is not a hard requirement.
# But, there is no way to tell rpm or yast to schedule the installation
# of perl-Bootloader before kernel-binary.rpm if both are in the list of
# packages to install/update. Likewise, this is true for mkinitrd.
# Need a perl-Bootloader with /usr/lib/bootloader/bootloader_entry
Requires(post): perl-Bootloader >= 0.4.15
%if %build_vanilla
Requires(post): mkinitrd
%else
# Require a mkinitrd that can handle usbhid/hid-generic built-in (bnc#773559)
Requires(post): mkinitrd >= 2.7.1
%endif
# Install the package providing /etc/SuSE-release early enough, so that
# the grub entry has correct title (bnc#757565)
Requires(post): distribution-release
# Do not install p-b and mkinitrd for the install check, the %post script is
# able to handle this
#!BuildIgnore: perl-Bootloader mkinitrd distribution-release
# Remove some packages that are installed automatically by the build system,
# but are not needed to build the kernel
#!BuildIgnore: autoconf automake gettext-runtime libtool cvs gettext-tools udev insserv

%ifarch s390 s390x
%if %build_vanilla && 0%{?suse_version} < 1130
BuildRequires:  dwarfextract
%endif
%endif
%ifarch %arm
BuildRequires:  u-boot-tools
%endif

Obsoletes:      microcode_ctl

# Force bzip2 instead of lzma compression to
# 1) allow install on older dist versions, and
# 2) decrease build times (bsc#962356)
%define _binary_payload w9.bzdio
# Do not recompute the build-id of vmlinux in find-debuginfo.sh (bsc#964063)
%undefine _unique_build_ids
%define _no_recompute_build_ids 1
# prevent usr/lib/debug/boot/vmlinux-4.12.14-11.10-default-4.12.14-11.10.ppc64le.debug
%undefine _unique_debug_names
# dead network if installed on SLES10, otherwise it will work (mostly)
Conflicts:      sysfsutils < 2.0
Conflicts:      apparmor-profiles <= 2.1
Conflicts:      apparmor-parser < 2.3
# root-lvm only works with newer udevs
Conflicts:      udev < 118
Conflicts:      lvm2 < 2.02.33
# Interface to hv_kvp_daemon changed
Conflicts:      hyper-v < 4
%ifarch %ix86
Conflicts:      libc.so.6()(64bit)
%endif
Provides:       kernel = %version-%source_rel
Provides:       kernel-srchash = a9fee0989a17203b0fa48196e464a738f1222412
Provides:       kernel-%build_flavor-base-srchash = a9fee0989a17203b0fa48196e464a738f1222412
# END COMMON DEPS
Provides:       %name-srchash = a9fee0989a17203b0fa48196e464a738f1222412
%ifarch s390x
Provides:       kernel-trace = 3.13
Obsoletes:      kernel-trace <= 3.13
%endif
%ifarch x86_64
Provides:       kernel-smp = 2.6.17
Obsoletes:      kernel-smp <= 2.6.17
Provides:       kernel-trace = 3.13
Obsoletes:      kernel-trace <= 3.13
Provides:       kernel-bigsmp = 3.1
Obsoletes:      kernel-bigsmp <= 3.1
Provides:       kernel-desktop = 4.3
Obsoletes:      kernel-desktop <= 4.3
Provides:       kernel-xen = 4.4
Obsoletes:      kernel-xen <= 4.4
Provides:       kernel-ec2 = 4.4
Obsoletes:      kernel-ec2 <= 4.4
%endif
%ifarch s390x
Provides:       kernel-trace-base = 3.13
Obsoletes:      kernel-trace-base <= 3.13
%endif
%ifarch x86_64
Provides:       kernel-trace-base = 3.13
Obsoletes:      kernel-trace-base <= 3.13
Provides:       kernel-bigsmp-base = 3.1
Obsoletes:      kernel-bigsmp-base <= 3.1
Provides:       kernel-desktop-base = 4.3
Obsoletes:      kernel-desktop-base <= 4.3
Provides:       kernel-xen-base = 4.4
Obsoletes:      kernel-xen-base <= 4.4
Provides:       kernel-ec2-base = 4.4
Obsoletes:      kernel-ec2-base <= 4.4
%endif
%obsolete_rebuilds %name
Source0:        http://www.kernel.org/pub/linux/kernel/v4.x/linux-%srcversion.tar.xz
Source2:        source-post.sh
Source3:        kernel-source.rpmlintrc
Source8:        devel-pre.sh
Source9:        devel-post.sh
Source10:       preun.sh
Source11:       postun.sh
Source12:       pre.sh
Source13:       post.sh
Source14:       series.conf
Source16:       guards
Source17:       apply-patches
Source21:       config.conf
Source23:       supported.conf
Source33:       check-for-config-changes
Source35:       group-source-files.pl
Source36:       README.PATCH-POLICY.SUSE
Source37:       README.SUSE
Source38:       README.KSYMS
Source39:       config-options.changes.txt
Source40:       source-timestamp
Source46:       split-modules
Source47:       modversions
Source48:       macros.kernel-source
Source49:       kernel-module-subpackage
Source50:       kabi.pl
Source51:       mkspec
Source52:       kernel-source%variant.changes
Source53:       kernel-source.spec.in
Source54:       kernel-binary.spec.in
Source55:       kernel-syms.spec.in
Source56:       kernel-docs.spec.in
Source57:       kernel-cert-subpackage
Source58:       constraints.in
Source60:       config.sh
Source61:       compute-PATCHVERSION.sh
Source62:       old-flavors
Source63:       arch-symbols
Source64:       package-descriptions
Source65:       kernel-spec-macros
Source67:       log.sh
Source68:       host-memcpy-hack.h
Source69:       try-disable-staging-driver
Source70:       kernel-obs-build.spec.in
Source71:       kernel-obs-qa.spec.in
Source72:       compress-vmlinux.sh
Source73:       dtb.spec.in.in
Source74:       mkspec-dtb
Source75:       release-projects
Source76:       check-module-license
Source78:       modules.fips
Source100:      config.tar.bz2
Source101:      config.addon.tar.bz2
Source102:      patches.arch.tar.bz2
Source103:      patches.drivers.tar.bz2
Source104:      patches.fixes.tar.bz2
Source105:      patches.rpmify.tar.bz2
Source106:      patches.suse.tar.bz2
Source108:      patches.addon.tar.bz2
Source109:      patches.kernel.org.tar.bz2
Source110:      patches.apparmor.tar.bz2
Source111:      patches.rt.tar.bz2
Source113:      patches.kabi.tar.bz2
Source120:      kabi.tar.bz2
Source121:      sysctl.tar.bz2
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
ExclusiveArch:  aarch64 armv7hl ppc64le s390x x86_64
%define kmp_target_cpu %_target_cpu
%ifarch %ix86
# Only i386/default supports i586, mark other flavors' packages as i686
%if ! %build_default
BuildArch:      i686
# KMPs are always built as i586, because rpm does not allow to build
# subpackages for different architectures. Therefore, we change the
# /usr/src/linux-obj/<arch> symlink to i586.
%define kmp_target_cpu i586
%endif
%endif

# These files are found in the kernel-source package:
NoSource:       0
NoSource:       2
NoSource:       3
NoSource:       8
NoSource:       9
NoSource:       10
NoSource:       11
NoSource:       12
NoSource:       13
NoSource:       14
NoSource:       16
NoSource:       17
NoSource:       21
NoSource:       23
NoSource:       33
NoSource:       35
NoSource:       36
NoSource:       37
NoSource:       38
NoSource:       39
NoSource:       40
NoSource:       46
NoSource:       47
NoSource:       48
NoSource:       49
NoSource:       50
NoSource:       51
NoSource:       52
NoSource:       53
NoSource:       54
NoSource:       55
NoSource:       56
NoSource:       57
NoSource:       58
NoSource:       60
NoSource:       61
NoSource:       62
NoSource:       63
NoSource:       64
NoSource:       65
NoSource:       67
NoSource:       68
NoSource:       69
NoSource:       70
NoSource:       71
NoSource:       72
NoSource:       73
NoSource:       74
NoSource:       75
NoSource:       76
NoSource:       78
NoSource:       100
NoSource:       101
NoSource:       102
NoSource:       103
NoSource:       104
NoSource:       105
NoSource:       106
NoSource:       108
NoSource:       109
NoSource:       110
NoSource:       111
NoSource:       113
NoSource:       120
NoSource:       121

# The following KMPs have been integrated into the kernel package,
# grouped by the last product that contained them.
# Usage: obsolete_kmp <basename> <upper bound of shipped versions>
# Note that KMPs embed the version of the kernel built against, that's why
# the _3 suffix for 2.6.x-based KMPs
%define obsolete_kmp() Obsoletes: %1-kmp-%build_flavor <= %2 \
Provides: %1-kmp = %2 \
Provides: %1-kmp-%build_flavor = %2
# sles10 / 10.3
%obsolete_kmp iwlwifi 1.3.27_3
%obsolete_kmp ipw3945 1.2.2_3
# sled10 / 11.0
%obsolete_kmp uvcvideo r200_3
# sle11-ga
%obsolete_kmp enic 0.0.1_3
%obsolete_kmp fnic 1.0.0_3
%obsolete_kmp brocade-bfa 1.1.0.2_3
%obsolete_kmp kvm 78.2.6.30.1_3
%obsolete_kmp perfmon 2_3
%obsolete_kmp iwlagn-2-6-27 1.0_3
%obsolete_kmp msi-wmi 1.0_3
# 11.1
%obsolete_kmp quickcam 0.6.7
# sle11-sp1
%obsolete_kmp   wacom 0.8.1_3
%obsolete_kmp   btrfs 0_3
%obsolete_kmp   brocade-bna 2.1.0.0_3
%obsolete_kmp   hyper-v 0_3
%obsolete_kmp   intel-e1000e 2.2.14
Obsoletes:      firewire <= 3.0
Provides:       firewire = 3.0
%obsolete_kmp   firewire 3.0
%obsolete_kmp   iwlagn 3.0
Obsoletes:      compat-ath9k <= 3.0
Provides:       compat-ath9k = 3.0
%obsolete_kmp   compat-ath9k 3.0
%obsolete_kmp   realtek-r8192ce_pci 2.6.0005_3
%obsolete_kmp   realtek-r8192se_pci 2.6.0019.1207.2010_3
%obsolete_kmp   rt3090 2.4.0.4_3
%obsolete_kmp   rt3592 2.4.1.1_3
%obsolete_kmp   rt5390 2.4.0.4_3
%obsolete_kmp   ath3k 1.0_3
%obsolete_kmp	compat-wireless 3.12
%obsolete_kmp	rts5229 1.08
%obsolete_kmp	rts_pstor 1.11
# sle12-sp1 / Leap 42.1
%obsolete_kmp	xen 4.6.1
%obsolete_kmp	compat-wireless 4.4
# TW 4.8
%obsolete_kmp	ftsteutates 20160601
# SLE12-SP3 / Leap 42.3
%obsolete_kmp   drm 4.12

# Will modules not listed in supported.conf abort the kernel build (0/1)?
%define supported_modules_check 0

%description
The standard kernel for both uniprocessor and multiprocessor systems.


%source_timestamp
%prep
if ! [ -e %{S:0} ]; then
    echo "The %name-%version.nosrc.rpm package does not contain the" \
	 "complete sources. Please install kernel-source-%version.src.rpm."
    exit 1
fi

SYMBOLS=
if test -e %_sourcedir/extra-symbols; then
	SYMBOLS=$(cat %_sourcedir/extra-symbols)
	echo "extra symbol(s):" $SYMBOLS
fi

# Unpack all sources and patches
%setup -q -c -T -a 0 -a 100 -a 101 -a 102 -a 103 -a 104 -a 105 -a 106 -a 108 -a 109 -a 110 -a 111 -a 113 -a 120 -a 121

mkdir -p %kernel_build_dir

# Generate a list of modules with their support status marking
%_sourcedir/guards --list --with-guards <%_sourcedir/supported.conf | \
awk '
	/\+external / {
		print $(NF) " external";
		next;
	}
	/^-/ {
		print $(NF) " no";
		next;
	}
	{
		print $(NF);
	}
' >%kernel_build_dir/Module.supported
subpackages=(
	base
%if %CONFIG_SUSE_KERNEL_SUPPORTED == "y"
	cluster-md-kmp dlm-kmp gfs2-kmp kselftests-kmp ocfs2-kmp
%endif
)
for package in "${subpackages[@]}"; do
	%_sourcedir/guards --default=0 "$package" \
		<%_sourcedir/supported.conf | sed 's,.*/,,; s,\.ko$,,' | \
		sort -u >%kernel_build_dir/Module."$package"
done

cd linux-%srcversion

%_sourcedir/apply-patches \
%if %{build_vanilla}
	--vanilla \
%endif
	%_sourcedir/series.conf .. $SYMBOLS

cd %kernel_build_dir

# Override the timestamp 'uname -v' reports with the source timestamp and
# the commit hash.
date=$(head -n 1 %_sourcedir/source-timestamp)
commit=$(sed -n 's/GIT Revision: //p' %_sourcedir/source-timestamp)
cat > .kernel-binary.spec.buildenv <<EOF
export KBUILD_BUILD_TIMESTAMP="$(LANG=C date -d "$date") (${commit:0:7})"
export KBUILD_VERBOSE=0
export KBUILD_SYMTYPES=1
export KBUILD_OVERRIDE=1
export KBUILD_BUILD_USER=geeko
export KBUILD_BUILD_HOST=buildhost
export HOST_EXTRACFLAGS="-include %_sourcedir/host-memcpy-hack.h"
EOF
source .kernel-binary.spec.buildenv

if [ -f %_sourcedir/localversion ] ; then
    cat %_sourcedir/localversion > localversion
fi

vanilla_base="default"
%ifarch %ix86
vanilla_base="pae"
%endif
if ! grep -q CONFIG_MMU= "%my_builddir/config/%cpu_arch_flavor"; then
cp "%my_builddir/config/%cpu_arch/$vanilla_base" .config
../scripts/kconfig/merge_config.sh -m .config \
                                   %my_builddir/config/%cpu_arch_flavor
else
cp %my_builddir/config/%cpu_arch_flavor .config
fi
if test -e %my_builddir/config.addon/%cpu_arch_flavor; then
	# FIXME: config.addon doesn't affect the %CONFIG_ macros defined at
	# the top of the specfile
	../scripts/kconfig/merge_config.sh -m .config %my_builddir/config.addon/%cpu_arch_flavor
fi

CONFIG_SUSE_KERNEL_RELEASED="--disable CONFIG_SUSE_KERNEL_RELEASED"
%if 0%{?_project:1}
if echo %_project | egrep -qx -f %_sourcedir/release-projects; then
	CONFIG_SUSE_KERNEL_RELEASED="--enable CONFIG_SUSE_KERNEL_RELEASED"
fi
%endif

../scripts/config \
	--set-str CONFIG_LOCALVERSION -%source_rel-%build_flavor \
	--enable  CONFIG_SUSE_KERNEL \
	$CONFIG_SUSE_KERNEL_RELEASED \
%if 0%{?__debug_package:1}
	--enable  CONFIG_DEBUG_INFO
%else
	--disable CONFIG_DEBUG_INFO
%endif

makeoutputsync=
if make --output-sync --help >/dev/null 2>&1 ; then
        makeoutputsync=--output-sync
else
        echo make does not support --output-sync flag. Build messages may be mangled. 1>&2
fi
MAKE_ARGS="$MAKE_ARGS $makeoutputsync %{?_smp_mflags}"
echo export MAKE_ARGS=\""$MAKE_ARGS"\" >> .kernel-binary.spec.buildenv

KERN_DIRS="-C .. O=$PWD"
if test -e %_sourcedir/TOLERATE-UNKNOWN-NEW-CONFIG-OPTIONS; then
    yes '' | make oldconfig $MAKE_ARGS $KERN_DIRS
else
    cp .config .config.orig
    make silentoldconfig $MAKE_ARGS $KERN_DIRS < /dev/null
    %_sourcedir/check-for-config-changes .config.orig .config
    rm .config.orig
fi

make prepare $MAKE_ARGS
make scripts $MAKE_ARGS
krel=$(make -s kernelrelease $MAKE_ARGS)

if [ "$krel" != "%kernelrelease-%build_flavor" ]; then
    echo "Kernel release mismatch: $krel != %kernelrelease-%build_flavor" >&2
    exit 1
fi

make clean $MAKE_ARGS

rm -f source
find . ! -type d ! -name 'Module.base' ! -name 'Module.*-kmp' -printf '%%P\n' \
	> %my_builddir/obj-files

%build
cd %kernel_build_dir
source .kernel-binary.spec.buildenv

# create *.symref files in the tree
if test -e %my_builddir/kabi/%cpu_arch/symtypes-%build_flavor; then
    %_sourcedir/modversions --unpack . < $_
fi

# copy module signing certificate(s). We use the default path and trick
# certs/Makefile to not regenerate the certificate. It is done this way so
# that the kernel-source package can be rebuilt even without the certificate
mkdir -p certs
for f in %_sourcedir/*.crt; do
    if ! test -e "$f"; then
        continue
    fi
    touch certs/x509.genkey
    cat "$f" >>certs/signing_key.pem
done

%if %CONFIG_KMSG_IDS == "y"
    chmod +x ../scripts/kmsg-doc
    MAKE_ARGS="$MAKE_ARGS D=2"
%endif

mkdir -p %_topdir/OTHER
log=%_topdir/OTHER/make-stderr.log
while true; do
    make all $MAKE_ARGS 2> >(tee "$log")
    if test "${PIPESTATUS[0]}" -eq 0; then
        break
    fi
    # In the linux-next and vanilla branches, we try harder to build a
    # package.
    if test 0%vanilla_only -gt 0 &&
			%_sourcedir/try-disable-staging-driver "$log"; then
        echo "Retrying make"
    else
        exit 1
    fi
done

%install

# sign the modules, firmware and possibly the kernel in the buildservice
BRP_PESIGN_FILES=""
%if %CONFIG_EFI_STUB == "y"
BRP_PESIGN_FILES="/boot/vmlinuz-%kernelrelease-%build_flavor"
%endif
%if %CONFIG_MODULE_SIG == "y"
BRP_PESIGN_FILES="$BRP_PESIGN_FILES *.ko"
%endif
%ifarch %ix86
# XXX: do not sign on x86, as the repackaging changes kernel-pae
# from i686 to i586
BRP_PESIGN_FILES=""
%endif
export BRP_PESIGN_FILES

# get rid of /usr/lib/rpm/brp-strip-debug
# strip removes too much from the vmlinux ELF binary
export NO_BRP_STRIP_DEBUG=true
export STRIP_KEEP_SYMTAB='*/vmlinux-*'

# /lib/modules/%kernelrelease-%build_flavor/source points to the source
# directory installed by kernel-devel. The kernel-%build_flavor-devel package
# has a correct dependency on kernel-devel, but the brp check does not see
# kernel-devel during build.
export NO_BRP_STALE_LINK_ERROR=yes

cd %kernel_build_dir

mkdir -p %buildroot/boot
# (Could strip out non-public symbols.)
cp -p System.map %buildroot/boot/System.map-%kernelrelease-%build_flavor

add_vmlinux()
{
    local vmlinux=boot/vmlinux-%kernelrelease-%build_flavor

    cp vmlinux %buildroot/$vmlinux
    # make sure that find-debuginfo.sh picks it up. In the filelist, we
    # mark the file 0644 again
    chmod +x %buildroot/$vmlinux
    if test $1 == "--compressed"; then
        # avoid using the gzip -n option to make kdump happy (bnc#880848#c20)
        ts="$(head -n1 %_sourcedir/source-timestamp)"
        touch -d "$ts" %buildroot/$vmlinux
        touch %buildroot/$vmlinux.gz
%if 0%{?__debug_package:1}
        # compress the vmlinux image after find-debuginfo.sh has processed it
%global __debug_install_post %__debug_install_post \
%_sourcedir/compress-vmlinux.sh %buildroot/boot/vmlinux-%kernelrelease-%build_flavor
%else
        %_sourcedir/compress-vmlinux.sh %buildroot/$vmlinux
%endif
        ghost_vmlinux=true
    else
        ghost_vmlinux=false
    fi
}

# architecture specifics
%ifarch %ix86 x86_64
    add_vmlinux --compressed
    image=bzImage
    cp -p arch/x86/boot/$image %buildroot/boot/vmlinuz-%kernelrelease-%build_flavor
    image=vmlinuz
%endif
%ifarch ppc ppc64 ppc64le
    add_vmlinux
    image=vmlinux
%endif
%ifarch s390 s390x
    add_vmlinux --compressed
    cp -p arch/s390/boot/image %buildroot/boot/image-%kernelrelease-%build_flavor
    image=image
    if test -e arch/s390/boot/kerntypes.o; then
        cp -p arch/s390/boot/kerntypes.o %buildroot/boot/Kerntypes-%kernelrelease-%build_flavor
    elif test -x "$(which dwarfextract 2>/dev/null)"; then
	dwarfextract vmlinux %buildroot/boot/Kerntypes-%kernelrelease-%build_flavor || echo "dwarfextract failed ($?)"
    fi
%if %CONFIG_KMSG_IDS == "y"
    mkdir -p %buildroot/usr/share/man/man9
    find man -name '*.9' -exec install -m 644 -D '{}' %buildroot/usr/share/man/man9/ ';'
%endif
%endif
%ifarch %arm
    add_vmlinux --compressed
    image=zImage
    cp -p arch/arm/boot/$image %buildroot/boot/$image-%kernelrelease-%build_flavor
%endif
%ifarch aarch64
    add_vmlinux --compressed
    image=Image
    cp -p arch/arm64/boot/$image %buildroot/boot/$image-%kernelrelease-%build_flavor
%endif

if test -x /usr/lib/rpm/pesign/gen-hmac; then
	$_ -r %buildroot /boot/$image-%kernelrelease-%build_flavor
fi

# Package the compiled-in certificates as DER files in /etc/uefi/certs
# and have mokutil enroll them when the kernel is installed
certs=()
if test %CONFIG_MODULE_SIG = "y"; then
    for f in %_sourcedir/*.crt; do
            if ! test -s "$f"; then
                    continue
            fi
            h=$(openssl x509 -inform PEM -fingerprint -noout -in "$f")
            test -n "$h"
            cert=/etc/uefi/certs/$(echo "$h" | \
                sed -rn 's/^SHA1 Fingerprint=//; T; s/://g; s/(.{8}).*/\1/p').crt
            if test -e %buildroot/"$cert"; then
                    continue
            fi
            mkdir -p %buildroot/etc/uefi/certs
            openssl x509 -inform PEM -in "$f" -outform DER -out %buildroot/"$cert"
            certs=("${certs[@]}" "$cert")
    done
fi

for sub in '-base' '' '-extra'; do
    case "$sub" in
    '-base' | '') base_package=1 ;;
    *) base_package=0 ;;
    esac
    for script in preun postun pre post devel-pre devel-post; do
        if test %build_flavor = "zfcpdump"; then
            : >%my_builddir/$script$sub.sh
            continue
        fi
        sed -e "s:@KERNELRELEASE@:%kernelrelease:g" \
            -e "s:@IMAGE@:$image:g" \
            -e "s:@FLAVOR""@:%build_flavor:g" \
            -e "s:@SUBPACKAGE@:%name$sub:g" \
            -e "s:@BASE_PACKAGE@:$base_package:g" \
            -e "s:@RPM_VERSION_RELEASE@:%version-%release:g" \
            -e "s:@RPM_TARGET_CPU@:%_target_cpu:g" \
	    -e "s:@CPU_ARCH_FLAVOR@:%cpu_arch_flavor:g" \
            -e "s:@SRCVARIANT@:%variant:g" \
            %_sourcedir/$script.sh > %my_builddir/$script$sub.sh
        if test "$base_package" -eq 1 -a "${#certs[@]}" -gt 0; then
            case "$script" in
            preun | postun | post)
                # Copy the respective scriptlet from kernel-cert-subpackage
                sed "1,/^%%$script / d; /^%%[^%%]/,\$ d; s:@CERTS@:${certs[*]}:g" \
                    %_sourcedir/kernel-cert-subpackage \
                    >>"%my_builddir/$script$sub.sh"
            esac
        fi
	# Do an exit 0 at the end of each scriptlet. If the last real command
	# in the scriptlet (e.g. update-bootloader call, see bnc#809617)
	# returns an error, we do not want to amplify the damage by leaving
	# the system in an inconsistent state.
	echo "exit 0" >>"%my_builddir/$script$sub.sh"
    done
done

%if %build_vanilla
# keep this -suffix list in sync with post.sh and postun.sh
suffix=-%build_flavor
%endif
ln -s $image$suffix %buildroot/boot/$image$suffix
ln -s initrd$suffix %buildroot/boot/initrd$suffix

cp -p .config %buildroot/boot/config-%kernelrelease-%build_flavor
sysctl_file=%buildroot/boot/sysctl.conf-%kernelrelease-%build_flavor
for file in %my_builddir/sysctl/{defaults,%cpu_arch/arch-defaults,%cpu_arch_flavor}; do
	if [ -f "$file" ]; then
		cat "$file"
	fi
done | sed '1i # Generated file - do not edit.' >$sysctl_file
if [ ! -s $sysctl_file ]; then
	rm $sysctl_file
fi

%if %install_vdso
# Install the unstripped vdso's that are linked in the kernel image
make vdso_install $MAKE_ARGS INSTALL_MOD_PATH=%buildroot
rm -rf %buildroot/lib/modules/%kernelrelease-%build_flavor/vdso/.build-id
%endif

# Create a dummy initrd with roughly the size the real one will have.
# That way, YaST will know that this package requires some additional
# space in /boot.
dd if=/dev/zero of=%buildroot/boot/initrd-%kernelrelease-%build_flavor \
	bs=1024 seek=2047 count=1
# Also reserve some space for the kdump initrd
cp %buildroot/boot/initrd-%kernelrelease-%build_flavor{,-kdump}

if [ %CONFIG_MODULES = y ]; then
    mkdir -p %rpm_install_dir/%cpu_arch_flavor
    mkdir -p %buildroot/usr/src/linux-obj/%cpu_arch
    ln -s %build_flavor %buildroot/usr/src/linux-obj/%cpu_arch_flavor
    install -m 755 -D -t %rpm_install_dir/%cpu_arch_flavor/scripts/mod/ scripts/mod/ksym-provides

    gzip -n -c9 < Module.symvers > %buildroot/boot/symvers-%kernelrelease-%build_flavor.gz

    make modules_install $MAKE_ARGS INSTALL_MOD_PATH=%buildroot

%ifarch s390 s390x
    if test -e arch/s390/boot/kerntypes.o; then
        :
    elif test -x "$(which dwarfextract 2>/dev/null)" -a \
	-f %buildroot/boot/Kerntypes-%kernelrelease-%build_flavor; then
	find %buildroot -name "*.ko" > kofiles.list
	dwarfextract %buildroot/boot/Kerntypes-%kernelrelease-%build_flavor -C kofiles.list || echo "dwarfextract failed ($?)"
    fi
%endif

    # Also put the resulting file in %rpm_install_dir/%cpu_arch/%build_flavor
    # so that kernel-devel + kernel-%build_flavor is sufficient for building
    # modules that have modversions as well.
    mkdir -p %rpm_install_dir/%cpu_arch/%build_flavor
    cp Module.symvers %rpm_install_dir/%cpu_arch/%build_flavor

    # Table of types used in exported symbols (for modversion debugging).
    %_sourcedir/modversions --pack . > %buildroot/boot/symtypes-%kernelrelease-%build_flavor
    if [ -s %buildroot/boot/symtypes-%kernelrelease-%build_flavor ]; then
	gzip -n -9 %buildroot/boot/symtypes-%kernelrelease-%build_flavor
    else
	rm -f %buildroot/boot/symtypes-%kernelrelease-%build_flavor
    fi

    # Some architecture's $(uname -m) output is different from the ARCH
    # parameter that needs to be passed to kbuild. Create symlinks from
    # $(uname -m) to the ARCH directory.
    if [ ! -e %rpm_install_dir/%kmp_target_cpu ]; then
        ln -sf %cpu_arch %rpm_install_dir/%kmp_target_cpu
        ln -sf %cpu_arch %buildroot/usr/src/linux-obj/%kmp_target_cpu
    fi

    # We were building in %my_builddir/linux-%srcversion, but the sources will
    # later be installed in /usr/src/linux-%srcversion-%source_rel. Fix up the
    # build symlink.
    rm -f %buildroot/lib/modules/%kernelrelease-%build_flavor/{source,build}
    ln -s %src_install_dir \
	%buildroot/lib/modules/%kernelrelease-%build_flavor/source
    ln -s %obj_install_dir/%cpu_arch/%build_flavor \
	%buildroot/lib/modules/%kernelrelease-%build_flavor/build

    # Abort if there are any undefined symbols
    msg="$(/sbin/depmod -F %buildroot/boot/System.map-%kernelrelease-%build_flavor \
			-b %buildroot -ae %kernelrelease-%build_flavor 2>&1)"
    if [ $? -ne 0 ] || echo "$msg" | grep  'needs unknown symbol'; then
	exit 1
    fi

    %_sourcedir/split-modules -d %buildroot \
	-o %my_builddir \
	-b %kernel_build_dir \
%if %CONFIG_SUSE_KERNEL_SUPPORTED == "y"
	-e \
%endif
%if ! %supported_modules_check
	-i
%endif
%if ! %split_extra
    cat %my_builddir/unsupported-modules >>%my_builddir/main-modules
%endif

    # The modules.dep file is sorted randomly which produces strange file
    # checksums. As the file is not included in the resulting RPM, it's
    # pointless to rely on its contents. Replacing by zeros to make the
    # checksums always the same for several builds of the same package.
    test -s %buildroot/lib/modules/%kernelrelease-%build_flavor/modules.dep && \
    dd if=/dev/zero of=%buildroot/lib/modules/%kernelrelease-%build_flavor/modules.dep ibs=`stat -c%s %buildroot/lib/modules/%kernelrelease-%build_flavor/modules.dep` count=1

    res=0
    if test -e %my_builddir/kabi/%cpu_arch/symvers-%build_flavor; then
        # check for kabi changes
        %_sourcedir/kabi.pl --rules %my_builddir/kabi/severities \
            %my_builddir/kabi/%cpu_arch/symvers-%build_flavor \
            Module.symvers || res=$?
    fi
    if [ $res -ne 0 ]; then
	# %ignore_kabi_badness is defined in the Kernel:* projects in the
	# OBS to be able to build the KOTD in spite of kabi errors
	if [ 0%{?ignore_kabi_badness} -eq 0 -a \
	     ! -e %my_builddir/kabi/%cpu_arch/ignore-%build_flavor -a \
	     ! -e %_sourcedir/IGNORE-KABI-BADNESS ]; then
	    echo "Create a file IGNORE-KABI-BADNESS in the kernel-source" \
		 "directory to build this kernel even though its badness is" \
		 "higher than allowed for an official kernel."
	   exit 1
	fi
    fi

    # Check the license in each module
    if ! sh %_sourcedir/check-module-license %buildroot; then
	echo "Please fix the missing licenses!"
%if %CONFIG_SUSE_KERNEL_SUPPORTED == "y"
	exit 1
%endif
    fi

    # These files are required for building external modules
    for FILE in arch/powerpc/lib/crtsavres.o arch/arm64/kernel/ftrace-mod.o; do
	    if [ -f %kernel_build_dir/$FILE ]; then
		echo $FILE >> %my_builddir/obj-files
	    fi
    done

    tar -cf - -T %my_builddir/obj-files | \
	tar -xf - -C %rpm_install_dir/%cpu_arch_flavor
    # bnc#507084
    find %rpm_install_dir/%cpu_arch_flavor/scripts -type f -perm -111 | \
        while read f; do
            case "$(file -b "$f")" in
            ELF\ *\ executable*)
                strip "$f"
            esac
        done
    # Recreate the generated Makefile with correct path
    sh ../scripts/mkmakefile ../../../%{basename:%src_install_dir} \
        %rpm_install_dir/%cpu_arch_flavor \
        $(echo %srcversion | sed -r 's/^([0-9]+)\.([0-9]+).*/\1 \2/')
fi

rm -rf %{buildroot}/lib/firmware

add_dirs_to_filelist() {
    sed -rn '
        # print file name
        p
        # remove filelist macros
        s:%%[a-z]+(\([^)]+\))? ?::g
        # add %%dir prefix
        s:^:%%dir :
        # print all parents
        :a
            # skip directories owned by other packages
            s:^%%dir (/boot|/etc|/lib/(modules|firmware)|/usr/src)/[^/]+$::
            s:/[^/]+$::p
        ta
    ' "$@" | sort -u
}

# Collect the file lists.
shopt -s nullglob dotglob
> %my_builddir/kernel-devel.files
for file in %buildroot/boot/symtypes* %buildroot/lib/modules/*/{build,source}; do
	f=${file##%buildroot}
	echo "$f"
done | add_dirs_to_filelist >%my_builddir/kernel-devel.files

{   cd %buildroot
    for f in boot/*; do
        if test -L "$f"; then
            echo "%%ghost /$f"
            continue
        elif test ! -f "$f"; then
            continue
        fi
        case "$f" in
        boot/initrd-*)
            echo "%%ghost /$f"
            continue
            ;;
        boot/vmlinux-*.gz)
            ;;
        boot/vmlinux-*)
            if $ghost_vmlinux; then
                echo "%%ghost /$f"
                continue
            fi
            ;;
        boot/symtypes*)
            continue
            ;;
        esac
        echo "%%attr(0644, root, root) /$f"
    done

    if [ %CONFIG_MODULES = y ]; then
	find lib/modules/%kernelrelease-%build_flavor \
	    -type d -o \
	    \( -path '*/modules.*' ! -path '*/modules.order' \
	     ! -path '*/modules.builtin' \) -printf '%%%%ghost /%%p\n' \
	       -o -name '*.ko' -prune -o -type f -printf '/%%p\n'
	cat %my_builddir/base-modules
    fi
    if test %CONFIG_MODULE_SIG = "y" -a -d etc/uefi/certs; then
        find etc/uefi/certs -type f -printf '/%%p\n'
    fi
    if test -d lib/firmware/%kernelrelease-%build_flavor; then
        echo "%%dir /lib/firmware/%kernelrelease-%build_flavor"
        cat %my_builddir/base-firmware
    fi
    if [ -e .%_docdir/%name ]; then
	echo "%%doc %_docdir/%name"
    fi
} | sort -u | add_dirs_to_filelist >%my_builddir/kernel-base.files

{
    add_dirs_to_filelist %my_builddir/{kernel-base.files,main-modules}
    if test -d %buildroot/lib/firmware/%kernelrelease-%build_flavor; then
	echo "/lib/firmware/%kernelrelease-%build_flavor"
    fi
} > %my_builddir/kernel-main.files
%if %split_extra
    add_dirs_to_filelist %my_builddir/unsupported-modules > %my_builddir/kernel-extra.files
%endif
for f in %my_builddir/*-kmp-modules; do
	f2=${f%%-modules}.files
	add_dirs_to_filelist "$f" >"$f2"
done

if [ %CONFIG_MODULES = y ]; then
  install -m 644 %_sourcedir/modules.fips %{buildroot}/lib/modules/%kernelrelease-%build_flavor/modules.fips
  echo /lib/modules/%kernelrelease-%build_flavor/modules.fips >> %my_builddir/kernel-base.files
fi

# Hardlink duplicate files automatically (from package fdupes): It doesn't save
# much, but it keeps rpmlint from breaking the package build. Note that we skip
# /usr/src/linux-obj intentionally, to not accidentally break timestamps there
%fdupes $RPM_BUILD_ROOT/lib

%preun -f preun.sh

%postun -f postun.sh

%pre -f pre.sh

%post -f post.sh

%files -f kernel-main.files
%defattr(-, root, root)

%if %CONFIG_MODULES == "y"
%package base
Summary:        The Standard Kernel - base modules
Group:          System/Kernel
Url:            http://www.kernel.org/
Provides:       kernel-base = %version-%source_rel
Provides:       multiversion(kernel)
Conflicts:      %name = %version-%source_rel
Requires(pre):  coreutils awk
# For /usr/lib/module-init-tools/weak-modules2
Requires(post): suse-module-tools
# For depmod (modutils is a dependency provided by both module-init-tools and
# kmod-compat)
Requires(post): modutils
# This Requires is wrong, because the post/postun scripts have a
# test -x update-bootloader, having perl-Bootloader is not a hard requirement.
# But, there is no way to tell rpm or yast to schedule the installation
# of perl-Bootloader before kernel-binary.rpm if both are in the list of
# packages to install/update. Likewise, this is true for mkinitrd.
# Need a perl-Bootloader with /usr/lib/bootloader/bootloader_entry
Requires(post): perl-Bootloader >= 0.4.15
%if %build_vanilla
Requires(post): mkinitrd
%else
# Require a mkinitrd that can handle usbhid/hid-generic built-in (bnc#773559)
Requires(post): mkinitrd >= 2.7.1
%endif
# Install the package providing /etc/SuSE-release early enough, so that
# the grub entry has correct title (bnc#757565)
Requires(post): distribution-release
# Do not install p-b and mkinitrd for the install check, the %post script is
# able to handle this
#!BuildIgnore: perl-Bootloader mkinitrd distribution-release
# Remove some packages that are installed automatically by the build system,
# but are not needed to build the kernel
#!BuildIgnore: autoconf automake gettext-runtime libtool cvs gettext-tools udev insserv

%ifarch s390 s390x
%if %build_vanilla && 0%{?suse_version} < 1130
BuildRequires:  dwarfextract
%endif
%endif
%ifarch %arm
BuildRequires:  u-boot-tools
%endif

Obsoletes:      microcode_ctl

# Force bzip2 instead of lzma compression to
# 1) allow install on older dist versions, and
# 2) decrease build times (bsc#962356)
%define _binary_payload w9.bzdio
# Do not recompute the build-id of vmlinux in find-debuginfo.sh (bsc#964063)
%undefine _unique_build_ids
%define _no_recompute_build_ids 1
# prevent usr/lib/debug/boot/vmlinux-4.12.14-11.10-default-4.12.14-11.10.ppc64le.debug
%undefine _unique_debug_names
# dead network if installed on SLES10, otherwise it will work (mostly)
Conflicts:      sysfsutils < 2.0
Conflicts:      apparmor-profiles <= 2.1
Conflicts:      apparmor-parser < 2.3
# root-lvm only works with newer udevs
Conflicts:      udev < 118
Conflicts:      lvm2 < 2.02.33
# Interface to hv_kvp_daemon changed
Conflicts:      hyper-v < 4
%ifarch %ix86
Conflicts:      libc.so.6()(64bit)
%endif
Provides:       kernel = %version-%source_rel
Provides:       kernel-srchash = a9fee0989a17203b0fa48196e464a738f1222412
Provides:       kernel-%build_flavor-base-srchash = a9fee0989a17203b0fa48196e464a738f1222412

%ifarch s390x
Provides:       kernel-trace-base = 3.13
Obsoletes:      kernel-trace-base <= 3.13
%endif
%ifarch x86_64
Provides:       kernel-trace-base = 3.13
Obsoletes:      kernel-trace-base <= 3.13
Provides:       kernel-bigsmp-base = 3.1
Obsoletes:      kernel-bigsmp-base <= 3.1
Provides:       kernel-desktop-base = 4.3
Obsoletes:      kernel-desktop-base <= 4.3
Provides:       kernel-xen-base = 4.4
Obsoletes:      kernel-xen-base <= 4.4
Provides:       kernel-ec2-base = 4.4
Obsoletes:      kernel-ec2-base <= 4.4
%endif
%obsolete_rebuilds %name-base
%ifarch %ix86
Conflicts:      libc.so.6()(64bit)
%endif

%description base
The standard kernel for both uniprocessor and multiprocessor systems.

This package contains only the base modules, required in all installs.


%source_timestamp
%preun base -f preun-base.sh

%postun base -f postun-base.sh

%pre base -f pre-base.sh

%post base -f post-base.sh

%files base -f kernel-base.files
%defattr(-, root, root)
%endif

%package extra
Summary:        The Standard Kernel - Unsupported kernel modules
Group:          System/Kernel
Url:            http://www.kernel.org/
Provides:       %name-extra_%_target_cpu = %version-%source_rel
Provides:       kernel-extra = %version-%source_rel
Provides:       multiversion(kernel)
Requires:       %{name}_%_target_cpu = %version-%source_rel
Requires(pre):  coreutils awk
Requires(post): modutils
Requires(post): perl-Bootloader
Requires(post): mkinitrd
%ifarch s390x
Provides:       kernel-trace-extra = 3.13
Obsoletes:      kernel-trace-extra <= 3.13
%endif
%ifarch x86_64
Provides:       kernel-trace-extra = 3.13
Obsoletes:      kernel-trace-extra <= 3.13
Provides:       kernel-bigsmp-extra = 3.1
Obsoletes:      kernel-bigsmp-extra <= 3.1
Provides:       kernel-desktop-extra = 4.3
Obsoletes:      kernel-desktop-extra <= 4.3
Provides:       kernel-xen-extra = 4.4
Obsoletes:      kernel-xen-extra <= 4.4
Provides:       kernel-ec2-extra = 4.4
Obsoletes:      kernel-ec2-extra <= 4.4
%endif
%obsolete_rebuilds %name-extra
Supplements:    packageand(product(SLED):%{name}_%_target_cpu)
Supplements:    packageand(product(sle-we):%{name}_%_target_cpu)
%ifarch %ix86
Conflicts:      libc.so.6()(64bit)
%endif

%description extra
The standard kernel for both uniprocessor and multiprocessor systems.

This package contains additional modules not supported by Novell.


%source_timestamp
%preun extra -f preun-extra.sh

%postun extra -f postun-extra.sh

%pre extra -f pre-extra.sh

%post extra -f post-extra.sh

%if %split_extra

%files extra -f kernel-extra.files
%defattr(-, root, root)
%endif

%if %CONFIG_KMSG_IDS == "y"

%package man
Summary:        The collection of man pages generated by the kmsg script
Group:          System/Kernel

%description man
This package includes the man pages that have been generated from the
kmsg message documentation comments.


%source_timestamp
%files man
%defattr(-,root,root)
/usr/share/man/man9/*
%endif

%package devel
Summary:        Development files necessary for building kernel modules
Group:          Development/Sources
Provides:       %name-devel = %version-%source_rel
Provides:       multiversion(kernel)
%if ! %build_vanilla
Requires:       kernel-devel%variant = %version-%source_rel
Recommends:     make
Recommends:     gcc
Recommends:     perl
# for objtool
Requires:	libelf-devel
Supplements:    packageand(%name:kernel-devel%variant)
%else
Requires:       kernel-source-vanilla = %version-%source_rel
Supplements:    packageand(%name:kernel-source-vanilla)
%endif
%ifarch s390x
Provides:       kernel-trace-devel = 3.13
Obsoletes:      kernel-trace-devel <= 3.13
%endif
%ifarch x86_64
Provides:       kernel-trace-devel = 3.13
Obsoletes:      kernel-trace-devel <= 3.13
Provides:       kernel-bigsmp-devel = 3.1
Obsoletes:      kernel-bigsmp-devel <= 3.1
Provides:       kernel-desktop-devel = 4.3
Obsoletes:      kernel-desktop-devel <= 4.3
Provides:       kernel-xen-devel = 4.4
Obsoletes:      kernel-xen-devel <= 4.4
Provides:       kernel-ec2-devel = 4.4
Obsoletes:      kernel-ec2-devel <= 4.4
%endif
%obsolete_rebuilds %name-devel
PreReq:         coreutils

%description devel
This package contains files necessary for building kernel modules (and
kernel module packages) against the %build_flavor flavor of the kernel.


%source_timestamp

%if %CONFIG_MODULES == "y"

%pre devel -f devel-pre.sh

%post devel -f devel-post.sh

%files devel -f kernel-devel.files
%defattr(-,root,root)
%dir %obj_install_dir
%dir %obj_install_dir/%cpu_arch
%dir /usr/src/linux-obj
%dir /usr/src/linux-obj/%cpu_arch
%ghost /usr/src/linux-obj/%cpu_arch_flavor
%obj_install_dir/%cpu_arch_flavor
%if %kmp_target_cpu != %cpu_arch
%obj_install_dir/%kmp_target_cpu
/usr/src/linux-obj/%kmp_target_cpu
%endif
%if %CONFIG_MODULE_SIG != "y"
# avoid unnecessary libopenssl dependency (bsc#1080250)
%exclude /usr/src/linux-*/*/*/scripts/extract-cert
%endif

%if %CONFIG_SUSE_KERNEL_SUPPORTED == "y"
%package livepatch
Summary:        Metapackage to pull in matching kernel-livepatch package
Group:          System/Kernel
Requires:       kernel-livepatch-%(echo %version-%source_rel | sed 'y/\./_/')-%build_flavor
Provides:       multiversion(kernel)
Provides:	kernel-default-kgraft = %version
Provides:	kernel-xen-kgraft = %version
Obsoletes:	kernel-default-kgraft < %version
Obsoletes:	kernel-xen-kgraft < %version

%description livepatch
This is a metapackage that pulls in the matching kernel-livepatch package for a
given kernel version. The advantage of the metapackage is that its name is
static, unlike the kernel-livepatch-<kernel-version>-flavor package names.

%files livepatch
# rpmlint complains about empty packages, so lets own something
%defattr(-, root, root)
%dir /lib/modules/%kernelrelease-%build_flavor
%endif

%if %CONFIG_SUSE_KERNEL_SUPPORTED == "y"
%package -n cluster-md-kmp-%build_flavor
Summary:        Clustering support for MD devices
Group:          System/Kernel
Requires:       %name = %version-%source_rel
Provides:       cluster-md-kmp = %version-%source_rel
Provides:       multiversion(kernel)
# tell weak-modules2 to ignore this package
Provides:       kmp_in_kernel
Requires(post): suse-module-tools >= 12.4
Requires:       dlm-kmp-%build_flavor = %version-%release

%description -n cluster-md-kmp-%build_flavor
Clustering support for MD devices. This enables locking and
synchronization across multiple systems on the cluster, so all
nodes in the cluster can access the MD devices simultaneously.

%post -n cluster-md-kmp-%build_flavor
wm2=/usr/lib/module-init-tools/weak-modules2
nvr=cluster-md-kmp-%build_flavor-%version-%release
if test -x "$wm2"; then
	rpm -ql "$nvr" | INITRD_IN_POSTTRANS=1 /bin/bash -${-/e/} "$wm2" \
	--add-kernel-modules %kernelrelease-%build_flavor
fi

%posttrans -n cluster-md-kmp-%build_flavor
%{?regenerate_initrd_posttrans}

%preun -n cluster-md-kmp-%build_flavor
nvr=cluster-md-kmp-%build_flavor-%version-%release
rpm -ql "$nvr" | grep '\.ko$' > "/var/run/rpm-$nvr-modules"

%postun -n cluster-md-kmp-%build_flavor
wm2=/usr/lib/module-init-tools/weak-modules2
nvr=cluster-md-kmp-%build_flavor-%version-%release
if test -x "$wm2"; then
	/bin/bash -${-/e/} "$wm2" < "/var/run/rpm-$nvr-modules" \
	--remove-kernel-modules %kernelrelease-%build_flavor
fi
rm -f "/var/run/rpm-$nvr-modules"

%files -n cluster-md-kmp-%build_flavor -f cluster-md-kmp.files
%defattr(-, root, root)

%package -n dlm-kmp-%build_flavor
Summary:        DLM kernel modules
Group:          System/Kernel
Requires:       %name = %version-%source_rel
Provides:       dlm-kmp = %version-%source_rel
Provides:       multiversion(kernel)
# tell weak-modules2 to ignore this package
Provides:       kmp_in_kernel
Requires(post): suse-module-tools >= 12.4

%description -n dlm-kmp-%build_flavor
DLM stands for Distributed Lock Manager, a means to synchronize access to
shared resources over the cluster.

%post -n dlm-kmp-%build_flavor
wm2=/usr/lib/module-init-tools/weak-modules2
nvr=dlm-kmp-%build_flavor-%version-%release
if test -x "$wm2"; then
	rpm -ql "$nvr" | INITRD_IN_POSTTRANS=1 /bin/bash -${-/e/} "$wm2" \
	--add-kernel-modules %kernelrelease-%build_flavor
fi

%posttrans -n dlm-kmp-%build_flavor
%{?regenerate_initrd_posttrans}

%preun -n dlm-kmp-%build_flavor
nvr=dlm-kmp-%build_flavor-%version-%release
rpm -ql "$nvr" | grep '\.ko$' > "/var/run/rpm-$nvr-modules"

%postun -n dlm-kmp-%build_flavor
wm2=/usr/lib/module-init-tools/weak-modules2
nvr=dlm-kmp-%build_flavor-%version-%release
if test -x "$wm2"; then
	/bin/bash -${-/e/} "$wm2" < "/var/run/rpm-$nvr-modules" \
	--remove-kernel-modules %kernelrelease-%build_flavor
fi
rm -f "/var/run/rpm-$nvr-modules"

%files -n dlm-kmp-%build_flavor -f dlm-kmp.files
%defattr(-, root, root)

%package -n gfs2-kmp-%build_flavor
Summary:        GFS2 kernel modules
Group:          System/Kernel
Requires:       %name = %version-%source_rel
Provides:       gfs2-kmp = %version-%source_rel
Provides:       multiversion(kernel)
# tell weak-modules2 to ignore this package
Provides:       kmp_in_kernel
Requires(post): suse-module-tools >= 12.4
Requires:       dlm-kmp-%build_flavor = %version-%release

%description -n gfs2-kmp-%build_flavor
GFS2 is Global Filesystem, a shared device filesystem.

%post -n gfs2-kmp-%build_flavor
wm2=/usr/lib/module-init-tools/weak-modules2
nvr=gfs2-kmp-%build_flavor-%version-%release
if test -x "$wm2"; then
	rpm -ql "$nvr" | INITRD_IN_POSTTRANS=1 /bin/bash -${-/e/} "$wm2" \
	--add-kernel-modules %kernelrelease-%build_flavor
fi

%posttrans -n gfs2-kmp-%build_flavor
%{?regenerate_initrd_posttrans}

%preun -n gfs2-kmp-%build_flavor
nvr=gfs2-kmp-%build_flavor-%version-%release
rpm -ql "$nvr" | grep '\.ko$' > "/var/run/rpm-$nvr-modules"

%postun -n gfs2-kmp-%build_flavor
wm2=/usr/lib/module-init-tools/weak-modules2
nvr=gfs2-kmp-%build_flavor-%version-%release
if test -x "$wm2"; then
	/bin/bash -${-/e/} "$wm2" < "/var/run/rpm-$nvr-modules" \
	--remove-kernel-modules %kernelrelease-%build_flavor
fi
rm -f "/var/run/rpm-$nvr-modules"

%files -n gfs2-kmp-%build_flavor -f gfs2-kmp.files
%defattr(-, root, root)

%package -n kselftests-kmp-%build_flavor
Summary:        Kernel sefltests
Group:          System/Kernel
Requires:       %name = %version-%source_rel
Provides:       kselftests-kmp = %version-%source_rel
Provides:       multiversion(kernel)
# tell weak-modules2 to ignore this package
Provides:       kmp_in_kernel
Requires(post): suse-module-tools >= 12.4

%description -n kselftests-kmp-%build_flavor
This package contains kernel modules which are part of the upstream kernel
selftest effort. kselftest is the name of the upstream kernel target to build
and run all selftests. You can also run each test individually from the
respective upstream tools/testing/selftests/ directory, this package is
intended to be used using individial upstream selftest scripts given only
select supported selftest drivers are enabled.

It should always be possible to always run the latest linux-next version of the
selftest scripts and tests against any older kernel selftest driver.  Certain
tests facilities may be backported onto older kernels to enable further
testing.

Selftests also provide for a vehicle or proof of concept issues to be
reproduced, verified and corrected.

Selftest drivers are intended to be supported only in testing and QA
environments, they are not intended to be run on production systems.

%post -n kselftests-kmp-%build_flavor
wm2=/usr/lib/module-init-tools/weak-modules2
nvr=kselftests-kmp-%build_flavor-%version-%release
if test -x "$wm2"; then
	rpm -ql "$nvr" | INITRD_IN_POSTTRANS=1 /bin/bash -${-/e/} "$wm2" \
	--add-kernel-modules %kernelrelease-%build_flavor
fi

%posttrans -n kselftests-kmp-%build_flavor
%{?regenerate_initrd_posttrans}

%preun -n kselftests-kmp-%build_flavor
nvr=kselftests-kmp-%build_flavor-%version-%release
rpm -ql "$nvr" | grep '\.ko$' > "/var/run/rpm-$nvr-modules"

%postun -n kselftests-kmp-%build_flavor
wm2=/usr/lib/module-init-tools/weak-modules2
nvr=kselftests-kmp-%build_flavor-%version-%release
if test -x "$wm2"; then
	/bin/bash -${-/e/} "$wm2" < "/var/run/rpm-$nvr-modules" \
	--remove-kernel-modules %kernelrelease-%build_flavor
fi
rm -f "/var/run/rpm-$nvr-modules"

%files -n kselftests-kmp-%build_flavor -f kselftests-kmp.files
%defattr(-, root, root)

%package -n ocfs2-kmp-%build_flavor
Summary:        OCFS2 kernel modules
Group:          System/Kernel
Requires:       %name = %version-%source_rel
Provides:       ocfs2-kmp = %version-%source_rel
Provides:       multiversion(kernel)
# tell weak-modules2 to ignore this package
Provides:       kmp_in_kernel
Requires(post): suse-module-tools >= 12.4
Requires:       dlm-kmp-%build_flavor = %version-%release

%description -n ocfs2-kmp-%build_flavor
OCFS2 is the Oracle Cluster Filesystem, a filesystem for shared devices
accessible simultaneously from multiple nodes of a cluster.

%post -n ocfs2-kmp-%build_flavor
wm2=/usr/lib/module-init-tools/weak-modules2
nvr=ocfs2-kmp-%build_flavor-%version-%release
if test -x "$wm2"; then
	rpm -ql "$nvr" | INITRD_IN_POSTTRANS=1 /bin/bash -${-/e/} "$wm2" \
	--add-kernel-modules %kernelrelease-%build_flavor
fi

%posttrans -n ocfs2-kmp-%build_flavor
%{?regenerate_initrd_posttrans}

%preun -n ocfs2-kmp-%build_flavor
nvr=ocfs2-kmp-%build_flavor-%version-%release
rpm -ql "$nvr" | grep '\.ko$' > "/var/run/rpm-$nvr-modules"

%postun -n ocfs2-kmp-%build_flavor
wm2=/usr/lib/module-init-tools/weak-modules2
nvr=ocfs2-kmp-%build_flavor-%version-%release
if test -x "$wm2"; then
	/bin/bash -${-/e/} "$wm2" < "/var/run/rpm-$nvr-modules" \
	--remove-kernel-modules %kernelrelease-%build_flavor
fi
rm -f "/var/run/rpm-$nvr-modules"

%files -n ocfs2-kmp-%build_flavor -f ocfs2-kmp.files
%defattr(-, root, root)

%endif # %CONFIG_SUSE_KERNEL_SUPPORTED
%endif # %CONFIG_MODULES

%changelog
* Fri May 11 2018 wqu@suse.com
- btrfs: Fix wrong first_key parameter in replace_path (follow
  up fix for bsc#1084721).
- commit 4346da1
* Fri May 11 2018 jeffm@suse.com
- btrfs: suspend qgroups during relocation recovery (bsc#1086467).
- commit f0b899a
* Fri May 11 2018 jeffm@suse.com
- Refresh
  patches.suse/btrfs-qgroups-fix-rescan-worker-running-races.patch.
  The previous version reintroduced the race that upstream commit 8d9eddad194
  was intended to fix.  This version addresses that issue as well as fixing
  a separate issue where the rescan worker might not have resumed on mount.
- commit 3847d2d
* Fri May 11 2018 jeffm@suse.com
- Delete
  patches.suse/btrfs-push-relocation-recovery-into-helper-thread.patch.
  Pushing relocation recovery into a thread allowed mounts to proceed
  but the file system would end up being unable to be unmounted for some
  time.
- commit a456afe
* Thu May 10 2018 jack@suse.cz
- ext4: Fix hole length detection in ext4_ind_map_blocks()
  (bsc#1090953).
- commit 6264cfb
* Thu May 10 2018 jkosina@suse.cz
- scripts/git_sort/git_sort.py: Remove duplicated repo entry
- commit 5449163
* Thu May 10 2018 msuchanek@suse.de
- powerpc/64s: Enhance the information in cpu_show_spectre_v1()
  (bsc#1068032).
- commit 447e243
* Wed May  9 2018 msuchanek@suse.de
- Enable uniput driver (bsc#1092566).
- commit 7e93d22
* Wed May  9 2018 nborisov@suse.com
- Refresh
  patches.suse/revert-btrfs-qgroup-move-half-of-the-qgroup-accounting-time-out-of-commit-trans.patch.
- commit 6bb3a77
* Tue May  8 2018 msuchanek@suse.de
- powerpc/lib: Fix off-by-one in alternate feature patching
  (bsc#1065729).
- commit 64ed10b
* Tue May  8 2018 msuchanek@suse.de
- ibmvnic: Clean actual number of RX or TX pools (bsc#1092289).
- commit 87e794b
* Fri May  4 2018 rgoldwyn@suse.com
- ovl: treat btrfs mounts as different superblocks (bsc#1059336).
- commit f3a38b6
* Fri May  4 2018 tbogendoerfer@suse.de
- net/mlx5: Avoid cleaning flow steering table twice during
  error flow (bsc#1091532).
- commit 62f9ca0
* Fri May  4 2018 bp@suse.de
- x86/xen: Calculate __max_logical_packages on PV domains
  (bsc#1091543).
- x86/smpboot: Do not use smp_num_siblings in
  __max_logical_packages calculation (bsc#1091543).
- xen/vcpu: Handle xen_vcpu_setup() failure at boot (bsc#1091543).
- commit bbde611
* Thu May  3 2018 msuchanek@suse.de
- powerpc/64s: Enable barrier_nospec based on firmware settings
  (bsc#1068032, bsc#1080157).
  Delete patches.arch/powerpc-64-barrier_nospec-Add-commandline-trigger.patch.
  Delete patches.arch/powerpc-64s-barrier_nospec-Add-hcall-trigger.patch.
- commit a3f6f3e
* Thu May  3 2018 msuchanek@suse.de
- Delete patches.arch/powerpc-64s-Use-barrier_nospec-in-RFI_FLUSH_SLOT.patch.
- commit f4a4c12
* Thu May  3 2018 msuchanek@suse.de
- Refresh patches.arch/powerpc-64-Use-barrier_nospec-in-syscall-entry.patch.
- commit 238866b
* Thu May  3 2018 msuchanek@suse.de
- powerpc: Use barrier_nospec in copy_from_user() (bsc#1068032,
  bsc#1080157).
- commit 080b1ec
* Thu May  3 2018 msuchanek@suse.de
- Refresh patches.arch/powerpc-Add-barrier_nospec.patch
  Refresh patches.arch/powerpc-64s-Add-support-for-ori-barrier_nospec-patch.patch
  Refresh patches.arch/powerpc-64-Patch-barrier_nospec-in-modules.patch
  Delete patches.arch/powerpc-64-barrier_nospec-Add-debugfs-trigger.patch
- commit 40ed6a0
* Wed May  2 2018 msuchanek@suse.de
- Refresh patches.drivers/ibmvfc-avoid-unnecessary-port-relogin.patch
- commit d88d95f
* Wed May  2 2018 bp@suse.de
- x86/smpboot: Fix __max_logical_packages estimate (bsc#1091543).
- commit 2eb7ead
* Wed May  2 2018 jthumshirn@suse.de
- qla2xxx: Enable T10-DIF with FC-NVMe enabled (bsc#1091264).
- commit fa61ec8
* Fri Apr 27 2018 msuchanek@suse.de
- kernel-binary: only install modules.fips on modular kernels.
- commit 6408562
* Thu Apr 26 2018 msuchanek@suse.de
- powerpc/64s/idle: Fix restore of AMOR on POWER9 after deep sleep
  (bsc#1055186, fate#323286).
- commit 6368307
* Thu Apr 26 2018 msuchanek@suse.de
- Update config files.
- commit 6174b6c
* Thu Apr 26 2018 msuchanek@suse.de
- powerpc/mm/radix: Fix checkstops caused by invalid tlbiel
  (bsc#1055186, fate#323286).
- powerpc/mm/radix: Update command line parsing for disable_radix
  (bsc#1055186, fate#323286).
- powerpc/mm/radix: Parse disable_radix commandline correctly
  (bsc#1055186, fate#323286).
- powerpc/mm/radix: Update pte fragment count from 16 to 256 on
  radix (bsc#1055186, fate#323286).
- powerpc/mm/radix: Fix always false comparison against
  MMU_NO_CONTEXT (bsc#1055186, fate#323286).
- powerpc/mm: Add a CONFIG option to choose if radix is used by
  default (bsc#1055186, fate#323286).
- commit e9d987c
* Thu Apr 26 2018 msuchanek@suse.de
- powerpc/xive: Fix wrong xmon output caused by typo
  (bsc#1088273).
- commit f3598fe
* Thu Apr 26 2018 jeffm@suse.com
- btrfs: qgroups, fix rescan worker running races (bsc#1091101).
- commit 3c4b9ba
* Wed Apr 25 2018 duwe@suse.de
- supported.conf: mark new FIPS modules as supported:
  sha2-mb, sha3, crc32 and crypto_engine (bsc#1074984)
- commit 9e8aa4a
* Wed Apr 25 2018 tiwai@suse.de
- random: fix crng_ready() test (CVE-2018-1108,bsc#1090818).
- commit 8c55b94
* Wed Apr 25 2018 jeffm@suse.com
- btrfs: use spinlock to protect ->caching_block_groups list
  (bsc#1083684).
- commit bb913e1
* Wed Apr 25 2018 tbogendoerfer@suse.de
- bnxt_en: Fix memory fault in bnxt_ethtool_init() (bsc#1050242
  FATE#322914).
- commit 65193fa
* Wed Apr 25 2018 jroedel@suse.de
- kvm/x86: fix icebp instruction handling (bsc#1087088).
- commit 364bcca
* Wed Apr 25 2018 mbrugger@suse.com
- crypto: cavium - Fix smp_processor_id() warnings (bsc#1089141).
- crypto: cavium - Fix statistics pending request value (bsc#1089141).
- crypto: cavium - Prevent division by zero (bsc#1089141).
- crypto: cavium - Limit result reading attempts (bsc#1089141).
- crypto: cavium - Fix fallout from CONFIG_VMAP_STACK (bsc#1089141).
- commit 6ff9496
* Tue Apr 24 2018 mcgrof@suse.com
- xfs: set format back to extents if xfs_bmap_extents_to_btree (bsc#1090717, CVE-2018-10323).
- commit cd127e8
* Tue Apr 24 2018 msuchanek@suse.de
- supported.conf: remove obsolete entry
  drivers/tty/serial/of_serial -> drivers/tty/serial/8250/8250_of
- commit 8e4b38c
* Mon Apr 23 2018 mcgrof@suse.com
- xfs: convert XFS_AGFL_SIZE to a helper function (bsc#1090534).
- commit 027dd64
* Mon Apr 23 2018 mcgrof@suse.com
- xfs: detect agfl count corruption and reset agfl (bsc#1090534).
- commit b1c0509
* Mon Apr 23 2018 mcgrof@suse.com
- xfs: allow CoW remap transactions to use reserve blocks (bsc#1090535).
- commit 03d1b76
* Mon Apr 23 2018 mcgrof@suse.com
- xfs: fix transaction allocation deadlock in IO path (bsc#1090535).
- commit 8697899
* Mon Apr 23 2018 nstange@suse.de
- ppc64le: reliable stacktrace: mark stacktraces with
  kretprobe_trampoline as unreliable (bsc#1090522).
- commit ed9151a
* Mon Apr 23 2018 nborisov@suse.com
- Refresh
  patches.suse/btrfs-fix-race-condition-between-delayed-refs-and-blockgroup-removal.patch.
- commit 1ba0893
* Mon Apr 23 2018 neilb@suse.com
- xprtrdma: Fix corner cases when handling device removal
  (git-fixes).
- nfsd: fix incorrect umasks (git-fixes).
- fs: Teach path_connected to handle nfs filesystems with multiple
  roots (git-fixes).
- md raid10: fix NULL deference in handle_write_completed()
  (git-fixes).
- fix kabi breaker in md.h (git-fixes).
- md: fix md_write_start() deadlock w/o metadata devices
  (git-fixes).
- nfs: system crashes after NFS4ERR_MOVED recovery (git-fixes).
- commit 69e2c71
* Fri Apr 20 2018 jeffm@suse.com
- Refresh
  patches.suse/btrfs-push-relocation-recovery-into-helper-thread.patch.
  There was a missing variable initialization due a stale patch refresh.
- commit 297fd49
* Fri Apr 20 2018 msuchanek@suse.de
- powerpc: Add ppc_breakpoint_available() (bsc#1055117).
- commit 0b632a4
* Fri Apr 20 2018 msuchanek@suse.de
- selftests/powerpc: Fix copyloops build since Power4 assembler
  change (bsc#1055117).
- commit e26f88f
* Fri Apr 20 2018 msuchanek@suse.de
- powerpc/64s: Fix CPU_FTRS_ALWAYS vs DT CPU features
  (bsc#1055117).
- powerpc/64s: Fix POWER9 DD2.2 and above in cputable features
  (bsc#1055117).
- powerpc/64s: Fix pkey support in dt_cpu_ftrs, add CPU_FTR_PKEY
  bit (bsc#1055117).
- powerpc/64s: Fix dt_cpu_ftrs to have restore_cpu clear unwanted
  LPCR bits (bsc#1055117).
- powerpc/64s: Refine feature sets for little endian builds
  (bsc#1055117).
- powerpc/64s: Remove POWER4 support (bsc#1055117).
- powerpc: Remove unused CPU_FTR_ARCH_201 (bsc#1055117).
- powerpc/64s: Fix POWER9 DD2.2 and above in DT CPU features
  (bsc#1055117).
- powerpc/64s: Set assembler machine type to POWER4 (bsc#1055117).
- powerpc/64s: Explicitly add vector features to CPU_FTRS_POSSIBLE
  (bsc#1055117).
- powerpc/64s: Add all POWER9 features to CPU_FTRS_ALWAYS
  (bsc#1055117).
- commit d8e1408
* Fri Apr 20 2018 mcgrof@suse.com
- xfs: fix intent use-after-free on abort (bsc#1085400).
- commit a15e224
* Fri Apr 20 2018 msuchanek@suse.de
- powerpc/pseries: Restore default security feature flags on setup
  (bsc#1068032).
  Refresh
  patches.arch/powerpc-64s-barrier_nospec-Add-hcall-trigger.patch.
- commit ff6c8ce
* Fri Apr 20 2018 msuchanek@suse.de
- Refresh patches.drivers/scsi-lpfc-fix-wq-cq-creation-for-older-asic-s.patch.
  fix commit hash
- commit bbbc951
* Fri Apr 20 2018 nborisov@suse.com
- btrfs: Fix race condition between delayed refs and blockgroup
  removal (bsc#1086224).
- commit ff195d7
* Fri Apr 20 2018 nborisov@suse.com
- Refresh
  patches.apparmor/apparmor-fix-resource-audit-messages-when-auditing-peer.patch.
- Refresh
  patches.drivers/ibmvnic-Do-not-reset-CRQ-for-Mobility-driver-resets.patch.
- Refresh patches.drivers/ibmvnic-Fix-DMA-mapping-mistakes.patch.
- Refresh
  patches.drivers/ibmvnic-Fix-failover-case-for-non-redundant-configur.patch.
- Refresh
  patches.drivers/ibmvnic-Fix-reset-scheduler-error-handling.patch.
- Refresh
  patches.drivers/ibmvnic-Zero-used-TX-descriptor-counter-on-reset.patch.
- commit c920800
* Fri Apr 20 2018 jthumshirn@suse.de
- Refresh
  patches.apparmor/apparmor-fix-resource-audit-messages-when-auditing-peer.patch.
- Refresh
  patches.drivers/ibmvnic-Do-not-reset-CRQ-for-Mobility-driver-resets.patch.
- Refresh patches.drivers/ibmvnic-Fix-DMA-mapping-mistakes.patch.
- Refresh
  patches.drivers/ibmvnic-Fix-failover-case-for-non-redundant-configur.patch.
- Refresh
  patches.drivers/ibmvnic-Fix-reset-scheduler-error-handling.patch.
- Refresh
  patches.drivers/ibmvnic-Zero-used-TX-descriptor-counter-on-reset.patch.
- Refresh
  patches.drivers/scsi-lpfc-fix-wq-cq-creation-for-older-asic-s.patch.
- commit 853016c
* Fri Apr 20 2018 mbenes@suse.cz
- kabi/severities: Ignore klp_shadow_* kABI changes
- commit a1324c3
* Fri Apr 20 2018 mbenes@suse.cz
- livepatch: Allow to call a custom callback when freeing shadow
  variables (bsc#1071995 fate#323487).
- commit add477a
* Fri Apr 20 2018 mbenes@suse.cz
- livepatch: Initialize shadow variables safely by a custom
  callback (bsc#1071995 fate#323487).
- commit ae78a45
* Fri Apr 20 2018 mbenes@suse.cz
- Refresh
  patches.apparmor/apparmor-fix-resource-audit-messages-when-auditing-peer.patch.
- Refresh
  patches.drivers/ibmvnic-Do-not-reset-CRQ-for-Mobility-driver-resets.patch.
- Refresh patches.drivers/ibmvnic-Fix-DMA-mapping-mistakes.patch.
- Refresh
  patches.drivers/ibmvnic-Fix-failover-case-for-non-redundant-configur.patch.
- Refresh
  patches.drivers/ibmvnic-Fix-reset-scheduler-error-handling.patch.
- Refresh
  patches.drivers/ibmvnic-Zero-used-TX-descriptor-counter-on-reset.patch.
- commit 98517c6
* Thu Apr 19 2018 jthumshirn@suse.de
- Update config files, add CONFIG_EXPOLINE_AUTO=y for s390x (bsc#1090098).
- commit 5c5cecd
* Thu Apr 19 2018 jthumshirn@suse.de
- s390: add automatic detection of the spectre defense
  (bsc#1090098).
- s390: add sysfs attributes for spectre (bsc#1090098).
- s390: correct nospec auto detection init order (bsc#1090098).
- s390/crypto: Adjust s390 aes and paes cipher priorities
  (bsc#1090098).
- s390: move nobp parameter functions to nospec-branch.c
  (bsc#1090098).
- s390: report spectre mitigation via syslog (bsc#1090098).
- Refresh patches.arch/s390-sles15-05-01-gmb.patch.
- commit 14f6493
* Thu Apr 19 2018 jthumshirn@suse.de
- Refresh
  patches.apparmor/apparmor-fix-resource-audit-messages-when-auditing-peer.patch.
- Refresh
  patches.drivers/ibmvnic-Do-not-reset-CRQ-for-Mobility-driver-resets.patch.
- Refresh patches.drivers/ibmvnic-Fix-DMA-mapping-mistakes.patch.
- Refresh
  patches.drivers/ibmvnic-Fix-failover-case-for-non-redundant-configur.patch.
- Refresh
  patches.drivers/ibmvnic-Fix-reset-scheduler-error-handling.patch.
- Refresh
  patches.drivers/ibmvnic-Zero-used-TX-descriptor-counter-on-reset.patch.
- Refresh
  patches.drivers/scsi-lpfc-fix-wq-cq-creation-for-older-asic-s.patch.
- commit 287c94f
* Wed Apr 18 2018 jeffm@suse.com
- btrfs: push relocation recovery into a helper thread
  (bsc#1086467).
- commit 37d11e6
* Wed Apr 18 2018 jthumshirn@suse.de
- nvme-rdma: Don't flush delete_wq by default during remove_one
  (bsc#1089977).
- commit c185cad
* Wed Apr 18 2018 jthumshirn@suse.de
- nvmet-rdma: Don't flush system_wq by default during remove_one
  (bsc#1089977).
- commit 902e88b
* Wed Apr 18 2018 jthumshirn@suse.de
- supported.conf: add arch/s390/crypto/crc32-vx_s390 (bsc#1089889).
- commit 3e7cb03
* Tue Apr 17 2018 bp@suse.de
- x86/mm/64: Fix vmapped stack syncing on very-large-memory
  4-level systems (bsc#1088374).
- commit 2ccb700
* Tue Apr 17 2018 nstange@suse.de
- ppc64le: reliable stacktrace: mark stacktraces with exception
  frames as unreliable (bsc#1089669).
- commit 6716d08
* Tue Apr 17 2018 bp@suse.de
- Sort series.conf
- Refresh
  patches.apparmor/apparmor-fix-resource-audit-messages-when-auditing-peer.patch.
- Refresh
  patches.drivers/ibmvnic-Do-not-reset-CRQ-for-Mobility-driver-resets.patch.
- Refresh patches.drivers/ibmvnic-Fix-DMA-mapping-mistakes.patch.
- Refresh
  patches.drivers/ibmvnic-Fix-failover-case-for-non-redundant-configur.patch.
- Refresh
  patches.drivers/ibmvnic-Fix-reset-scheduler-error-handling.patch.
- Refresh
  patches.drivers/ibmvnic-Zero-used-TX-descriptor-counter-on-reset.patch.
- commit 5e8c6bc
* Tue Apr 17 2018 nstange@suse.de
- ppc64le: reliable stacktrace: handle graph traced functions (bsc#1089664).
- commit df850c8
* Tue Apr 17 2018 wqu@suse.com
- btrfs: Only check first key for committed tree blocks
  (bsc#1084721).
- btrfs: Validate child tree block's level and first key
  (bsc#1084721).
- commit 82a46d9
* Mon Apr 16 2018 msuchanek@suse.de
- ibmvnic: Clear pending interrupt after device reset
  (bsc#1089644).
- commit 7d7ebab
* Mon Apr 16 2018 dbueso@suse.de
- sched/rt: Fix rq->clock_update_flags < RQCF_ACT_SKIP warning (bsc#1022476).
- commit 6643f8c
* Mon Apr 16 2018 dbueso@suse.de
- run series_sort.py
- commit 5f59a40
* Mon Apr 16 2018 msuchanek@suse.de
- config.sh: build against openSUSE:Leap:15.0:Update
- commit 61f2f25
* Mon Apr 16 2018 tbogendoerfer@suse.de
- virtio_net: fix return value check in receive_mergeable()
  (bsc#1089271).
- commit e169907
* Mon Apr 16 2018 tbogendoerfer@suse.de
- Re-sorted patches
- Refresh
  patches.apparmor/apparmor-fix-resource-audit-messages-when-auditing-peer.patch.
- Refresh
  patches.drivers/ibmvnic-Do-not-reset-CRQ-for-Mobility-driver-resets.patch.
- Refresh patches.drivers/ibmvnic-Fix-DMA-mapping-mistakes.patch.
- Refresh
  patches.drivers/ibmvnic-Fix-failover-case-for-non-redundant-configur.patch.
- Refresh
  patches.drivers/ibmvnic-Fix-reset-scheduler-error-handling.patch.
- Refresh
  patches.drivers/ibmvnic-Zero-used-TX-descriptor-counter-on-reset.patch.
- commit 18304f1
* Mon Apr 16 2018 hare@suse.de
- Revert "scsi: make 'state' device attribute pollable"
  (bsc#1085341).
- commit aab4000
* Mon Apr 16 2018 hare@suse.de
- Refresh
  patches.apparmor/apparmor-fix-resource-audit-messages-when-auditing-peer.patch.
- Refresh
  patches.drivers/ibmvnic-Do-not-reset-CRQ-for-Mobility-driver-resets.patch.
- Refresh patches.drivers/ibmvnic-Fix-DMA-mapping-mistakes.patch.
- Refresh
  patches.drivers/ibmvnic-Fix-failover-case-for-non-redundant-configur.patch.
- Refresh
  patches.drivers/ibmvnic-Fix-reset-scheduler-error-handling.patch.
- Refresh
  patches.drivers/ibmvnic-Zero-used-TX-descriptor-counter-on-reset.patch.
- commit 30e2159
* Fri Apr 13 2018 msuchanek@suse.de
- ibmvnic: Do not notify peers on parameter change resets
  (bsc#1089198).
- ibmvnic: Handle all login error conditions (bsc#1089198).
- ibmvnic: Define vnic_login_client_data name field as unsized
  array (bsc#1089198).
- commit 6882e8d
* Fri Apr 13 2018 yousaf.kaukab@suse.com
- kabi: arm64: update crc for cpu_hwcaps and cpu_hwcap_keys
  References: bsc#1089086
- commit e99d689
* Wed Apr 11 2018 yousaf.kaukab@suse.com
- mmc: dw_mmc: Fix the DTO/CTO timeout overflow calculation for
  32-bit systems (bsc#1088713).
- commit 0b4165d
* Wed Apr 11 2018 yousaf.kaukab@suse.com
- kabi: arm64: reserve space in cpu_hwcaps and cpu_hwcap_keys
  arrays (bsc#1089086).
- KVM: arm64: Fix HYP idmap unmap when using 52bit PA
  (bsc#1089074).
- ipmi_ssif: Fix kernel panic at msg_done_handler (bsc#1088872).
- commit 8c1d75d
* Wed Apr 11 2018 acho@suse.com
- ima: Add cgroups2 to the defaults list (bsc#1073915).
- commit aa0be85
* Wed Apr 11 2018 nborisov@suse.com
- Update config files. (fate#321934)
- commit 15c0ffc
* Wed Apr 11 2018 glin@suse.com
- bpf: skip unnecessary capability check (bsc#1083647).
- bpf, x64: increase number of passes (bsc#1083647).
- bpf: fix corruption on concurrent perf_event_output calls
  (bsc#1083647).
- bpf: avoid excessive stack usage for perf_sample_data
  (bsc#1083647).
- commit 22e80bf
* Tue Apr 10 2018 jthumshirn@suse.de
- scsi: lpfc: Fix WQ/CQ creation for older asic's (bsc#1085241).
- commit d8f53e9
* Tue Apr 10 2018 jthumshirn@suse.de
- Add mkp's queue to git_sort.py
- commit 96f199e
* Tue Apr 10 2018 jthumshirn@suse.de
- Refresh
  patches.arch/KVM-PPC-Book3S-HV-Work-around-TEXASR-bug-in-fake-sus.patch.
- Refresh
  patches.arch/KVM-PPC-Book3S-HV-Work-around-XER-SO-bug-in-fake-sus.patch.
- Refresh
  patches.arch/KVM-PPC-Book3S-HV-Work-around-transactional-memory-b.patch.
- Refresh
  patches.arch/PCI-hotplug-ppc-correct-a-php_slot-usage-after-free.patch.
- Refresh
  patches.arch/cxl-Check-if-PSL-data-cache-is-available-before-issu.patch.
- Refresh
  patches.arch/cxl-Enable-NORST-bit-in-PSL_DEBUG-register-for-PSL9.patch.
- Refresh
  patches.arch/cxl-Fix-possible-deadlock-when-processing-page-fault.patch.
- Refresh
  patches.arch/cxl-Fix-timebase-synchronization-status-on-P9.patch.
- Refresh
  patches.arch/cxl-Remove-function-write_timebase_ctrl_psl9-for-PSL.patch.
- Refresh
  patches.arch/cxl-read-PHB-indications-from-the-device-tree.patch.
- Refresh
  patches.arch/powerpc-64-Call-H_REGISTER_PROC_TBL-when-running-as-.patch.
- Refresh
  patches.arch/powerpc-64s-Enhance-the-information-in-cpu_show_melt.patch.
- Refresh patches.arch/powerpc-64s-Move-cpu_show_meltdown.patch.
- Refresh
  patches.arch/powerpc-64s-Wire-up-cpu_show_spectre_v1.patch.
- Refresh
  patches.arch/powerpc-64s-Wire-up-cpu_show_spectre_v2.patch.
- Refresh
  patches.arch/powerpc-Add-CPU-feature-bits-for-TM-bug-workarounds-.patch.
- Refresh
  patches.arch/powerpc-Add-security-feature-flags-for-Spectre-Meltd.patch.
- Refresh
  patches.arch/powerpc-Book-E-Remove-unused-CPU_FTR_L2CSR-bit.patch.
- Refresh
  patches.arch/powerpc-Free-up-CPU-feature-bits-on-64-bit-machines.patch.
- Refresh
  patches.arch/powerpc-Move-default-security-feature-flags.patch.
- Refresh
  patches.arch/powerpc-Remove-unused-flush_dcache_phys_range.patch.
- Refresh
  patches.arch/powerpc-Rename-plapr-routines-to-plpar.patch.
- Refresh
  patches.arch/powerpc-Use-feature-bit-for-RTC-presence-rather-than.patch.
- Refresh
  patches.arch/powerpc-kexec_file-Fix-error-code-when-trying-to-loa.patch.
- Refresh
  patches.arch/powerpc-lpar-debug-Initialize-flags-before-printing-.patch.
- Refresh
  patches.arch/powerpc-mm-Drop-the-function-native_register_proc_ta.patch.
- Refresh
  patches.arch/powerpc-mm-slice-Remove-intermediate-bitmap-copy.patch.
- Refresh
  patches.arch/powerpc-powernv-Fix-SMT4-forcing-idle-code.patch.
- Refresh
  patches.arch/powerpc-powernv-Provide-a-way-to-force-a-core-into-S.patch.
- Refresh
  patches.arch/powerpc-powernv-Set-or-clear-security-feature-flags.patch.
- Refresh
  patches.arch/powerpc-powernv-Use-the-security-flags-in-pnv_setup_.patch.
- Refresh
  patches.arch/powerpc-pseries-Add-new-H_GET_CPU_CHARACTERISTICS-fl.patch.
- Refresh
  patches.arch/powerpc-pseries-Fix-clearing-of-security-feature-fla.patch.
- Refresh
  patches.arch/powerpc-pseries-Set-or-clear-security-feature-flags.patch.
- Refresh
  patches.arch/powerpc-pseries-Use-the-security-flags-in-pseries_se.patch.
- Refresh
  patches.arch/powerpc-rfi-flush-Always-enable-fallback-flush-on-ps.patch.
- Refresh
  patches.arch/powerpc-rfi-flush-Call-setup_rfi_flush-after-LPM-mig.patch.
- Refresh
  patches.arch/powerpc-rfi-flush-Differentiate-enabled-and-patched-.patch.
- Refresh
  patches.arch/powerpc-rfi-flush-Make-it-possible-to-call-setup_rfi.patch.
- Refresh
  patches.arch/powerpc-rfi-flush-Move-the-logic-to-avoid-a-redo-int.patch.
- Refresh
  patches.arch/powerpc-xmon-Clear-all-breakpoints-when-xmon-is-disa.patch.
- Refresh
  patches.arch/powerpc-xmon-Setup-debugger-hooks-when-first-break-p.patch.
- Refresh
  patches.suse/suse-hv-PCI-hv-Fix-2-hang-issues-in-hv_compose_msi_msg.patch.
- Refresh
  patches.suse/suse-hv-PCI-hv-Fix-a-comment-typo-in-_hv_pcifront_read_confi.patch.
- Refresh
  patches.suse/suse-hv-PCI-hv-Only-queue-new-work-items-in-hv_pci_devices_p.patch.
- Refresh
  patches.suse/suse-hv-PCI-hv-Remove-the-bogus-test-in-hv_eject_device_work.patch.
- Refresh
  patches.suse/suse-hv-PCI-hv-Serialize-the-present-and-eject-work-items.patch.
- commit d96e797
* Tue Apr 10 2018 msuchanek@suse.de
- powerpc: Don't write to DABR on >= Power8 if DAWR is disabled
  (bsc#1055117).
- commit e5c3f87
* Mon Apr  9 2018 msuchanek@suse.de
- powerpc/hw_breakpoint: Only disable hw breakpoint if cpu
  supports it (bsc#1055117).
- commit e44aa5c
* Mon Apr  9 2018 msuchanek@suse.de
- powerpc: Disable DAWR in the base POWER9 CPU features
  (bsc#1055117).
- powerpc: Disable DAWR on POWER9 via CPU feature quirk
  (bsc#1055117).
- powerpc: Update xmon to use ppc_breakpoint_available()
  (bsc#1072829).
- powerpc: Update ptrace to use ppc_breakpoint_available()
  (bsc#1056686).
- commit 46f5e9e
* Mon Apr  9 2018 oneukum@suse.com
- usb: dwc3: Fix lock-up on ID change during system suspend/resume
  (bsc#1087092).
- commit d535713
* Mon Apr  9 2018 oneukum@suse.com
- Refresh
  patches.arch/KVM-PPC-Book3S-HV-Work-around-TEXASR-bug-in-fake-sus.patch.
- Refresh
  patches.arch/KVM-PPC-Book3S-HV-Work-around-XER-SO-bug-in-fake-sus.patch.
- Refresh
  patches.arch/KVM-PPC-Book3S-HV-Work-around-transactional-memory-b.patch.
- Refresh
  patches.arch/PCI-hotplug-ppc-correct-a-php_slot-usage-after-free.patch.
- Refresh
  patches.arch/cxl-Check-if-PSL-data-cache-is-available-before-issu.patch.
- Refresh
  patches.arch/cxl-Enable-NORST-bit-in-PSL_DEBUG-register-for-PSL9.patch.
- Refresh
  patches.arch/cxl-Fix-possible-deadlock-when-processing-page-fault.patch.
- Refresh
  patches.arch/cxl-Fix-timebase-synchronization-status-on-P9.patch.
- Refresh
  patches.arch/cxl-Remove-function-write_timebase_ctrl_psl9-for-PSL.patch.
- Refresh
  patches.arch/cxl-read-PHB-indications-from-the-device-tree.patch.
- Refresh
  patches.arch/powerpc-64-Call-H_REGISTER_PROC_TBL-when-running-as-.patch.
- Refresh
  patches.arch/powerpc-64s-Enhance-the-information-in-cpu_show_melt.patch.
- Refresh patches.arch/powerpc-64s-Move-cpu_show_meltdown.patch.
- Refresh
  patches.arch/powerpc-64s-Wire-up-cpu_show_spectre_v1.patch.
- Refresh
  patches.arch/powerpc-64s-Wire-up-cpu_show_spectre_v2.patch.
- Refresh
  patches.arch/powerpc-Add-CPU-feature-bits-for-TM-bug-workarounds-.patch.
- Refresh
  patches.arch/powerpc-Add-security-feature-flags-for-Spectre-Meltd.patch.
- Refresh
  patches.arch/powerpc-Book-E-Remove-unused-CPU_FTR_L2CSR-bit.patch.
- Refresh
  patches.arch/powerpc-Free-up-CPU-feature-bits-on-64-bit-machines.patch.
- Refresh
  patches.arch/powerpc-Move-default-security-feature-flags.patch.
- Refresh
  patches.arch/powerpc-Remove-unused-flush_dcache_phys_range.patch.
- Refresh
  patches.arch/powerpc-Rename-plapr-routines-to-plpar.patch.
- Refresh
  patches.arch/powerpc-Use-feature-bit-for-RTC-presence-rather-than.patch.
- Refresh
  patches.arch/powerpc-kexec_file-Fix-error-code-when-trying-to-loa.patch.
- Refresh
  patches.arch/powerpc-lpar-debug-Initialize-flags-before-printing-.patch.
- Refresh
  patches.arch/powerpc-mm-Drop-the-function-native_register_proc_ta.patch.
- Refresh
  patches.arch/powerpc-mm-slice-Remove-intermediate-bitmap-copy.patch.
- Refresh
  patches.arch/powerpc-powernv-Fix-SMT4-forcing-idle-code.patch.
- Refresh
  patches.arch/powerpc-powernv-Provide-a-way-to-force-a-core-into-S.patch.
- Refresh
  patches.arch/powerpc-powernv-Set-or-clear-security-feature-flags.patch.
- Refresh
  patches.arch/powerpc-powernv-Use-the-security-flags-in-pnv_setup_.patch.
- Refresh
  patches.arch/powerpc-pseries-Add-new-H_GET_CPU_CHARACTERISTICS-fl.patch.
- Refresh
  patches.arch/powerpc-pseries-Fix-clearing-of-security-feature-fla.patch.
- Refresh
  patches.arch/powerpc-pseries-Set-or-clear-security-feature-flags.patch.
- Refresh
  patches.arch/powerpc-pseries-Use-the-security-flags-in-pseries_se.patch.
- Refresh
  patches.arch/powerpc-rfi-flush-Always-enable-fallback-flush-on-ps.patch.
- Refresh
  patches.arch/powerpc-rfi-flush-Call-setup_rfi_flush-after-LPM-mig.patch.
- Refresh
  patches.arch/powerpc-rfi-flush-Differentiate-enabled-and-patched-.patch.
- Refresh
  patches.arch/powerpc-rfi-flush-Make-it-possible-to-call-setup_rfi.patch.
- Refresh
  patches.arch/powerpc-rfi-flush-Move-the-logic-to-avoid-a-redo-int.patch.
- Refresh
  patches.arch/powerpc-xmon-Clear-all-breakpoints-when-xmon-is-disa.patch.
- Refresh
  patches.arch/powerpc-xmon-Setup-debugger-hooks-when-first-break-p.patch.
- Refresh
  patches.suse/suse-hv-PCI-hv-Fix-2-hang-issues-in-hv_compose_msi_msg.patch.
- Refresh
  patches.suse/suse-hv-PCI-hv-Fix-a-comment-typo-in-_hv_pcifront_read_confi.patch.
- Refresh
  patches.suse/suse-hv-PCI-hv-Only-queue-new-work-items-in-hv_pci_devices_p.patch.
- Refresh
  patches.suse/suse-hv-PCI-hv-Remove-the-bogus-test-in-hv_eject_device_work.patch.
- Refresh
  patches.suse/suse-hv-PCI-hv-Serialize-the-present-and-eject-work-items.patch.
  Linus has pulled. Take over the ordering.
- commit 1ad4e83
* Mon Apr  9 2018 oneukum@suse.com
- blacklist.conf: not a bug fix, optimization
- commit 5e5824b
* Mon Apr  9 2018 oneukum@suse.com
- blacklist.conf: cosmetic issue
- commit 4b47d7a
* Mon Apr  9 2018 jthumshirn@suse.de
- Update config files, enable CONFIG_SMARTPQI on arm64 (bsc#1088634).
- commit fb9aa6d
* Mon Apr  9 2018 msuchanek@suse.de
- ibmvnic: Do not reset CRQ for Mobility driver resets
  (bsc#1088600).
- ibmvnic: Fix failover case for non-redundant configuration
  (bsc#1088600).
- ibmvnic: Fix reset scheduler error handling (bsc#1088600).
- ibmvnic: Zero used TX descriptor counter on reset (bsc#1088600).
- ibmvnic: Fix DMA mapping mistakes (bsc#1088600).
- commit ec5530d
* Mon Apr  9 2018 msuchanek@suse.de
- ibmvnic: Disable irqs before exiting reset from closed state
  (bsc#1084610).
- commit 3658918
* Mon Apr  9 2018 msuchanek@suse.de
- Update kabi files from RC3 submission.
- commit 43a8c6f
* Mon Apr  9 2018 ohering@suse.de
- add mainline tag to various patches to be able to get further work done
- commit 500958e
* Sat Apr  7 2018 dbueso@suse.de
- futex: Fix OWNER_DEAD fixup (bsc#1067665).
- futex: Avoid violating the 10th rule of futex (bsc#1067665).
- commit 820eb95
* Sat Apr  7 2018 dbueso@suse.de
- run series_sort.py
- commit 9b0b8df
* Fri Apr  6 2018 msuchanek@suse.de
- Update arm kabi files to reflect changes in iProc driver.
- commit 5c17dc1
* Fri Apr  6 2018 msuchanek@suse.de
- Update ppc kabi files to reflect kabi fixes.
- commit d584de6
* Fri Apr  6 2018 msuchanek@suse.de
- Remove patces for bug 1087405 due to regression
- Refresh patches.arch/powerpc-numa-Invalidate-numa_cpu_lookup_table-on-cpu.patch.
- Delete patches.arch/cpu-hotplug-Convert-hotplug-locking-to-percpu-rwsem.patch.
- Delete patches.arch/cpu-hotplug-Provide-cpus_read-write_-un-lock.patch.
- Delete patches.arch/cpu-hotplug-Provide-lockdep_assert_cpus_held.patch.
- Delete patches.arch/powerpc-Don-t-call-lockdep_assert_cpus_held-from-arc.patch.
- Delete patches.arch/powerpc-Only-obtain-cpu_hotplug_lock-if-called-by-rt.patch.
- Delete patches.arch/stop_machine-Provide-stop_machine_cpuslocked.patch.
- Delete patches.arch/workqueue-Work-around-edge-cases-for-calc-of-pool-s-.patch.
- Delete patches.suse/KABI-cpu-hotplug-provide-the-old-get-put_online_cpus.patch.
- commit f91a2ea
* Fri Apr  6 2018 msuchanek@suse.de
- Update ppc kabi files.
  A change in mm_context_t
- commit 4e5f64a
* Fri Apr  6 2018 mhocko@suse.com
- mm, sparse: do not swamp log with huge vmemmap allocation (bnc#1082184, bnc#1087928).
- commit 080516f
* Fri Apr  6 2018 msuchanek@suse.de
- powerpc/mm: Fixup tlbie vs store ordering issue on POWER9
  (bsc#1087908).
- powerpc/mm/radix: Move the functions that does the actual tlbie closer (bsc#1087908).
- Refresh patches.arch/powerpc-Add-CPU-feature-bits-for-TM-bug-workarounds-.patch.
- Refresh patches.arch/powerpc-Free-up-CPU-feature-bits-on-64-bit-machines.patch.
- commit 9f17cf2
* Fri Apr  6 2018 msuchanek@suse.de
- powerpc/mm: Workaround Nest MMU bug with TLB invalidations
  (bsc#1087908).
- commit 2dc45cc
* Fri Apr  6 2018 msuchanek@suse.de
- powerpc/64s/radix: Optimize TLB range flush barriers
  (bsc#1087908).
- commit ab0534b
* Fri Apr  6 2018 duwe@suse.de
- powerpc/kprobes: Fix warnings from __this_cpu_read() on preempt
  kernels (bsc#1088321).
- powerpc/kprobes: Clean up jprobe detection in livepatch handler
  (bsc#1088321).
- commit de980ac
* Fri Apr  6 2018 duwe@suse.de
- powerpc/modules: Don't try to restore r2 after a sibling call
  (bsc#1088321).
- powerpc/modules: Add REL24 relocation support of livepatch
  symbols (bsc#1088321).
- commit 2e9366a
* Fri Apr  6 2018 tiwai@suse.de
- Fix kABI for musb flush_irq_work field addition (bsc#1085536).
- commit bd7d8c7
* Fri Apr  6 2018 jkosina@suse.cz
- kABI: protect struct mlx5_core_srq (bsc#1046305 FATE#322943).
- Delete
  patches.suse/kabi-IB-mlx5-Fix-integer-overflows-in-mlx5_ib_create_srq.patch.
  Move kABI workaround to patches.kabi/
- commit 8b4c573
* Fri Apr  6 2018 tbogendoerfer@suse.de
- kABI: protect struct mlx5_core_srq (bsc#1046305 FATE#322943).
- commit 722e1e3
* Fri Apr  6 2018 mbenes@suse.cz
- kabi/severities: Ignore livepatching kABI changes
  Namely klp_*_patch symbols (enable, disable, (un)register).
- commit 1162b94
* Fri Apr  6 2018 msuchanek@suse.de
- powerpc/lib/xor_vmx: Ensure no altivec code executes before
  enable_kernel_altivec() (bsc#1065729).
- commit a384ead
* Fri Apr  6 2018 msuchanek@suse.de
- powerpc: Fix check for copy/paste instructions in alignment
  handler (bsc#1055117).
- commit d9df9cc
* Fri Apr  6 2018 mbenes@suse.cz
- livepatch: Add an extra flag to distinguish registered patches
  (bsc#1071995 fate#323487).
- livepatch: Remove Nop structures when unused (bsc#1071995
  fate#323487).
- livepatch: Remove replaced patches from the stack (bsc#1071995
  fate#323487).
- Refresh patches.suse/livepatch-add-atomic-replace.patch.
- Refresh
  patches.suse/livepatch-allow-to-replace-even-disabled-patches.patch.
- Refresh
  patches.suse/livepatch-atomic-replace-and-cumulative-patches-documentation.patch.
- Refresh
  patches.suse/livepatch-free-only-structures-with-initialized-kobject.patch.
- Refresh
  patches.suse/livepatch-use-lists-to-manage-patches-objects-and-functions.patch.
- Delete
  patches.suse/livepatch-allow-to-unpatch-only-functions-of-the-given-type.patch.
- Delete
  patches.suse/livepatch-correctly-handle-atomic-replace-for-not-yet-loaded-modules.patch.
- Delete
  patches.suse/livepatch-improve-dynamic-struct-klp_object-detection-and-manipulation.patch.
- Delete
  patches.suse/livepatch-initial-support-for-dynamic-structures.patch.
- Delete
  patches.suse/livepatch-support-separate-list-for-replaced-patches.patch.
  Atomic replace, update to v11.
- commit 25ee7a3
* Fri Apr  6 2018 jkosina@suse.cz
- Delete kabi/arm64/symtypes-default.
- Delete kabi/arm64/symvers-default.
- Delete kabi/ppc64le/symtypes-default.
- Delete kabi/ppc64le/symvers-default.
- Delete kabi/s390x/symtypes-default.
- Delete kabi/s390x/symvers-default.
- Delete kabi/x86_64/symtypes-default.
- Delete kabi/x86_64/symvers-default.
  Disable imported kABI for now for openSUSE-15.0 branch.
- commit 460eb3a
* Fri Apr  6 2018 mbenes@suse.cz
- Refresh
  patches.drivers/crypto-ccp-add-check-to-get-psp-master-only-when-psp-is-detected.patch.
- Refresh
  patches.drivers/scsi-csiostor-add-support-for-32-bit-port-capabiliti.patch.
- Refresh
  patches.drivers/scsi-lpfc-Add-64G-link-speed-support.patch.
- Refresh
  patches.drivers/scsi-lpfc-Add-PCI-Ids-for-if_type-6-hardware.patch.
- Refresh
  patches.drivers/scsi-lpfc-Add-SLI-4-if_type-6-support-to-the-code-ba.patch.
- Refresh
  patches.drivers/scsi-lpfc-Add-WQ-Full-Logic-for-NVME-Target.patch.
- Refresh
  patches.drivers/scsi-lpfc-Add-embedded-data-pointers-for-enhanced-pe.patch.
- Refresh
  patches.drivers/scsi-lpfc-Add-if_type-6-support-for-cycling-valid-bi.patch.
- Refresh
  patches.drivers/scsi-lpfc-Add-push-to-adapter-support-to-sli4.patch.
- Refresh
  patches.drivers/scsi-lpfc-Allow-set-of-maximum-outstanding-SCSI-cmd-.patch.
- Refresh
  patches.drivers/scsi-lpfc-Change-Copyright-of-12.0.0.0-modified-file.patch.
- Refresh
  patches.drivers/scsi-lpfc-Enable-fw-download-on-if_type-6-devices.patch.
- Refresh
  patches.drivers/scsi-lpfc-Fix-IO-failure-during-hba-reset-testing-wi.patch.
- Refresh
  patches.drivers/scsi-lpfc-Fix-PRLI-handling-when-topology-type-chang.patch.
- Refresh
  patches.drivers/scsi-lpfc-Fix-RQ-empty-firmware-trap.patch.
- Refresh
  patches.drivers/scsi-lpfc-Fix-SCSI-io-host-reset-causing-kernel-cras.patch.
- Refresh
  patches.drivers/scsi-lpfc-Fix-frequency-of-Release-WQE-CQEs.patch.
- Refresh
  patches.drivers/scsi-lpfc-Fix-header-inclusion-in-lpfc_nvmet.patch.
- Refresh
  patches.drivers/scsi-lpfc-Fix-issue_lip-if-link-is-disabled.patch.
- Refresh
  patches.drivers/scsi-lpfc-Fix-nonrecovery-of-NVME-controller-after-c.patch.
- Refresh
  patches.drivers/scsi-lpfc-Fix-nvme-embedded-io-length-on-new-hardwar.patch.
- Refresh
  patches.drivers/scsi-lpfc-Fix-soft-lockup-in-lpfc-worker-thread-duri.patch.
- Refresh
  patches.drivers/scsi-lpfc-Increase-CQ-and-WQ-sizes-for-SCSI.patch.
- Refresh
  patches.drivers/scsi-lpfc-Indicate-CONF-support-in-NVMe-PRLI.patch.
- Refresh
  patches.drivers/scsi-lpfc-Rework-lpfc-to-allow-different-sli4-cq-and.patch.
- Refresh
  patches.drivers/scsi-lpfc-Rework-sli4-doorbell-infrastructure.patch.
- Refresh
  patches.drivers/scsi-lpfc-Treat-SCSI-Write-operation-Underruns-as-an.patch.
- Refresh
  patches.drivers/scsi-lpfc-Update-11.4.0.7-modified-files-for-2018-Co.patch.
- Refresh
  patches.drivers/scsi-lpfc-Validate-adapter-support-for-SRIU-option.patch.
- Refresh
  patches.drivers/scsi-lpfc-Work-around-NVME-cmd-iu-SGL-type.patch.
- Refresh
  patches.drivers/scsi-lpfc-change-copyright-of-12.0.0.1-modified-files-to.patch.
- Refresh
  patches.drivers/scsi-lpfc-code-cleanup-for-128byte-wqe-data-type.patch.
- Refresh
  patches.drivers/scsi-lpfc-correct-debug-counters-for-abort.patch.
- Refresh
  patches.drivers/scsi-lpfc-fix-mailbox-wait-for-post_sgl-mbox-command.patch.
- Refresh
  patches.drivers/scsi-lpfc-fix-scsi-lun-discovery-when-port-configured-for.patch.
- Refresh
  patches.drivers/scsi-lpfc-make-several-unions-static-fix-non-ansi.patch.
- Refresh
  patches.drivers/scsi-lpfc-memory-allocation-error-during-driver-start-up-on.patch.
- Refresh
  patches.drivers/scsi-lpfc-move-placement-of-target-destroy-on-driver.patch.
- Refresh
  patches.drivers/scsi-lpfc-streamline-nvme-initiator-wqe-setup.patch.
- Refresh
  patches.drivers/scsi-lpfc-streamline-nvme-targe6t-wqe-setup.patch.
- Refresh
  patches.drivers/scsi-lpfc-update-driver-version-to-11.4.0.7.patch.
- Refresh
  patches.drivers/scsi-lpfc-update-driver-version-to-12.0.0.0.patch.
- Refresh
  patches.drivers/scsi-lpfc-update-driver-version-to-12.0.0.1.patch.
  Move patches to the sorted section.
- commit fbb5005
* Fri Apr  6 2018 tiwai@suse.de
- intel_th: Use correct method of finding hub (FATE#325099).
- commit 0af4c94
* Fri Apr  6 2018 tiwai@suse.de
- Preliminary patch sort & update
- commit 1073359
* Fri Apr  6 2018 jthumshirn@suse.de
- scsi: lpfc: Add missing unlock in WQ full logic (bsc#1077989).
- scsi: lpfc: use __raw_writeX on DPP copies (bsc#1077989).
- commit 62cee1d
* Fri Apr  6 2018 jthumshirn@suse.de
- s390/qeth: on channel error, reject further cmd requests
  (bnc#1088343, LTC#165985).
- commit 5b6cf5f
* Fri Apr  6 2018 jthumshirn@suse.de
- Refresh
  patches.drivers/scsi-csiostor-add-support-for-32-bit-port-capabiliti.patch.
- Refresh
  patches.drivers/scsi-lpfc-Add-64G-link-speed-support.patch.
- Refresh
  patches.drivers/scsi-lpfc-Add-PCI-Ids-for-if_type-6-hardware.patch.
- Refresh
  patches.drivers/scsi-lpfc-Add-SLI-4-if_type-6-support-to-the-code-ba.patch.
- Refresh
  patches.drivers/scsi-lpfc-Add-WQ-Full-Logic-for-NVME-Target.patch.
- Refresh
  patches.drivers/scsi-lpfc-Add-embedded-data-pointers-for-enhanced-pe.patch.
- Refresh
  patches.drivers/scsi-lpfc-Add-if_type-6-support-for-cycling-valid-bi.patch.
- Refresh
  patches.drivers/scsi-lpfc-Add-push-to-adapter-support-to-sli4.patch.
- Refresh
  patches.drivers/scsi-lpfc-Allow-set-of-maximum-outstanding-SCSI-cmd-.patch.
- Refresh
  patches.drivers/scsi-lpfc-Change-Copyright-of-12.0.0.0-modified-file.patch.
- Refresh
  patches.drivers/scsi-lpfc-Enable-fw-download-on-if_type-6-devices.patch.
- Refresh
  patches.drivers/scsi-lpfc-Fix-IO-failure-during-hba-reset-testing-wi.patch.
- Refresh
  patches.drivers/scsi-lpfc-Fix-PRLI-handling-when-topology-type-chang.patch.
- Refresh
  patches.drivers/scsi-lpfc-Fix-RQ-empty-firmware-trap.patch.
- Refresh
  patches.drivers/scsi-lpfc-Fix-SCSI-io-host-reset-causing-kernel-cras.patch.
- Refresh
  patches.drivers/scsi-lpfc-Fix-frequency-of-Release-WQE-CQEs.patch.
- Refresh
  patches.drivers/scsi-lpfc-Fix-header-inclusion-in-lpfc_nvmet.patch.
- Refresh
  patches.drivers/scsi-lpfc-Fix-issue_lip-if-link-is-disabled.patch.
- Refresh
  patches.drivers/scsi-lpfc-Fix-nonrecovery-of-NVME-controller-after-c.patch.
- Refresh
  patches.drivers/scsi-lpfc-Fix-nvme-embedded-io-length-on-new-hardwar.patch.
- Refresh
  patches.drivers/scsi-lpfc-Fix-soft-lockup-in-lpfc-worker-thread-duri.patch.
- Refresh
  patches.drivers/scsi-lpfc-Increase-CQ-and-WQ-sizes-for-SCSI.patch.
- Refresh
  patches.drivers/scsi-lpfc-Indicate-CONF-support-in-NVMe-PRLI.patch.
- Refresh
  patches.drivers/scsi-lpfc-Rework-lpfc-to-allow-different-sli4-cq-and.patch.
- Refresh
  patches.drivers/scsi-lpfc-Rework-sli4-doorbell-infrastructure.patch.
- Refresh
  patches.drivers/scsi-lpfc-Treat-SCSI-Write-operation-Underruns-as-an.patch.
- Refresh
  patches.drivers/scsi-lpfc-Update-11.4.0.7-modified-files-for-2018-Co.patch.
- Refresh
  patches.drivers/scsi-lpfc-Validate-adapter-support-for-SRIU-option.patch.
- Refresh
  patches.drivers/scsi-lpfc-Work-around-NVME-cmd-iu-SGL-type.patch.
- Refresh
  patches.drivers/scsi-lpfc-change-copyright-of-12.0.0.1-modified-files-to.patch.
- Refresh
  patches.drivers/scsi-lpfc-code-cleanup-for-128byte-wqe-data-type.patch.
- Refresh
  patches.drivers/scsi-lpfc-correct-debug-counters-for-abort.patch.
- Refresh
  patches.drivers/scsi-lpfc-fix-mailbox-wait-for-post_sgl-mbox-command.patch.
- Refresh
  patches.drivers/scsi-lpfc-fix-scsi-lun-discovery-when-port-configured-for.patch.
- Refresh
  patches.drivers/scsi-lpfc-make-several-unions-static-fix-non-ansi.patch.
- Refresh
  patches.drivers/scsi-lpfc-memory-allocation-error-during-driver-start-up-on.patch.
- Refresh
  patches.drivers/scsi-lpfc-move-placement-of-target-destroy-on-driver.patch.
- Refresh
  patches.drivers/scsi-lpfc-streamline-nvme-initiator-wqe-setup.patch.
- Refresh
  patches.drivers/scsi-lpfc-streamline-nvme-targe6t-wqe-setup.patch.
- Refresh
  patches.drivers/scsi-lpfc-update-driver-version-to-11.4.0.7.patch.
- Refresh
  patches.drivers/scsi-lpfc-update-driver-version-to-12.0.0.0.patch.
- Refresh
  patches.drivers/scsi-lpfc-update-driver-version-to-12.0.0.1.patch.
- commit 78112c4
* Fri Apr  6 2018 ohering@suse.de
- hv_balloon: fix bugs in num_pages_onlined accounting
  (fate#323887).
- hv_balloon: simplify hv_online_page()/hv_page_online_one()
  (fate#323887).
- hv_balloon: fix printk loglevel (fate#323887).
- commit 0be921f
* Fri Apr  6 2018 ohering@suse.de
- PCI: hv: Only queue new work items in hv_pci_devices_present()
  if necessary (fate#323887, bsc#1087659).
- PCI: hv: Remove the bogus test in hv_eject_device_work()
  (fate#323887, bsc#1087659).
- PCI: hv: Fix a comment typo in _hv_pcifront_read_config()
  (fate#323887, bsc#1087659).
- PCI: hv: Fix 2 hang issues in hv_compose_msi_msg() (fate#323887,
  bsc#1087659, bsc#1087906).
- PCI: hv: Serialize the present and eject work items
  (fate#323887, bsc#1087659).
- commit ae18380
* Fri Apr  6 2018 ohering@suse.de
- add mainline tag to various patches to be able to get further work done
- commit 6ad1ff6
* Fri Apr  6 2018 lduncan@suse.com
- iscsi-target: Fix non-immediate TMR reference leak
  (bsc#1088381).
- iscsi-target: Make TASK_REASSIGN use proper se_cmd->cmd_kref
  (bsc#1088381).
- iscsi-target: fix memory leak in lio_target_tiqn_addtpg()
  (bsc#1088381).
- commit 34e6573
* Thu Apr  5 2018 lduncan@suse.com
- Ran series_sort.py prior to adding my patches.
- commit da61622
* Thu Apr  5 2018 msuchanek@suse.de
- kabi/severities: ignore PPC KVM
- commit 7d22756
* Thu Apr  5 2018 msuchanek@suse.de
- powerpc/traps: Use SRR1 defines for program check reasons
  (bsc#1061840).
- commit ea11890
* Thu Apr  5 2018 msuchanek@suse.de
- powerpc: Add PPC_FEATURE2_HTM_NO_SUSPEND (bsc#1055117).
- commit 7ef8218
* Thu Apr  5 2018 msuchanek@suse.de
- powerpc/xive: prepare all hcalls to support long busy delays
  (bsc#1088273).
- powerpc/xive: shutdown XIVE when kexec or kdump is performed
  (bsc#1088273).
- powerpc/xive: fix hcall H_INT_RESET to support long busy delays
  (bsc#1088273).
- powerpc/64/kexec: fix race in kexec when XIVE is shutdowned
  (bsc#1088273).
- commit 61f67a6
* Thu Apr  5 2018 msuchanek@suse.de
- KVM: PPC: Book3S HV: Work around TEXASR bug in fake suspend
  state (bsc#1061840).
- KVM: PPC: Book3S HV: Work around XER[SO] bug in fake suspend
  mode (bsc#1061840).
- KVM: PPC: Book3S HV: Work around transactional memory bugs in
  POWER9 (bsc#1061840).
- powerpc/powernv: Provide a way to force a core into SMT4 mode
  (bsc#1061840).
- powerpc: Add CPU feature bits for TM bug workarounds on POWER9
  v2.2 (bsc#1061840).
- powerpc: Free up CPU feature bits on 64-bit machines
  (bsc#1061840).
- powerpc: Book E: Remove unused CPU_FTR_L2CSR bit (bsc#1061840).
- powerpc: Use feature bit for RTC presence rather than timebase
  presence (bsc#1061840).
- powerpc/pseries: Fix clearing of security feature flags
  (bsc#1068032).
- commit acbd042
* Thu Apr  5 2018 msuchanek@suse.de
- powerpc/powernv: Enable TM without suspend if possible
  (bsc#1055117).
- Refresh patches.arch/powerpc-powernv-Check-device-tree-for-RFI-flush-sett.patch.
- Refresh patches.arch/powerpc-powernv-Set-or-clear-security-feature-flags.patch.
- commit 53035ed
* Thu Apr  5 2018 msuchanek@suse.de
- powerpc/tm: Add commandline option to disable hardware
  transactional memory (bsc#1055117).
- commit d4945ad
* Thu Apr  5 2018 msuchanek@suse.de
- powerpc/64s: msgclr when handling doorbell exceptions from
  system reset (bsc#1065729).
- commit 920b4d2
* Thu Apr  5 2018 msuchanek@suse.de
- powerpc/64s: Avoid cpabort in context switch when possible
  (bsc#1055117).
- Refresh patches.arch/powerpc-64s-Replace-CONFIG_PPC_STD_MMU_64-with-CONFI.patch.
- Refresh patches.arch/powerpc-store-and-restore-the-pkey-state-across-cont.patch.
- commit 4153120
* Thu Apr  5 2018 brogers@suse.com
- fw_cfg: write vmcoreinfo details (bsc#1077919).
- crash: export paddr_vmcoreinfo_note() (bsc#1077919).
- fw_cfg: add DMA register (bsc#1077919).
- fw_cfg: add a public uapi header (bsc#1077919).
- fw_cfg: handle fw_cfg_read_blob() error (bsc#1077919).
- fw_cfg: remove inline from fw_cfg_read_blob() (bsc#1077919).
- fw_cfg: fix sparse warnings around FW_CFG_FILE_DIR read
  (bsc#1077919).
- fw_cfg: fix sparse warning reading FW_CFG_ID (bsc#1077919).
- fw_cfg: fix sparse warnings with fw_cfg_file (bsc#1077919).
- fw_cfg: fix sparse warnings in fw_cfg_sel_endianness()
  (bsc#1077919).
- commit d4b3f19
* Thu Apr  5 2018 msuchanek@suse.de
- powerpc/64: Drop explicit hwsync in context switch
  (bsc#1065729).
- Refresh patches.arch/powerpc-64s-Add-support-for-ori-barrier_nospec-patch.patch.
- Refresh patches.arch/powerpc-Add-barrier_nospec.patch.
- commit e5a5881
* Thu Apr  5 2018 msuchanek@suse.de
- powerpc/64: Drop reservation-clearing ldarx in context switch
  (bsc#1065729).
- commit 6038e82
* Thu Apr  5 2018 brogers@suse.com
- fw_cfg: fix driver remove (bsc#1077919).
- fw_cfg: fix the command line module name (bsc#1077919).
- commit e296044
* Thu Apr  5 2018 msuchanek@suse.de
- powerpc/powernv: Fix SMT4 forcing idle code (bsc#1061840).
- powerpc/lpar/debug: Initialize flags before printing debug
  message (bsc#1065729).
- powerpc: Move default security feature flags (bsc#1068032).
- commit a13eef9
* Thu Apr  5 2018 brogers@suse.com
- Refresh
  patches.drivers/crypto-ccp-add-check-to-get-psp-master-only-when-psp-is-detected.patch.
- commit 6ad4507
* Thu Apr  5 2018 jroedel@suse.de
- x86/platform/UV: Fix critical UV MMR address error
  (bsc#1087542).
- x86/platform/UV: Fix GAM Range Table entries less than 1GB
  (bsc#1087542).
- commit 1ed61f7
* Thu Apr  5 2018 jroedel@suse.de
- Refresh
  patches.drivers/crypto-ccp-add-check-to-get-psp-master-only-when-psp-is-detected.patch.
- commit 8376280
* Thu Apr  5 2018 dbueso@suse.de
- ipc/shm: Fix pid freeing (bsc#1088323).
- ipc/sem: Fix semctl(..., GETPID, ...) between pid namespaces
  (bsc#1088323).
- ipc/msg: Fix msgctl(..., IPC_STAT, ...) between pid namespaces
  (bsc#1088323).
- ipc/shm: Fix shmctl(..., IPC_STAT, ...) between pid namespaces
  (bsc#1088323).
- ipc/util: Helpers for making the sysvipc operations pid
  namespace aware (bsc#1088323).
- commit 834881a
* Thu Apr  5 2018 msuchanek@suse.de
- powerpc/64: Call H_REGISTER_PROC_TBL when running as a HPT
  guest on POWER9 (bsc#1055117).
- commit d22d56e
* Thu Apr  5 2018 msuchanek@suse.de
- cxl: Fix possible deadlock when processing page faults from
  cxllib (bsc#1055014).
- cxl: Fix timebase synchronization status on P9 (bsc#1055014).
- commit 97da1b3
* Thu Apr  5 2018 dbueso@suse.de
- run series_sort.py
- commit dcd8dad
* Thu Apr  5 2018 msuchanek@suse.de
- powerpc/64s: Wire up cpu_show_spectre_v2() (bsc#1068032).
- powerpc/64s: Wire up cpu_show_spectre_v1() (bsc#1068032).
- powerpc/64s: Enhance the information in cpu_show_meltdown()
  (bsc#1068032).
- commit 63a2f99
* Thu Apr  5 2018 msuchanek@suse.de
- powerpc/64s: Move cpu_show_meltdown() (bsc#1068032).
  Refresh patches.arch/powerpc-64-barrier_nospec-Add-debugfs-trigger.patch.
- commit e6621ab
* Thu Apr  5 2018 msuchanek@suse.de
- powerpc/powernv: Use the security flags in pnv_setup_rfi_flush()
  (bsc#1068032).
- powerpc/powernv: Set or clear security feature flags
  (bsc#1068032).
- commit 88dba39
* Thu Apr  5 2018 msuchanek@suse.de
- powerpc/pseries: Set or clear security feature flags
  (bsc#1068032).
- powerpc/pseries: Use the security flags in
  pseries_setup_rfi_flush() (bsc#1068032).
- Refresh
  patches.arch/powerpc-64s-barrier_nospec-Add-hcall-trigger.patch.
- commit a943584
* Thu Apr  5 2018 jack@suse.cz
- FS-Cache: fix dereference of NULL user_key_payload
  (bsc#1052766).
- commit 55e6fcf
* Thu Apr  5 2018 jack@suse.cz
- nilfs2: fix race condition that causes file system corruption
  (bsc#1052766).
- commit a722fb7
* Thu Apr  5 2018 jack@suse.cz
- ocfs2: fix cluster hang after a node dies (bsc#1052766).
- commit 4120511
* Thu Apr  5 2018 msuchanek@suse.de
- powerpc: Add security feature flags for Spectre/Meltdown
  (bsc#1068032).
- commit 5f230fd
* Thu Apr  5 2018 jack@suse.cz
- quota: propagate error from __dquot_initialize (bsc#1052766).
- commit cb9d963
* Thu Apr  5 2018 jack@suse.cz
- fsnotify: fix pinning group in fsnotify_prepare_user_wait()
  (bsc#1052766).
- commit c437982
* Thu Apr  5 2018 jack@suse.cz
- fscrypt: lock mutex before checking for bounce page pool
  (bsc#1052766).
- commit 209ee5e
* Thu Apr  5 2018 jack@suse.cz
- fscrypt: fix dereference of NULL user_key_payload (bsc#1052766).
- commit f373382
* Thu Apr  5 2018 msuchanek@suse.de
- powerpc/pseries: Add new H_GET_CPU_CHARACTERISTICS flags
  (bsc#1068032).
- commit b7a53a4
* Thu Apr  5 2018 jack@suse.cz
- isofs: fix timestamps beyond 2027 (bsc#1052766).
- commit a587b63
* Thu Apr  5 2018 msuchanek@suse.de
- Refresh rfi patches
  patches.arch/powerpc-rfi-flush-Always-enable-fallback-flush-on-ps.patch
  patches.arch/powerpc-rfi-flush-Call-setup_rfi_flush-after-LPM-mig.patch
  patches.arch/powerpc-rfi-flush-Differentiate-enabled-and-patched-.patch
- commit d7870ce
* Thu Apr  5 2018 oneukum@suse.com
- NET: usb: qmi_wwan: add support for YUGA CLM920-NC5 PID 0x9625
  (bsc#1085539).
- commit 1d9d091
* Thu Apr  5 2018 jack@suse.cz
- jbd2: fix sphinx kernel-doc build warnings (bsc#1052766).
- commit fc5bd65
* Thu Apr  5 2018 jack@suse.cz
- ext4: correct documentation for grpid mount option
  (bsc#1052766).
- commit 93f8b5b
* Thu Apr  5 2018 jack@suse.cz
- ext4: save error to disk in __ext4_grp_locked_error()
  (bsc#1052766).
- commit 3dda242
* Thu Apr  5 2018 oneukum@suse.com
- net: usb: qmi_wwan: add Telit ME910 PID 0x1101 support
  (bsc#1085539).
- commit c074125
* Thu Apr  5 2018 jack@suse.cz
- ext4: fix a race in the ext4 shutdown path (bsc#1052766).
- commit 51e6374
* Thu Apr  5 2018 jack@suse.cz
- ext4: fix crash when a directory's i_size is too small
  (bsc#1052766).
- commit 7d7ac9f
* Thu Apr  5 2018 jack@suse.cz
- ext4: fix fdatasync(2) after fallocate(2) operation
  (bsc#1052766).
- commit 887455a
* Thu Apr  5 2018 msuchanek@suse.de
- powerpc/64s: Relax PACA address limitations (bsc#1065729).
  Refresh patches.arch/powerpc-rfi-flush-Make-it-possible-to-call-setup_rfi.patch
- commit 16255f0
* Thu Apr  5 2018 oneukum@suse.com
- net: qmi_wwan: add Sierra EM7565 1199:9091 (bsc#1085539).
- commit d8901e2
* Thu Apr  5 2018 msuchanek@suse.de
- powerpc/64s/radix: Remove bolted-SLB address limit for per-cpu
  stacks (bsc#1055186, fate#323286).
- commit 79fc554
* Thu Apr  5 2018 oneukum@suse.com
- net: qmi_wwan: add Quectel BG96 2c7c:0296 (bsc#1085539).
- commit 78209a8
* Thu Apr  5 2018 jack@suse.cz
- ext4: fix interaction between i_size, fallocate, and delalloc
  after a crash (bsc#1052766).
- commit cbe1a44
* Thu Apr  5 2018 jack@suse.cz
- ext4: fix quota inconsistency during orphan cleanup for
  read-only mounts (bsc#1052766).
- commit f8cbe3f
* Thu Apr  5 2018 jack@suse.cz
- ext4: fix incorrect quotaoff if the quota feature is enabled
  (bsc#1052766).
- commit 5e83762
* Thu Apr  5 2018 jack@suse.cz
- run series_sort.py
- commit b8d67c7
* Thu Apr  5 2018 msuchanek@suse.de
- Refresh patches.arch/powerpc-rfi-flush-Move-the-logic-to-avoid-a-redo-int.patch
- commit 0f4792f
* Thu Apr  5 2018 msuchanek@suse.de
- lkdtm: fix handle_irq_event symbol for INT_HW_IRQ_EN
  (bsc#1052766).
- cpu/hotplug: Remove unused check_for_tasks() function
  (bsc#1087405).
- commit aff55d7
* Thu Apr  5 2018 jthumshirn@suse.de
- scsi: aacraid: remove redundant setting of variable c
  (bsc#1077989).
- commit 46a3cd8
* Thu Apr  5 2018 msuchanek@suse.de
- eeprom: at24: fix reading from 24MAC402/24MAC602 (bsc#1052766).
- commit e377943
* Thu Apr  5 2018 ohering@suse.de
- scripts/git_sort/git_sort.py: helgas/pci.git
  bsc#1087659
- commit 718b019
* Thu Apr  5 2018 ohering@suse.de
- add mainline tag to one crypto patch to be able to get further work done
- commit ce6483f
* Thu Apr  5 2018 jthumshirn@suse.de
- libata: Modify quirks for MX100 to limit NCQ_TRIM quirk to
  MU01 version (bsc#1077989).
- libata: Make Crucial BX100 500GB LPM quirk apply to all firmware
  versions (bsc#1077989).
- libata: Apply NOLPM quirk to Crucial M500 480 and 960GB SSDs
  (bsc#1077989).
- libata: Enable queued TRIM for Samsung SSD 860 (bsc#1077989).
- ahci: Add PCI-id for the Highpoint Rocketraid 644L card
  (bsc#1077989).
- libata: disable LPM for Crucial BX100 SSD 500GB drive
  (bsc#1077989).
- libata: Apply NOLPM quirk to Crucial MX100 512GB SSDs
  (bsc#1077989).
- libata: don't try to pass through NCQ commands to non-NCQ
  devices (bsc#1077989).
- libata: remove WARN() for DMA or PIO command without data
  (bsc#1077989).
- libata: fix length validation of ATAPI-relayed SCSI commands
  (bsc#1077989).
- libata: apply MAX_SEC_1024 to all LITEON EP1 series devices
  (bsc#1077989).
- commit c6aedf4
* Thu Apr  5 2018 jthumshirn@suse.de
- libnvdimm: passthru functions clear to send (FATE#324636).
- Refresh
  patches.drivers/libnvdimm-fix-integer-overflow-static-analysis-warni.patch.
- commit 9f63ca3
* Thu Apr  5 2018 jthumshirn@suse.de
- scsi: ibmvfc: fix misdefined reserved field in
  ibmvfc_fcp_rsp_info (bsc#1077989).
- scsi: core: scsi_get_device_flags_keyed(): Always return device
  flags (bsc#1077989).
- scsi: core: Fix a scsi_show_rq() NULL pointer dereference
  (bsc#1077989).
- scsi: ufs: ufshcd: fix potential NULL pointer dereference in
  ufshcd_config_vreg (bsc#1077989).
- commit 56f0ee6
* Thu Apr  5 2018 jthumshirn@suse.de
- scsi: aacraid: Fix udev inquiry race condition (bsc#1077989).
- Refresh patches.drivers/scsi-aacraid-Fix-hang-in-kdump.patch.
- commit 2a83436
* Thu Apr  5 2018 hare@suse.de
- scsi: mpt3sas: wait for and flush running commands on
  shutdown/unload (bsc#1081917).
- scsi: mpt3sas: fix oops in error handlers after shutdown/unload
  (bsc#1081917).
- commit a349d88
* Thu Apr  5 2018 hare@suse.de
- scsi: mpt3sas: Do not use 32-bit atomic request descriptor
  for Ventura controllers (bsc#1081917).
- scsi: mpt3sas: make function _get_st_from_smid static
  (bsc#1081917).
- scsi: mpt3sas: lockless command submission (bsc#1081917).
- scsi: mpt3sas: simplify _wait_for_commands_to_complete()
  (bsc#1081917).
- scsi: mpt3sas: simplify mpt3sas_scsi_issue_tm() (bsc#1081917).
- scsi: mpt3sas: simplify task management functions (bsc#1081917).
- scsi: mpt3sas: always use first reserved smid for ioctl
  passthrough (bsc#1081917).
- scsi: mpt3sas: check command status before attempting abort
  (bsc#1081917).
- scsi: mpt3sas: Introduce mpt3sas_get_st_from_smid()
  (bsc#1081917).
- scsi: mpt3sas: open-code _scsih_scsi_lookup_get() (bsc#1081917).
- scsi: mpt3sas: separate out _base_recovery_check()
  (bsc#1081917).
- scsi: mpt3sas: use list_splice_init() (bsc#1081917).
- scsi: mpt3sas: set default value for cb_idx (bsc#1081917).
- scsi: mpt3sas: Remove unused variable requeue_event
  (bsc#1081917).
- scsi: mpt3sas: Replace PCI pool old API (bsc#1081917).
- commit cb50073
* Thu Apr  5 2018 jthumshirn@suse.de
- libnvdimm, {btt, blk}: do integrity setup before add_disk()
  (FATE#323731).
- libnvdimm, btt: Fix an incompatibility in the log layout
  (FATE#323731).
- libnvdimm, namespace: fix label initialization to use valid
  seq numbers (FATE#323731).
- libnvdimm, dimm: clear 'locked' status on successful DIMM enable
  (FATE#323731).
- commit d622fe7
* Thu Apr  5 2018 lhenriques@suse.com
- ceph: only dirty ITER_IOVEC pages for direct read (bsc#1084898).
- commit 39d3e00
* Thu Apr  5 2018 lhenriques@suse.com
- Refresh
  patches.drivers/crypto-ccp-add-check-to-get-psp-master-only-when-psp-is-detected.patch.
- commit 0eac7e1
* Thu Apr  5 2018 hare@suse.de
- Refresh
  patches.drivers/crypto-ccp-add-check-to-get-psp-master-only-when-psp-is-detected.patch.
- commit 31ba015
* Thu Apr  5 2018 colyli@suse.de
- dm: bump DM_VERSION_MINOR in response to target method error
  code changes (fate#322738,fate#322919,fate#322950,fate#323773).
- dm ioctl: fix alignment of event number in the device list
  (fate#322738,fate#322919,fate#322950,fate#323773).
- bcache: don't attach backing with duplicate UUID (bsc#1076110).
- bcache: fix crashes in duplicate cache device register
  (bsc#1076110).
- Refresh with patch-mainline info from upstream
  patches.drivers/crypto-ccp-add-check-to-get-psp-master-only-when-psp-is-detected.patch.
- commit d9ed9f7
* Thu Apr  5 2018 jthumshirn@suse.de
- Refresh
  patches.drivers/crypto-ccp-add-check-to-get-psp-master-only-when-psp-is-detected.patch.
- commit 3c722f3
* Thu Apr  5 2018 ohering@suse.de
- hv_netvsc: enable multicast if necessary (fate#323887).
- commit 8ac01bc
* Thu Apr  5 2018 bpoirier@suse.com
- i40evf: fix mac filter removal timing issue (bsc#1085952).
- commit 77d77ad
* Thu Apr  5 2018 rgoldwyn@suse.com
- Check all profiles attached to the label (bsc#1085996).
- commit bdb6960
* Wed Apr  4 2018 bp@suse.de
- EDAC, sb_edac: Fix missing DIMM sysfs entries with KNL SNC2/SNC4
  mode (bsc#1087398).
- commit 379aede
* Wed Apr  4 2018 mbrugger@suse.com
- clk: bcm2835: Protect sections updating shared registers
  (bsc#1085535).
- clk: bcm2835: Fix ana->maskX definitions (bsc#1085535).
- clk: migrate the count of orphaned clocks at init (bsc#1085535).
- i2c: bcm2835: Set up the rising/falling edge delays
  (bsc#1085535).
- clk: Don't touch hardware when reparenting during registration
  (bsc#1085535).
- clk: fix a panic error caused by accessing NULL pointer
  (bsc#1085535).
- clk: imx: imx7d: Fix parent clock for OCRAM_CLK (bsc#1085535).
- clocksource/drivers/arm_arch_timer: Validate CNTFRQ after
  enabling frame (bsc#1085535).
- clocksource/drivers/arm_arch_timer: Fix mem frame loop
  initialization (bsc#1085535).
- commit 99eb15b
* Wed Apr  4 2018 bp@suse.de
- perf/x86/intel/uncore: Fix multi-domain PCI CHA enumeration
  bug on Skylake servers (bsc#1086359).
- commit e6b5922
* Wed Apr  4 2018 mbrugger@suse.com
- arm64: Relax ARM_SMCCC_ARCH_WORKAROUND_1 discovery
  (bsc#1088051).
- arm64: mm: fix thinko in non-global page table attribute check
  (bsc#1088049).
- arm64: Remove unimplemented syscall log message (bsc#1085535).
- arm64: cpufeature: Fix CTR_EL0 field definitions (bsc#1085535).
- arm64: proc: Set PTE_NG for table entries to avoid traversing
  them twice (bsc#1085535).
- arm64: fix CONFIG_DEBUG_WX address reporting (bsc#1085535).
- arm64: mm: Fix false positives in set_pte_at access/dirty race
  detection (bsc#1085535).
- arm64: Initialise high_memory global variable earlier
  (bsc#1085535).
- arm64: fpsimd: Prevent registers leaking from dead tasks
  (bsc#1085535).
- arm64: prevent regressions in compressed kernel image size
  when upgrading to binutils 2.27 (bsc#1085535).
- arm64: Implement arch-specific pte_access_permitted()
  (bsc#1085535).
- arm64: ensure __dump_instr() checks addr_limit (bsc#1085535).
- arm64: fault: Route pte translation faults via
  do_translation_fault (bsc#1085535).
- arm64: mm: Use READ_ONCE when dereferencing pointer to pte table
  (bsc#1085535).
- arm64: Make sure SPsel is always set (bsc#1085535).
- commit 9ca6ca7
* Wed Apr  4 2018 tiwai@suse.de
- mmc: block: fix updating ext_csd caches on ioctl call
  (bsc#1051510).
- commit 750d5f5
* Wed Apr  4 2018 tiwai@suse.de
- blacklist.conf: update mmc entry
- commit 2ee5678
* Wed Apr  4 2018 oneukum@suse.com
- usb: usbmon: Read text within supplied buffer size
  (bsc#1087092).
- commit 86b2669
* Wed Apr  4 2018 oneukum@suse.com
- USB: storage: Add JMicron bridge 152d:2567 to unusual_devs.h
  (bsc#1087092).
- commit 1ed8de7
* Wed Apr  4 2018 oneukum@suse.com
- Revert "usb: musb: host: don't start next rx urb if current
  one failed" (bsc#1087092).
- commit b079d8b
* Wed Apr  4 2018 oneukum@suse.com
- usb: ohci: Proper handling of ed_rm_list to handle race
  condition between usb_kill_urb() and finish_unlinks()
  (bsc#1087092).
- commit 5b90439
* Wed Apr  4 2018 oneukum@suse.com
- xhci: Fix front USB ports on ASUS PRIME B350M-A (bsc#1087092).
- commit f61cb1b
* Wed Apr  4 2018 mfleming@suse.de
- nohz: Prevent a timer interrupt storm in
  tick_nohz_stop_sched_tick() (bsc#1051510).
- Refresh
  patches.suse/kernel-add-release-status-to-kernel-build.patch.
- Refresh patches.suse/sched-throttle-nohz.patch.
- commit a31081c
* Wed Apr  4 2018 tiwai@suse.de
- blacklist.conf: Add mac80211 entry
- commit 8a71e13
* Wed Apr  4 2018 tiwai@suse.de
- media: s3c-camif: fix out-of-bounds array access (bsc#1051510).
- media: vivid: fix incorrect capabilities for radio
  (bsc#1051510).
- media: cx25821: prevent out-of-bounds read on array card
  (bsc#1051510).
- media: au0828: fix VIDEO_V4L2 dependency (bsc#1051510).
- ath10k: fix recent bandwidth conversion bug (bsc#1051510).
- ath10k: advertize beacon_int_min_gcd (bsc#1051510).
- iwlwifi: mvm: check if mac80211_queue is valid in
  iwl_mvm_disable_txq (bsc#1051510).
- ath9k: Protect queue draining by rcu_read_lock() (bsc#1051510).
- mac80211: don't WARN on bad WMM parameters from buggy APs
  (bsc#1051510).
- mt7601u: let mac80211 validate rx CCMP PN (bsc#1051510).
- regmap: Format data for raw write in regmap_bulk_write
  (bsc#1051510).
- regmap: Don't use format_val in regmap_bulk_read (bsc#1051510).
- regmap: Correct offset handling in regmap_volatile_range
  (bsc#1051510).
- regmap-i2c: Off by one in regmap_i2c_smbus_i2c_read/write()
  (bsc#1051510).
- regmap: Fix reversed bounds check in regmap_raw_write()
  (bsc#1051510).
- regmap: Correct comparison in regmap_cached (bsc#1051510).
- commit f0366d2
* Wed Apr  4 2018 tiwai@suse.de
- add a cherry-picked id to earlycon fix patch
- commit c41f9b4
* Wed Apr  4 2018 bp@suse.de
- x86/cpu/amd: Derive L3 shared_cpu_map from cpu_llc_shared_mask
  (stable fixes).
- x86/efi: Fix kernel param add_efi_memmap regression (stable
  fixes).
- x86: Make X86_BUG_FXSAVE_LEAK detectable in CPUID on AMD
  (stable fixes).
- x86/microcode/intel: Disable late loading on model 79 (stable
  fixes).
- x86/microcode/intel: Extend BDW late-loading further with LLC
  size check (stable fixes).
- x86/microcode/intel: Extend BDW late-loading with a revision
  check (stable fixes).
- x86/mm, mm/hwpoison: Clear PRESENT bit for kernel 1:1 mappings
  of poison pages (stable fixes).
- x86/mm, mm/hwpoison: Don't unconditionally unmap kernel 1:1
  pages (stable fixes).
- blacklist.conf:
- Refresh
  patches.arch/x86-cpufeatures-add-amd-feature-bits-for-speculation-control.patch.
- Refresh
  patches.arch/x86-cpufeatures-clean-up-spectre-v2-related-cpuid-flags.patch.
- commit 6fad1e8
* Wed Apr  4 2018 oneukum@suse.com
- HID: multitouch: Support PTP Stick and Touchpad device
  (bsc#1085535).
- commit 121a18f
* Wed Apr  4 2018 mbrugger@suse.com
- blacklist.conf: arm64: ignore compiler warning fix
- commit f435aeb
* Wed Apr  4 2018 oneukum@suse.com
- HID: quirks: Fix keyboard + touchpad on Toshiba Click Mini
  not working (bsc#1087092).
- commit c28bdad
* Wed Apr  4 2018 aaptel@suse.com
- Fix encryption labels and lengths for SMB3.1.1 (bsc#1085536).
- commit 1064d6b
* Wed Apr  4 2018 oneukum@suse.com
- HID: multitouch: Only look at non touch fields in first packet
  of a frame (bsc#1087092).
- commit d86f5f8
* Wed Apr  4 2018 aaptel@suse.com
- Fix SMB3.1.1 guest authentication to Samba (bsc#1085536).
- commit 1a6f5eb
* Wed Apr  4 2018 aaptel@suse.com
- SMB3: Don't ignore O_SYNC/O_DSYNC and O_DIRECT flags
  (bsc#1085536).
- commit b7e7367
* Wed Apr  4 2018 aaptel@suse.com
- SMB3: handle new statx fields (bsc#1085536).
- commit 137a353
* Wed Apr  4 2018 aaptel@suse.com
- SMB: Validate negotiate (to protect against downgrade) even
  if signing off (bsc#1085536).
- commit 4cd7fa4
* Wed Apr  4 2018 aaptel@suse.com
- SMB3: Warn user if trying to sign connection that authenticated
  as guest (bsc#1085536).
- commit 17be9ec
* Wed Apr  4 2018 oneukum@suse.com
- PCMCIA / PM: Avoid noirq suspend aborts during suspend-to-idle
  (bsc#1087092).
- commit c4ccc7e
* Wed Apr  4 2018 agraf@suse.de
- Refresh patches.suse/0001-lan78xx-Connect-phy-early.patch.
- commit 1f9e0fb
* Tue Apr  3 2018 yousaf.kaukab@suse.com
- arm64: assembler: Change order of macro arguments in
  phys_to_ttbr (bsc#1087414).
- commit 50ba314
* Tue Apr  3 2018 tbogendoerfer@suse.de
- net/mlx4_core: Fix memory leak while delete slave's resources
  (bsc#1046300 FATE#322946).
- net/mlx4_en: Fix mixed PFC and Global pause user control
  requests (bsc#1046299 FATE#322947).
- net/mlx5e: Avoid using the ipv6 stub in the TC offload neigh
  update path (bsc#1046303 FATE#322944).
- net/mlx5e: Fix memory usage issues in offloading TC flows
  (bsc#1046303 FATE#322944).
- net/mlx5e: Fix traffic being dropped on VF representor
  (bsc#1046303 FATE#322944).
- net/mlx5e: Don't override vport admin link state in switchdev
  mode (bsc#1046303 FATE#322944).
- RDMA/ucma: Check that device exists prior to accessing it
  (bsc#1046306 FATE#322942).
- RDMA/ucma: Check that device is connected prior to access it
  (bsc#1046306 FATE#322942).
- RDMA/qedr: Fix QP state initialization race (bsc#1050545
  FATE#322893).
- RDMA/qedr: Fix rc initialization on CNQ allocation failure
  (bsc#1050545 FATE#322893).
- RDMA/qedr: fix QP's ack timeout configuration (bsc#1050545
  FATE#322893).
- bnxt_en: Check valid VNIC ID in bnxt_hwrm_vnic_set_tpa()
  (bsc#1050242 FATE#322914).
- RDMA/ucma: Ensure that CM_ID exists prior to access it
  (bsc#1046306 FATE#322942).
- RDMA/ucma: Fix use-after-free access in ucma_close (bsc#1046306
  FATE#322942).
- RDMA/ucma: Fix access to non-initialized CM_ID object
  (bsc#1046306 FATE#322942).
- commit bacc3ae
* Tue Apr  3 2018 tbogendoerfer@suse.de
- net/mlx5e: Sync netdev vxlan ports at open (bsc#1046303
  FATE#322944).
- RDMA/core: Do not use invalid destination in determining port
  reuse (bsc#1046306 FATE#322942).
- IB/mlx5: Fix integer overflows in mlx5_ib_create_srq
  (bsc#1046305 FATE#322943).
- IB/mlx5: Fix incorrect size of klms in the memory region
  (bsc#1046305 FATE#322943).
- commit 78a69dd
* Tue Apr  3 2018 tbogendoerfer@suse.de
- net/mlx5: Make eswitch support to depend on switchdev
  (bsc#1046305 FATE#322943).
- RDMA/rdma_cm: Fix use after free race with process_one_req
  (bsc#1046306 FATE#322942).
- RDMA/ucma: Correct option size check using optlen (bsc#1046306
  FATE#322942).
- RDMA/ucma: Check AF family prior resolving address (bsc#1046306
  FATE#322942).
- RDMA/ucma: Don't allow join attempts for unsupported AF family
  (bsc#1046306 FATE#322942).
- IB/mlx5: Fix out-of-bounds read in create_raw_packet_qp_rq
  (bsc#1046305 FATE#322943).
- commit 9a507f9
* Tue Apr  3 2018 tiwai@suse.de
- Move a few upstreamed i915 patches into sorted section
- commit 31b54c4
* Tue Apr  3 2018 tbogendoerfer@suse.de
- Re-sorted sorted section.
- Refresh
  patches.arch/powerpc-64s-Fix-NULL-AT_BASE_PLATFORM-when-using-DT-.patch.
- Refresh
  patches.arch/powerpc-64s-Fix-lost-pending-interrupt-due-to-race-c.patch.
- Refresh
  patches.arch/powerpc-mm-Add-tracking-of-the-number-of-coprocessor.patch.
- Refresh patches.arch/powerpc-mm-radix-Remove-unused-code.patch.
- Refresh
  patches.drivers/drm-i915-Fix-DPLCLKA_CFGCR0-bits-for-Port-F.
- Refresh
  patches.drivers/drm-i915-For-HPD-connected-port-use-hpd_pin-instead-.
- Refresh patches.drivers/drm-i915-cnl-Add-AUX-F-support.
- Refresh
  patches.drivers/drm-i915-cnl-Add-Cannonlake-PCI-IDs-for-another-SKU.
- Refresh patches.drivers/drm-i915-cnl-Add-HPD-support-for-Port-F.
- Refresh patches.drivers/drm-i915-cnl-Add-Port-F-definition.
- Refresh
  patches.drivers/drm-i915-cnl-Add-right-GMBUS-pin-number-for-HDMI-on-.
- Refresh patches.drivers/drm-i915-cnl-Enable-DDI-F-on-Cannonlake.
- Refresh patches.drivers/drm-i915-cnl-Extend-Wa-1178-to-Aux-F.
- Refresh
  patches.drivers/drm-i915-cnl-Fix-DP-max-rate-for-Cannonlake-with-por.
- Refresh
  patches.drivers/drm-i915-cnl-Fix-_CNL_PORT_TX_DW2_LN0_F-definition.
- Refresh
  patches.drivers/drm-i915-cnl-Fix-aux-selection-for-WA-1178.
- Refresh
  patches.drivers/drm-i915-cnl-WaPipeControlBefore3DStateSamplePattern.
- Refresh
  patches.drivers/drm-i915-cnl-apply-Display-WA-1178-to-fix-type-C-don.
- Refresh patches.drivers/drm-i915-dmc-DMC-1.07-for-Cannonlake.
- Refresh
  patches.drivers/drm-i915-dp-abstract-rate-array-length-limiting.
- Refresh
  patches.drivers/drm-i915-dp-clean-up-source-rate-limiting-for-cnl.
- Refresh
  patches.drivers/drm-i915-dp-limit-DP-link-rate-based-on-VBT-on-CNL.
- commit 7eebb19
* Tue Apr  3 2018 msuchanek@suse.de
- powerpc/kexec_file: Fix error code when trying to load kdump
  kernel (bsc#1065729).
- powerpc: Fix invalid use of register expressions (bsc#1065729).
- commit 7f76cbc
* Tue Apr  3 2018 tiwai@suse.de
- drm/i915: Fix hibernation with ACPI S0 target state
  (bsc#1051510).
- drm/i915/execlists: Use a locked clear_bit() for synchronisation
  with interrupt (bsc#1051510).
- drm/i915: Wrap engine->schedule in RCU locks for set-wedge
  protection (bsc#1051510).
- drm/i915/psr: Check for the specific AUX_FRAME_SYNC cap bit
  (bsc#1051510).
- drm/i915: Correctly handle limited range YCbCr data on VLV/CHV
  (bsc#1051510).
- ALSA: pcm: Use dma_bytes as size parameter in
  dma_mmap_coherent() (bsc#1051510).
- ASoC: mt8173-rt5650: fix child-node lookup (bsc#1051510).
- commit 2b920b8
* Tue Apr  3 2018 tiwai@suse.de
- Preliminary patch sort and update
- commit 7e40132
* Tue Apr  3 2018 tiwai@suse.de
- blacklist.conf: Update drm and ath9k blacklist
- commit cd79980
* Tue Apr  3 2018 yousaf.kaukab@suse.com
- arm64: mm: ignore memory above supported physical address size (bsc#1087414).
- commit 492164f
* Tue Apr  3 2018 yousaf.kaukab@suse.com
- arm64: fix comment above tcr_compute_pa_size (bsc#1087414).
- commit 084a935
* Tue Apr  3 2018 yousaf.kaukab@suse.com
- KVM: arm/arm64: fix HYP ID map extension to 52 bits (bsc#1087414).
- commit 816eb92
* Tue Apr  3 2018 yousaf.kaukab@suse.com
- arm64: fix ID map extension to 52 bits (bsc#1087414).
- commit 08c26ef
* Mon Apr  2 2018 jslaby@suse.cz
- objtool: Fix 32-bit build (bnc#1058115 git-fixes).
- commit 17df039
* Mon Apr  2 2018 jlee@suse.com
- acpi, numa: fix pxm to online numa node associations
  (bsc#1087144).
- commit cc55a09
* Mon Apr  2 2018 jlee@suse.com
- Refresh
  patches.arch/powerpc-64s-Fix-NULL-AT_BASE_PLATFORM-when-using-DT-.patch.
- Refresh
  patches.arch/powerpc-64s-Fix-lost-pending-interrupt-due-to-race-c.patch.
- Refresh
  patches.arch/powerpc-mm-Add-tracking-of-the-number-of-coprocessor.patch.
- Refresh patches.arch/powerpc-mm-radix-Remove-unused-code.patch.
- commit 8e8e208
* Sun Apr  1 2018 nstange@suse.de
- ppc64le: reliable stacktrace: fix .text check (bsc#1087458).
- commit 1aa954a
* Sat Mar 31 2018 nstange@suse.de
- ppc64le: reliable stacktrace: fix stacktrace for idle tasks (bsc#1087458).
- commit 5938588
* Thu Mar 29 2018 bp@suse.de
- x86/entry/64: Don't use IST entry for #BP stack (bsc#1087088).
- commit 10d3c90
* Thu Mar 29 2018 jslaby@suse.cz
- posix-timers: Protect posix clock array access against
  speculation (bnc#1081358 CVE-2017-5715).
- commit 5a1acc8
* Thu Mar 29 2018 msuchanek@suse.de
- KABI: cpu/hotplug: provide the old get|put_online_cpus()
  (bsc#1087405).
- commit f687c6d
* Thu Mar 29 2018 msuchanek@suse.de
- Import kabi files from RC2
- commit 3f5879f
* Thu Mar 29 2018 aaptel@suse.com
- run series_sort.py
- commit d353f7c
* Thu Mar 29 2018 msuchanek@suse.de
- powerpc: Don't call lockdep_assert_cpus_held() from
  arch_update_cpu_topology() (bsc#1087405).
- workqueue: Work around edge cases for calc of pool's cpumask
  (bsc#1087405).
- powerpc: Only obtain cpu_hotplug_lock if called by rtasd
  (bsc#1087405).
  Refresh patches.arch/powerpc-numa-Invalidate-numa_cpu_lookup_table-on-cpu.patch.
- cpu/hotplug: Convert hotplug locking to percpu rwsem
  (bsc#1087405).
- stop_machine: Provide stop_machine_cpuslocked() (bsc#1087405).
- cpu/hotplug: Provide lockdep_assert_cpus_held() (bsc#1087405).
- cpu/hotplug: Provide cpus_read|write_[un]lock() (bsc#1087405).
- commit 47384e4
* Thu Mar 29 2018 jack@suse.cz
- ipc/shm.c: add split function to shm_vm_ops (bsc#1052766).
- commit 4d132c0
* Thu Mar 29 2018 jack@suse.cz
- dax: fix vma_is_fsdax() helper (bsc#1052766).
- commit b56bd6f
* Thu Mar 29 2018 jack@suse.cz
- Run series_sort.py:
  patches.arch/powerpc-64s-Fix-NULL-AT_BASE_PLATFORM-when-using-DT-.patch.
  patches.arch/powerpc-64s-Fix-lost-pending-interrupt-due-to-race-c.patch.
  patches.arch/powerpc-mm-Add-tracking-of-the-number-of-coprocessor.patch.
  patches.arch/powerpc-mm-radix-Remove-unused-code.patch.
- commit d6d2551
* Thu Mar 29 2018 oneukum@suse.com
- blacklist.conf: config only
- commit 80e80db
* Thu Mar 29 2018 oneukum@suse.com
- HID: wacom: generic: Recognize WACOM_HID_WD_PEN as a type of
  pen collection (bsc#1085539).
- commit 45e56be
* Thu Mar 29 2018 oneukum@suse.com
- HID: hid-elecom: extend to fix descriptor for HUGE trackball
  (bsc#1085536).
- commit 31aa2e9
* Thu Mar 29 2018 yousaf.kaukab@suse.com
- Update config files.
- commit f6b4573
* Thu Mar 29 2018 oneukum@suse.com
- HID: usbhid: fix out-of-bounds bug (bsc#1085536).
- commit 8c5a469
* Thu Mar 29 2018 yousaf.kaukab@suse.com
- arm64: Fix TTBR + PAN + 52-bit PA logic in cpu_do_switch_mm (bsc#1087414).
- commit 78c2b65
* Thu Mar 29 2018 oneukum@suse.com
- HID: wacom: Always increment hdev refcount within
  wacom_get_hdev_data (bsc#1085536).
- commit 928bfef
* Thu Mar 29 2018 yousaf.kaukab@suse.com
- arm64: enable 52-bit physical address support (bsc#1087414).
- commit 19c75f1
* Thu Mar 29 2018 oneukum@suse.com
- HID: wacom: generic: Clear ABS_MISC when tool leaves proximity
  (bsc#1085536).
- commit 52ce6f1
* Thu Mar 29 2018 oneukum@suse.com
- HID: wacom: generic: Send MSC_SERIAL and ABS_MISC when leaving
  prox (bsc#1085536).
- commit 7d14c4c
* Thu Mar 29 2018 oneukum@suse.com
- HID: i2c-hid: allocate hid buffers for real worst case
  (bsc#1085536).
- commit 8469205
* Thu Mar 29 2018 oneukum@suse.com
- HID: wacom: Correct coordinate system of touchring and pen twist
  (bsc#1085536).
- HID: wacom: Properly report negative values from Intuos Pro
  2 Bluetooth (bsc#1085536).
- commit 3415c32
* Thu Mar 29 2018 oneukum@suse.com
- HID: wacom: leds: Don't try to control the EKR's read-only LEDs
  (bsc#1085536).
- commit 9dd7e47
* Thu Mar 29 2018 oneukum@suse.com
- HID: wacom: bits shifted too much for 9th and 10th buttons
  (bsc#1085536).
- commit 981162e
* Thu Mar 29 2018 oneukum@suse.com
- isdn/i4l: fetch the ppp_write buffer in one shot (bsc#1085536).
- commit b48a9e9
* Thu Mar 29 2018 yousaf.kaukab@suse.com
- arm64: allow ID map to be extended to 52 bits (bsc#1087414).
- commit 6c68c5d
* Thu Mar 29 2018 yousaf.kaukab@suse.com
- arm64: handle 52-bit physical addresses in page table entries (bsc#1087414).
- commit b24364b
* Thu Mar 29 2018 oneukum@suse.com
- ohci-hcd: Fix race condition caused by ohci_urb_enqueue()
  and io_watchdog_func() (bsc#1087092).
- commit 9648543
* Thu Mar 29 2018 yousaf.kaukab@suse.com
- arm64: don't open code page table entry creation (bsc#1087414).
- commit d140261
* Thu Mar 29 2018 yousaf.kaukab@suse.com
- arm64: head.S: handle 52-bit PAs in PTEs in early page table setup (bsc#1087414).
- Delete out-of-tree patch
  patches.suse/arm64-add-PTE_ADDR_MASK.patch
- commit a185a0c
* Thu Mar 29 2018 yousaf.kaukab@suse.com
- arm64: handle 52-bit addresses in TTBR (bsc#1087414).
- Refresh
  patches.suse/0010-arm64-Move-post_ttbr_update_workaround-to-C-code.patch.
- Refresh
  patches.suse/0012-arm64-KVM-Use-per-CPU-vector-when-BP-hardening-is-en.patch
- Refresh
  patches.suse/arm64-Add-software-workaround-for-Falkor-erratum-104.patch
- Refresh
  patches.suse/v2-4-9-arm64-kpti-Add---enable-callback-to-remap-swapper-using-nG-mappings.patch.
- commit 2db3dd8
* Thu Mar 29 2018 tiwai@suse.de
- mfd: lpc_ich: Avoton/Rangeley uses SPI_BYT method (bsc#1051510).
- commit 4767d8c
* Thu Mar 29 2018 tiwai@suse.de
- ima/policy: fix parsing of fsuuid (bsc#1051510).
- ima: relax requiring a file signature for new files with zero
  length (bsc#1051510).
- commit 2cdd97f
* Thu Mar 29 2018 yousaf.kaukab@suse.com
- arm64: limit PA size to supported range (bsc#1087414).
- commit 70ee670
* Thu Mar 29 2018 yousaf.kaukab@suse.com
- arm64: add kconfig symbol to configure physical address size (bsc#1087414).
- commit d185b34
* Thu Mar 29 2018 tiwai@suse.de
- earlycon: add reg-offset to physical address before mapping
  (bsc#1051510).
- commit 4cbd533
* Thu Mar 29 2018 tiwai@suse.de
- brcmfmac: fix P2P_DEVICE ethernet address generation
  (bsc#1051510).
- commit f59d048
* Thu Mar 29 2018 tiwai@suse.de
- Bluetooth: btusb: Add Dell OptiPlex 3060 to
  btusb_needs_reset_resume_table (bsc#1051510).
- commit f568264
* Thu Mar 29 2018 tiwai@suse.de
- Preliminary series sort / update
- commit 50c4a36
* Thu Mar 29 2018 oneukum@suse.com
- usb: Don't print a warning if interface driver rebind is
  deferred at resume (bsc#1087211).
- commit a2c4fdd
* Thu Mar 29 2018 oneukum@suse.com
- USB: usbip: remove useless call in usbip_recv (bsc#1087092).
- commit 01880ff
* Thu Mar 29 2018 tiwai@suse.de
- Input: matrix_keypad - fix race when disabling interrupts
  (bsc#1051510).
- commit e958019
* Thu Mar 29 2018 ohering@suse.de
- Drivers: hv: vmbus: Fix ring buffer signaling (fate#323887).
- hv_netvsc: common detach logic (fate#323887).
- hv_netvsc: change GPAD teardown order on older versions
  (fate#323887).
- hv_netvsc: use RCU to fix concurrent rx and queue changes
  (fate#323887).
- hv_netvsc: disable NAPI before channel close (fate#323887).
- hv_netvsc: fix locking during VF setup (fate#323887).
- hv_netvsc: fix locking for rx_mode (fate#323887).
- hv_netvsc: avoid repeated updates of packet filter
  (fate#323887).
- hv_netvsc: fix filter flags (fate#323887).
- scsi: storvsc: Spread interrupts when picking a channel for
  I/O requests (fate#323887).
- hv_netvsc: propagate rx filters to VF (fate#323887).
- hv_netvsc: filter multicast/broadcast (fate#323887).
- hv_netvsc: defer queue selection to VF (fate#323887).
- hv_netvsc: use napi_schedule_irqoff (fate#323887).
- hv_netvsc: fix race in napi poll when rescheduling
  (fate#323887).
- hv_netvsc: cancel subchannel setup before halting device
  (fate#323887).
- hv_netvsc: fix error unwind handling if vmbus_open fails
  (fate#323887).
- hv_netvsc: only wake transmit queue if link is up (fate#323887).
- hv_netvsc: avoid retry on send during shutdown (fate#323887).
- scsi: storvsc: Increase cmd_per_lun for higher speed devices
  (fate#323887).
- commit c2c371a
* Wed Mar 28 2018 tiwai@suse.de
- rtlwifi: rtl8723be: Fix loss of signal (bsc#1051510).
- mmc: dw_mmc: fix falling from idmac to PIO mode when
  dw_mci_reset occurs (bsc#1051510).
- mmc: core: Disable HPI for certain Micron (Numonyx) eMMC cards
  (bsc#1051510).
- mmc: dw_mmc: Avoid accessing registers in runtime suspended
  state (bsc#1051510).
- mmc: sdhci-pci: Fix S0i3 for Intel BYT-based controllers
  (bsc#1051510).
- mmc: avoid removing non-removable hosts during suspend
  (bsc#1051510).
- mmc: mmc_test: Ensure command queue is disabled for testing
  (bsc#1051510).
- commit f5a53da
* Wed Mar 28 2018 tiwai@suse.de
- ALSA: aloop: Fix access to not-yet-ready substream via cable
  (bsc#1051510).
- ALSA: aloop: Sync stale timer before release (bsc#1051510).
- ALSA: hda/realtek - Fix speaker no sound after system resume
  (bsc#1051510).
- ALSA: hda/realtek - Fix Dell headset Mic can't record
  (bsc#1051510).
- ALSA: hda - Force polling mode on CFL for fixing codec
  communication (bsc#1051510).
- ALSA: usb-audio: Fix parsing descriptor of UAC2 processing unit
  (bsc#1051510).
- ALSA: hda/realtek - Always immediately update mute LED with
  pin VREF (bsc#1051510).
- drm: udl: Properly check framebuffer mmap offsets (bsc#1051510).
- drm: Reject getfb for multi-plane framebuffers (bsc#1051510).
- drm/vmwgfx: Fix a destoy-while-held mutex problem (bsc#1051510).
- drm/vmwgfx: Fix black screen and device errors when running
  without fbdev (bsc#1051510).
- drm/radeon: Don't turn off DP sink when disconnected
  (bsc#1051510).
- commit f5e4005
* Wed Mar 28 2018 enadolski@suse.com
- btrfs: add missing initialization in btrfs_check_shared
  (bsc#1087185).
- commit 0dc4dff
* Wed Mar 28 2018 tiwai@suse.de
- mei: me: allow runtime pm for platform with D0i3 (bsc#1087204).
- commit 91f0e9a
* Wed Mar 28 2018 oneukum@suse.com
- usbip: keep usbip_device sockfd state in sync with tcp_socket
  (bsc#1087092).
- commit a9c0193
* Wed Mar 28 2018 aaptel@suse.com
- CIFS: zero sensitive data when freeing (bsc#1087092).
- commit 342e490
* Wed Mar 28 2018 oneukum@suse.com
- usbip: list: don't list devices attached to vhci_hcd
  (bsc#1087092).
- commit 80e4e06
* Wed Mar 28 2018 oneukum@suse.com
- usbip: prevent bind loops on devices attached to vhci_hcd
  (bsc#1087092).
- commit 1b1531b
* Wed Mar 28 2018 aaptel@suse.com
- cifs: Fix autonegotiate security settings mismatch (bsc#1087092).
- commit 7bd8fc2
* Wed Mar 28 2018 aaptel@suse.com
- cifs: Fix missing put_xid in cifs_file_strict_mmap (bsc#1087092).
- commit 15a395c
* Wed Mar 28 2018 aaptel@suse.com
- cifs: fix NULL deref in SMB2_read (bsc#1085539).
- commit a05b05d
* Wed Mar 28 2018 aaptel@suse.com
- cifs: check MaxPathNameComponentLength != 0 before using it
  (bsc#1085536).
- commit 5af1893
* Wed Mar 28 2018 oneukum@suse.com
- usbip: vudc_tx: fix v_send_ret_submit() vulnerability to null
  xfer buffer (bsc#1085539).
- commit cba3218
* Wed Mar 28 2018 aaptel@suse.com
- cifs: Select all required crypto modules (bsc#1085536).
- commit 23399f9
* Wed Mar 28 2018 aaptel@suse.com
- cifs: release auth_key.response for reconnect (bsc#1085536).
- commit 0221ea3
* Wed Mar 28 2018 aaptel@suse.com
- cifs: release cifs root_cred after exit_cifs (bsc#1085536).
- commit 5fcee93
* Wed Mar 28 2018 aaptel@suse.com
- cifs: check rsp for NULL before dereferencing in SMB2_open
  (bsc#1085536).
- commit bb4352e
* Wed Mar 28 2018 oneukum@suse.com
- usbip: remove kernel addresses from usb device and urb debug
  msgs (bsc#1085539).
- usbip: fix vudc_rx: harden CMD_SUBMIT path to handle malicious
  input (bsc#1085539).
- commit 6015ddb
* Wed Mar 28 2018 oneukum@suse.com
- usbip: fix usbip bind writing random string after command in
  match_busid (bsc#1085539).
- commit 251451b
* Wed Mar 28 2018 msuchanek@suse.de
- powerpc/64s: Fix i-side SLB miss bad address handler saving
  nonvolatile GPRs (bsc#1065729).
- commit 5dca109
* Wed Mar 28 2018 oneukum@suse.com
- usbip: prevent leaking socket pointer address in messages
  (bsc#1085539).
- commit c149b42
* Wed Mar 28 2018 lpechacek@suse.com
- powerpc/livepatch: Fix livepatch stack access (bsc#1086660).
- commit 37df8c9
* Wed Mar 28 2018 oneukum@suse.com
- usbip: stub: stop printing kernel pointer addresses in messages
  (bsc#1085539).
- commit 9f24363
* Wed Mar 28 2018 oneukum@suse.com
- usbip: vhci: stop printing kernel pointer addresses in messages
  (bsc#1085539).
- commit dbda174
* Wed Mar 28 2018 oneukum@suse.com
- blacklist.conf: we do not build the tools
- commit 24b7f9c
* Wed Mar 28 2018 msuchanek@suse.de
- Update patches.arch/powerpc-tm-Flush-TM-only-if-CPU-has-TM-feature.patch
  (bsc#1075746, bsc#1087231, CVE-2018-1091).
- commit 7102e9a
* Wed Mar 28 2018 oneukum@suse.com
- blacklist.conf: false positive
- commit d595303
* Wed Mar 28 2018 oneukum@suse.com
- usbnet: fix alignment for frames with no ethernet header
  (bsc#1085539).
- Refresh
  patches.suse/0002-Add-a-void-suse_kabi_padding-placeholder-to-some-USB.patch.
- commit 45660b1
* Wed Mar 28 2018 oneukum@suse.com
- uwb: properly check kthread_run return value (bsc#1085536).
- commit f546456
* Wed Mar 28 2018 oneukum@suse.com
- uwb: ensure that endpoint is interrupt (bsc#1085536).
- commit 5aba24e
* Wed Mar 28 2018 oneukum@suse.com
- xhci: Don't add a virt_dev to the devs array before it's fully
  allocated (bsc#1085539).
- commit df88c42
* Wed Mar 28 2018 oneukum@suse.com
- xhci: Cleanup current_cmd in xhci_cleanup_command_queue()
  (bsc#1085536).
- commit b7e5b94
* Wed Mar 28 2018 oneukum@suse.com
- xhci: Identify USB 3.1 capable hosts by their port protocol
  capability (bsc#1085536).
- commit bd7eec8
* Wed Mar 28 2018 oneukum@suse.com
- Revert "xhci: Limit USB2 port wake support for AMD Promontory
  hosts" (bsc#1085536).
- commit 6bc0fd3
* Wed Mar 28 2018 oneukum@suse.com
- xhci: Fix sleeping with spin_lock_irq() held in ASmedia 1042A
  workaround (bsc#1085536).
- commit bb7b728
* Wed Mar 28 2018 neilb@suse.com
- staging: ncpfs: memory corruption in ncp_read_kernel()
  (bsc#1086162, CVE-2018-8822).
- commit 4da6eb3
* Tue Mar 27 2018 jgross@suse.com
- /pirq: fix error path cleanup when binding MSIs (bnc#1065600).
- commit 01219ee
* Tue Mar 27 2018 jgross@suse.com
- x86/mm: Fix {pmd,pud}_{set,clear}_flags() (bnc#1065600).
- commit f6df79c
* Tue Mar 27 2018 jgross@suse.com
- xen/balloon: Mark unallocated host memory as UNUSABLE
  (bnc#1065600).
- commit d2ace39
* Tue Mar 27 2018 jgross@suse.com
- x86-64/Xen: eliminate W+X mappings (bnc#1065600).
- commit df523b5
* Tue Mar 27 2018 oneukum@suse.com
- xhci: fix wrong endpoint ESIT value shown in tracing
  (bsc#1085536).
- commit 33411cf
* Tue Mar 27 2018 oneukum@suse.com
- xhci: fix finding correct bus_state structure for USB 3.1 hosts
  (bsc#1085536).
- commit 85ca58c
* Tue Mar 27 2018 oneukum@suse.com
- blacklist.conf: we do not buil the tools
- commit a686bd3
* Tue Mar 27 2018 oneukum@suse.com
- uas: fix comparison for error code (bsc#1051943).
- commit 3e3561a
* Tue Mar 27 2018 oneukum@suse.com
- usb: uas: unconditionally bring back host after reset
  (bsc#1051943).
- commit 323a206
* Tue Mar 27 2018 oneukum@suse.com
- blacklist.conf: patch changes only logging
- commit ac5efdb
* Tue Mar 27 2018 oneukum@suse.com
- blacklist.conf:subsystem not used
- commit 695a5dd
* Tue Mar 27 2018 msuchanek@suse.de
- net: ibm: ibmveth: constify vio_device_id (bsc#1061843).
- ibmveth: properly unwind on init errors (bsc#1061843).
- net: ibm: ibmveth: constify dev_pm_ops structures (bsc#1061843).
- commit da73308
* Tue Mar 27 2018 oneukum@suse.com
- USB: serial: io_edgeport: fix possible sleep-in-atomic
  (bsc#1085539).
- usb: misc: usb3503: make sure reset is low for at least 100us
  (bsc#1085539).
- commit 4030478
* Tue Mar 27 2018 oneukum@suse.com
- USB: serial: cp210x: add new device ID ELV ALC 8xxx
  (bsc#1085539).
- commit 885cc1c
* Tue Mar 27 2018 jthumshirn@suse.de
- Update
  patches.drivers/nvmet_fc-prevent-new-io-rqsts-in-possible-isr-comple.patch
  (bsc#1083575).
- commit 44b0542
* Tue Mar 27 2018 oneukum@suse.com
- USB: serial: cp210x: add IDs for LifeScan OneTouch Verio IQ
  (bsc#1085539).
- commit de14177
* Tue Mar 27 2018 oneukum@suse.com
- blacklist.conf: subsystem not used
- commit 0406ef2
* Tue Mar 27 2018 oneukum@suse.com
- USB: fix usbmon BUG trigger (bsc#1085539).
- commit 4896206
* Tue Mar 27 2018 oneukum@suse.com
- usb: xhci: Add XHCI_TRUST_TX_LENGTH for Renesas uPD720201
  (bsc#1085539).
- commit 4a1b6e3
* Tue Mar 27 2018 oneukum@suse.com
- USB: serial: ftdi_sio: add id for Airbus DS P8GR (bsc#10855539).
- commit 8912afa
* Tue Mar 27 2018 oneukum@suse.com
- USB: serial: option: adding support for YUGA CLM920-NC5
  (bsc#1085539).
- commit 651ceb3
* Tue Mar 27 2018 oneukum@suse.com
- USB: serial: qcserial: add Sierra Wireless EM7565 (bsc#1085539).
- commit 814b845
* Tue Mar 27 2018 oneukum@suse.com
- USB: serial: option: add support for Telit ME910 PID 0x1101
  (bsc#1085539).
- commit ccecbba
* Tue Mar 27 2018 oneukum@suse.com
- blacklist.conf: not needed in our configuration
- commit 192f439
* Tue Mar 27 2018 oneukum@suse.com
- usb: Add device quirk for Logitech HD Pro Webcam C925e
  (bsc#1085539).
- commit 2db4499
* Tue Mar 27 2018 oneukum@suse.com
- usb: add RESET_RESUME for ELSA MicroLink 56K (bsc#1085539).
- commit fdc4f36
* Tue Mar 27 2018 mgorman@suse.de
- sched/numa: avoid trapping faults and attempting migration
  of file-backed dirty pages (bnc#1064414 reduce unnecessary
  migrations and numab conflicts).
- commit ca8fdbf
* Tue Mar 27 2018 jeffm@suse.com
- audit: fix memleak in auditd_send_unicast_skb (bsc#1086997).
- commit a70d9a2
* Tue Mar 27 2018 jeffm@suse.com
- crypto: dh - fix memleak in setkey (bsc#1086994).
- commit e6b64ce
* Mon Mar 26 2018 tiwai@suse.de
- sched/sysctl: Check user input value of sysctl_sched_time_avg
  (bsc#1086946).
- commit b6afd97
* Mon Mar 26 2018 tiwai@suse.de
- brcmsmac: allocate ucode with GFP_KERNEL (bsc#1085174).
- commit f82808c
* Mon Mar 26 2018 bp@suse.de
- crypto: ccp - add check to get PSP master only when PSP is
  detected (bsc#1063068).
- KVM: x86: Fix device passthrough when SME is active
  (bsc#1084912).
- x86/efi: Free efi_pgd with free_pages() (git-fixes
  d9e9a6418065).
- x86/vsyscall/64: Use proper accessor to update P4D entry
  (git-fixes 49275fef986a).
- scripts/git_sort/git_sort.py:
- commit 0188aa6
* Mon Mar 26 2018 msuchanek@suse.de
- blacklist
  c179ea270100 powerpc/kprobes: Fix warnings from __this_cpu_read() on preempt kernels
  94d3084a0f8c powerpc/32s: Fix compile error with CONFIG_PPC_PTDUMP
- commit f6243d1
* Mon Mar 26 2018 msuchanek@suse.de
- powerpc/bpf/jit: Fix 32-bit JIT for seccomp_data access
  (bsc#1065729).
- commit b6d0e6a
* Mon Mar 26 2018 oneukum@suse.com
- usb: dwc3: of-simple: fix missing clk_disable_unprepare
  (bsc#1085539).
- commit c383569
* Mon Mar 26 2018 oneukum@suse.com
- usb: dwc3: gadget: Wait longer for controller to end command
  processing (bsc#1085539).
- commit ccd154d
* Mon Mar 26 2018 oneukum@suse.com
- usb: xhci: fix TDS for MTK xHCI1.1 (bsc#1085539).
- commit 9eac7a6
* Mon Mar 26 2018 oneukum@suse.com
- USB: uas and storage: Add US_FL_BROKEN_FUA for another JMicron
  JMS567 ID (bsc#1085539).
- commit 23cc14b
* Mon Mar 26 2018 msuchanek@suse.de
- Refresh patches.drivers/ibmvnic-Potential-NULL-dereference-in-clean_one_tx_p.patch.
- commit c83e9b6
* Mon Mar 26 2018 oneukum@suse.com
- usb: musb: da8xx: fix babble condition handling (bsc#1085539).
- commit 1be976d
* Mon Mar 26 2018 tiwai@suse.de
- drm/amdgpu: fix prime teardown order (bsc#1051510).
- watchdog: hpwdt: Remove legacy NMI sourcing (bsc#1051510).
- Revert "drm/radeon/pm: autoswitch power state when in balanced
  mode" (bsc#1051510).
- PM / runtime: Update links_count also if !CONFIG_SRCU
  (bsc#1051510).
- watchdog: imx2_wdt: restore previous timeout after
  suspend+resume (bsc#1051510).
- watchdog: hpwdt: fix unused variable warning (bsc#1051510).
- watchdog: hpwdt: Check source of NMI (bsc#1051510).
- watchdog: hpwdt: SMBIOS check (bsc#1051510).
- watchdog: Fix potential kref imbalance when opening watchdog
  (bsc#1051510).
- media: [RESEND] media: dvb-frontends: Add delay to Si2168
  restart (bsc#1051510).
- media: bt8xx: Fix err 'bt878_probe()' (bsc#1051510).
- PCI: designware-ep: Fix ->get_msi() to check MSI_EN bit
  (bsc#1051510).
- PCI: endpoint: Fix find_first_zero_bit() usage (bsc#1051510).
- vgacon: Set VGA struct resource types (bsc#1051510).
- pinctrl: Really force states during suspend/resume
  (bsc#1051510).
- pinctrl: intel: Initialize GPIO properly when used through
  irqchip (bsc#1051510).
- agp/intel: Flush all chipset writes after updating the GGTT
  (bsc#1051510).
- ath10k: handling qos at STA side based on AP WMM enable/disable
  (bsc#1051510).
- rtlwifi: rtl_pci: Fix the bug when inactiveps is enabled
  (bsc#1051510).
- Bluetooth: btqcomsmd: Fix skb double free corruption
  (bsc#1051510).
- Bluetooth: hci_qca: Avoid setup failure on missing rampatch
  (bsc#1051510).
- crypto: cavium - fix memory leak on info (bsc#1051510).
- PM / devfreq: Propagate error from devfreq_add_device()
  (bsc#1051510).
- pinctrl: cherryview: Mask all interrupts on Intel_Strago based
  systems (bsc#1051510).
- drm/exynos: gem: Drop NONCONTIG flag for buffers allocated
  without IOMMU (bsc#1051510).
- PM / runtime: Fix handling of suppliers with disabled runtime PM
  (bsc#1051510).
- crypto: brcm - Explicity ACK mailbox message (bsc#1051510).
- rtl8188eu: Fix a possible sleep-in-atomic bug in
  rtw_disassoc_cmd (bsc#1051510).
- PM: core: Fix device_pm_check_callbacks() (bsc#1051510).
- commit 6b1c180
* Mon Mar 26 2018 oneukum@suse.com
- usb: xhci: fix panic in xhci_free_virt_devices_depth_first
  (bsc#1085539).
- commit 821249d
* Mon Mar 26 2018 tbogendoerfer@suse.de
- qed: Fix MPA unalign flow in case header is split across two
  packets (bsc#1050536 FATE#322898 bsc#1050545 FATE#322893).
- bnxt_en: Return standard Linux error codes for hwrm flow cmds
  (bsc#1050242 FATE#32291).
- bnxt_en: Remove unwanted ovs-offload messages in some conditions
  (bsc#1050242 FATE#32291).
- infiniband: bnxt_re: use BIT_ULL() for 64-bit bit masks
  (bsc#1050244 FATE#322915).
- infiniband: qplib_fp: fix pointer cast (bsc#1050244
  FATE#322915).
- commit 72c0fdb
* Mon Mar 26 2018 oneukum@suse.com
- blacklist.conf: subsystem not used
- commit c778a11
* Mon Mar 26 2018 oneukum@suse.com
- blacklist.conf: subsystem not used
- commit 11379a6
* Mon Mar 26 2018 oneukum@suse.com
- blacklist.conf: subsystem not used
- commit 1fab475
* Mon Mar 26 2018 oneukum@suse.com
- blacklist.conf: subsystem not used
- commit 506214b
* Mon Mar 26 2018 oneukum@suse.com
- blacklist.conf: subsystem not used
- commit 5d07732
* Mon Mar 26 2018 oneukum@suse.com
- USB: serial: usb_debug: add new USB device id (bsc#1085539).
- USB: serial: option: add Quectel BG96 id (bsc#1085539).
- commit c98442a
* Mon Mar 26 2018 tbogendoerfer@suse.de
- svcrdma: Estimate Send Queue depth properly (bsc#1081515).
- svcrdma: Limit RQ depth (bsc#1081515).
- commit 8eb6546
* Mon Mar 26 2018 oneukum@suse.com
- usb: quirks: Add no-lpm quirk for KY-688 USB 3.1 Type-C Hub
  (bsc#1085539).
- commit 4176e03
* Mon Mar 26 2018 oneukum@suse.com
- blacklist.conf: not applicable change to Makefiles
- commit a0544d1
* Mon Mar 26 2018 oneukum@suse.com
- usb: hub: Cycle HUB power when initialization fails
  (bsc#1085539).
- commit d1a83ef
* Mon Mar 26 2018 jroedel@suse.de
- PCI/DPC: Enable DPC only if AER is available (bsc#1082368).
- commit 654d5a4
* Mon Mar 26 2018 msuchanek@suse.de
- powerpc: System reset avoid interleaving oops using die
  synchronisation (bsc#1086791).
- commit 715df69
* Mon Mar 26 2018 msuchanek@suse.de
- powerpc/crash: Remove the test for cpu_online in the IPI
  callback (bsc#1086791).
- powerpc: Do not send system reset request through the oops path
  (bsc#1086791).
- commit fe60432
* Mon Mar 26 2018 msuchanek@suse.de
- get_fs_type: Validate fs type string argument (bsc#1082943).
- commit 709e045
* Mon Mar 26 2018 nborisov@suse.com
- dcache: Add cond_resched in shrink_dentry_list (bsc#1086194).
- commit 413a765
* Mon Mar 26 2018 bpoirier@suse.com
- net: phy: mdio-bcm-unimac: fix potential NULL dereference in
  unimac_mdio_probe() (bsc#1084829 CVE-2018-8043).
- commit 4836f39
* Mon Mar 26 2018 bpoirier@suse.com
- Fix whitespace breakage in series.conf
  Commit ceb4998ac05a ("s390: scrub registers on kernel entry and KVM exit
  (LTC#164304, bsc#1084911).") changed the first line of series.conf.
  Incidentally, the scripts in scripts/git_sort/quilt-mode.sh rely on this
  line being present for the replacement (via the modified quilt) of the
  simple series file in the expanded tree with a link to series.conf.
- commit d49c5e2
* Fri Mar 23 2018 mcgrof@suse.com
- Refresh patches.drivers/0001-module-warn-if-module-init-probe-takes-long.patch.
- commit caebf3e
* Fri Mar 23 2018 msuchanek@suse.de
- KVM: PPC: Book3S HV: Disable tb_offset (bsc#1086196).
- commit 529e36c
* Fri Mar 23 2018 agraf@suse.de
- armv7hl: Disable uacces with memcpy (boo#1080435)
- commit 4e513aa
* Fri Mar 23 2018 tiwai@suse.de
- drm/amdgpu/dce: Don't turn off DP sink when disconnected
  (bsc#1051510).
- commit 15ae848
* Fri Mar 23 2018 tiwai@suse.de
- drm/i915: Disable tv output on i9x5gm (bsc#1086657).
- drm/i915: Specify which engines to reset following
  semaphore/event lockups (FATE#322643 bsc#1055900).
- commit 0838c05
* Fri Mar 23 2018 msuchanek@suse.de
- powerpc: Remove unused flush_dcache_phys_range() (bsc#1065729).
- powerpc/mm/radix: Remove unused code (bsc#1055186, fate#323286,
  git-fixes).
- powerpc/mm: Add tracking of the number of coprocessors using
  a context (bsc#1055014).
- powerpc/64s: Fix lost pending interrupt due to race causing
  lost update to irq_happened (bsc#1065729).
- commit ff3617a
* Fri Mar 23 2018 tiwai@suse.de
- drm/i915/dp: Write to SET_POWER dpcd to enable MST hub
  (bsc#1051510).
- ACPI / watchdog: Fix off-by-one error at resource assignment
  (bsc#1073960).
- Bluetooth: btusb: Fix quirk for Atheros 1525/QCA6174
  (bsc#1082504).
- Bluetooth: btusb: Remove Yoga 920 from the
  btusb_needs_reset_resume_table (bsc#1051510).
- commit ce5f883
* Fri Mar 23 2018 tiwai@suse.de
- Preliminary patch sort / update (again)
- commit 805d5d7
* Fri Mar 23 2018 msuchanek@suse.de
- ibmvnic: Potential NULL dereference in clean_one_tx_pool()
  (bsc#1085224, git-fixes).
- commit 7acb565
* Fri Mar 23 2018 tiwai@suse.de
- supported.conf: Add AMDGPU driver (bsc#1069343)
- commit 591ff59
* Fri Mar 23 2018 mhocko@suse.com
- hugetlbfs: check for pgoff value overflow (bnc#1084353,
  CVE-2018-7740).
- commit 621f100
* Fri Mar 23 2018 glin@suse.com
- test_bpf: Fix testing with CONFIG_BPF_JIT_ALWAYS_ON=y on other
  arches (bsc#1083647).
- commit 4714d41
* Fri Mar 23 2018 glin@suse.com
- Move bpf-introduce-ARG_PTR_TO_MEM_OR_NULL.patch to the sorted section
  The patch was added to the KABI section mistakenly.
- commit 638bcf0
* Fri Mar 23 2018 oneukum@suse.com
- USB: Fix off by one in type-specific length check of BOS SSP
  capability (bsc#1085539).
- commit f57a20f
* Thu Mar 22 2018 mcgrof@suse.com
- xfs: disable per-inode DAX flag (bsc#1085535).
- commit 30f0d9f
* Thu Mar 22 2018 jeffm@suse.com
- Btrfs: fix blk_status_t/errno confusion (bsc#1086457).
- commit 25d99b4
* Thu Mar 22 2018 jeffm@suse.com
- build: fix incompatible pointer warnings with PROVE_RCU=y (bsc#1086527).
- Refresh
  patches.fixes/tcp-dccp-fix-lockdep-splat-in-inet_csk_route_req.patch.
- Refresh
  patches.fixes/tcp-dccp-fix-other-lockdep-splats-accessing-ireq_opt.patch.
- commit 956c819
* Thu Mar 22 2018 oneukum@suse.com
- uas: ignore UAS for Norelsys NS1068(X) chips (bsc#1085539).
- commit e48778e
* Thu Mar 22 2018 oneukum@suse.com
- uas: Always apply US_FL_NO_ATA_1X quirk to Seagate devices
  (bsc#1085539).
- commit 20d01c9
* Thu Mar 22 2018 oneukum@suse.com
- USB: core: Add type-specific length check of BOS descriptors
  (bsc#1085539).
- commit 4eca3f0
* Thu Mar 22 2018 oneukum@suse.com
- usb: host: fix incorrect updating of offset (bsc#1085539).
- commit 1c87c04
* Thu Mar 22 2018 oneukum@suse.com
- USB: ulpi: fix bus-node lookup (bsc#1085539).
- commit 4dc623a
* Thu Mar 22 2018 jeffm@suse.com
- config: update product ID and supported state for openSUSE Leap 15.0
- SUSE_PRODUCT_OPENSUSE_LEAP=y
- SUSE_KERNEL_SUPPORTED=n
- commit 48e5be3
* Thu Mar 22 2018 oneukum@suse.com
- USB: usbfs: Filter flags passed in from user space
  (bsc#1085539).
- commit 489cccb
* Thu Mar 22 2018 oneukum@suse.com
- blacklist.conf: subsystem not used
- commit 371489f
* Thu Mar 22 2018 oneukum@suse.com
- USB: usbfs: compute urb->actual_length for isochronous
  (bsc#1085539).
- commit 5677c73
* Thu Mar 22 2018 oneukum@suse.com
- USB: serial: Change DbC debug device binding ID (bsc#1085539).
- commit 2d8a16d
* Thu Mar 22 2018 oneukum@suse.com
- USB: early: Use new USB product ID and strings for DbC device
  (bsc#1085539).
- commit 6d94237
* Thu Mar 22 2018 oneukum@suse.com
- USB: Add delay-init quirk for Corsair K70 LUX keyboards
  (bsc#1085539).
- commit 8a8f7d0
* Thu Mar 22 2018 oneukum@suse.com
- USB: serial: qcserial: add pid/vid for Sierra Wireless EM7355
  fw update (bsc#1085539).
- commit d2e8e71
* Thu Mar 22 2018 oneukum@suse.com
- USB: serial: metro-usb: stop I/O after failed open
  (bsc#1085539).
- commit 1ee3a90
* Thu Mar 22 2018 tiwai@suse.de
- ath10k: fix invalid STS_CAP_OFFSET_MASK (bsc#1051510).
- ath10k: update tdls teardown state to target (bsc#1051510).
- commit 76d759a
* Thu Mar 22 2018 oneukum@suse.com
- USB: serial: garmin_gps: fix memory leak on probe errors
  (bsc#1085539).
- commit 313cabb
* Thu Mar 22 2018 tiwai@suse.de
- ASoC: wm_adsp: For TLV controls only register TLV get/set
  (bsc#1051510).
- ASoC: sgtl5000: Fix suspend/resume (bsc#1051510).
- ASoC: rt5651: Fix regcache sync errors on resume (bsc#1051510).
- ASoC: nau8825: fix issue that pop noise when start capture
  (bsc#1051510).
- ASoC: rsnd: fixup ADG register mask (bsc#1051510).
- commit 775374f
* Thu Mar 22 2018 oneukum@suse.com
- USB: serial: garmin_gps: fix I/O after failed probe and remove
  (bsc#1085539).
- commit 687813c
* Thu Mar 22 2018 oneukum@suse.com
- usb: phy: tahvo: fix error handling in tahvo_usb_probe()
  (bsc#1085539).
- commit 72163b1
* Thu Mar 22 2018 tiwai@suse.de
- drm/nouveau/kms: remove call to drm_crtc_vblank_off() during
  unload/suspend (FATE#322643,bsc#1055900).
- commit 7187702
* Thu Mar 22 2018 tiwai@suse.de
- drm/nouveau/kms/nv50: update vblank state in response to
  modeset actions (FATE#322643,bsc#1055900).
- Refresh patches.drivers/drm-vblank-Consistent-drm_crtc_-prefix.
- commit d257cff
* Thu Mar 22 2018 tiwai@suse.de
- Preliminary sort/update
- commit edc6792
* Thu Mar 22 2018 oneukum@suse.com
- usb: mtu3: fix error return code in ssusb_gadget_init()
  (bsc#1085539).
- commit 122a412
* Thu Mar 22 2018 oneukum@suse.com
- usb: xhci: Return error when host is dead in xhci_disable_slot()
  (bsc#1085539).
- commit 191f47b
* Thu Mar 22 2018 oneukum@suse.com
- usb: hub: Allow reset retry for USB2 devices on connect bounce
  (bsc#1085536).
- commit 94358bf
* Thu Mar 22 2018 oneukum@suse.com
- USB: serial: metro-usb: add MS7820 device id (bsc#1085536).
- commit 5244c71
* Thu Mar 22 2018 oneukum@suse.com
- usb: quirks: add quirk for WORLDE MINI MIDI keyboard
  (bsc#1085536).
- commit 65b36d5
* Thu Mar 22 2018 jthumshirn@suse.de
- Refresh
  patches.drivers/scsi-qla2xxx-Remove-FC_NO_LOOP_ID-for-FCP-and-FC-NVM.patch.
- commit 5dec0d7
* Thu Mar 22 2018 mcgrof@suse.com
- vfs: Return -ENXIO for negative SEEK_HOLE / SEEK_DATA offsets
  (bsc#1085535).
- commit 9c22a97
* Wed Mar 21 2018 jeffm@suse.com
- btrfs: minimal conversion to errseq_t writeback error reporting
  on fsync (bsc#1086149 bsc#1086285).
- xfs: minimal conversion to errseq_t writeback error reporting
  (bsc#1086285).
- ext4: use errseq_t based error handling for reporting data
  writeback errors (bsc#1086285).
- fs: convert __generic_file_fsync to use errseq_t based reporting
  (bsc#1086149 bsc#1086285).
- block: convert to errseq_t based writeback error tracking
  (bsc#1086285).
- dax: set errors in mapping when writeback fails (bsc#1086149
  bsc#1086285).
- Documentation: flesh out the section in vfs.txt on storing
  and reporting writeback errors (bsc#1086285).
- mm: set both AS_EIO/AS_ENOSPC and errseq_t in mapping_set_error
  (bsc#1086149 bsc#1086285).
- commit 12c97b8
* Wed Mar 21 2018 jeffm@suse.com
- mm: don't TestClearPageError in __filemap_fdatawait_range
  (bsc#1086149 bsc#1086285).
- commit 328af1b
* Wed Mar 21 2018 jeffm@suse.com
- mm: clear AS_EIO/AS_ENOSPC when writeback initiation fails
  (bsc#1086149 bsc#1086285).
- jbd2: don't clear and reset errors after waiting on writeback
  (bsc#1086285).
- buffer: set errors in mapping at the time that the error occurs
  (bsc#1086149 bsc#1086285).
- fs: check for writeback errors after syncing out buffers in
  generic_file_fsync (bsc#1086149 bsc#1086285).
- buffer: use mapping_set_error instead of setting the flag
  (bsc#1086149 bsc#1086285).
- mm: fix mapping_set_error call in me_pagecache_dirty
  (bsc#1086149 bsc#1086285).
- commit 09f9abc
* Wed Mar 21 2018 oneukum@suse.com
- usb: musb: sunxi: Explicitly release USB PHY on exit
  (bsc#1085536).
- commit 04fa959
* Wed Mar 21 2018 oneukum@suse.com
- usb: musb: Check for host-mode using is_host_active() on reset
  interrupt (bsc#1085536).
- commit 3803e19
* Wed Mar 21 2018 oneukum@suse.com
- usb: musb: musb_cppi41: Configure the number of channels for
  DA8xx (bsc#1085536).
- commit 3bbded4
* Wed Mar 21 2018 oneukum@suse.com
- usb: musb: musb_cppi41: Fix cppi41_set_dma_mode() for DA8xx
  (bsc#1085536).
- commit e037007
* Wed Mar 21 2018 oneukum@suse.com
- usb: musb: musb_cppi41: Fix the address of teardown and autoreq
  registers (bsc#1085536).
- commit cd326ce
* Wed Mar 21 2018 oneukum@suse.com
- USB: musb: fix late external abort on suspend (bsc#1085536).
- commit 76b398a
* Wed Mar 21 2018 tiwai@suse.de
- drm/nouveau: Merge pre/postclose hooks (FATE#322643
  bsc#1055900).
- commit 4be949d
* Wed Mar 21 2018 oneukum@suse.com
- USB: musb: fix session-bit runtime-PM quirk (bsc#1085536).
- commit 83d81a2
* Wed Mar 21 2018 oneukum@suse.com
- usb: cdc_acm: Add quirk for Elatec TWN3 (bsc#1085536).
- commit db32900
* Wed Mar 21 2018 oneukum@suse.com
- USB: devio: Revert "USB: devio: Don't corrupt user memory"
  (bsc#1085536).
- commit b735c95
* Wed Mar 21 2018 oneukum@suse.com
- usb: xhci: Handle error condition in xhci_stop_device()
  (bsc#1085536).
- commit 9884645
* Wed Mar 21 2018 oneukum@suse.com
- usb: xhci: Reset halted endpoint if trb is noop (bsc#1085536).
- commit 2b4bd6f
* Wed Mar 21 2018 oneukum@suse.com
- usb: usbtest: fix NULL pointer dereference (bsc#1085536).
- commit ddf19a6
* Wed Mar 21 2018 oneukum@suse.com
- blacklist.conf:
  subsystem not used
- commit f6c209c
* Wed Mar 21 2018 oneukum@suse.com
- blacklist.conf:
  subsystem not used
- commit c1380cf
* Wed Mar 21 2018 oneukum@suse.com
- usb: renesas_usbhs: Fix DMAC sequence for receiving zero-length
  packet (bsc#1085536).
- commit 08c1674
* Wed Mar 21 2018 oneukum@suse.com
- blacklist.conf:
  subsystem not used
- commit 609c138
* Wed Mar 21 2018 oneukum@suse.com
- USB: serial: qcserial: add Dell DW5818, DW5819 (bsc#1085536).
- commit 572bd85
* Wed Mar 21 2018 oneukum@suse.com
- USB: serial: cp210x: add support for ELV TFD500 (bsc#1085536).
- commit 36d66d3
* Wed Mar 21 2018 oneukum@suse.com
- USB: serial: cp210x: fix partnum regression (bsc#1085536).
- commit ef7a186
* Wed Mar 21 2018 oneukum@suse.com
- USB: serial: option: add support for TP-Link LTE module
  (bsc#1085536).
- commit 7e4d166
* Wed Mar 21 2018 oneukum@suse.com
- USB: serial: ftdi_sio: add id for Cypress WICED dev board
  (bsc#1085536).
- commit 60faefa
* Wed Mar 21 2018 oneukum@suse.com
- blacklist.conf:
  subsystem not used
- commit 66cadf8
* Wed Mar 21 2018 oneukum@suse.com
- blacklist.conf:
  we do not compiler the driver these patches are for
- commit 3dd4c55
* Wed Mar 21 2018 glin@suse.com
- blacklist.conf: update for minor bpf selftest Makefile change
- commit 2b3dbb0
* Wed Mar 21 2018 ptesarik@suse.cz
- supported.conf: Enable s390-trng (bsc#1085820)
- commit 5ced6c1
* Wed Mar 21 2018 glin@suse.com
- bpf: allow xadd only on aligned memory (bsc#1083647).
- commit e79d0c8
* Wed Mar 21 2018 glin@suse.com
- bpf, arm64: fix out of bounds access in tail call (bsc#1083647).
- commit 4b4e122
* Wed Mar 21 2018 glin@suse.com
- bpf: fix rcu lockdep warning for lpm_trie map_free callback
  (bsc#1083647).
- commit 5acee86
* Wed Mar 21 2018 glin@suse.com
- bpf: fix memory leak in lpm_trie map_free callback function
  (bsc#1083647).
- commit 22440c4
* Wed Mar 21 2018 jeffm@suse.com
- Btrfs: fix log replay failure after unlink and link combination
  (bsc#1086151).
- Btrfs: fix log replay failure after linking special file and
  fsync (bsc#1086150).
- commit 8ea5a6a
* Wed Mar 21 2018 neilb@suse.com
- autofs: revert "autofs: take more care to not update last_used
  on path walk" (git-fixes).
- commit 68bbdc6
* Wed Mar 21 2018 neilb@suse.com
- blacklist.conf:
  Add some unwanted fixes.
- commit 5c4df93
* Tue Mar 20 2018 jeffm@suse.com
- btrfs: fix error handling in free_log_tree (bsc#1086116).
- commit 094871b
* Tue Mar 20 2018 jeffm@suse.com
- btrfs: defer adding raid type kobject until after chunk relocation
  (bsc#1086086).
- btrfs: remove dead create_space_info calls (bsc#1086086).
- btrfs: Remove redundant argument of __link_block_group
  (bsc#1086086).
- btrfs: Refactor update_space_info (bsc#1086086).
- btrfs: Separate space_info create/update (bsc#1086086).
- commit 375db74
* Tue Mar 20 2018 jeffm@suse.com
- REVERT: btrfs: qgroup: Move half of the qgroup accounting time
  out of commit trans (bsc#1083684).
- commit 0442bf4
* Tue Mar 20 2018 tiwai@suse.de
- seccomp: make function __get_seccomp_filter static
  (bsc#1051510).
- commit 0b7ff10
* Tue Mar 20 2018 tiwai@suse.de
- rtc: set the alarm to the next expiring timer (bsc#1051510).
- seccomp: fix the usage of get/put_seccomp_filter() in
  seccomp_get_filter() (bsc#1051510).
- commit 9202bc2
* Tue Mar 20 2018 tiwai@suse.de
- PCI: dwc: Fix enumeration end when reaching root subordinate
  (bsc#1051510).
- PCI: keystone: Fix interrupt-controller-node lookup
  (bsc#1051510).
- PCI: iproc: Fix NULL pointer dereference for BCMA (bsc#1051510).
- PCI: Disable MSI for HiSilicon Hip06/Hip07 only in Root Port
  mode (bsc#1051510).
- mac80211: remove BUG() when interface type is invalid
  (bsc#1051510).
- mac80211_hwsim: enforce PS_MANUAL_POLL to be set after
  PS_ENABLED (bsc#1051510).
- iwlwifi: mvm: avoid dumping assert log when device is stopped
  (bsc#1051510).
- mwifiex: cfg80211: do not change virtual interface during scan
  processing (bsc#1051510).
- iwlwifi: mvm: rs: don't override the rate history in the search
  cycle (bsc#1051510).
- PCI / PM: Force devices to D0 in pci_pm_thaw_noirq()
  (bsc#1051510).
- PCI/ASPM: Use correct capability pointer to program
  LTR_L1.2_THRESHOLD (bsc#1051510).
- PCI/ASPM: Account for downstream device's Port
  Common_Mode_Restore_Time (bsc#1051510).
- PCI/ASPM: Deal with missing root ports in link state handling
  (bsc#1051510).
- PCI/AER: Report non-fatal errors only to the affected endpoint
  (bsc#1051510).
- PCI: Fix race condition with driver_override (bsc#1051510).
- commit 9f73db8
* Tue Mar 20 2018 tiwai@suse.de
- drm/amdgpu:Always save uvd vcpu_bo in VM Mode (bsc#1051510).
- drm/amdgpu:Correct max uvd handles (bsc#1051510).
- drm/amdgpu: Notify sbios device ready before send request
  (bsc#1051510).
- drm/amdgpu: fix KV harvesting (bsc#1051510).
- drm/amdgpu: used cached pcie gen info for SI (v2) (bsc#1051510).
- drm/amd/powerplay: fix power over limit on Fiji (bsc#1051510).
- drm/nouveau: prefer XBGR2101010 for addfb ioctl (bsc#1051510).
- drm/radeon: insist on 32-bit DMA for Cedar on PPC64/PPC64LE
  (bsc#1051510).
- drm/amd/powerplay/smu7: allow mclk switching with no displays
  (bsc#1051510).
- drm/amd/powerplay/vega10: allow mclk switching with no displays
  (bsc#1051510).
- drm/amdkfd: Fix memory leaks in kfd topology (bsc#1051510).
- drm/amdgpu: fix get_max_engine_clock_in_mhz (bsc#1051510).
- drm/amdgpu: always cancel uvd idle handler in uvd suspend
  (bsc#1051510).
- drm/amdgpu:fix virtual dce bug (bsc#1051510).
- drm/edid: set ELD connector type in drm_edid_to_eld()
  (bsc#1051510).
- drm/amdgpu: rename rdev to adev (bsc#1051510).
- commit b85f5b3
* Tue Mar 20 2018 jslaby@suse.cz
- x86/speculation: Remove Skylake C2 from Speculation Control
  microcode blacklist (bnc#1068032 bnc#1085823 CVE-2017-5715).
- x86/spectre_v2: Don't check microcode versions when running
  under hypervisors (bnc#1068032 bnc#1085823 CVE-2017-5715).
- x86/speculation: Correct Speculation Control microcode blacklist
  again (bnc#1068032 bnc#1085823 CVE-2017-5715).
- x86/speculation: Update Speculation Control microcode blacklist
  (bnc#1068032 bnc#1085823 CVE-2017-5715).
- commit 1b63bae
* Tue Mar 20 2018 oneukum@suse.com
- blacklist.conf:
  subsystem not used
- commit ab9f3ef
* Tue Mar 20 2018 oneukum@suse.com
- USB: cdc-wdm: ignore -EPIPE from GetEncapsulatedResponse
  (bsc#1085536).
- commit 8f1dae7
* Tue Mar 20 2018 jslaby@suse.cz
- x86/enter: Use IBRS on syscall and interrupts (bsc#1068032
  CVE-2017-5753).
- x86/enter: Create macros to restrict/unrestrict Indirect Branch
  Speculation (bsc#1068032 CVE-2017-5753).
- x86/idle: Control Indirect Branch Speculation in idle
  (bsc#1068032 CVE-2017-5753).
- x86/speculation: Add inlines to control Indirect Branch
  Speculation (bsc#1068032 CVE-2017-5753).
- x86/speculation: Add basic IBRS support infrastructure
  (bsc#1068032 CVE-2017-5753).
- x86/spectre: Check CONFIG_RETPOLINE in command line parser
  (bnc#1068032 bnc#1085823 CVE-2017-5715).
- commit d36b0df
* Tue Mar 20 2018 oneukum@suse.com
- USB: devio: Don't corrupt user memory (bsc#1085536).
- commit b67cff4
* Tue Mar 20 2018 oneukum@suse.com
- USB: devio: Prevent integer overflow in proc_do_submiturb()
  (bnc#1085536).
- commit 05a6bea
* Tue Mar 20 2018 oneukum@suse.com
- blacklist.conf: driver is not used
- commit 9e98cbf
* Tue Mar 20 2018 oneukum@suse.com
- blacklist.conf: driver is not used
- commit 5ab00b7
* Tue Mar 20 2018 oneukum@suse.com
- usb-storage: unusual_devs entry to fix write-access regression
  for Seagate external drives (bsc#1085536).
- commit 978c2cc
* Tue Mar 20 2018 oneukum@suse.com
- usb-storage: fix bogus hardware error messages for ATA pass-thru
  devices (bsc#1085536).
- commit b53e42c
* Tue Mar 20 2018 oneukum@suse.com
- blacklist.conf: driver is not compiled
- commit d28686d
* Tue Mar 20 2018 oneukum@suse.com
- usb: dwc3: ep0: fix DMA starvation by assigning req->trb on ep0
  (bsc#1085536).
- commit 3bc98c7
* Tue Mar 20 2018 oneukum@suse.com
- usb: host: xhci-plat: allow sysdev to inherit from ACPI
  (bsc#1085536).
- commit f97459a
* Tue Mar 20 2018 jslaby@suse.cz
- x86/speculation: Move firmware_restrict_branch_speculation_*()
  from C to CPP (bnc#1068032 bnc#1085823 CVE-2017-5715).
- commit 0e9f8e3
* Tue Mar 20 2018 oneukum@suse.com
- usb: pci-quirks.c: Corrected timeout values used in handshake
  (bsc#1085536).
- commit dd7714b
* Tue Mar 20 2018 oneukum@suse.com
- usb: xhci: Free the right ring in xhci_add_endpoint()
  (bsc#1085336).
- commit a4d34c5
* Tue Mar 20 2018 jslaby@suse.cz
- x86/cpu/bugs: Make retpoline module warning conditional
  (bnc#1068032 CVE-2017-5715).
- x86/speculation: Use IBRS if available before calling into
  firmware (bnc#1068032 CVE-2017-5715).
- Refresh
  patches.arch/x86-cpufeatures-clean-up-spectre-v2-related-cpuid-flags.patch.
  This is only IBRS_FW from upstream. The out-of-tree IBRS proper will
  come as a separate PR later. (bnc#1085823)
- commit 04d2542
* Tue Mar 20 2018 oneukum@suse.com
- usb: Increase quirk delay for USB devices (bsc#1085536).
- commit 5e12030
* Tue Mar 20 2018 ptesarik@suse.cz
- KVM: s390: provide only a single function for setting the tod
  (fix SCK) (bsc#1085269).
- commit 8b5d3bf
* Tue Mar 20 2018 ptesarik@suse.cz
- KVM: s390: consider epoch index on TOD clock syncs
  (bsc#1085269).
- commit a15ff18
* Tue Mar 20 2018 ptesarik@suse.cz
- KVM: s390: consider epoch index on hotplugged CPUs
  (bsc#1085269).
- commit 9a02e48
* Tue Mar 20 2018 ptesarik@suse.cz
- KVM: s390: take care of clock-comparator sign control
  (bsc#1085269).
- commit 6c10fe8
* Tue Mar 20 2018 jkosina@suse.cz
- series.conf: re-sort after script bugfix
- commit 91f9daf
* Tue Mar 20 2018 mbrugger@suse.com
- arm64: Run enable method for errata work arounds on late CPUs
  (bsc#1068032).
- arm64: cpufeature: __this_cpu_has_cap() shouldn't stop early
  (bsc#1068032).
- arm64: capabilities: Handle duplicate entries for a capability
  (bsc#1068032).
- commit c010a8c
* Tue Mar 20 2018 bpoirier@suse.com
- rpm/config.sh: Enable checking the sorted patches section of series.conf in pre-commit hook
- commit f9b47cc
* Tue Mar 20 2018 bpoirier@suse.com
- Refresh
  patches.drivers/scsi-lpfc-change-copyright-of-12.0.0.1-modified-files-to.patch.
- Refresh
  patches.drivers/scsi-lpfc-code-cleanup-for-128byte-wqe-data-type.patch.
- Refresh
  patches.drivers/scsi-lpfc-fix-mailbox-wait-for-post_sgl-mbox-command.patch.
- Refresh
  patches.drivers/scsi-lpfc-fix-scsi-lun-discovery-when-port-configured-for.patch.
- Refresh
  patches.drivers/scsi-lpfc-memory-allocation-error-during-driver-start-up-on.patch.
- Refresh
  patches.drivers/scsi-lpfc-streamline-nvme-initiator-wqe-setup.patch.
- Refresh
  patches.drivers/scsi-lpfc-streamline-nvme-targe6t-wqe-setup.patch.
- Refresh
  patches.drivers/scsi-lpfc-update-driver-version-to-12.0.0.1.patch.
- commit e04e333
* Mon Mar 19 2018 tiwai@suse.de
- Input: mms114 - fix license module information (bsc#1051510).
- platform/x86: mlx-platform: fix module aliases (bsc#1051510).
- media: c8sectpfe: fix potential NULL pointer dereference in
  c8sectpfe_timer_interrupt (bsc#1051510).
- Input: psmouse - fix Synaptics detection when protocol is
  disabled (bsc#1051510).
- crypto: seqiv - Remove unused alg/spawn variable (bsc#1051510).
- crypto: caam/qi - use correct print specifier for size_t
  (bsc#1051510).
- PM / runtime: Drop children check from __pm_runtime_set_status()
  (bsc#1051510).
- Input: adxl34x - do not treat FIFO_MODE() as boolean
  (bsc#1051510).
- media: coda: disable BWB only while decoding on CODA 960
  (bsc#1051510).
- crypto: caam/qi - fix AD length endianness in S/G entry
  (bsc#1051510).
- crypto: caam/qi - handle large number of S/Gs case
  (bsc#1051510).
- ACPI / PM / EC: Flush all EC work in acpi_freeze_sync()
  (bsc#1051510).
- crypto: testmgr - Reenable sha1/aes in FIPS mode (bsc#1051510).
- commit 49cf21e
* Mon Mar 19 2018 mkubecek@suse.cz
- netfilter: ebtables: fix erroneous reject of last rule
  (CVE-2018-1068 bsc#1085107).
- netfilter: ebtables: CONFIG_COMPAT: don't trust userland offsets
  (CVE-2018-1068 bsc#1085107).
- commit caa60e7
* Mon Mar 19 2018 mkubecek@suse.cz
- series.conf: refresh
  Ran series_sort.py (no effect on expanded tree).
- commit c5e3798
* Mon Mar 19 2018 msuchanek@suse.de
- kernel-*.spec: remove remaining occurences of %%release from dependencies
  There is a mix of %%release and %%source_rel in manually added
  dependencies and the %%release dependencies tend to fail due to rebuild
  sync issues. So get rid of them.
- commit b4ec514
* Mon Mar 19 2018 msuchanek@suse.de
- ibmvnic: Remove unused TSO resources in TX pool structure
  (bsc#1085224).
- commit c081465
* Mon Mar 19 2018 msuchanek@suse.de
- ibmvnic: Update TX pool cleaning routine (bsc#1085224).
- commit 9804de0
* Mon Mar 19 2018 msuchanek@suse.de
- Refresh metadata of ibmvnic patches
  Refresh patches.drivers/ibmvnic-Generalize-TX-pool-structure.patch.
  Refresh patches.drivers/ibmvnic-Update-and-clean-up-reset-TX-pool-routine.patch.
  Refresh patches.drivers/ibmvnic-Update-release-TX-pool-routine.patch
  Refresh patches.drivers/ibmvnic-Update-TX-pool-initialization-routine.patch.
  Refresh patches.drivers/ibmvnic-Update-TX-and-TX-completion-routines.patch.
  Refresh patches.drivers/ibmvnic-Improve-TX-buffer-accounting.patch.
- commit 36929d0
* Mon Mar 19 2018 yousaf.kaukab@suse.com
- PCI: Remove redundant probes for device reset support
  (bsc#1084889).
- PCI: Probe for device reset support during enumeration
  (bsc#1084889).
- ACPI / CPPC: Use 64-bit arithmetic instead of 32-bit
  (bsc#1084771).
- ACPI: CPPC: remove initial assignment of pcc_ss_data
  (bsc#1084771).
- ACPI / CPPC: Fix KASAN global out of bounds warning
  (bsc#1084771).
- PCI: Avoid slot reset if bridge itself is broken (bsc#1084918).
- PCI: Avoid bus reset if bridge itself is broken (bsc#1084918).
- ACPI / CPPC: Make CPPC ACPI driver aware of PCC subspace IDs
  (bsc#1084771).
- mailbox: PCC: Move the MAX_PCC_SUBSPACES definition to header
  file (bsc#1084771).
- mailbox: pcc: Drop uninformative output during boot
  (bsc#1084771).
- ACPI: processor: use dev_dbg() instead of dev_warn() when CPPC
  probe failed (bsc#1084771).
- mailbox: pcc: Fix crash when request PCC channel 0
  (bsc#1084771).
- ACPICA: Add support for new PCCT subtables (bsc#1084771).
- commit 7fecb4d
* Sun Mar 18 2018 mbrugger@suse.com
- Refresh patches.drivers/net-hns-Fix-ethtool-private-flags.patch.
- commit 30b4cfe
* Sat Mar 17 2018 tiwai@suse.de
- ALSA: hda: add dock and led support for HP ProBook 640 G2
  (bsc#1052235).
- ALSA: hda: add dock and led support for HP EliteBook 820 G3
  (bsc#1052235).
- commit d23a5b8
* Sat Mar 17 2018 tiwai@suse.de
- drm/radeon: fix prime teardown order (bsc#1051510).
- drm/radeon: fix KV harvesting (bsc#1051510).
- commit dbeae71
* Sat Mar 17 2018 tiwai@suse.de
- drm/i915/gvt: Correct the privilege shadow batch buffer address
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: keep oa config in shadow ctx (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Add runtime_pm_get/put into gvt_switch_mmio
  (FATE#322643 bsc#1055900).
- drm/nouveau/bl: Fix oops on driver unbind (bsc#1051510).
- drm/i915: Kick the rps worker when changing the boost frequency
  (FATE#322643 bsc#1055900).
- drm/i915: Only prune fences after wait-for-all (FATE#322643
  bsc#1055900).
- drm/i915: Enable VBT based BL control for DP (FATE#322643
  bsc#1055900).
- drm/i915: Suspend submission tasklets around wedging
  (FATE#322643 bsc#1055900).
- drm/i915/perf: fix perf stream opening lock (FATE#322643
  bsc#1055900).
- commit 7928411
* Sat Mar 17 2018 mcgrof@suse.com
- buffer: use mapping_set_error instead of setting the flag (bsc#1085535).
- commit e58067e
* Sat Mar 17 2018 mcgrof@suse.com
- buffer: set errors in mapping at the time that the error occurs (bsc#1085535).
- commit 98a5540
* Fri Mar 16 2018 mcgrof@suse.com
- xfs: Properly retry failed dquot items in case of error during buffer writeback (bsc#1085535, bsc#1085737).
- commit bd133bd
* Fri Mar 16 2018 mcgrof@suse.com
- xfs: fortify xfs_alloc_buftarg error handling (bsc#1085535).
- commit 6d33267
* Fri Mar 16 2018 mcgrof@suse.com
- xfs: fix forgotten rcu read unlock when skipping inode reclaim (bsc#1085535).
- commit 045fde2
* Fri Mar 16 2018 mcgrof@suse.com
- xfs: check if an inode is cached and allocated (bsc#1085535).
- commit 4678d27
* Fri Mar 16 2018 mcgrof@suse.com
- xfs: return a distinct error code value for IGET_INCORE cache misses (bsc#1085535)
- commit d7b171e
* Fri Mar 16 2018 mcgrof@suse.com
- xfs: move two more RT specific functions into CONFIG_XFS_RT (bsc#1085535, bsc#1073411).
- commit 92df594
* Fri Mar 16 2018 mcgrof@suse.com
- xfs: trim writepage mapping to within eof (bsc#1085535, bsc#1073411).
- commit e28559b
* Fri Mar 16 2018 mcgrof@suse.com
- xfs: cancel dirty pages on invalidation (bsc#1085535, bsc#1073406).
- commit 459af78
* Fri Mar 16 2018 mcgrof@suse.com
- xfs: don't change inode mode if ACL update fails (bsc#1085535, bsc#1073406).
- commit a513898
* Fri Mar 16 2018 mcgrof@suse.com
- xfs: move more RT specific code under CONFIG_XFS_RT (bsc#1085535).
- commit d9135ff
* Fri Mar 16 2018 mcgrof@suse.com
- xfs: Don't log uninitialised fields in inode structures (bsc#1085535). - Refresh patches.fixes/xfs-convert-to-new-i_version-API.patch.
- commit ab8d0ef
* Fri Mar 16 2018 mcgrof@suse.com
- xfs: handle racy AIO in xfs_reflink_end_cow (bsc#1085535).
- commit 928bee7
* Fri Mar 16 2018 mcgrof@suse.com
- xfs: always swap the cow forks when swapping extents (bsc#1085535)
- commit 900bc36
* Fri Mar 16 2018 mcgrof@suse.com
- xfs: Capture state of the right inode in xfs_iflush_done (bsc#1085535, bsc#1070682).
- commit b235462
* Fri Mar 16 2018 mcgrof@suse.com
- xfs: perag initialization should only touch m_ag_max_usable for AG 0 (bsc#1085535).
- commit 16cf407
* Fri Mar 16 2018 mcgrof@suse.com
- xfs: update i_size after unwritten conversion in dio completion (bsc#1085535).
- commit 93c9c20
* Fri Mar 16 2018 mcgrof@suse.com
- xfs: validate bdev support for DAX inode flag (bsc#1085535).
- commit eb71679
* Fri Mar 16 2018 mcgrof@suse.com
- xfs: report zeroed or not correctly in xfs_zero_range() (bsc#1085535).
- commit 6298786
* Fri Mar 16 2018 mcgrof@suse.com
- xfs: evict CoW fork extents when performing finsert/fcollapse (bsc#1085535).
- commit dc06c2e
* Fri Mar 16 2018 jeffm@suse.com
- iomap_dio_rw: Allocate AIO completion queue before submitting
  dio (bsc#1085711).
- commit 3211750
* Fri Mar 16 2018 mcgrof@suse.com
- xfs: don't unconditionally clear the reflink flag on zero-block files (bsc#1085535).
- commit bcb1820
* Fri Mar 16 2018 jeffm@suse.com
- btrfs: fix lockdep splat in btrfs_alloc_subvolume_writers
  (bsc#1085699).
- commit 73b177a
* Fri Mar 16 2018 mcgrof@suse.com
- xfs: use kmem_free to free return value of kmem_zalloc (bsc#1085535).
- commit 8d1ab0c
* Fri Mar 16 2018 mcgrof@suse.com
- xfs: open code end_buffer_async_write in xfs_finish_page_writeback (bsc#1085535).
- commit 5dc9796
* Fri Mar 16 2018 mcgrof@suse.com
- xfs: don't set v3 xflags for v2 inodes (bsc#1085535).
- commit 2e1a433
* Fri Mar 16 2018 mcgrof@suse.com
- xfs: fix compiler warnings (bsc#1085535).
- commit 231ac4b
* Fri Mar 16 2018 mcgrof@suse.com
- xfs: fix incorrect log_flushed on fsync (bsc#1085535).
- commit 55862a4
* Fri Mar 16 2018 jeffm@suse.com
- btrfs: propagate error to btrfs_cmp_data_prepare caller
  (bsc#1076088).
- commit 20a82e4
* Fri Mar 16 2018 msuchanek@suse.de
- Refresh patches.arch/powerpc-64-Use-barrier_nospec-in-syscall-entry.patch.
- Refresh patches.arch/powerpc-Use-barrier_nospec-in-copy_from_user.patch.
  move barrier after branch
- commit bace443
* Fri Mar 16 2018 jthumshirn@suse.de
- scsi: sg: Re-fix off by one in sg_fill_request_table()
  (bsc#1085654).
- scsi: sg: fixup infoleak when using SG_GET_REQUEST_TABLE
  (bsc#1085654).
- scsi: sg: factor out sg_fill_request_table() (bsc#1085654).
- commit d70aad9
* Fri Mar 16 2018 jthumshirn@suse.de
- Refresh
  patches.drivers/scsi-lpfc-change-copyright-of-12.0.0.1-modified-files-to.patch.
- Refresh
  patches.drivers/scsi-lpfc-code-cleanup-for-128byte-wqe-data-type.patch.
- Refresh
  patches.drivers/scsi-lpfc-fix-mailbox-wait-for-post_sgl-mbox-command.patch.
- Refresh
  patches.drivers/scsi-lpfc-fix-scsi-lun-discovery-when-port-configured-for.patch.
- Refresh
  patches.drivers/scsi-lpfc-memory-allocation-error-during-driver-start-up-on.patch.
- Refresh
  patches.drivers/scsi-lpfc-streamline-nvme-initiator-wqe-setup.patch.
- Refresh
  patches.drivers/scsi-lpfc-streamline-nvme-targe6t-wqe-setup.patch.
- Refresh
  patches.drivers/scsi-lpfc-update-driver-version-to-12.0.0.1.patch.
- commit 7b6b825
* Fri Mar 16 2018 jthumshirn@suse.de
- loop: fix concurrent lo_open/lo_release (bsc#1085643).
- commit ec3edfb
* Fri Mar 16 2018 hare@suse.de
- nvmet_fc: prevent new io rqsts in possible isr completions
  (FATE#323952, FATE#322506).
- commit 03750dd
* Fri Mar 16 2018 hare@suse.de
- nvme_fc: on remoteport reuse, set new nport_id and role
  (bsc#1076760).
- commit 18875d5
* Fri Mar 16 2018 hare@suse.de
- nvme_fc: fix abort race on teardown with lld reject
  (bsc#1083750).
- nvme_fc: io timeout should defer abort to ctrl reset
  (bsc#1085054).
- commit fcde440
* Fri Mar 16 2018 hare@suse.de
- nvme_fc: fix ctrl create failures racing with workq items
  (bsc#1083750).
- commit 9b8dc65
* Fri Mar 16 2018 hare@suse.de
- scripts/git_sort/git_sort.py: Update nvme tree to 4.17
- commit 99db2a2
* Fri Mar 16 2018 jthumshirn@suse.de
- virtio_blk: Fix an SG_IO regression (bsc#1085636).
- commit 2954f97
* Fri Mar 16 2018 jthumshirn@suse.de
- scsi: scsi_transport_fc: fix NULL pointer dereference in
  fc_bsg_job_timeout (bsc#1085634).
- commit 68473f0
* Fri Mar 16 2018 hare@suse.de
- nvme_fc: rework sqsize handling (bsc#1083750).
- nvme-pci: Fix EEH failure on ppc (bsc#1085342).
- commit e100d7e
* Fri Mar 16 2018 hare@suse.de
- nvmet: fix PSDT field check in command format (FATE#323952,
  FATE#322506).
- nvme-pci: Fix nvme queue cleanup if IRQ setup fails
  (FATE#323952, FATE#322506).
- nvmet-loop: use blk_rq_payload_bytes for sgl selection
  (FATE#323952, FATE#322506).
- nvme-rdma: use blk_rq_payload_bytes instead of blk_rq_bytes
  (FATE#323952, FATE#322506).
- nvme-fabrics: don't check for non-NULL module in
  nvmf_register_transport (FATE#323952, FATE#322506).
- nvme-rdma: fix sysfs invoked reset_ctrl error flow (FATE#323952,
  FATE#322506).
- nvmet: Change return code of discard command if not supported
  (FATE#323952, FATE#322506).
- nvme: fix the deadlock in nvme_update_formats (bsc#1083750).
- nvme: Don't use a stack buffer for keep-alive command
  (FATE#323952, FATE#322506).
- nvme: Fix discard buffer overrun (FATE#323952, FATE#322506).
- nvme: delete NVME_CTRL_LIVE --> NVME_CTRL_CONNECTING transition
  (FATE#323952, FATE#322506).
- nvme-rdma: use NVME_CTRL_CONNECTING state to mark init process
  (FATE#323952, FATE#322506).
- commit 5a5189c
* Fri Mar 16 2018 jthumshirn@suse.de
- bsg-lib: don't free job in bsg_prepare_job (bsc#1085630).
- commit 5645dd9
* Fri Mar 16 2018 tiwai@suse.de
- supported.conf: Enable pinctrl/intel modules (FATE#325095,FATE#325124,FATE#322647,FATE#321356)
- commit 34f89b2
* Fri Mar 16 2018 tiwai@suse.de
- Update config files: Enable CONFIG_PINCTRL_DENVERTON for x86_64 (FATE#325124)
- commit 32e2f2c
* Fri Mar 16 2018 tiwai@suse.de
- pinctrl: intel: Add Intel Denverton pin controller support
  (FATE#325124).
- commit 63c5269
* Fri Mar 16 2018 msuchanek@suse.de
- ibmvnic: Fix reset return from closed state (bsc#1084610).
- commit 07460ad
* Fri Mar 16 2018 hare@suse.de
- kabi/severities: Do not blacklist drivers/message/fusion
- commit f791f8f
* Fri Mar 16 2018 hare@suse.de
- block: kyber: fix domain token leak during requeue
  (bsc#1077989).
- blk-mq: don't call io sched's .requeue_request when requeueing
  rq to ->dispatch (bsc#1077989).
- blk-wbt: account flush requests correctly (bsc#1077989).
- blk_rq_map_user_iov: fix error override (bsc#1077989).
- blk-mq: quiesce queue before freeing queue (bsc#1077989).
- block: drain queue before waiting for q_usage_counter becoming
  zero (bsc#1077989).
- block-throttle: avoid double charge (bsc#1077989).
- block: don't let passthrough IO go into .make_request_fn()
  (bsc#1077989).
- ata: fixes kernel crash while tracing ata_eh_link_autopsy event
  (bsc#1077989).
- blk-mq-sched: dispatch from scheduler IFF progress is made in
  - >dispatch (bsc#1077989).
- block,bfq: Disable writeback throttling (bsc#1077989).
- bio_copy_user_iov(): don't ignore ->iov_offset (bsc#1077989).
- more bio_map_user_iov() leak fixes (bsc#1077989).
- block: directly insert blk-mq request from
  blk_insert_cloned_request() (bsc#1077989).
- commit 755e323
* Fri Mar 16 2018 tbogendoerfer@suse.de
- scsi: csiostor: add support for 32 bit port capabilities
  (bsc#1084463).
- commit 2a6691d
* Fri Mar 16 2018 hare@suse.de
- Update config files.
- commit 8f7bcb9
* Fri Mar 16 2018 jthumshirn@suse.de
- dm mpath: fix passing integrity data (bsc#1085599).
- commit 079d71d
* Fri Mar 16 2018 hare@suse.de
- ahci: Add PCI ids for Intel Bay Trail, Cherry Trail and Apollo Lake AHCI (bsc#1077989). - ahci: Allow setting a default LPM policy for mobile chipsets (bsc#1079088). - ahci: Annotate PCI ids for mobile Intel chipsets as such (bsc#1077989). - ata: ahci_brcm: Avoid writing to read-only registers (1079088). - libata: Add the AHCI_HFLAG_NO_WRITE_TO_RO flag (1079088). - libata: Add the AHCI_HFLAG_YES_ALPM flag (1079088). - libata: sata_down_spd_limit should return if driver has not recorded sstatus speed (bsc#1079088). - Refresh patches.fixes/0001-ahci-Add-Intel-Cannon-Lake-PCH-H-PCI-ID.patch.
- commit 20e9c8c
* Fri Mar 16 2018 jthumshirn@suse.de
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-crashes-in-qla2x00_probe_one-on-pro.patch.
  Refresh Patch-mainline
- commit 83e7885
* Fri Mar 16 2018 tiwai@suse.de
- Move sound patches into the sorted section
- commit 9e5a89a
* Fri Mar 16 2018 neilb@suse.com
- NFSv4: handle EINVAL from EXCHANGE_ID better (bsc#1074661).
- commit 328ecd0
* Fri Mar 16 2018 mcgrof@suse.com
- xfs: remove double-underscore integer types (bsc#1085535).
- commit bad7273
* Fri Mar 16 2018 mcgrof@suse.com
- xfs: relog dirty buffers during swapext bmbt owner change (bsc#1085535).
- commit d182840
* Fri Mar 16 2018 mcgrof@suse.com
- xfs: disallow marking previously dirty buffers as ordered (bsc#1085535).
- commit fbe5afe
* Fri Mar 16 2018 mcgrof@suse.com
- xfs: move bmbt owner change to last step of extent swap (bsc#1085535).
- commit b1ccefc
* Fri Mar 16 2018 mcgrof@suse.com
- xfs: don't log dirty ranges for ordered buffers (bsc#1085535).
- commit 1059f79
* Fri Mar 16 2018 mcgrof@suse.com
- xfs: refactor buffer logging into buffer dirtying helper (bsc#1085535).
- commit c4ad563
* Fri Mar 16 2018 mcgrof@suse.com
- xfs: ordered buffer log items are never formatted (bsc#1085535).
- commit bf9d73a
* Fri Mar 16 2018 mcgrof@suse.com
- xfs: remove bli from AIL before release on transaction abort (bsc#1085400).
- commit fe017ba
* Thu Mar 15 2018 brogers@suse.com
- KVM: nVMX: Fix bug of injecting L2 exception into L1
  (bsc#1082743).
- commit c911389
* Thu Mar 15 2018 msuchanek@suse.de
- powerpc/64: barrier_nospec: Add commandline trigger
  (bsc#1068032, bsc#1080157).
- powerpc/64s: barrier_nospec: Add hcall trigger (bsc#1068032,
  bsc#1080157).
- powerpc/64: barrier_nospec: Add debugfs trigger (bsc#1068032,
  bsc#1080157).
- powerpc/64: Patch barrier_nospec in modules (bsc#1068032,
  bsc#1080157).
- powerpc/64s: Add support for ori barrier_nospec patching
  (bsc#1068032, bsc#1080157).
- powerpc/64s: Use barrier_nospec in RFI_FLUSH_SLOT (bsc#1068032,
  bsc#1080157).
- powerpc/64: Use barrier_nospec in syscall entry (bsc#1068032,
  bsc#1080157).
- powerpc: Use barrier_nospec in copy_from_user (bsc#1068032,
  bsc#1080157).
- powerpc: Add barrier_nospec (bsc#1068032, bsc#1080157).
- commit 61e5a68
* Thu Mar 15 2018 msuchanek@suse.de
- rfi-flush: Always enable fallback flush on pseries
  (bsc#1068032).
- rfi-flush: Call setup_rfi_flush() after LPM migration
  (bsc#1068032).
- rfi-flush: Differentiate enabled and patched flush types
  (bsc#1068032).
- rfi-flush: Make it possible to call setup_rfi_flush() again
  (bsc#1068032).
- Delete
  patches.arch/powerpc-pseries-rfi-flush-Call-setup_rfi_flush-after.patch.
- commit bedae0a
* Thu Mar 15 2018 oneukum@suse.com
- Refresh
  patches.suse/0001-Add-a-void-suse_kabi_padding-placeholder-to-some-USB.patch.
  Refresh
  patches.suse/0002-Add-a-void-suse_kabi_padding-placeholder-to-some-USB.patch.
  Added placeholders to new structures and structures likely to see
  additions with USB 3.2
- commit 2e13f72
* Thu Mar 15 2018 mcgrof@suse.com
- xfs: remove unnecessary dirty bli format check for ordered bufs (bsc#1085535, bsc#1085400).
- commit 878b923
* Thu Mar 15 2018 msuchanek@suse.de
- Refresh patches.arch/powerpc-rfi-flush-Move-the-logic-to-avoid-a-redo-int.patch
- commit 15d094c
* Thu Mar 15 2018 msuchanek@suse.de
- Delete patches.arch/powerpc-rfi-flush-Add-DEBUG_RFI-config-option.patch.
- commit c144715
* Thu Mar 15 2018 mcgrof@suse.com
- xfs: release bli from transaction properly on fs shutdown (bsc#1085400).
- commit d1eb889
* Thu Mar 15 2018 mcgrof@suse.com
- xfs: open-code xfs_buf_item_dirty() (bsc#1085535, bsc#1085400).
- commit 0219f88
* Thu Mar 15 2018 mcgrof@suse.com
- xfs: check for race with xfs_reclaim_inode() in xfs_ifree_cluster() (bsc#1085535).
- commit 63625ee
* Thu Mar 15 2018 ptesarik@suse.cz
- s390/entry.S: fix spurious zeroing of r0 (LTC#164304,
  bsc#1084911).
- commit 385e43e
* Thu Mar 15 2018 ptesarik@suse.cz
- s390: do not bypass BPENTER for interrupt system calls
  (LTC#164304, bsc#1084911).
- commit ed1afdf
* Thu Mar 15 2018 mcgrof@suse.com
- xfs: handle -EFSCORRUPTED during head/tail verification (bsc#1085535).
- commit adcbd09
* Thu Mar 15 2018 ptesarik@suse.cz
- s390: Replace IS_ENABLED(EXPOLINE_*) with
  IS_ENABLED(CONFIG_EXPOLINE_*) (LTC#164304, bsc#1084911).
- commit 8bea736
* Thu Mar 15 2018 mcgrof@suse.com
- xfs: fix log recovery corruption error due to tail overwrite (bsc#1085535).
- commit 504e04b
* Thu Mar 15 2018 ptesarik@suse.cz
- s390: introduce execute-trampolines for branches (LTC#164304,
  bsc#1084911).
- commit 8b70679
* Thu Mar 15 2018 oneukum@suse.com
- Thunderbolt: kABI paddings added (bsc#1070681).
- commit 211b2ae
* Thu Mar 15 2018 mcgrof@suse.com
- xfs: always verify the log tail during recovery (bsc#1085535).
- commit 24a67e9
* Thu Mar 15 2018 ptesarik@suse.cz
- s390: run user space and KVM guests with modified branch
  prediction (LTC#164304, bsc#1084911).
- commit 2450b20
* Thu Mar 15 2018 ptesarik@suse.cz
- s390: add optimized array_index_mask_nospec (LTC#164304,
  bsc#1084911).
- commit b8c619a
* Thu Mar 15 2018 mcgrof@suse.com
- xfs: fix recovery failure when log record header wraps log end (bsc#1085535).
- commit 7ffd57a
* Thu Mar 15 2018 ptesarik@suse.cz
- s390: scrub registers on kernel entry and KVM exit (LTC#164304,
  bsc#1084911).
- commit ceb4998
* Thu Mar 15 2018 oneukum@suse.com
- PCI: pciehp: Do not clear Presence Detect Changed during
  initialization (bsc#1070681).
- PCI: pciehp: Fix race condition handling surprise link down
  (bsc#1070681).
- commit c6224de
* Thu Mar 15 2018 ptesarik@suse.cz
- s390: add options to change branch prediction behaviour for
  the kernel (LTC#164304, bsc#1068032, bsc#1084911).
- Delete patches.arch/s390-sles15-99-02-nobp.patch.
- commit ab35499
* Thu Mar 15 2018 oneukum@suse.com
- PCI: Distribute available resources to hotplug-capable bridges
  (bsc#1070681).
- commit c7a131a
* Thu Mar 15 2018 oneukum@suse.com
- PCI: Distribute available buses to hotplug-capable bridges
  (bsc#1070681).
- commit f245576
* Thu Mar 15 2018 mbrugger@suse.com
- watchdog: sbsa: use 32-bit read for WCV (bsc#1083411).
- commit 95be6a2
* Thu Mar 15 2018 mbrugger@suse.com
- scsi: hisi_sas: directly attached disk LED feature for v2 hw
  (bsc#1083411).
- commit 82b07af
* Thu Mar 15 2018 ptesarik@suse.cz
- s390/alternative: use a copy of the facility bit mask
  (LTC#164304, bsc#1084911).
- commit a6eeafb
* Thu Mar 15 2018 mbrugger@suse.com
- net: hns: Fix ethtool private flags (bsc#1085511).
- commit db6e0ea
* Thu Mar 15 2018 ptesarik@suse.cz
- s390/spinlock: add gmb memory barrier (LTC#164304, bsc#1084911).
- commit 60f06f8
* Thu Mar 15 2018 oneukum@suse.com
- PCI: Open-code the two pass loop when scanning bridges
  (bsc#1070681).
- PCI: Add for_each_pci_bridge() helper (bsc#1070681).
- commit 7ef9727
* Thu Mar 15 2018 hare@suse.de
- loop: Fix lost writes caused by missing flag (bsc#1077989).
- block: fix a typo (bsc#1077989).
- block: display the correct diskname for bio (bsc#1077989).
- block: fix the count of PGPGOUT for WRITE_SAME (bsc#1077989).
- genhd: Fix leaked module reference for NVME devices (bsc#1077989).
- scsi: mpt3sas: fix an out of bound write (bsc#1077989).
- scsi: libsas: fix memory leak in sas_smp_get_phy_events() (bsc#1077989).
- block: only bdi_unregister() in del_gendisk() if !GENHD_FL_HIDDEN (bsc#1077989).
- block: wake up all tasks blocked in get_request() (bsc#1077989).
- commit 11bfaef
* Thu Mar 15 2018 jthumshirn@suse.de
- scsi: lpfc: make several unions static, fix non-ANSI prototype
  (bsc#1085387).
- scsi: lpfc: Change Copyright of 12.0.0.1 modified files to 2018
  (bsc#1085387).
- scsi: lpfc: update driver version to 12.0.0.1 (bsc#1085387).
- scsi: lpfc: Memory allocation error during driver start-up on
  power8 (bsc#1085387).
- scsi: lpfc: Fix mailbox wait for POST_SGL mbox command
  (bsc#1085387).
- scsi: lpfc: Fix SCSI lun discovery when port configured for
  both SCSI and NVME (bsc#1085387).
- scsi: lpfc: Streamline NVME Targe6t WQE setup (bsc#1085387).
- scsi: lpfc: Streamline NVME Initiator WQE setup (bsc#1085387).
- scsi: lpfc: Code cleanup for 128byte wqe data type
  (bsc#1085387).
- commit 1cb568e
* Thu Mar 15 2018 yousaf.kaukab@suse.com
- Update config files.
- commit c93abb9
* Thu Mar 15 2018 oneukum@suse.com
- PCI: Move pci_hp_add_bridge() to drivers/pci/probe.c
  (bsc#1070681).
- commit 1eea5d4
* Thu Mar 15 2018 hare@suse.de
- scsi: libsas: notify event PORTE_BROADCAST_RCVD in
  sas_enable_revalidation() (bsc#1085000).
- scsi: libsas: direct call probe and destruct (bsc#1085000).
- scsi: libsas: use flush_workqueue to process disco events
  synchronously (bsc#1085000).
- scsi: libsas: Use new workqueue to run sas event and disco event
  (bsc#1085000).
- scsi: libsas: make the event threshold configurable
  (bsc#1085000).
- scsi: libsas: shut down the PHY if events reached the threshold
  (bsc#1085000).
- scsi: libsas: Use dynamic alloced work to avoid sas event lost
  (bsc#1085000).
- commit 23a9718
* Thu Mar 15 2018 jthumshirn@suse.de
- scsi: qla2xxx: Fix crashes in qla2x00_probe_one on probe failure
  (bsc#1077338).
- commit faf79cf
* Thu Mar 15 2018 rgoldwyn@suse.com
- Correct placement of apparmor-next patches
  This needed a new section for jj/linux-apparmor for apparmor-next
  branch.
- commit 70d2dc4
* Thu Mar 15 2018 hare@suse.de
- qla2xxx: Update driver version to 10.00.00.06-k (bsc#1084570).
- qla2xxx: Fix Async GPN_FT for FCP and FC-NVMe scan
  (bsc#1084570).
- qla2xxx: Cleanup code to improve FC-NVMe error handling
  (bsc#1084570).
- qla2xxx: Fix FC-NVMe IO abort during driver reset (bsc#1084570).
- qla2xxx: Fix retry for PRLI RJT with reason of BUSY
  (bsc#1084570).
- qla2xxx: Remove nvme_done_list (bsc#1084570).
- qla2xxx: Return busy if rport going away (bsc#1084570).
- qla2xxx: Fix n2n_ae flag to prevent dev_loss on PDB change
  (bsc#1084570).
- qla2xxx: Add FC-NVMe abort processing (bsc#1084570).
- qla2xxx: Restore ZIO threshold setting (bsc#1084570).
- qla2xxx: Add changes for devloss timeout in driver
  (bsc#1084570).
- qla2xxx: Set IIDMA and fcport state before
  qla_nvme_register_remote() (bsc#1084570).
- qla2xxx: Remove unneeded message and minor cleanup for FC-NVMe
  (bsc#1084570).
- scsi: qla2xxx: Remove FC_NO_LOOP_ID for FCP and FC-NVMe
  Discovery (bsc#1084569).
- scsi: qla2xxx: Fix NULL pointer crash due to active timer for
  ABTS (bsc#1082979).
- commit b0e8cae
* Thu Mar 15 2018 oneukum@suse.com
- thunderbolt: Mask ring interrupt properly when polling starts
  (bsc#1070681).
- commit 3a626f5
* Thu Mar 15 2018 jthumshirn@suse.de
- s390/qeth: fix IP address lookup for L3 devices (bsc#1085486).
- s390/qeth: fix double-free on IP add/remove race (bsc#1085486).
- s390/qeth: fix IP removal on offline cards (bsc#1085486).
- s390/qeth: improve error reporting on IP add/removal
  (bsc#1085486).
- commit 7ed1eb8
* Thu Mar 15 2018 oneukum@suse.com
- thunderbolt: Allocate ring HopID automatically if requested
  (bsc#1070681).
- commit 70ae42d
* Thu Mar 15 2018 oneukum@suse.com
- thunderbolt: Add polling mode for rings (bsc#1070681).
- commit 3c69806
* Thu Mar 15 2018 tiwai@suse.de
- security/keys: BIG_KEY requires CONFIG_CRYPTO (bsc#1051510).
- commit 1e8d44b
* Thu Mar 15 2018 jthumshirn@suse.de
- Fix sorting
- commit 0515713
* Thu Mar 15 2018 hare@suse.de
- Update patch-header with upstream commit ID
- Refresh
  patches.drivers/qla2xxx-Fixup-locking-for-session-deletion.patch.
- Refresh
  patches.drivers/qla2xxx-do-not-check-login_state-if-no-loop-id-is-as.patch.
- Refresh
  patches.drivers/qla2xxx-ensure-async-flags-are-reset-correctly.patch.
- commit 6ceddbd
* Thu Mar 15 2018 tiwai@suse.de
- staging: rtl8188eu: Fix incorrect response to SIOCGIWESSID
  (bsc#1051510).
- ima: do not update security.ima if appraisal status is not
  INTEGRITY_PASS (bsc#1051510).
- staging: rtl8188eu: avoid a null dereference on pmlmepriv
  (bsc#1051510).
- ima: fix hash algorithm initialization (bsc#1051510).
- staging: bcm2835-audio: Fix memory corruption (bsc#1051510).
- security/keys: rewrite all of big_key crypto (bsc#1051510).
- security/keys: properly zero out sensitive key material in
  big_key (bsc#1051510).
- commit 6649606
* Thu Mar 15 2018 oneukum@suse.com
- thunderbolt: Use spinlock in NHI serialization (bsc#1070681).
- thunderbolt: Use spinlock in ring serialization (bsc#1070681).
- thunderbolt: Move ring descriptor flags to thunderbolt.h
  (bsc#1070681).
- commit a02064a
* Thu Mar 15 2018 msuchanek@suse.de
- ipmi: use dynamic memory for DMI driver override (bsc#1085477).
- workqueue: avoid hard lockups in show_workqueue_state()
  (bsc#1085474).
- kdump: write correct address of mem_section into vmcoreinfo
  (bsc#1052766).
- genirq: Guard handle_bad_irq log messages (bsc#1070194).
- ipmi: Stop timers before cleaning up the module (bsc#1085477).
- kdb: Fix handling of kallsyms_symbol_next() return value
  (bsc#1052766).
- smp/hotplug: Move step CPUHP_AP_SMPCFD_DYING to the correct
  place (bsc#1052766).
- workqueue: Fix NULL pointer dereference (bsc#1085474).
- workqueue: replace pool->manager_arb mutex with a flag
  (bsc#1085474).
- irq/generic-chip: Don't replace domain's name (bsc#1070194).
- smp/hotplug: Handle removal correctly in cpuhp_store_callbacks()
  (bsc#1052766).
- commit 2d0ceb8
* Thu Mar 15 2018 msuchanek@suse.de
- Sort apparmor patch.
- commit 1285305
* Thu Mar 15 2018 tbogendoerfer@suse.de
- RDMA/rxe: Fix rxe_qp_cleanup() (bsc#1050662 FATE#323951).
- RDMA/rxe: Fix a race condition in rxe_requester() (bsc#1050662
  FATE#323951).
- RDMA/rxe: Fix a race condition related to the QP error state
  (bsc#1050662 FATE#323951).
- i40e: don't remove netdev->dev_addr when syncing uc list
  (bsc#1056658 FATE#322188 bsc#1056662 FATE#322186).
- i40e/i40evf: Account for frags split over multiple descriptors
  in check linearize (bsc#1056658 FATE#322188 bsc#1056662
  FATE#322186).
- IB/srpt: Disable RDMA access by the initiator (bsc#1046306
  FATE#322942).
- IB/core: Init subsys if compiled to vmlinuz-core (bsc#1046306
  FATE#322942).
- RDMA/cma: Make sure that PSN is not over max allowed
  (bsc#1046306 FATE#322942).
- i40evf: Use smp_rmb rather than read_barrier_depends
  (bsc#1056658 FATE#322188 bsc#1056662 FATE#322186).
- i40e: Use smp_rmb rather than read_barrier_depends (bsc#1056658
  FATE#322188 bsc#1056662 FATE#322186).
- Ib/hfi1: Return actual operational VLs in port info query
  (bsc#1060463 FATE#323043).
- RDMA/cma: Avoid triggering undefined behavior (bsc#1046306
  FATE#322942).
- IB/opa_vnic: Properly clear Mac Table Digest (bsc#1060463
  FATE#323043).
- IB/opa_vnic: Properly return the total MACs in UC MAC list
  (bsc#1060463 FATE#323043).
- i40e: use the safe hash table iterator when deleting mac filters
  (bsc#1056658 FATE#322188 bsc#1056662 FATE#322186).
- i40e/i40evf: spread CPU affinity hints across online CPUs only
  (bsc#1056658 FATE#322188 bsc#1056662 FATE#322186).
- i40e: fix client notify of VF reset (bsc#1056658 FATE#322188
  bsc#1056662 FATE#322186).
- commit be14663
* Thu Mar 15 2018 tbogendoerfer@suse.de
- Fix sorting
- commit 99f04f6
* Thu Mar 15 2018 jroedel@suse.de
- PCI: Mark AMD Stoney GPU ATS as broken (bsc#1085438).
- x86/platform/uv/BAU: Disable BAU on single hub configurations
  (bsc#1085438).
- x86/platform/uv/BAU: Fix congested_response_us not taking effect
  (bsc#1085438).
- commit f016967
* Thu Mar 15 2018 jroedel@suse.de
- Refresh patches.fixes/x86-mm-pkeys-fix-fill_sig_info_pkey.patch.
- commit be26314
* Thu Mar 15 2018 msuchanek@suse.de
- ibmvfc: Avoid unnecessary port relogin (bsc#1085404).
- commit 0423e5a
* Thu Mar 15 2018 oneukum@suse.com
- thunderbolt: Export ring handling functions to modules
  (bsc#1070681).
- commit 0c97603
* Thu Mar 15 2018 oneukum@suse.com
- thunderbolt: Add support for frame mode (bsc#1070681).
- commit 78125e0
* Thu Mar 15 2018 oneukum@suse.com
- thunderbolt: Configure interrupt throttling for all interrupts
  (bsc#1070681).
- commit c6505dc
* Thu Mar 15 2018 jkosina@suse.cz
- Update config files: run oldconfig on arm64, ppc64le, s390x
- commit 92d9f93
* Thu Mar 15 2018 bpoirier@suse.com
- e1000e: Fix link check race condition (bsc#1056664 FATE#322185).
- Revert "e1000e: Separate signaling for link check/link up"
  (bsc#1056664 FATE#322185).
- e1000e: allocate ring descriptors with dma_zalloc_coherent
  (bsc#1056664 FATE#322185).
- e1000e: Fix check_for_link return value with autoneg off
  (bsc#1056664 FATE#322185).
- e1000e: Avoid missed interrupts following ICR read (bsc#1056664
  FATE#322185).
- e1000e: Fix queue interrupt re-raising in Other interrupt
  (bsc#1056664 FATE#322185).
- Partial revert "e1000e: Avoid receiver overrun interrupt bursts"
  (bsc#1056664 FATE#322185).
- e1000e: Remove Other from EIAC (bsc#1056664 FATE#322185).
- e1000e: Alert the user that C-states will be disabled by
  enabling jumbo frames (bsc#1056664 FATE#322185).
- e1000e: Set HTHRESH when PTHRESH is used (bsc#1056664
  FATE#322185).
- e1000e: Be drop monitor friendly (bsc#1056664 FATE#322185).
- e1000e: apply burst mode settings only on default (bsc#1056664
  FATE#322185).
- drivers: net: e1000e: use setup_timer() helper (bsc#1056664
  FATE#322185).
- commit fd1dad2
* Thu Mar 15 2018 gqjiang@suse.com
- md-cluster: fix wrong condition check in raid1_write_request
  (bsc#1085402).
- commit de51b30
* Thu Mar 15 2018 mcgrof@suse.com
- xfs: quota: fix missed destroy of qi_tree_lock (bnc#1012382, bsc#1085525).
- commit 64fa650
* Thu Mar 15 2018 mcgrof@suse.com
- xfs: ubsan fixes (bnc#1012382, bsc#1085525).
- commit d7cba96
* Thu Mar 15 2018 mcgrof@suse.com
- xfs: quota: check result of register_shrinker() (bnc#1012382, bsc#1085525).
- commit 98da9d7
* Thu Mar 15 2018 mcgrof@suse.com
- xfs: fix log block underflow during recovery cycle verification (bnc#1012382, bsc#1085525).
- commit 967d992
* Thu Mar 15 2018 mcgrof@suse.com
- xfs: fix incorrect extent state in xfs_bmap_add_extent_unwritten_real (bsc#1085525, bnc#1012382).
- commit e1a9c24
* Thu Mar 15 2018 mcgrof@suse.com
- iomap: report collisions between directio and buffered writes
  to userspace (bsc#1074275).
- commit 065d584
* Thu Mar 15 2018 mcgrof@suse.com
- errseq: rename __errseq_set to errseq_set (bsc#1074275).
- commit 76c35ea
* Thu Mar 15 2018 mcgrof@suse.com
- fs: new infrastructure for writeback error handling and
  reporting (bsc#1074275).
- commit 592f3a3
* Thu Mar 15 2018 mcgrof@suse.com
- lib: add errseq_t type and infrastructure for handling it
  (bsc#1074275).
- commit 2949364
* Wed Mar 14 2018 jkosina@suse.cz
- Update config files: qcom=m
- commit 2552aaa
* Wed Mar 14 2018 rgoldwyn@suse.com
- git-sort: correct branch of apparmor repository
  Change branch name from v4.8-aa2.8-out-of-tree to apparmor-next.
- commit d8d3200
* Wed Mar 14 2018 msuchanek@suse.de
- KVM: PPC: Book3S HV: Drop locks before reading guest memory
  (bsc#1061840).
- KVM: PPC: Book3S HV: Make sure we don't re-enter guest without
  XIVE loaded (bsc#1061840).
- commit f67f69d
* Wed Mar 14 2018 msuchanek@suse.de
- powerpc/kernel: Change retrieval of pci_dn (bsc#1078720).
- commit 5779938
* Wed Mar 14 2018 msuchanek@suse.de
- tpm: fix potential buffer overruns caused by bit glitches on
  the bus (bsc#1082555).
- tpm: st33zp24: fix potential buffer overruns caused by bit
  glitches on the bus (bsc#1082555).
- tpm_i2c_infineon: fix potential buffer overruns caused by bit
  glitches on the bus (bsc#1082555).
- tpm_i2c_nuvoton: fix potential buffer overruns caused by bit
  glitches on the bus (bsc#1082555).
- tpm_tis: fix potential buffer overruns caused by bit glitches
  on the bus (bsc#1082555).
- tpm-dev-common: Reject too short writes (bsc#1082555).
- commit e071d12
* Wed Mar 14 2018 msuchanek@suse.de
- powerpc/mm/radix: Split linear mapping on hot-unplug
  (bsc#1065729).
- proc: fix coredump vs read /proc/*/stat race (bsc#1052766).
- powerpc/perf: Fix oops when grouping different pmu events
  (bsc#1065729).
- powerpc/perf: Fix pmu_count to count only nest imc pmus
  (bsc#1065729).
- powerpc/64s: Fix masking of SRR1 bits on instruction fault
  (bsc#1065729).
- powerpc/powernv/idle: Round up latency and residency values
  (bsc#1065729).
- powerpc/kprobes: Disable preemption before invoking probe
  handler for optprobes (bsc#1065729).
- powerpc/ipic: Fix status get and status clear (bsc#1065729).
- powerpc/perf/hv-24x7: Fix incorrect comparison in memord
  (bsc#1065729).
- powerpc/xmon: Avoid tripping SMP hardlockup watchdog
  (bsc#1065729).
- powerpc: Fix DAR reporting when alignment handler faults
  (bsc#1065729).
- powerpc/mm: Use symbolic constants for filtering SRR1 bits on
  ISIs (bsc#1065729).
- commit e8616ce
* Wed Mar 14 2018 tiwai@suse.de
- Re-enable patches.suse/tpm-Downgrade-error-level (bsc#1042535)
  False-positive errors still appear on many machines
- commit 3708692
* Wed Mar 14 2018 tiwai@suse.de
- Move shpinx fix patch into the sorted section
- commit 49924e7
* Wed Mar 14 2018 tiwai@suse.de
- crypto: s5p-sss - Fix kernel Oops in AES-ECB mode (bsc#1051510).
- crypto: caam - fix endless loop when DECO acquire fails
  (bsc#1051510).
- crypto: talitos - fix Kernel Oops on hashing an empty file
  (bsc#1051510).
- crypto: sha512-mb - initialize pending lengths correctly
  (bsc#1051510).
- crypto: aesni - handle zero length dst buffer (bsc#1051510).
- crypto: hash - prevent using keyed hashes without setting key
  (bsc#1051510).
- crypto: hash - annotate algorithms taking optional key
  (bsc#1051510).
- crypto: poly1305 - remove ->setkey() method (bsc#1051510).
- crypto: mcryptd - pass through absence of ->setkey()
  (bsc#1051510).
- crypto: cryptd - pass through absence of ->setkey()
  (bsc#1051510).
- crypto: hash - introduce crypto_hash_alg_has_setkey()
  (bsc#1051510).
- crypto: af_alg - whitelist mask and type (bsc#1051510).
- crypto: x86/twofish-3way - Fix %%rbp usage (bsc#1051510).
- crypto: tcrypt - fix S/G table for test_aead_speed()
  (bsc#1051510).
- crypto: algapi - fix NULL dereference in crypto_remove_spawns()
  (bsc#1051510).
- crypto: n2 - cure use after free (bsc#1051510).
- crypto: mcryptd - protect the per-CPU queue with a lock
  (bsc#1051510).
- crypto: dh - Fix double free of ctx->p (bsc#1051510).
- crypto: tcrypt - fix buffer lengths in test_aead_speed()
  (bsc#1051510).
- crypto: talitos - fix ctr-aes-talitos (bsc#1051510).
- crypto: talitos - fix use of sg_link_tbl_len (bsc#1051510).
- crypto: talitos - fix AEAD for sha224 on non sha224 capable
  chips (bsc#1051510).
- crypto: talitos - fix setkey to check key weakness
  (bsc#1051510).
- crypto: talitos - fix memory corruption on SEC2 (bsc#1051510).
- crypto: talitos - fix AEAD test failures (bsc#1051510).
- crypto: crypto4xx - increase context and scatter ring buffer
  elements (bsc#1051510).
- crypto: aesni - Use GCM IV size constant (bsc#1051510).
- crypto: gcm - add GCM IV size constant (bsc#1051510).
- crypto: ccm - preserve the IV buffer (bsc#1051510).
- crypto: x86/sha1-mb - fix panic due to unaligned access
  (bsc#1051510).
- crypto: x86/sha256-mb - fix panic due to unaligned access
  (bsc#1051510).
- crypto: shash - Fix zero-length shash ahash digest crash
  (bsc#1051510).
- crypto: talitos - Don't provide setkey for non hmac hashing algs
  (bsc#1051510).
- crypto: talitos - fix hashing (bsc#1051510).
- crypto: talitos - fix sha224 (bsc#1051510).
- crypto: drbg - fix freeing of resources (bsc#1051510).
- crypto: ccp - Fix XTS-AES-128 support on v5 CCPs (bsc#1051510).
- crypto: scompress - don't sleep with preemption disabled
  (bsc#1051510).
- crypto: caam/qi - properly set IV after {en,de}crypt
  (bsc#1051510).
- crypto: caam/qi - fix typo in authenc alg driver name
  (bsc#1051510).
- commit 72727a1
* Wed Mar 14 2018 yousaf.kaukab@suse.com
- Update config files.
- commit 36b5fce
* Wed Mar 14 2018 yousaf.kaukab@suse.com
- phy: qcom-ufs: add MODULE_LICENSE tag (bsc#1085301).
- power: reset: zx-reboot: add missing
  MODULE_DESCRIPTION/AUTHOR/LICENSE (bsc#1085301).
- cpufreq: mediatek: add missing MODULE_DESCRIPTION/AUTHOR/LICENSE
  (bsc#1085301).
- commit cfc93a7
* Wed Mar 14 2018 yousaf.kaukab@suse.com
- mmc: mmci: stop building qcom dml as module (bsc#1085301).
- supported.conf:
- commit 5a9b68a
* Wed Mar 14 2018 msuchanek@suse.de
- hwmon: (pmbus) Use 64bit math for DIRECT format values
  (bsc#1052766).
- hwmon: (pmbus/core) Prevent unintentional setting of page to
  0xFF (bsc#1052766).
- commit 54a3243
* Wed Mar 14 2018 msuchanek@suse.de
- cpufreq: powernv: Dont assume distinct pstate values for
  nominal and pmin (bsc#1065729).
- backlight: pwm_bl: Fix overflow condition (bsc#1052766).
- device property: Track owner device of device property
  (bsc#1052766).
- auxdisplay: charlcd: properly restore atomic counter on error
  path (bsc#1052766).
- commit 96648fb
* Wed Mar 14 2018 oneukum@suse.com
- thunderbolt: Move tb_switch_phy_port_from_link() to
  thunderbolt.h (bsc#1070681).
- commit e0e498b
* Wed Mar 14 2018 agraf@suse.de
- lan78xx: Connect phy early (bsc#1085262).
- commit 7b14d88
* Wed Mar 14 2018 msuchanek@suse.de
- KVM: PPC: Book3S HV: Fix guest time accounting with
  VIRT_CPU_ACCOUNTING_GEN (bsc#1061840).
- KVM: PPC: Book3S PR: Fix broken select due to misspelling
  (bsc#1061840).
- commit 31b626e
* Wed Mar 14 2018 oneukum@suse.com
- thunderbolt: Move thunderbolt domain structure to thunderbolt.h
  (bsc#1070681).
- thunderbolt: Move enum tb_cfg_pkg_type to thunderbolt.h
  (bsc#1070681).
- commit 7ab081a
* Wed Mar 14 2018 oneukum@suse.com
- thunderbolt: Add support for XDomain properties (bsc#1070681).
- commit 30b5374
* Wed Mar 14 2018 oneukum@suse.com
- thunderbolt: Remove __packed from ICM message structures
  (bsc#1070681).
- commit 9d00945
* Wed Mar 14 2018 oneukum@suse.com
- byteorder: Move {cpu_to_be32, be32_to_cpu}_array() from
  Thunderbolt to core (bsc#1070681).
- commit e4d3505
* Wed Mar 14 2018 jeffm@suse.com
- rpm/kernel-source.spec.in: Add check-module-license to Sources
  The package builds in the build service but the script won't make it
  into the SRPM if it's not in the Sources list.
- commit 031ed9e
* Wed Mar 14 2018 msuchanek@suse.de
- ibmvnic: Improve TX buffer accounting (bsc#1085224).
- ibmvnic: Update TX and TX completion routines (bsc#1085224).
- ibmvnic: Update TX pool initialization routine (bsc#1085224).
- ibmvnic: Update release RX pool routine (bsc#1085224).
- ibmvnic: Update and clean up reset TX pool routine
  (bsc#1085224).
- ibmvnic: Generalize TX pool structure (bsc#1085224).
- ibmvnic: Fix recent errata commit (bsc#1085239).
- ibmvnic: Handle TSO backing device errata (bsc#1085239).
- ibmvnic: Pad small packets to minimum MTU size (bsc#1085239).
- ibmvnic: Account for VLAN header length in TX buffers
  (bsc#1085239).
- ibmvnic: Account for VLAN tag in L2 Header descriptor
  (bsc#1085239).
- powerpc/xive: Use hw CPU ids when configuring the CPU queues
  (bsc#1085030).
- KVM: PPC: Book3S HV: Enable use of the new XIVE "single
  escalation" feature (bsc#1085030).
- powerpc/xive: Add interrupt flag to disable automatic EOI
  (bsc#1085030).
- powerpc/xive: Remove incorrect debug code (bsc#1085030).
- treewide: make "nr_cpu_ids" unsigned (bsc#1085030).
- commit 32f736d
* Wed Mar 14 2018 agraf@suse.de
- supported.conf: Add lan78xx as supported (bsc#1085262)
- commit 315bd24
* Wed Mar 14 2018 msuchanek@suse.de
- cxl: read PHB indications from the device tree (bsc#1055014).
- cxl: Check if PSL data-cache is available before issue flush
  request (bsc#1055014).
- cxl: Remove function write_timebase_ctrl_psl9() for PSL9
  (bsc#1055014).
- cxl: Enable NORST bit in PSL_DEBUG register for PSL9
  (bsc#1055014).
- commit 0894623
* Wed Mar 14 2018 msuchanek@suse.de
- powerpc/mm: Drop the function native_register_proc_table()
  (bsc#1065729).
- commit 8669224
* Wed Mar 14 2018 msuchanek@suse.de
- powerpc/mm/slice: Remove intermediate bitmap copy (bsc#1065729).
- commit 2120582
* Wed Mar 14 2018 msuchanek@suse.de
- PCI/hotplug: ppc: correct a php_slot usage after free
  (bsc#1065729).
- commit 64ebfbc
* Wed Mar 14 2018 msuchanek@suse.de
- powerpc: Rename plapr routines to plpar (bsc#1065729).
- commit c4bc3eb
* Wed Mar 14 2018 msuchanek@suse.de
- powerpc/64s: Fix NULL AT_BASE_PLATFORM when using DT CPU
  features (bsc#1065729).
- commit ea2ff2c
* Wed Mar 14 2018 msuchanek@suse.de
- powerpc/xmon: Clear all breakpoints when xmon is disabled via
  debugfs (bsc#1072829).
- powerpc/xmon: Setup debugger hooks when first break-point is
  set (bsc#1072829).
- commit b18a100
* Wed Mar 14 2018 msuchanek@suse.de
- Delete patches.arch/powerpc-xmon-Dont-register-sysrq-key-when-kernel-param-xmon-off.patch.
- commit 732f3c8
* Wed Mar 14 2018 rgoldwyn@suse.com
- apparmor: fix resource audit messages when auditing peer (bsc#1084839).
- Refresh patches.apparmor/apparmor-basic-networking-rules.patch.
- commit 18e0246
* Wed Mar 14 2018 tiwai@suse.de
- mac80211_hwsim: fix possible memory leak in hwsim_new_radio_nl()
  (CVE-2018-8087,bsc#1085053).
- commit f65296f
* Wed Mar 14 2018 dchang@suse.com
- r8169: fix RTL8168EP take too long to complete driver
  initialization (bsc#1051510).
- r8169: fix memory corruption on retrieval of hardware statistics
  (bsc#1051510).
- commit 7a2625d
* Tue Mar 13 2018 msuchanek@suse.de
- mkspec: fix perl warning
- commit f15670f
* Tue Mar 13 2018 tiwai@suse.de
- drivers/fsi: Add module license to core driver (bsc#1085115).
- commit 3e3aa12
* Tue Mar 13 2018 tbogendoerfer@suse.de
- RDMA/mlx5: Fix integer overflow while resizing CQ (bsc#1046305
  FATE#322943).
- RDMA/ucma: Check that user doesn't overflow QP state
  (bsc#1046306 FATE#322942).
- RDMA/ucma: Limit possible option size (bsc#1046306 FATE#322942).
- IB/core: Fix possible crash to access NULL netdev (bsc#1046306
  FATE#322942).
- IB/mlx5: Fix an error code in __mlx5_ib_modify_qp() (bsc#1046305
  FATE#322943).
- IB/mlx4: Include GID type when deleting GIDs from HW table
  under RoCE (bsc#1046302 FATE#322945).
- IB/mlx4: Fix corruption of RoCEv2 IPv4 GIDs (bsc#1046302
  FATE#322945).
- commit 0097c5e
* Tue Mar 13 2018 tbogendoerfer@suse.de
- IB/core : Add null pointer check in addr_resolve (bsc#1046306
  FATE#322942).
- IB/core: Fix missing RDMA cgroups release in case of failure
  to register device (bsc#1046306 FATE#322942).
- IB/mlx: Set slid to zero in Ethernet completion struct
  (bsc#1046306 FATE#322942).
- IB/mlx5: Avoid passing an invalid QP type to firmware
  (bsc#1046305 FATE#322943).
- commit 8343347
* Tue Mar 13 2018 tiwai@suse.de
- ALSA: hda/realtek - Make dock sound work on ThinkPad L570
  (bsc#1051510).
- ALSA: hda/realtek - Fix dock line-out volume on Dell Precision
  7520 (bsc#1051510).
- ALSA: hda/realtek: Limit mic boost on T480 (bsc#1051510).
- ALSA: hda/realtek - Add headset mode support for Dell laptop
  (bsc#1051510).
- ALSA: hda/realtek - Add support headset mode for DELL WYSE
  (bsc#1051510).
- ALSA: hda - Fix a wrong FIXUP for alc289 on Dell machines
  (bsc#1051510).
- commit 0199631
* Tue Mar 13 2018 tbogendoerfer@suse.de
- RDMA/bnxt_re: Avoid Hard lockup during error CQE processing
  (bsc#1050244 FATE#322915).
- RDMA/bnxt_re: Fix the ib_reg failure cleanup (bsc#1050244
  FATE#322915).
- RDMA/bnxt_re: Fix incorrect DB offset calculation (bsc#1050244
  FATE#322915).
- RDMA/bnxt_re: Unconditionly fence non wire memory operations
  (bsc#1050244 FATE#322915).
- RDMA/bnxt_re: Avoid system hang during device un-reg
  (bsc#1050244 FATE#322915).
- RDMA/bnxt_re: Fix system crash during load/unload (bsc#1050244
  FATE#322915).
- RDMA/bnxt_re: Synchronize destroy_qp with poll_cq (bsc#1050244
  FATE#322915).
- RDMA/bnxt_re: Unpin SQ and RQ memory if QP create fails
  (bsc#1050244 FATE#322915).
- RDMA/bnxt_re: Disable atomic capability on bnxt_re adapters
  (bsc#1050244 FATE#322915).
- commit a191f43
* Tue Mar 13 2018 tiwai@suse.de
- ALSA: seq: Clear client entry before deleting else at closing
  (CVE-2018-1000004,bsc#1076017).
- ALSA: seq: Fix possible UAF in snd_seq_check_queue()
  (CVE-2018-1000004,bsc#1076017).
- ALSA: hda - Revert power_save option default value
  (bsc#1052235).
- ALSA: seq: Remove superfluous snd_seq_queue_client_leave_cells()
  call (CVE-2018-1000004,bsc#1076017).
- ALSA: seq: More protection for concurrent write and ioctl races
  (CVE-2018-1000004,bsc#1076017).
- ALSA: seq: Don't allow resizing pool in use
  (CVE-2018-1000004,bsc#1076017).
- commit d35b672
* Tue Mar 13 2018 tiwai@suse.de
- i2c: piix4: Fix port number check on release (bsc#1051510).
- commit 0c59e1d
* Tue Mar 13 2018 tiwai@suse.de
- media: m88ds3103: don't call a non-initalized function
  (bsc#1051510).
- mmc: bcm2835: Don't overwrite max frequency unconditionally
  (bsc#1051510).
- ACPI: sbshc: remove raw pointer from printk() message
  (bsc#1051510).
- Revert "apple-gmux: lock iGP IO to protect from vgaarb changes"
  (bsc#1051510).
- media: cxusb, dib0700: ignore XC2028_I2C_FLUSH (bsc#1051510).
- media: dvb-frontends: fix i2c access helpers for KASAN
  (bsc#1051510).
- media: r820t: fix r820t_write_reg for KASAN (bsc#1051510).
- media: pvrusb2: properly check endpoint types (bsc#1051510).
- media: dvb-usb-v2: lmedm04: move ts2020 attach to
  dm04_lme2510_tuner (bsc#1051510).
- media: soc_camera: soc_scale_crop: add missing
  MODULE_DESCRIPTION/AUTHOR/LICENSE (bsc#1051510).
- media: mtk-vcodec: add missing MODULE_LICENSE/DESCRIPTION
  (bsc#1051510).
- gpio: Fix kernel stack leak to userspace (bsc#1051510).
- mac80211: mesh: drop frames appearing to be from us
  (bsc#1051510).
- nl80211: Check for the required netlink attribute presence
  (bsc#1051510).
- leds: core: Fix regression caused by commit 2b83ff96f51d
  (bsc#1051510).
- drm/ttm: check the return value of kzalloc (bsc#1051510).
- led: core: Fix brightness setting when setting delay_off=0
  (bsc#1051510).
- drm/nouveau/pci: do a msi rearm on init (bsc#1051510).
- mac80211_hwsim: Fix a possible sleep-in-atomic bug in
  hwsim_get_radio_nl (bsc#1051510).
- media: dvb: i2c transfers over usb cannot be done from stack
  (bsc#1051510).
- media: s5k6aa: describe some function parameters (bsc#1051510).
- media: usbtv: add a new usbid (bsc#1051510).
- media: rc: sir_ir: detect presence of port (bsc#1051510).
- i2c: i2c-boardinfo: fix memory leaks on devinfo (bsc#1051510).
- i2c: i801: Fix Failed to allocate irq -2147483648 error
  (bsc#1051510).
- mmc: core: Do not leave the block driver in a suspended state
  (bsc#1051510).
- ACPI / EC: Fix regression related to PM ops support in ECDT
  device (bsc#1051510).
- ACPI / bus: Leave modalias empty for devices which are not
  present (bsc#1051510).
- media: Don't do DMA on stack for firmware upload in the AS102
  driver (bsc#1051510).
- media: v4l2-ctrl: Fix flags field on Control events
  (bsc#1051510).
- media: rc: check for integer overflow (bsc#1051510).
- ACPI / EC: Fix regression related to triggering source of EC
  event handling (bsc#1051510).
- ACPI / APEI: remove the unused dead-code for SEA/NMI
  notification type (bsc#1051510).
- ACPI / APEI: adjust a local variable type in
  ghes_ioremap_pfn_irq() (bsc#1051510).
- ACPI / PM: Fix acpi_pm_notifier_lock vs flush_workqueue()
  deadlock (bsc#1051510).
- i2c: piix4: Fix SMBus port selection for AMD Family 17h chips
  (bsc#1051510).
- media: cec: Respond to unregistered initiators, when applicable
  (bsc#1051510).
- media: s5p-cec: add NACK detection support (bsc#1051510).
- media: dvb: i2c transfers over usb cannot be done from stack
  (bsc#1051510).
- nl80211: Define policy for packet pattern attributes
  (bsc#1051510).
- media: uvcvideo: Prevent heap overflow when accessing mapped
  controls (bsc#1051510).
- media: adv7180: add missing adv7180cp, adv7180st i2c device IDs
  (bsc#1051510).
- ACPI: EC: Fix possible issues related to EC initialization order
  (bsc#1051510).
- commit 2fdde9f
* Tue Mar 13 2018 tiwai@suse.de
- Refresh / move APEI ERST fix with upstream version (bsc#1072556).
- commit d6f15a6
* Tue Mar 13 2018 mbenes@suse.cz
- livepatch: Allow to replace even disabled patches (bsc#1071995
  fate#323487).
  Atomic replace, update to v10.
- commit 8ab47ee
* Tue Mar 13 2018 mbenes@suse.cz
- livepatch: Improve dynamic struct klp_object detection and
  manipulation (bsc#1071995 fate#323487).
  Atomic replace, update to v10.
- commit 8dbcd34
* Tue Mar 13 2018 mbenes@suse.cz
- livepatch: Correctly handle atomic replace for not yet loaded
  modules (bsc#1071995 fate#323487).
  Atomic replace, update to v10.
- commit 21d8f42
* Tue Mar 13 2018 mbenes@suse.cz
- Refresh
  patches.drivers/scsi-megaraid_sas-Do-not-use-32-bit-atomic-request-d.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-FC-NVMe-LUN-discovery.patch.
  Move patches to the sorted section.
- commit c676d27
* Tue Mar 13 2018 jlee@suse.com
- Update config files.
  Add CONFIG_IMA_KEYRINGS_PERMIT_SIGNED_BY_BUILTIN_OR_SECONDARY=y
  (bsc#1075517)
- commit f8bf472
* Tue Mar 13 2018 lhenriques@suse.com
- ceph: fix potential memory leak in init_caches() (bsc#1084898).
- ceph: fix dentry leak when failing to init debugfs
  (bsc#1084898).
- libceph, ceph: avoid memory leak when specifying same option
  several times (bsc#1084898).
- ceph: flush dirty caps of unlinked inode ASAP (bsc#1084898).
- commit 0065157
* Tue Mar 13 2018 mbenes@suse.cz
- Refresh patches.suse/livepatch-add-atomic-replace.patch.
  Atomic replace, update to v10.
- commit 01ce0f9
* Tue Mar 13 2018 mbenes@suse.cz
- Refresh
  patches.suse/livepatch-support-separate-list-for-replaced-patches.patch.
  Atomic replace, update to v10.
- commit 4d5d788
* Tue Mar 13 2018 mbenes@suse.cz
- Refresh
  patches.suse/livepatch-initial-support-for-dynamic-structures.patch.
  Atomic replace, update to v10.
- commit 1476fb6
* Tue Mar 13 2018 dchang@suse.com
- e1000e: fix the use of magic numbers for buffer overrun issue
  (bsc#1056664 FATE#322185).
- fm10k: Use smp_rmb rather than read_barrier_depends (bsc#1056660
  FATE#322187).
- ixgbevf: Use smp_rmb rather than read_barrier_depends
  (bsc#1056653 FATE#322190).
- ixgbe: Fix skb list corruption on Power systems (bsc#1056657
  FATE#322189).
- e1000e: fix buffer overrun while the I219 is processing DMA
  transactions (bsc#1056664 FATE#322185).
- e1000e: Avoid receiver overrun interrupt bursts (bsc#1056664
  FATE#322185).
- ixgbe: fix use of uninitialized padding (bsc#1056657
  FATE#322189).
- fm10k: fix mis-ordered parameters in declaration for
  .ndo_set_vf_bw (bsc#1056660 FATE#322187).
- fm10k: ensure we process SM mbx when processing VF mbx
  (bsc#1056660 FATE#322187).
- commit 40b77c1
* Tue Mar 13 2018 dchang@suse.com
- qlcnic: fix deadlock bug (bsc#1050540 FATE#322896).
- e1000: fix disabling already-disabled warning (bsc#1056665
  FATE#322184).
- bnx2x: Improve reliability in case of nested PCI errors
  (bsc#1050319 FATE#322906).
- tg3: Enable PHY reset in MTU change path for 5720 (bsc#1050260
  FATE#322917).
- tg3: Add workaround to restrict 5762 MRRS to 2048 (bsc#1050260
  FATE#322917).
- tg3: Fix rx hang on MTU change with 5717/5719 (bsc#1050260
  FATE#322917).
- igb: Use smp_rmb rather than read_barrier_depends (bsc#1056651
  FATE#322191).
- igbvf: Use smp_rmb rather than read_barrier_depends (bsc#1056643
  FATE#322192).
- sfc: don't warn on successful change of MAC (bsc#1058169
  FATE#322922).
- igb: check memory allocation failure (bsc#1056651 FATE#322191).
- commit cb56e2c
* Tue Mar 13 2018 glin@suse.com
- bpf: one perf event close won't free bpf program attached by
  another perf event (bsc#1083647).
- commit 742d87d
* Mon Mar 12 2018 bp@suse.de
- perf/core: Fix memory leak triggered by perf --namespace
  (git-fixes e422267322cd).
- blacklist.conf:
- commit 049df66
* Mon Mar 12 2018 bp@suse.de
- blacklist.conf:
- Refresh
  patches.drivers/scsi-megaraid_sas-Do-not-use-32-bit-atomic-request-d.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-FC-NVMe-LUN-discovery.patch.
- commit e089071
* Mon Mar 12 2018 rgoldwyn@suse.com
- direct-io: Fix sleep in atomic due to sync AIO (bsc#1084888).
- commit 9abf20b
* Mon Mar 12 2018 jthumshirn@suse.de
- Revert "nvme: create 'slaves' and 'holders' entries for hidden
  controllers" (bsc#1082241).
- commit 7ca03c6
* Sat Mar 10 2018 jeffm@suse.com
- kernel: add release status to kernel build (FATE#325281).
- commit 420b4de
* Sat Mar 10 2018 jeffm@suse.com
- rpm: use %%_sourcedir prefix for release-projects
- rpm: set SUSE_KERNEL_RELEASED based on project name
  Set SUSE_KERNEL_RELEASED in the config only if the project name matches
  a list of projects that are part of official release channels.  This
  list of projects is maintained per-branch.
- commit a391a5b
* Fri Mar  9 2018 jeffm@suse.com
- config: added new 'kvmsmall' flavor
  This flavor is an unreleased internal configuration intended for kernel
  developers to use in simple virtual machines.  It contains only the
  device drivers necessary to use a KVM virtual machine *without* device
  passthrough enabled.  Common local and network file systems are enabled.
  All device mapper targets are enabled.  Only the network and graphics
  drivers for devices that qemu emulates are enabled.  Many subsystems
  enabled in the default kernel are entirely disabled.  This kernel is
  meant to be small and to build very quickly.  There will be no kABI
  stability and its configuration may be changed arbitrarily.
- commit 59711f5
* Fri Mar  9 2018 jthumshirn@suse.de
- Refresh
  patches.drivers/scsi-megaraid_sas-Do-not-use-32-bit-atomic-request-d.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-FC-NVMe-LUN-discovery.patch.
- commit 2532eab
* Fri Mar  9 2018 tiwai@suse.de
- blacklist.conf: Add entries from stable 4.13.x/4.14.x
- commit 2c9c302
* Fri Mar  9 2018 tiwai@suse.de
- iwlwifi: add a new a000 device (bsc#1051510).
- Refresh
  patches.drivers/iwlwifi-add-new-cards-for-a000-series.patch.
- commit 6a92cc7
* Fri Mar  9 2018 tiwai@suse.de
- iwlwifi: mvm: fix the TX queue hang timeout for MONITOR vif type
  (bsc#1051510).
- mac80211: fix the update of path metric for RANN frame
  (bsc#1051510).
- mac80211: use QoS NDP for AP probing (bsc#1051510).
- mac80211: flush hw_roc_start work before cancelling the ROC
  (bsc#1051510).
- mac80211_hwsim: Use proper TX power (bsc#1051510).
- mac80211: fix VLAN handling with TXQs (bsc#1051510).
- commit d44c253
* Fri Mar  9 2018 tiwai@suse.de
- drivers: base: cacheinfo: fix cache type for non-architected
  system cache (bsc#1051510).
- driver core: platform: Don't read past the end of
  "driver_override" buffer (bsc#1051510).
- commit 84a3ffe
* Fri Mar  9 2018 tiwai@suse.de
- Input: synaptics-rmi4 - do not delete interrupt memory too early
  (bsc#1051510).
- Input: trackpoint - force 3 buttons if 0 button is reported
  (bsc#1051510).
- Input: xpad - add support for PDP Xbox One controllers
  (bsc#1051510).
- Input: synaptics-rmi4 - prevent UAF reported by KASAN
  (bsc#1051510).
- Input: ALPS - fix multi-touch decoding on SS4 plus touchpads
  (bsc#1051510).
- Input: elantech - add new icbody type 15 (bsc#1051510).
- dynamic-debug-howto: fix optional/omitted ending line number
  to be LARGE instead of 0 (bsc#1051510).
- Input: elan_i2c - add ELAN060C to the ACPI table (bsc#1051510).
- Input: elan_i2c - add ELAN0611 to the ACPI table (bsc#1051510).
- Input: i8042 - add Gigabyte P57 to the keyboard reset table
  (bsc#1051510).
- Input: xpad - validate USB endpoint type during probe
  (bsc#1051510).
- commit c7a5d22
* Fri Mar  9 2018 tiwai@suse.de
- platform/x86: wmi: Call acpi_wmi_init() later (bsc#1051510).
- platform/x86: asus-wireless: send an EV_SYN/SYN_REPORT between
  state changes (bsc#1051510).
- platform/x86: dell-laptop: Fix keyboard max lighting for Dell
  Latitude E6410 (bsc#1051510).
- platform/x86: intel_punit_ipc: Fix resource ioremap warning
  (bsc#1051510).
- platform/x86: hp_accel: Add quirk for HP ProBook 440 G4
  (bsc#1051510).
- commit 3e187f3
* Fri Mar  9 2018 tiwai@suse.de
- rt2x00usb: mark device removed when get ENOENT usb error
  (bsc#1051510).
- rtlwifi: fix uninitialized rtlhal->last_suspend_sec time
  (bsc#1051510).
- rtlwifi: rtl8192ee: Fix memory leak when loading firmware
  (bsc#1051510).
- rtl8188eu: Fix a possible sleep-in-atomic bug in
  rtw_createbss_cmd (bsc#1051510).
- commit 235d38c
* Fri Mar  9 2018 tiwai@suse.de
- drm/amdgpu: add new device to use atpx quirk (bsc#1051510).
- drm/radeon: adjust tested variable (bsc#1051510).
- drm/amdgpu: Avoid leaking PM domain on driver unbind (v2)
  (bsc#1051510).
- drm/ttm: Don't add swapped BOs to swap-LRU list (bsc#1051510).
- drm/amdgpu: add atpx quirk handling (v2) (bsc#1051510).
- drm/amdgpu: Add dpm quirk for Jet PRO (v2) (bsc#1051510).
- drm/radeon: Add dpm quirk for Jet PRO (v2) (bsc#1051510).
- drm/qxl: unref cursor bo when finished with it (bsc#1051510).
- drm/vmwgfx: Potential off by one in vmw_view_add()
  (bsc#1051510).
- drm/vmwgfx: Don't cache framebuffer maps (bsc#1051510).
- drm/amdgpu: don't try to move pinned BOs (bsc#1051510).
- drm/amdkfd: Fix SDMA oversubsription handling (bsc#1051510).
- drm/amdkfd: Fix SDMA ring buffer size calculation (bsc#1051510).
- drm/amdgpu: Fix SDMA load/unload sequence on HWS disabled mode
  (bsc#1051510).
- drm/amd/pp: fix typecast error in powerplay (bsc#1051510).
- drm/amdgpu: Properly allocate VM invalidate eng v2
  (bsc#1051510).
- drm/amdgpu: Remove check which is not valid for certain VBIOS
  (bsc#1051510).
- drm/vblank: Tune drm_crtc_accurate_vblank_count() WARN down
  to a debug (bsc#1051510).
- drm: Add retries for lspcon mode detection (bsc#1051510).
- commit 3372213
* Fri Mar  9 2018 tiwai@suse.de
- drm/radeon: fix atombios on big endian (bsc#1051510).
- drm/amdgpu: fix error handling in amdgpu_bo_do_create
  (bsc#1051510).
- drm/ttm: once more fix ttm_buffer_object_transfer (bsc#1051510).
- drm/amdgpu: correct reference clock value on vega10
  (bsc#1051510).
- drm/vblank: Fix flip event vblank count (bsc#1051510).
- drm/vmwgfx: Fix Ubuntu 17.10 Wayland black screen issue
  (bsc#1051510).
- drm/amdgpu: allow harvesting check for Polaris VCE
  (bsc#1051510).
- drm/amdgpu: return -ENOENT from uvd 6.0 early init for
  harvesting (bsc#1051510).
- drm/amd/powerplay: fix uninitialized variable (bsc#1051510).
- drm/nouveau/kms/nv50: fix oops during DP IRQ handling on
  non-MST boards (bsc#1051510).
- drm/nouveau/bsp/g92: disable by default (bsc#1051510).
- drm/nouveau/mmu: flush tlbs before deleting page tables
  (bsc#1051510).
- drm/amdgpu: read reg in each iterator of psp_wait_for loop
  (bsc#1051510).
- commit 1358bbc
* Fri Mar  9 2018 tiwai@suse.de
- Bluetooth: btusb: Use DMI matching for QCA reset_resume quirking
  (bsc#1051510).
- Bluetooth: BT_HCIUART now depends on SERIAL_DEV_BUS
  (bsc#1051510).
- commit 8e5482b
* Fri Mar  9 2018 tiwai@suse.de
- console/dummy: leave .con_font_get set to NULL (bsc#1051510).
- Bluetooth: btusb: Restore QCA Rome suspend/resume fix with a
  "rewritten" version (bsc#1051510).
- Bluetooth: btsdio: Do not bind to non-removable BCM43341
  (bsc#1051510).
- brcmfmac: Avoid build error with make W=1 (bsc#1051510).
- brcmfmac: change driver unbind order of the sdio function
  devices (bsc#1051510).
- ath9k: fix tx99 potential info leak (bsc#1051510).
- Bluetooth: hci_ldisc: Fix another race when closing the tty
  (bsc#1051510).
- Bluetooth: btusb: Add new NFA344A entry (bsc#1051510).
- Bluetooth: hci_uart_set_flow_control: Fix NULL deref when
  using serdev (bsc#1051510).
- Bluetooth: btqcomsmd: Add support for BD address setup
  (bsc#1051510).
- cfg80211: fix connect/disconnect edge cases (bsc#1051510).
- brcmsmac: make some local variables 'static const' to reduce
  stack size (bsc#1051510).
- brcmfmac: Add check for short event packets (bsc#1051510).
- brcmfmac: setup passive scan if requested by user-space
  (bsc#1051510).
- brcmfmac: add length check in brcmf_cfg80211_escan_handler()
  (bsc#1051510).
- Bluetooth: btusb: Add support for 0489:e0a2 QCA_ROME device
  (bsc#1051510).
- Bluetooth: hci_ldisc: Use rwlocking to avoid closing proto races
  (bsc#1051510).
- commit f42c236
* Fri Mar  9 2018 msuchanek@suse.de
- ibmvnic: Do not disable device during failover or partition
  migration (bsc#1084610).
- ibmvnic: Reorganize device close (bsc#1084610).
- ibmvnic: Clean up device close (bsc#1084610).
- commit d14516e
* Fri Mar  9 2018 glin@suse.com
- bpf, arm64: fix stack_depth tracking in combination with tail
  calls (bsc#1083647).
- bpf: take advantage of stack_depth tracking in powerpc JIT
  (bsc#1083647).
- s390/bpf: take advantage of stack_depth tracking (bsc#1083647).
- commit 1d58a6a
* Fri Mar  9 2018 glin@suse.com
- x86: bpf_jit: small optimization in emit_bpf_tail_call()
  (bsc#1083647).
- Refresh patches.drivers/bpf-fix-bpf_tail_call-x64-JIT.patch.
- commit 2e51427
* Fri Mar  9 2018 glin@suse.com
- bpf, arm64: take advantage of stack_depth tracking
  (bsc#1083647).
- bpf: take advantage of stack_depth tracking in x64 JIT
  (bsc#1083647).
- bpf: change x86 JITed program stack layout (bsc#1083647).
- commit a045c8c
* Thu Mar  8 2018 msuchanek@suse.de
- mkspec: do not build dtbs for architectures with no kernel.
- commit 8394abf
* Thu Mar  8 2018 tiwai@suse.de
- ASoC: ux500: add MODULE_LICENSE tag (bsc#1051510).
- ASoC: pcm512x: add missing MODULE_DESCRIPTION/AUTHOR/LICENSE
  (bsc#1051510).
- ASoC: skl: Fix kernel warning due to zero NHTL entry
  (bsc#1051510).
- ASoC: codecs: msm8916-wcd-analog: fix module autoload
  (bsc#1051510).
- ASoC: img-parallel-out: Add pm_runtime_get/put to set_fmt
  callback (bsc#1051510).
- ASoC: rsnd: rsnd_ssi_run_mods() needs to care ssi_parent_mod
  (bsc#1051510).
- ASoC: Intel: Skylake: Fix uuid_module memory leak in failure
  case (bsc#1051510).
- commit 0dddbdc
* Thu Mar  8 2018 tiwai@suse.de
- ALSA: usb: add more device quirks for USB DSD devices
  (bsc#1051510).
- ALSA: usb-audio: add implicit fb quirk for Behringer UFX1204
  (bsc#1051510).
- ALSA: line6: Add a sanity check for invalid EPs (bsc#1051510).
- ALSA: caiaq: Add a sanity check for invalid EPs (bsc#1051510).
- ALSA: bcd2000: Add a sanity check for invalid EPs (bsc#1051510).
- usb: core: Add a helper function to check the validity of EP
  type in URB (bsc#1051510).
- commit 4d4a9cb
* Thu Mar  8 2018 duwe@suse.de
- Update config files.
- commit c87ae8c
* Thu Mar  8 2018 yousaf.kaukab@suse.com
- Update config files.
- commit e355af1
* Thu Mar  8 2018 mbrugger@suse.com
- arm64: Update config files. (bsc#1084143)
  Build ARM_MT8173_CPUFREQ as a module
- commit 0db2cc6
* Thu Mar  8 2018 duwe@suse.de
- On ppc64le we HAVE_RELIABLE_STACKTRACE (bsc#1072856).
- commit a4da14c
* Thu Mar  8 2018 oneukum@suse.com
- supported.conf: declared thunderbolt.ko supported
  This used to be an Apple only driver. It has been changed to generic
  thunderbolt support. We want this on SLES, too. (bsc#1084516)
- commit b51cbd2
* Thu Mar  8 2018 tiwai@suse.de
- drm/i915/cnl: Add WaRsDisableCoarsePowerGating (FATE#322643
  bsc#1055900).
- commit 3b71519
* Thu Mar  8 2018 tiwai@suse.de
- drm/i915: Apply headless DMC workaround for CNL (FATE#322643
  bsc#1055900).
- commit 1e7e0de
* Thu Mar  8 2018 yousaf.kaukab@suse.com
- ACPI/IORT: Add msi address regions reservation helper
  (bsc#1084475).
- ACPI/IORT: Enable SMMUv3/PMCG IORT MSI domain set-up
  (bsc#1084475).
- ACPI/IORT: Add SMMUv3 specific special index mapping handling
  (bsc#1084475).
- ACPI/IORT: Enable special index ITS group mappings for IORT
  nodes (bsc#1084475).
- ACPI/IORT: Look up IORT node through struct fwnode_handle
  pointer (bsc#1084475).
- ACPI/IORT: Make platform devices initialization code SMMU
  agnostic (bsc#1084475).
- ACPI/IORT: Improve functions return type/storage class specifier
  indentation (bsc#1084475).
- ACPI/IORT: Remove leftover ACPI_IORT_SMMU_V3_PXM_VALID guard
  (bsc#1084475).
- acpi/arm64: pr_err() strings should end with newlines
  (bsc#1084475).
- ACPI/IORT: Fix PCI ACS enablement (bsc#1084475).
- commit 4f0cd1c
* Thu Mar  8 2018 yousaf.kaukab@suse.com
- ACPI/IORT: Fix build regression without IOMMU (bsc#1084475).
- ACPI/IORT: Handle PCI aliases properly for IOMMUs (bsc#1084475).
- commit a805c57
* Thu Mar  8 2018 yousaf.kaukab@suse.com
- iommu/arm-smmu-v3, acpi: Add temporary Cavium SMMU-V3 IORT
  model number definitions (bsc#1084475).
- Refresh
  patches.suse/iommu-arm-smmu-v3-Enable-ACPI-based-HiSilicon-CMD_PR.patch.
- commit 80781a3
* Thu Mar  8 2018 yousaf.kaukab@suse.com
- ACPI/IORT: Remove iort_node_match() (bsc#1084475).
- commit edbe598
* Thu Mar  8 2018 yousaf.kaukab@suse.com
- i2c: xlp9xx: Add support for SMBAlert (bsc#1084310).
- i2c: xlp9xx: Handle NACK on DATA properly (bsc#1084310).
- i2c: xlp9xx: Check for Bus state before every transfer
  (bsc#1084310).
- i2c: xlp9xx: Handle transactions with I2C_M_RECV_LEN properly
  (bsc#1060799).
- i2c: xlp9xx: return ENXIO on slave address NACK (bsc#1060799).
- ahci: thunderx2: update stop engine errata delay values
  (bsc#1084308).
- arm64: Add missing Falkor part number for branch predictor
  hardening (bsc#1068032).
- ARM64 / cpuidle: Use new cpuidle macro for entering retention
  state (bsc#1084328).
- cpuidle: Add new macro to enter a retention idle state
  (bsc#1084328).
- ipmi: fix unsigned long underflow (bsc#1060799).
- tpm/tpm_crb: Use start method value from ACPI table directly
  (bsc#1084452).
- char: ipmi: constify bmc_dev_attr_group and bmc_device_type
  (bsc#1060799).
- ipmi:ssif: Check dev before setting drvdata (bsc#1060799).
- ipmi: Convert DMI handling over to a platform device
  (bsc#1060799).
- ipmi: Create a platform device for a DMI-specified IPMI
  interface (bsc#1060799).
- ipmi:ssif: Use i2c_adapter_id instead of adapter->nr
  (bsc#1060799).
- ipmi: Use the proper default value for register size in ACPI
  (bsc#1060799).
- ipmi_ssif: remove redundant null check on array
  client->adapter->name (bsc#1060799).
- ACPICA: Add header support for TPM2 table changes (bsc#1084452).
- cpufreq / CPPC: Initialize policy->min to lowest nonlinear
  performance (bsc#1084342).
- commit 9834636
* Thu Mar  8 2018 glin@suse.com
- bpf: introduce ARG_PTR_TO_MEM_OR_NULL (bsc#1083647).
- commit e744b9e
* Thu Mar  8 2018 msuchanek@suse.de
- config.sh: build against SLE-15 in OBS.
- commit e4aa6f4
* Thu Mar  8 2018 tiwai@suse.de
- intel_th: pci: Add Lewisburg PCH support (FATE#325099).
- intel_th: pci: Add Cedar Fork PCH support (FATE#325099).
- intel_th: Perform time resync on capture start (FATE#325099).
- intel_th: Add global activate/deactivate callbacks for the
  glue layers (FATE#325099).
- intel_th: pci: Use drvdata for quirks (FATE#325099).
- intel_th: pti: Support Low Power Path output port type
  (FATE#325099).
- intel_th: Enumerate Low Power Path output port type
  (FATE#325099).
- intel_th: msu: Use the real device in case of IOMMU domain
  allocation (FATE#325099).
- intel_th: Make the switch allocate its subdevices (FATE#325099).
- intel_th: Make SOURCE devices children of the root device
  (FATE#325099).
- intel_th: Streamline the subdevice tree accessors (FATE#325099).
- intel_th: Output devices without ports don't need assigning
  (FATE#325099).
- intel_th: pci: Enable bus mastering (FATE#325099).
- commit e948cb6
* Thu Mar  8 2018 tiwai@suse.de
- Preliminary series.conf sort and update
- commit e372e1c
* Thu Mar  8 2018 glin@suse.com
- bpf: remove explicit handling of 0 for arg2 in bpf_probe_read
  (bsc#1083647).
- bpf: change helper bpf_probe_read arg2 type to
  ARG_CONST_SIZE_OR_ZERO (bsc#1083647).
- commit c81cbaf
* Thu Mar  8 2018 glin@suse.com
- selftests/bpf: add tests for recent bugfixes (bsc#1083647).
- bpf: change bpf_probe_write_user to bpf_trace_printk in
  test_verifier (bsc#1083647).
- bpf: fix and add test cases for ARG_CONST_SIZE_OR_ZERO semantics
  change (bsc#1083647).
- commit 3eadeee
* Wed Mar  7 2018 mbrugger@suse.com
- net: hns: add ACPI mode support for ethtool -p (bsc#1084041).
- commit 1534335
* Wed Mar  7 2018 agraf@suse.de
- lan78xx: Avoid spurious kevent 4 "error" (bsc#1084332).
- lan78xx: Enable LEDs and auto-negotiation (bsc#1084332).
- lan78xx: Correctly indicate invalid OTP (bsc#1084332).
- lan78xx: Read MAC address from DT if present (bsc#1084332).
- lan78xx: Fix failure in USB Full Speed (bsc#1084332).
- lan78xx: Use default values loaded from EEPROM/OTP after reset
  (bsc#1084332).
- lan78xx: Allow EEPROM write for less than MAX_EEPROM_SIZE
  (bsc#1084332).
- lan78xx: Fix for eeprom read/write when device auto suspend
  (bsc#1084332).
- lan78xx: Fix to handle hard_header_len update (bsc#1084332).
- lan78xx: USB fast connect/disconnect crash fix (bsc#1084332).
- commit a355989
* Wed Mar  7 2018 tiwai@suse.de
- rpm/kernel-binary.spec.in: Check module licenses (bsc#1083215,bsc#1083527)
- commit e41de0c
* Wed Mar  7 2018 tiwai@suse.de
- x86/kvm/vmx: do not use vm-exit instruction length for fast
  MMIO when running nested (bsc#1081431).
- commit 0b3a20a
* Wed Mar  7 2018 oneukum@suse.com
- usbip: prevent vhci_hcd driver from leaking a socket pointer address (bsc#1078674 CVE-2017-16911).
- commit d07e5b4
* Wed Mar  7 2018 pmladek@suse.com
- printk: Wake klogd when passing console_lock owner
  (bsc#1084301).
- commit 7dbb932
* Wed Mar  7 2018 dchang@suse.com
- net: dst: move cpu inside ifdef to avoid compilation warning
  (bsc#1083647).
- commit dcdefd8
* Wed Mar  7 2018 dchang@suse.com
- bpf: don't rely on the verifier lock for metadata_dst allocation
  (bsc#1083647).
- commit 4fec793
* Wed Mar  7 2018 dchang@suse.com
- bpf: allow access to skb->len from offloads (bsc#1083647).
- commit 6cb18cc
* Tue Mar  6 2018 tbogendoerfer@suse.de
- ixgbe: fix crash in build_skb Rx code path (bsc#1056657
  FATE#322189).
- RDMA/uverbs: Protect from command mask overflow (bsc#1046306
  FATE#322942).
- IB/uverbs: Improve lockdep_check (bsc#1046306 FATE#322942).
- RDMA/uverbs: Protect from races between lookup and destroy of
  uobjects (bsc#1046306 FATE#322942).
- IB/ipoib: Do not warn if IPoIB debugfs doesn't exist
  (bsc#1046307 FATE#322941).
- net: fix race on decreasing number of TX queues (bsc#1056787).
- s390/qeth: fix SETIP command handling (bsc#1061024 FATE#323301).
- net/mlx5e: Remove timestamp set from netdevice open flow
  (bsc#1046303 FATE#322944).
- commit bbd85ba
* Tue Mar  6 2018 msuchanek@suse.de
- scsi: sr: workaround VMware ESXi cdrom emulation bug
  (bsc#1080813).
- commit d2067fc
* Tue Mar  6 2018 glin@suse.com
- bpf, ppc64: implement jiting of BPF_J{LT, LE, SLT, SLE}
  (bsc#1083647).
- bpf, s390x: implement jiting of BPF_J{LT, LE, SLT, SLE}
  (bsc#1083647).
- bpf, arm64: implement jiting of BPF_J{LT, LE, SLT, SLE}
  (bsc#1083647).
- bpf, x86: implement jiting of BPF_J{LT,LE,SLT,SLE}
  (bsc#1083647).
- commit a245dfe
* Tue Mar  6 2018 tbogendoerfer@suse.de
- net: ethtool: don't ignore return from driver get_fecparam
  method (bsc#1046540 FATE#322930).
- commit 90a64af
* Tue Mar  6 2018 nborisov@suse.com
- btrfs: preserve i_mode if __btrfs_set_acl() fails (bsc#1083000).
- commit 1eddbfd
* Tue Mar  6 2018 nborisov@suse.com
- Btrfs: incremental send, fix wrong unlink path after renaming
  file (bsc#1083000).
- Btrfs: incremental send, fix emission of invalid clone
  operations (bsc#1083000).
- commit 0e8595f
* Tue Mar  6 2018 nborisov@suse.com
- Btrfs: fix unexpected -EEXIST when creating new inode
  (bsc#1083000).
- Btrfs: fix extent state leak from tree log (bsc#1083000).
- Btrfs: fix crash due to not cleaning up tree log block's dirty
  bits (bsc#1083000).
- Btrfs: fix deadlock in run_delalloc_nocow (bsc#1083000).
- Btrfs: avoid losing data raid profile when deleting a device
  (bsc#1083000).
- Btrfs: fix stale entries in readdir (bsc#1083000).
- btrfs: Fix possible off-by-one in btrfs_search_path_in_tree
  (bsc#1083000).
- btrfs: clear ordered flag on cleaning up ordered extents
  (bsc#1083000).
- btrfs: fix readdir deadlock with pagefault (bsc#1083000).
- commit 1e19d87
* Tue Mar  6 2018 jslaby@suse.cz
- x86/speculation: Add <asm/msr-index.h> dependency (bnc#1058115).
- commit 3d60a5f
* Tue Mar  6 2018 tiwai@suse.de
- Update the usptreamed tag for i915 patch
  Also moved to sorted section:
  patches.drivers/drm-i915-cnl-Fix-PORT_TX_DW5-7-register-address
- commit d4f2341
* Tue Mar  6 2018 tiwai@suse.de
- Sort patches / update tags
- commit 8fad596
* Tue Mar  6 2018 jslaby@suse.cz
- objtool: Add module specific retpoline rules (bnc#1058115).
- objtool: Add retpoline validation (bnc#1058115).
- objtool: Use existing global variables for options
  (bnc#1058115).
- x86/mm/sme, objtool: Annotate indirect call in
  sme_encrypt_execute() (bnc#1058115).
- x86/boot, objtool: Annotate indirect jump in
  secondary_startup_64() (bnc#1058115).
- x86/paravirt, objtool: Annotate indirect calls (bnc#1058115).
- x86/speculation, objtool: Annotate indirect calls/jumps for
  objtool (bnc#1058115).
- commit bacb170
* Tue Mar  6 2018 jslaby@suse.cz
- objtool: Fix switch-table detection (bnc#1058115).
- commit deefb76
* Tue Mar  6 2018 jslaby@suse.cz
- Refresh
  patches.fixes/l2tp-don-t-use-inet_shutdown-on-ppp-session-destroy.patch.
- Refresh
  patches.fixes/l2tp-don-t-use-inet_shutdown-on-tunnel-destroy.patch.
- Refresh
  patches.fixes/l2tp-fix-race-in-pppol2tp_release-with-session-objec.patch.
- Refresh
  patches.fixes/l2tp-fix-races-with-tunnel-socket-close.patch.
- Refresh
  patches.fixes/l2tp-fix-tunnel-lookup-use-after-free-race.patch.
  Ran series_sort.
- commit 18a48e4
* Tue Mar  6 2018 nborisov@suse.com
- Refresh
  patches.fixes/l2tp-don-t-use-inet_shutdown-on-ppp-session-destroy.patch.
- Refresh
  patches.fixes/l2tp-don-t-use-inet_shutdown-on-tunnel-destroy.patch.
- Refresh
  patches.fixes/l2tp-fix-race-in-pppol2tp_release-with-session-objec.patch.
- Refresh
  patches.fixes/l2tp-fix-races-with-tunnel-socket-close.patch.
- Refresh
  patches.fixes/l2tp-fix-tunnel-lookup-use-after-free-race.patch.
- commit bd5bc11
* Tue Mar  6 2018 glin@suse.com
- bpf: fix selftests/bpf test_kmod.sh failure when
  CONFIG_BPF_JIT_ALWAYS_ON=y (bsc#1083647).
- selftests/bpf: make 'dubious pointer arithmetic' test useful
  (bsc#1083647).
- bpf: fix stack state printing in verifier log (bsc#1083647).
- commit 9391768
* Mon Mar  5 2018 neilb@suse.com
- dm: fix race between dm_get_from_kobject() and __dm_destroy()
  (bsc#1083242, CVE-2017-18203).
- commit 1b6ebbf
* Mon Mar  5 2018 msuchanek@suse.de
- rpm: provide %%name%%-srchash = <kernel-source commit hash> (FATE#325312).
  - Also use for kernel-obs-build dependency.
- commit b6fccdf
* Mon Mar  5 2018 tbogendoerfer@suse.de
- net: ena: increase ena driver version to 1.5.0 (bsc#1083548).
- net: ena: add detection and recovery mechanism for handling
  missed/misrouted MSI-X (bsc#1083548).
- net: ena: fix error handling in ena_down() sequence
  (bsc#1083548).
- net: ena: unmask MSI-X only after device initialization is
  completed (bsc#1083548).
- net: ena: fix race condition between device reset and link up
  setup (bsc#1083548).
- net: ena: increase ena driver version to 1.3.0 (bsc#1083548).
- net: ena: add new admin define for future support of IPv6 RSS
  (bsc#1083548).
- net: ena: add statistics for missed tx packets (bsc#1083548).
- net: ena: add power management ops to the ENA driver
  (bsc#1083548).
- net: ena: remove legacy suspend suspend/resume support
  (bsc#1083548).
- net: ena: improve ENA driver boot time (bsc#1083548).
- net: ena: Remove redundant unlikely() (bsc#1083548).
- net: ena: fix wrong max Tx/Rx queues on ethtool (bsc#1083548).
- net: ena: fix rare kernel crash when bar memory remap fails
  (bsc#1083548).
- net: ena: reduce the severity of some printouts (bsc#1083548).
- commit 46c382b
* Mon Mar  5 2018 jgross@suse.com
- x86/xen: Zero MSR_IA32_SPEC_CTRL before suspend (bnc#1065600).
- commit 0c69d71
* Mon Mar  5 2018 tbogendoerfer@suse.de
- Drop patches, because new notifier semantic is not in SLE15 (bsc#1082743)
- Delete
  patches.drivers/IB-hfi1-update-to-new-mmu_notifier-semantic.patch.
- Delete
  patches.drivers/IB-umem-update-to-new-mmu_notifier-semantic.patch.
- commit c8f3eed
* Mon Mar  5 2018 glin@suse.com
- selftests/bpf: fix test_align (bsc#1083647).
- selftests/bpf: add test for bogus operations on pointers
  (bsc#1083647).
- selftests/bpf: add a test to test_align (bsc#1083647).
- selftests/bpf: rewrite test_align (bsc#1083647).
- bpf: allow to specify log level and reduce it for test_verifier
  (bsc#1083647).
- selftests/bpf: make correct use of exit codes in bpf selftests
  (bsc#1083647).
- bpf, tests: set rlimit also for test_align, so it doesn't fail
  (bsc#1083647).
- commit 623858a
* Mon Mar  5 2018 mkubecek@suse.cz
- Update
  patches.fixes/netfilter-add-back-stackpointer-size-checks.patch
  references (add CVE-2018-1065 bsc#1083650).
- commit 603dd8a
* Mon Mar  5 2018 mkubecek@suse.cz
- Update
  patches.fixes/net-ipv6-fix-regression-of-no-RTM_DELADDR-sent-after.patch
  references (add bsc#1083557).
- commit 0c85cde
* Mon Mar  5 2018 mkubecek@suse.cz
- doc: Change the min default value of tcp_wmem/tcp_rmem
  (bsc#1076830).
- commit 2dfc414
* Mon Mar  5 2018 mkubecek@suse.cz
- Fix upstream reference:
  patches.drivers/scsi-qla2xxx-Fix-FC-NVMe-LUN-discovery.patch.
- commit 5b6cf57
* Mon Mar  5 2018 gqjiang@suse.com
- raid10: change the size of resync window for clustered raid
  (bsc#1076343).
- commit d4d2d17
* Mon Mar  5 2018 mgalbraith@suse.de
- x86/platform/intel-mid: Handle Intel Edison reboot correctly (Git-fixes).
- blacklist.conf:
- timers: Forward timer base before migrating timers (Git-fixes).
- commit d95fda8
* Mon Mar  5 2018 glin@suse.com
- bpf: mark dst unknown on inconsistent {s, u}bounds adjustments
  (bsc#1083647).
- bpf: reject stores into ctx via st and xadd (bsc#1083647).
- bpf: fix 32-bit divide by zero (bsc#1083647).
- bpf: fix divides by zero (bsc#1083647).
- bpf: arsh is not supported in 32 bit alu thus reject it
  (bsc#1083647).
- bpf: fix spelling mistake: "obusing" -> "abusing" (bsc#1083647).
- bpf: introduce BPF_JIT_ALWAYS_ON config (bsc#1083647).
  Update config files to set CONFIG_BPF_JIT_ALWAYS_ON to y
- bpf: do not allow root to mangle valid pointers (bsc#1083647).
- commit 81ce49e
* Mon Mar  5 2018 glin@suse.com
- bpf: guarantee r1 to be ctx in case of
  bpf_helper_changes_pkt_data (bsc#1083647).
- bpf: add schedule points to map alloc/free (bsc#1083647).
- commit 2ff84f7
* Mon Mar  5 2018 glin@suse.com
- bpf: improve verifier ARG_CONST_SIZE_OR_ZERO semantics
  (bsc#1083647).
- bpf: fix verifier NULL pointer dereference (bsc#1083647).
- bpf: fix out-of-bounds access warning in bpf_check
  (bsc#1083647).
- bpf: fix link error without CONFIG_NET (bsc#1083647).
- bpf: fix verifier memory leaks (bsc#1083647).
- bpf: reduce verifier memory consumption (bsc#1083647).
  Refresh patches.fixes/bpf-fix-branch-pruning-logic.patch.
  Refresh
  patches.fixes/bpf-fix-incorrect-tracking-of-register-size-truncati.patch.
- bpf: move knowledge about post-translation offsets out of
  verifier (bsc#1083647).
- bpf: remove the verifier ops from program structure
  (bsc#1083647).
- bpf: split verifier and program ops (bsc#1083647).
- tracing: bpf: Hide bpf trace events when they are not used
  (bsc#1083647).
- bpf: verifier: set reg_type on context accesses in second pass
  (bsc#1083647).
- bpf: write back the verifier log buffer as it gets filled
  (bsc#1083647).
- bpf: move instruction printing into a separate file
  (bsc#1083647).
- bpf: Optimize lpm trie delete (bsc#1083647).
- bpf: Implement map_delete_elem for BPF_MAP_TYPE_LPM_TRIE
  (bsc#1083647).
- bpf: Allow cgroup sock filters to use get_current_uid_gid helper
  (bsc#1083647).
- selftests/bpf: don't try to access past MAX_PACKET_OFF in
  test_verifier (bsc#1083647).
- selftests/bpf: change test_verifier expectations (bsc#1083647).
  Refresh
  patches.drivers/bpf-verifier-reject-BPF_ALU64-BPF_END.patch.
- commit ea80b65
* Sun Mar  4 2018 msuchanek@suse.de
- arch-symbols: use bash as interpreter since the script uses bashism.
- commit 4cdfb23
* Fri Mar  2 2018 mcgrof@suse.com
- xfs: truncate pagecache before writeback in xfs_setattr_size() (bsc#1073412).
- commit 73496e4
* Fri Mar  2 2018 dbueso@suse.de
- ipc/msg: introduce msgctl(MSG_STAT_ANY) (bsc#1072689).
- ipc/sem: introduce semctl(SEM_STAT_ANY) (bsc#1072689).
- ipc/shm: introduce shmctl(SHM_STAT_ANY) (bsc#1072689).
- commit c31f2e1
* Fri Mar  2 2018 vbabka@suse.cz
- fs/hugetlbfs/inode.c: change put_page/unlock_page order in
  hugetlbfs_fallocate() (git-fixes, bsc#1083745).
- commit 22c8c94
* Fri Mar  2 2018 agraf@suse.de
- Delete
  patches.suse/KVM-update-to-new-mmu_notifier-semantic-v2.patch. (bsc#1082743)
- Delete patches.suse/KVM-x86-fix-APIC-page-invalidation.patch. (bsc#1082743)
- commit 8dfc569
* Fri Mar  2 2018 vbabka@suse.cz
- mm: do not rely on preempt_count in print_vma_addr (git-fixes,
  bsc#1083704).
- commit 6b725d8
* Fri Mar  2 2018 msuchanek@suse.de
- kernel-binary: do not BuildIgnore m4.
  It is actually needed for regenerating zconf when it is not up-to-date
  due to merge.
- commit 967b28b
* Fri Mar  2 2018 mkubecek@suse.cz
- rpm/kernel-binary.spec.in: add build requirement for flex
  In addition to bison, we also need flex for "make oldconfig".
- commit 83d831c
* Fri Mar  2 2018 mkubecek@suse.cz
- rpm/kernel-binary.spec.in: remove m4 from BuildIgnore list
  As bison depends on m4, we cannot set !BuildIgnore for it any more.
- commit d7695e1
* Fri Mar  2 2018 tiwai@suse.de
- Documentation/sphinx: Fix Directive import error (bsc#1083694).
- commit 1407e51
* Fri Mar  2 2018 bp@suse.de
- include: psp-sev: Capitalize invalid length enum (bsc#1063068).
- KVM/nVMX: Set the CPU_BASED_USE_MSR_BITMAPS if we have a valid
  L02 MSR bitmap (bsc#1068032 CVE-2017-5754).
- KVM: SVM: Fix SEV LAUNCH_SECRET command (bsc#1063068).
- KVM: SVM: no need to call access_ok() in LAUNCH_MEASURE command
  (bsc#1063068).
- KVM/x86: Reduce retpoline performance impact in
  slot_handle_level_range(), by always inlining iterator helper
  methods (bsc#1068032 CVE-2017-5754).
- KVM/x86: Remove indirect MSR op calls from SPEC_CTRL
  (bsc#1063068).
- nospec: Move array_index_nospec() parameter checking into
  separate macro (bsc#1068032 CVE-2017-5754).
- objtool: Fix segfault in ignore_unreachable_insn() (bsc#1068032
  CVE-2017-5754).
- x86/debug, objtool: Annotate WARN()-related UD2 as reachable
  (bsc#1068032 CVE-2017-5754).
- x86/debug: Use UD2 for WARN() (bsc#1068032 CVE-2017-5754).
- x86/entry/64: Clear extra registers beyond syscall arguments, to
  reduce speculation attack surface (bsc#1068032 CVE-2017-5754).
- x86/entry/64: Clear registers for exceptions/interrupts, to
  reduce speculation attack surface (bsc#1068032 CVE-2017-5754).
- x86/entry/64/compat: Clear registers for compat syscalls, to
  reduce speculation attack surface (bsc#1068032 CVE-2017-5754).
- x86/entry/64: Fix CR3 restore in paranoid_exit() (bsc#1068032
  CVE-2017-5754).
- x86/entry/64: Fix paranoid_entry() frame pointer warning
  (bsc#1068032 CVE-2017-5754).
- x86/entry/64: Get rid of the ALLOC_PT_GPREGS_ON_STACK and
  SAVE_AND_CLEAR_REGS macros (bsc#1068032 CVE-2017-5754).
- x86/entry/64: Indent PUSH_AND_CLEAR_REGS and POP_REGS properly
  (bsc#1068032 CVE-2017-5754).
- x86/entry/64: Interleave XOR register clearing with PUSH
  instructions (bsc#1068032 CVE-2017-5754).
- x86/entry/64: Introduce the PUSH_AND_CLEAN_REGS macro
  (bsc#1068032 CVE-2017-5754).
- x86/entry/64: Merge SAVE_C_REGS and SAVE_EXTRA_REGS, remove
  unused extensions (bsc#1068032 CVE-2017-5754).
- x86/entry/64: Merge the POP_C_REGS and POP_EXTRA_REGS macros
  into a single POP_REGS macro (bsc#1068032 CVE-2017-5754).
- x86/entry/64: Remove the unused 'icebp' macro (bsc#1068032
  CVE-2017-5754).
- x86/entry/64: Use PUSH_AND_CLEAN_REGS in more cases (bsc#1068032
  CVE-2017-5754).
- x86/mm: Rename flush_tlb_single() and flush_tlb_one() to
  __flush_tlb_one_[user|kernel]() (bsc#1068032 CVE-2017-5754).
- X86/nVMX: Properly set spec_ctrl and pred_cmd before merging
  MSRs (bsc#1068032 CVE-2017-5754).
- x86/speculation: Clean up various Spectre related details
  (bsc#1068032 CVE-2017-5754).
- x86/speculation: Fix up array_index_nospec_mask() asm constraint
  (bsc#1068032 CVE-2017-5754).
- Refresh
  patches.arch/09.0-x86-spectre-fix-an-error-message.patch.
- commit f83739a
* Fri Mar  2 2018 mgorman@suse.de
- mm/free_pcppages_bulk: prefetch buddy while not holding lock
  (bnc#971975 VM performance -- page allocator).
- mm/free_pcppages_bulk: do not hold lock when picking pages to
  free (bnc#971975 VM performance -- page allocator).
- mm/free_pcppages_bulk: update pcp->count inside (bnc#971975
  VM performance -- page allocator).
- commit b395d98
* Fri Mar  2 2018 mgorman@suse.de
- x86/cpu: Remove unused and undefined __generic_processor_info()
  declaration (bnc#1056230).
- commit 112c00f
* Fri Mar  2 2018 vbabka@suse.cz
- x86/mm/pkeys: Fix fill_sig_info_pkey (git-fixes, bsc#1083529).
- commit 2c7fc72
* Fri Mar  2 2018 tiwai@suse.de
- media: v4l2-compat-ioctl32.c: make ctrl_is_pointer work for
  subdevs (CVE-2017-13166,bsc#1072865).
- media: v4l2-compat-ioctl32.c: refactor compat ioctl32 logic
  (CVE-2017-13166,bsc#1072865).
- media: v4l2-compat-ioctl32.c: don't copy back the result for
  certain errors (CVE-2017-13166,bsc#1072865).
- media: v4l2-compat-ioctl32.c: drop pr_info for unknown buffer
  type (CVE-2017-13166,bsc#1072865).
- media: v4l2-compat-ioctl32.c: copy clip list in
  put_v4l2_window32 (CVE-2017-13166,bsc#1072865).
- media: v4l2-compat-ioctl32.c: fix ctrl_is_pointer
  (CVE-2017-13166,bsc#1072865).
- media: v4l2-compat-ioctl32.c: copy m.userptr in put_v4l2_plane32
  (CVE-2017-13166,bsc#1072865).
- media: v4l2-compat-ioctl32.c: avoid sizeof(type)
  (CVE-2017-13166,bsc#1072865).
- media: v4l2-compat-ioctl32.c: move 'helper' functions to
  __get/put_v4l2_format32 (CVE-2017-13166,bsc#1072865).
- media: v4l2-compat-ioctl32.c: fix the indentation
  (CVE-2017-13166,bsc#1072865).
- media: v4l2-compat-ioctl32.c: add missing VIDIOC_PREPARE_BUF
  (CVE-2017-13166,bsc#1072865).
- media: v4l2-ioctl.c: don't copy back the result for -ENOTTY
  (CVE-2017-13166,bsc#1072865).
- media: v4l2-ioctl.c: use check_fmt for enum/g/s/try_fmt
  (CVE-2017-13166,bsc#1072865).
- commit 5d9eae0
* Fri Mar  2 2018 tiwai@suse.de
- drm/i915: Make global seqno known in i915_gem_request_execute
  tracepoint (FATE#322643 bsc#1055900).
- drm/i915: Clear the in-use marker on execbuf failure
  (FATE#322643 bsc#1055900).
- drm/i915/audio: fix check for av_enc_map overflow (FATE#322643
  bsc#1055900).
- drm/i915: Fix rsvd2 mask when out-fence is returned (FATE#322643
  bsc#1055900).
- ALSA: hda - Fix pincfg at resume on Lenovo T470 dock
  (bsc#1052235).
- ALSA: usb-audio: Add a quirck for B&W PX headphones
  (bsc#1051510).
- ALSA: hda: Add a power_save blacklist (bsc#1052235).
- commit b784bf6
* Thu Mar  1 2018 mwilck@suse.com
- fs: aio: fix the increment of aio-nr and counting against
  aio-max-nr (bsc#1068075, bsc#1078921).
- commit e2a476e
* Thu Mar  1 2018 tiwai@suse.de
- Update config files: re-enable CONFIG_CRYPTO_FIPS=y (bsc#1083512)
- commit c380188
* Thu Mar  1 2018 tiwai@suse.de
- 9p: add missing module license for xen transport (bsc#1083527).
- commit c36c39b
* Thu Mar  1 2018 hare@suse.de
- supported.conf: Add dm-zoned (FATE#318724)
- commit e97e249
* Thu Mar  1 2018 msuchanek@suse.de
- Include ACPI button driver in base kernel (bsc#1062056).
- commit 412fabd
* Thu Mar  1 2018 hare@suse.de
- Enable dm-zoned (FATE#318724).
- commit 6098432
* Thu Mar  1 2018 mhocko@suse.com
- Update
  patches.fixes/mm-madvise.c-fix-madvise-infinite-loop-under-special.patch
  (bnc#1070964, bnc#1083494, CVE-2017-18208).
- commit b82f489
* Thu Mar  1 2018 bp@suse.de
- Refresh
  patches.drivers/ibmvnic-Fix-early-release-of-login-buffer.patch.
- commit 9aac42a
* Thu Mar  1 2018 mkubecek@suse.cz
- Delete
  patches.suse/0001-kabi-Lift-ifdefs-for-some-disabled-network-protocols.patch.
  When DCCP was disabled in SLE12-SP2, this patch was added to make it
  possible to build it as a KMP in case it would turn out someone is actually
  using it. As there have been no sign of that since, let's drop the patch.
- commit 285564e
* Thu Mar  1 2018 hare@suse.de
- scsi: qla2xxx: Fix FC-NVMe LUN discovery (bsc#1083224).
- commit 58d375c
* Thu Mar  1 2018 hare@suse.de
- Fixup patch description for patches.drivers/ibmvnic-Fix-early-release-of-login-buffer.patch
- commit 95e3c32
* Thu Mar  1 2018 tiwai@suse.de
- ALSA: seq: Fix racy pool initializations
  (CVE-2018-7566,bsc#1083483).
- commit c7a35b5
* Thu Mar  1 2018 mkubecek@suse.cz
- l2tp: fix tunnel lookup use-after-free race (bsc#1076830).
- l2tp: fix race in pppol2tp_release with session object destroy
  (bsc#1076830).
- l2tp: fix races with tunnel socket close (bsc#1076830).
- l2tp: don't use inet_shutdown on ppp session destroy
  (bsc#1076830).
- l2tp: don't use inet_shutdown on tunnel destroy (bsc#1076830).
- regulatory: add NUL to request alpha2 (bsc#1076830).
- net: ipv4: Set addr_type in hash_keys for forwarded case
  (bsc#1076830).
- tcp_bbr: better deal with suboptimal GSO (bsc#1076830).
- netfilter: IDLETIMER: be syzkaller friendly (bsc#1076830).
- netfilter: nat: cope with negative port range (bsc#1076830).
- netfilter: x_tables: fix missing timer initialization in xt_LED
  (bsc#1076830).
- netfilter: ipt_CLUSTERIP: fix a refcount bug in
  clusterip_config_find_get() (bsc#1076830).
- netfilter: add back stackpointer size checks (bsc#1076830).
- netfilter: drop outermost socket lock in getsockopt()
  (bsc#1076830).
- netfilter: ipt_CLUSTERIP: fix a race condition of proc file
  creation (bsc#1076830).
- udplite: fix partial checksum initialization (bsc#1076830).
- dn_getsockoptdecnet: move nf_{get/set}sockopt outside sock lock
  (bsc#1076830).
- tcp: Honor the eor bit in tcp_mtu_probe (bsc#1076830).
- sctp: do not pr_err for the duplicated node in transport rhlist
  (bsc#1076830).
- bridge: check brport attr show in brport_show (bsc#1076830).
- ipv6: set all.accept_dad to 0 by default (bsc#1076830).
- l2tp: remove l2tp_tunnel_count and l2tp_session_count
  (bsc#1076830).
  Refresh patches.fixes/l2tp-don-t-close-sessions-in-l2tp_tunnel_destruct.patch
- l2tp: remove ->ref() and ->deref() (bsc#1076830).
- l2tp: initialise PPP sessions before registering them
  (bsc#1076830).
- l2tp: protect sock pointer of struct pppol2tp_session with RCU
  (bsc#1076830).
- ipv6: addrconf: increment ifp refcount before ipv6_del_addr()
  (bsc#1076830).
- l2tp: hold tunnel in pppol2tp_connect() (bsc#1076830).
- ipv6: fix net.ipv6.conf.all.accept_dad behaviour for real
  (bsc#1076830).
  Refresh
  patches.fixes/net-ipv6-send-unsolicited-NA-after-DAD.patch
- l2tp: fix race between l2tp_session_delete() and
  l2tp_tunnel_closeall() (bsc#1076830).
- l2tp: ensure sessions are freed after their PPPOL2TP socket
  (bsc#1076830).
- ipv6: fix net.ipv6.conf.all interface DAD handlers
  (bsc#1076830).
- net: ipv6: fix regression of no RTM_DELADDR sent after DAD
  failure (bsc#1076830).
- net: don't decrement kobj reference count on init failure
  (bsc#1076830).
- netfilter: ipt_CLUSTERIP: do not hold dev (bsc#1076830).
- commit 5f23ad9
* Thu Mar  1 2018 mhocko@suse.com
- Remove page cache limit (fate#323778)
- Delete patches.suse/mm-uninline-add-to-page-cache.patch.
- Delete patches.suse/pagecache-limit-dirty.diff.
- Delete patches.suse/pagecache-limit-fix-get_nr_swap_pages.patch.
- Delete patches.suse/pagecache-limit-fix-shmem-deadlock.patch.
- Delete
  patches.suse/pagecache-limit-reduce-zone-lrulock-bouncing.patch.
- Delete patches.suse/pagecache-limit-unmapped.diff.
- Delete patches.suse/pagecache-limit-warn-on-usage.patch.
- Delete patches.suse/pagecache-limit.patch.
- Delete patches.suse/pagecachelimit_batch_huge_nr_to_scan.patch.
- commit d39d94a
* Thu Mar  1 2018 mkubecek@suse.cz
- blacklist.conf: add two commits
  d5902f6d1fbd - a merge commit (we have both commits from the branch)
  fae8b6f4a6be - fixes comments
- commit 9b213a5
* Thu Mar  1 2018 mkubecek@suse.cz
- Update upstream reference:
  patches.drivers/ibmvnic-Fix-early-release-of-login-buffer.patch.
- commit df1695c
* Thu Mar  1 2018 bpoirier@suse.com
- Refresh
  patches.drivers/ibmvnic-Fix-early-release-of-login-buffer.patch.
- commit 70a1572
* Wed Feb 28 2018 jack@suse.cz
- ocfs2: should wait dio before inode lock in ocfs2_setattr()
  (bsc#1083244 CVE-2017-18204).
- commit f78f4f7
* Wed Feb 28 2018 oneukum@suse.com
- xhci: Don't show incorrect WARN message about events for empty
  rings (bsc#1068674).
- commit 2728c81
* Wed Feb 28 2018 msuchanek@suse.de
- bs-upload-kernel: do not set %%opensuse_bs
  Since SLE15 it is not set in the distribution project so do not set it
  for kernel projects either.
- commit d696aa0
* Wed Feb 28 2018 msuchanek@suse.de
- ibmvnic: Do not attempt to login if RX or TX queues are not
  allocated (bsc#1082993).
- ibmvnic: Report queue stops and restarts as debug output
  (bsc#1082993).
- ibmvnic: Harden TX/RX pool cleaning (bsc#1082993).
- ibmvnic: Allocate statistics buffers during probe (bsc#1082993).
- ibmvnic: Fix TX descriptor tracking again (bsc#1082993).
- commit 953c6c5
* Wed Feb 28 2018 oneukum@suse.com
- media: usbtv: prevent double free in error case (bsc#1074426
  CVE-2017-17975).
- commit b36e4d6
* Wed Feb 28 2018 msuchanek@suse.de
- Move cdrom patches to storage section.
- cdrom: turn off autoclose by default (bsc#1080813).
- commit 3c15342
* Wed Feb 28 2018 jack@suse.cz
- fs/dax.c: release PMD lock even when there is no PMD support
  in DAX (bsc#1052766).
- commit 4806870
* Wed Feb 28 2018 jack@suse.cz
- ocfs2: return error when we attempt to access a dirty bh in jbd2
  (bsc#1052766).
- commit aeb7ce9
* Wed Feb 28 2018 jack@suse.cz
- fscache: Fix the default for fscache_maybe_release_page()
  (bsc#1052766).
- commit 45cac8c
* Wed Feb 28 2018 jack@suse.cz
- orangefs: off by ones in xattr size checks (bsc#1052766).
- commit caf695e
* Wed Feb 28 2018 jack@suse.cz
- f2fs: trigger normal fsync for non-atomic_write file
  (bsc#1052766).
- commit 8f867cc
* Wed Feb 28 2018 oneukum@suse.com
- HID: rmi: Make sure the HID device is opened on resume
  (bsc#1081188).
- commit c315d03
* Wed Feb 28 2018 tbogendoerfer@suse.de
- net: mvneta: eliminate wrong call to handle rx descriptor error
  (fate#319899).
- net: mvneta: use proper rxq_number in loop on rx queues
  (fate#319899).
- net: mvneta: fix handling of the Tx descriptor counter
  (fate#319899).
- commit 24508d7
* Wed Feb 28 2018 tbogendoerfer@suse.de
- ip6_gre: remove the incorrect mtu limit for ipgre tap
  (bsc#1056787).
- ip_gre: remove the incorrect mtu limit for ipgre tap
  (bsc#1056787).
- i40iw: Reinitialize IEQ on MTU change (bsc#1058659 FATE#322535).
- commit 426bcab
* Wed Feb 28 2018 tiwai@suse.de
- drm: fix tainted kernel caused by drm_panel_orientation_quirks.c
  (bsc#1083215).
- commit b67ad61
* Wed Feb 28 2018 jeffm@suse.com
- kernel: add product-identifying information to kernel build (FATE#325281).
- commit b163d4a
* Wed Feb 28 2018 jeffm@suse.com
- kconfig: move SUSE options from init/Kconfig to init/Kconfig.suse
- commit 8aa8057
* Wed Feb 28 2018 bpoirier@suse.com
- Refresh patch order in sorted section
- Refresh
  patches.drivers/ibmvnic-Check-for-NULL-skb-s-in-NAPI-poll-routine.patch.
- Refresh
  patches.drivers/scsi-megaraid_sas-Do-not-use-32-bit-atomic-request-d.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Avoid-triggering-undefined-behavior-in-.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-a-locking-imbalance-in-qlt_24xx_han.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-double-free-bug-after-firmware-time.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-incorrect-handle-for-abort-IOCB.patch.
- commit 63c83e7
* Wed Feb 28 2018 lduncan@suse.com
- KEYS: reject NULL restriction string when type is specified
  (bsc#1082623).
- Fix misannotated out-of-line _copy_to_user() (bsc#1082625).
- commit bbdb58c
* Tue Feb 27 2018 neilb@suse.com
- Delete patches.suse/blk-timeout-no-round.
  The flag isn't actually being using, and
  probably isn't needed.
  Bug 768084 has lots of discussion about delays being a little too long,
  but I cannot find anything specific about this patch.
  I suspect the real concern what that the delay
  was longer than expected, and that maybe in different circumstances it
  could end up being much longer.  As the extra unexpected delay is
  limited to 1 second, it is probably safe.
- commit 7adce7e
* Tue Feb 27 2018 jack@suse.cz
- Update tags in
  patches.fixes/ext4-Fix-ENOSPC-handling-in-DAX-page-fault-handler.patch.
- commit 2d083b7
* Tue Feb 27 2018 jbohac@suse.cz
- x86/platform/UV: Add check of TSC state set by UV BIOS
  (bsc#1082579).
- x86/tsc: Add option that TSC on Socket 0 being non-zero is valid
  (bsc#1082579).
- x86/tsc: Drastically reduce the number of firmware bug warnings
  (bsc#1082579).
- x86/tsc: Make CONFIG_X86_TSC=n build work again (bsc#1082579).
- x86/tsc: Provide a means to disable TSC ART (bsc#1082579).
- x86/tsc: Skip TSC test and error messages if already unstable
  (bsc#1082579).
- commit 9667786
* Tue Feb 27 2018 ddiss@suse.de
- target/rbd: use target_configure_unmap_from_queue() helper
  (bsc#1064320).
- target/rbd: handle zero length UNMAP requests early
  (bsc#1064320).
- commit 15a71ab
* Tue Feb 27 2018 ddiss@suse.de
- ceph: fix rebased xattr and cmpext support (bsc#1082443)
- Refresh
  patches.drivers/ceph-osd_client-add-support-for-CEPH_OSD_OP_GETXATTR.patch.
- Refresh
  patches.drivers/libceph-add-support-for-CMPEXT-compare-extent-reques.patch.
- Refresh
  patches.suse/rbd-do-away-with-obj_request-in-cmpsetxattr.patch.
- Refresh
  patches.suse/rbd-do-away-with-obj_request-in-setxattr.patch.
- commit 8add4f9
* Tue Feb 27 2018 msuchanek@suse.de
- ibmvnic: Fix early release of login buffer (bsc#1081134,
  git-fixes).
- commit c7b7dcd
* Tue Feb 27 2018 msuchanek@suse.de
- Revert "rpm/kernel-binary.spec.in: Also require m4 for build."
  This reverts commit 0d7b4b3f948c2efb67b7d1b95b5e1dcae225991c.
- commit f5686d2
* Tue Feb 27 2018 jeffm@suse.com
- btrfs: account for pinned bytes in should_alloc_chunk
  (bsc#1040182).
- commit fc228ad
* Tue Feb 27 2018 jeffm@suse.com
- housekeeping: move suse-only out-of-tree patches after sorted section
- commit 2b8141c
* Tue Feb 27 2018 mhocko@suse.com
- Update
  patches.fixes/mm-oom_reaper-gather-each-vma-to-prevent-leaking-TLB.patch
  (bnc#1073258, bnc#1083088, CVE-2017-18202).
- commit f906298
* Tue Feb 27 2018 jeffm@suse.com
- housekeeping: move kABI fixes after sorted section
- commit ed8c9b1
* Tue Feb 27 2018 jthumshirn@suse.de
- nvme-pci: Fix timeouts in connecting state (FATE#323952,
  FATE#322506).
- commit 10ad0a0
* Tue Feb 27 2018 jthumshirn@suse.de
- nvme: rename NVME_CTRL_RECONNECTING state to
  NVME_CTRL_CONNECTING (FATE#323952, FATE#322506).
- Refresh patches.drivers/nvme_fc-cleanup-io-completion.patch.
- Refresh
  patches.drivers/nvme_fc-correct-abort-race-condition-on-resets.patch.
- commit c1726a2
* Tue Feb 27 2018 nborisov@suse.com
- btrfs: finish ordered extent cleaning if no progress is found (bsc#1082964).
- commit d584b06
* Tue Feb 27 2018 tiwai@suse.de
- kernel-binary: do not package extract-cert when not signing modules
  (boo#1080250).
- commit 10a8bc4
* Mon Feb 26 2018 jeffm@suse.com
- housekeeping: move kbuild/supported patches after sorted section
- commit 20e13fb
* Mon Feb 26 2018 jeffm@suse.com
- housekeeping: moved SUSE-specific performance fixes after sorted section
- commit e4df9c8
* Mon Feb 26 2018 jeffm@suse.com
- housekeeping: move driver core patch after sorted section
- commit c3bf010
* Mon Feb 26 2018 jeffm@suse.com
- housekeeping: move cpufreq patches to sorted section
- commit 689ded1
* Mon Feb 26 2018 jeffm@suse.com
- housekeeping: remove empty sections
- commit 96041ef
* Mon Feb 26 2018 jeffm@suse.com
- housekeeping: move scheduler/core patches to sorted section
- commit c8094ad
* Mon Feb 26 2018 tbogendoerfer@suse.de
- net_sched: gen_estimator: fix broken estimators based on percpu
  stats (bsc#1056787).
- net/mlx5: Add header re-write to the checks for conflicting
  actions (bsc#1046305 FATE#322943).
- net/mlx5: Use 128B cacheline size for 128B or larger cachelines
  (bsc#1081944).
- net/mlx5e: Specify numa node when allocating drop rq
  (bsc#1046305 FATE#322943).
- net/mlx5e: Return error if prio is specified when offloading
  eswitch vlan push (bsc#1046305 FATE#322943).
- net/mlx5e: Verify inline header size do not exceed SKB linear
  size (bsc#1046305 FATE#322943).
- net/mlx5e: Fix loopback self test when GRO is off (bsc#1046305
  FATE#322943).
- net/mlx5e: Fix TCP checksum in LRO buffers (bsc#1046305
  FATE#322943).
- RDMA/vmw_pvrdma: Fix usage of user response structures in ABI
  file (bsc#1046306 FATE#322942).
- RDMA/uverbs: Sanitize user entered port numbers prior to access
  it (bsc#1046306 FATE#322942).
- RDMA/uverbs: Fix circular locking dependency (bsc#1046306
  FATE#322942).
- RDMA/uverbs: Fix bad unlock balance in ib_uverbs_close_xrcd
  (bsc#1046306 FATE#322942).
- IB/uverbs: Fix unbalanced unlock on error path for
  rdma_explicit_destroy (bsc#1046306 FATE#322942).
- IB/uverbs: Hold the uobj write lock after allocate (bsc#1046306
  FATE#322942).
- IB/uverbs: Fix method merging in uverbs_ioctl_merge (bsc#1046306
  FATE#322942).
- PCI/cxgb4: Extend T3 PCI quirk to T4+ devices (bsc#1064802
  bsc#1066129).
- cxgb4: fix trailing zero in CIM LA dump (bsc#1064802
  bsc#1066129).
- commit 2727999
* Mon Feb 26 2018 jeffm@suse.com
- housekeeping: move locking/core patches to sorted section
- commit 023fb41
* Mon Feb 26 2018 jeffm@suse.com
- housekeeping: moved s390 patches to sorted section
- commit fba6ff3
* Mon Feb 26 2018 jeffm@suse.com
- housekeeping: move x86 patches to sorted section
- commit 484f12c
* Mon Feb 26 2018 tbogendoerfer@suse.de
- Re-sorted series
- Refresh
  patches.drivers/ibmvnic-Check-for-NULL-skb-s-in-NAPI-poll-routine.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Avoid-triggering-undefined-behavior-in-.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-a-locking-imbalance-in-qlt_24xx_han.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-double-free-bug-after-firmware-time.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-incorrect-handle-for-abort-IOCB.patch.
- commit 9b71c59
* Mon Feb 26 2018 tiwai@suse.de
- nl80211: take RCU read lock when calling ieee80211_bss_get_ie()
  (bsc#1051510).
- nl80211: fix nl80211_send_iface() error paths (bsc#1051510).
- commit d8941e6
* Mon Feb 26 2018 jeffm@suse.com
- housekeeping: move VM/FS patches to sorted section
- commit 1fd8e1f
* Mon Feb 26 2018 tiwai@suse.de
- blacklist.conf: add a media blacklist
- commit a3cbc5c
* Mon Feb 26 2018 tiwai@suse.de
- extcon: int3496: process id-pin first so that we start with
  the right status (bsc#1051510).
- ALSA: usb-audio: Fix UAC2 get_ctl request with a RANGE attribute
  (bsc#1051510).
- media: exynos4-is: properly initialize frame format
  (bsc#1051510).
- media: cpia2: Fix a couple off by one bugs (bsc#1051510).
- Input: 88pm860x-ts - fix child-node lookup (bsc#1051510).
- Input: twl6040-vibra - fix child-node lookup (bsc#1051510).
- Input: twl4030-vibra - fix sibling-node lookup (bsc#1051510).
- cfg80211: fix station info handling bugs (bsc#1051510).
- cfg80211: check dev_set_name() return value (bsc#1051510).
- mfd: twl6040: Fix child-node lookup (bsc#1051510).
- mfd: twl4030-audio: Fix sibling-node lookup (bsc#1051510).
- nl80211: don't expose wdev->ssid for most interfaces
  (bsc#1051510).
- Documentation/sphinx: fix kernel-doc decode for non-utf-8 locale
  (bsc#1051510).
- [media] dvb uapi docs: enums are passed by value, not reference
  (bsc#1051510).
- Docs: Fix breakage with Sphinx 1.5 and upper (bsc#1051510).
- Docs: Include the Latex "ifthen" package (bsc#1051510).
- commit d06484d
* Mon Feb 26 2018 tiwai@suse.de
- drm/vmwgfx: fix memory corruption with legacy/sou connectors
  (bsc#1051510).
- drm/atomic: Unref duplicated drm_atomic_state in
  drm_atomic_helper_resume() (bsc#1051510).
- commit 18be9dc
* Mon Feb 26 2018 tiwai@suse.de
- blacklist.conf: add duplicated (cherry-picked) commits
- commit 4abafa8
* Mon Feb 26 2018 tiwai@suse.de
- blacklist.conf: Update drm blacklists
  They can't be applied because of the lack of some DRM stuff
- commit 92abf6d
* Mon Feb 26 2018 tiwai@suse.de
- mac80211: fix calling sleeping function in atomic context
  (bsc#1051510).
- mac80211: fix a possible leak of station stats (bsc#1051510).
- cfg80211: fix cfg80211_beacon_dup (bsc#1051510).
- PKCS#7: fix direct verification of SignerInfo signature
  (bsc#1051510).
- PKCS#7: fix certificate blacklisting (bsc#1051510).
- PKCS#7: fix certificate chain verification (bsc#1051510).
- i2c: designware: must wait for enable (bsc#1051510).
- drm: Handle unexpected holes in color-eviction (bsc#1051510).
- drm/edid: Add 6 bpc quirk for CPT panel in Asus UX303LA
  (bsc#1051510).
- drm/atomic: Fix memleak on ERESTARTSYS during non-blocking
  commits (bsc#1051510).
- drm/cirrus: Load lut in crtc_commit (bsc#1051510).
- drm: cirrus: remove dead code and pointless local lut storage
  (bsc#1051510).
- commit ff526a9
* Mon Feb 26 2018 tiwai@suse.de
- Preliminary series sort / updates
- commit 91ac254
* Mon Feb 26 2018 msuchanek@suse.de
- powerpc/powernv: Support firmware disable of RFI flush
  (bsc#1068032).
- powerpc/pseries: Support firmware disable of RFI flush
  (bsc#1068032).
- commit cfd8a20
* Mon Feb 26 2018 msuchanek@suse.de
- powerpc/mm/drmem: Fix unexpected flag value in
  ibm,dynamic-memory-v2 (FATE#324825, bsc#1077428).
- commit 2c4ae37
* Mon Feb 26 2018 bp@suse.de
- media: hdpvr: Fix an error handling path in hdpvr_probe()
  (bsc#1067118 CVE-2017-16644).
- commit 487f60d
* Mon Feb 26 2018 jlee@suse.com
- KEYS: prevent creating a different user's keyrings
  (bnc#1065999).
- commit 29ba1a4
* Mon Feb 26 2018 nborisov@suse.com
- f2fs: fix a bug caused by NULL extent tree (bsc#1082478).
- commit 1902646
* Mon Feb 26 2018 jeffm@suse.com
- housekeeping: move IPC patches to sorted section
- commit 3d6c0d8
* Mon Feb 26 2018 jeffm@suse.com
- housekeeping: moved small misc fixes to sorted section
- commit 2dae190
* Mon Feb 26 2018 jeffm@suse.com
- housekeeping: moved ACPI patches to sorted section
- commit 6332c79
* Mon Feb 26 2018 jeffm@suse.com
- housekeeping: move hyperv patches to sorted section
- commit 0cbd157
* Mon Feb 26 2018 jeffm@suse.com
- housekeeping: move ocfs2/dlm patches to sorted section
- commit 7a0f77b
* Mon Feb 26 2018 jeffm@suse.com
- housekeeping: move arm patches into sorted section
  There is a code change here, but it matches what the upstream ordering is.
- commit e55cbe7
* Mon Feb 26 2018 jeffm@suse.com
- housekeeping: move driver patches to sorted section
- commit 2167086
* Mon Feb 26 2018 jeffm@suse.com
- housekeeping: move cifs patches to sorted section
- commit 648f4e7
* Mon Feb 26 2018 jeffm@suse.com
- housekeeping: move epoll and lib patches to sorted section
- commit 435924b
* Sun Feb 25 2018 jeffm@suse.com
- housekeeping: move powerpc patches to sorted section
- commit 5f0255b
* Sun Feb 25 2018 jthumshirn@suse.de
- scsi: lpfc: Change Copyright of 12.0.0.0 modified files to 2018
  (bsc#1082595).
- scsi: lpfc: update driver version to 12.0.0.0 (bsc#1082595).
- scsi: lpfc: Work around NVME cmd iu SGL type (bsc#1082595).
- scsi: lpfc: Fix nvme embedded io length on new hardware
  (bsc#1082595).
- scsi: lpfc: Add embedded data pointers for enhanced performance
  (bsc#1082595).
- scsi: lpfc: Enable fw download on if_type=6 devices
  (bsc#1082595).
- scsi: lpfc: Add if_type=6 support for cycling valid bits
  (bsc#1082595).
- scsi: lpfc: Add 64G link speed support (bsc#1082595).
- scsi: lpfc: Add PCI Ids for if_type=6 hardware (bsc#1082595).
- scsi: lpfc: Add push-to-adapter support to sli4 (bsc#1082595).
- scsi: lpfc: Add SLI-4 if_type=6 support to the code base
  (bsc#1082595).
- scsi: lpfc: Rework sli4 doorbell infrastructure (bsc#1082595).
- scsi: lpfc: Rework lpfc to allow different sli4 cq and eq
  handlers (bsc#1082595).
- scsi: scsi_transport_fc: fix typos on 64/128 GBit define names
  (bsc#1082595).
- commit baa2a7f
* Sun Feb 25 2018 jthumshirn@suse.de
- Refresh
  patches.drivers/ibmvnic-Check-for-NULL-skb-s-in-NAPI-poll-routine.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Avoid-triggering-undefined-behavior-in-.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-a-locking-imbalance-in-qlt_24xx_han.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-double-free-bug-after-firmware-time.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-incorrect-handle-for-abort-IOCB.patch.
- commit fae1c5f
* Sun Feb 25 2018 jeffm@suse.com
- housekeeping: move storage patches into sorted section
- commit cab2152
* Sun Feb 25 2018 jeffm@suse.com
- housekeeping: move v4l patches to sorted section
- commit 5947eb8
* Sun Feb 25 2018 jeffm@suse.com
- housekeeping: move random patch to sorted section
- commit f7c56ff
* Sun Feb 25 2018 jeffm@suse.com
- housekeeping: move spectre/meltdown fixes to sorted section
- commit 425c053
* Sun Feb 25 2018 jeffm@suse.com
- housekeeping: move xen patches to sorted section
- commit 193f238
* Sun Feb 25 2018 jeffm@suse.com
- housekeeping: move livepatching to sorted section
- commit 32b7773
* Sun Feb 25 2018 jeffm@suse.com
- housekeeping: movw sysctl selftests to sorted section
- commit 21d7c50
* Sun Feb 25 2018 jeffm@suse.com
- housekeeping: move sysctl patches to sorted section
- commit 5453ebc
* Sun Feb 25 2018 jeffm@suse.com
- housekeeping: move iommu patches to sorted section
- commit 5ed331f
* Sun Feb 25 2018 jeffm@suse.com
- housekeeping: move perf patches to sorted section
- commit e4f7f31
* Sun Feb 25 2018 jeffm@suse.com
- housekeeping: move kdump patches to sorted section
- commit 32d312b
* Sun Feb 25 2018 jeffm@suse.com
- housekeeping: move objtool patches to sorted section
- commit cb30180
* Sat Feb 24 2018 jeffm@suse.com
- housekeeping: move some modsign patches into sorted section
- commit 69f402d
* Sat Feb 24 2018 jeffm@suse.com
- housekeeping: move crypto patches to sorted section
- commit 2f5e73f
* Sat Feb 24 2018 jeffm@suse.com
- housekeeping: move security patches to sorted section
- commit 7826f37
* Sat Feb 24 2018 jeffm@suse.com
- housekeeping: move md patches to sorted section
- commit 0d60c5b
* Sat Feb 24 2018 jeffm@suse.com
- housekeeping: move suspend/resume patches to sorted section
- commit eb55162
* Sat Feb 24 2018 jeffm@suse.com
- housekeeping: moved other drivers to sorted section
- commit d00ddbb
* Sat Feb 24 2018 jeffm@suse.com
- housekeeping: move printk patches to sorted section
- commit a3b711d
* Sat Feb 24 2018 jeffm@suse.com
- housekeeping: moved input patches to sorted section
- commit e6a3294
* Sat Feb 24 2018 jeffm@suse.com
- housekeeping: move serial patches to sorted section
- commit 7439018
* Sat Feb 24 2018 jeffm@suse.com
- housekeeping: move I2C patches to sorted section
- commit 81970be
* Sat Feb 24 2018 jeffm@suse.com
- housekeeping: move PCI patches to sorted section
- commit bc33814
* Sat Feb 24 2018 jeffm@suse.com
- housekeeping: move thunderbolt patches to sorted section
- commit ceb04da
* Sat Feb 24 2018 jeffm@suse.com
- housekeeping: move USB to sorted section
- commit 6f2b28e
* Fri Feb 23 2018 jeffm@suse.com
- housekeeping: move intel-drm to sorted section
- commit ad78bb9
* Fri Feb 23 2018 jeffm@suse.com
- housekeeping: rename some fs patches
- commit 14854d5
* Fri Feb 23 2018 jeffm@suse.com
- housekeeping: move other file system patches into sorted section
- commit d6e80d0
* Fri Feb 23 2018 jeffm@suse.com
- housekeeping: move apparmor to sorted section
- commit eb353f7
* Fri Feb 23 2018 jeffm@suse.com
- housekeeping: move NFS to sorted section
- commit eb19955
* Fri Feb 23 2018 jeffm@suse.com
- housekeeping: move cephfs patches into sorted section
- commit c1e3883
* Fri Feb 23 2018 msuchanek@suse.de
- git_sort: add powerpc/fixes branch.
- commit efaef8c
* Fri Feb 23 2018 jeffm@suse.com
- housekeeping: relocate xfs, btrfs, reiserfs, and ext4 patches to sorted
- commit 667c204
* Fri Feb 23 2018 mwilck@suse.com
- Update and enable
  patches.suse/scsi-do-not-print-reservation-conflict-for-TEST-UNIT.patch
  (bsc#1027054, bsc#1082587).
- commit c6ccd44
* Fri Feb 23 2018 mwilck@suse.com
- Enable patches.fixes/sd-always-scan-VPD-pages-if-thin-provisioning-is-ena.patch (bsc#1013792, bsc#1082587).
- commit 83c00c1
* Fri Feb 23 2018 jeffm@suse.com
- housekeeping: update tags and resort series
- commit 1f975c7
* Fri Feb 23 2018 mwilck@suse.com
- Refresh and enable
  patches.fixes/sd-always-retry-READ-CAPACITY-for-ALUA-state-transit.patch (bsc#1082587, bsc#895814).
- commit 426325e
* Fri Feb 23 2018 aaptel@suse.com
- refresh patch to fix build when SMB2 disabled
- commit e54b17e
* Fri Feb 23 2018 mwilck@suse.com
- Refresh and enable
  patches.fixes/scsi-disable-VPD-page-check-on-error.patch (bsc#1082587,
  bsc#981854).
- commit 53727b5
* Fri Feb 23 2018 mwilck@suse.com
- Delete
  patches.suse/scsi-always-retry-internal-target-error.patch (bsc#1082587).
  This one is superseded by
  patches.fixes/scsi-handle-special-return-codes-for-ABORTED-COMM.patch
- commit 62ad20c
* Fri Feb 23 2018 mwilck@suse.com
- Delete patches.suse/aacraid-export-fixed-module-param (bsc#1082587).
  This patch has a comment: "should be dropped in SLES13".
  Thus dropping it.
- commit 5794c6c
* Fri Feb 23 2018 mwilck@suse.com
- Refresh and enable
  patches.fixes/scsi_scan-Send-TEST-UNIT-READY-to-LUN0-before-LUN-sc.patch (bnc#843236, bnc#893377, bsc#1063043).
- commit 1972fc8
* Fri Feb 23 2018 msuchanek@suse.de
- blacklist
  171360d7800c tpm: fix type of a local variable in tpm2_get_cc_attrs_tbl()
  1a7a9b26c69d tpm: fix type of a local variables in tpm_tis_spi.c
  4557d4bedc9c tpm: fix type of a local variable in tpm2_map_command()
  These only add endian annotation to variables.
- commit 5804018
* Fri Feb 23 2018 msuchanek@suse.de
- tpm_tis_spi: Use DMA-safe memory for SPI transfers
  (bsc#1082555).
- tpm: constify transmit data pointers (bsc#1082555).
- tpm/tpm_crb: fix priv->cmd_size initialisation (bsc#1082555).
- tpm_tis: Use platform_get_irq (bsc#1082555).
- tpm_tis: Fix IRQ autoprobing when using platform_device
  (bsc#1082555).
- commit 8ed9550
* Fri Feb 23 2018 mwilck@suse.com
- scsi: handle special return codes for ABORTED COMMAND
  (bsc#1069138, bnc#745640, bnc#825227).
- commit 291f96e
* Fri Feb 23 2018 mwilck@suse.com
- Refresh
  patches.drivers/scsi-megaraid_sas-Do-not-use-32-bit-atomic-request-d.patch.
- commit d3bb77b
* Fri Feb 23 2018 mbrugger@suse.com
- drivers/fbdev/efifb: Allow BAR to be moved instead of claiming
  it (fate#323912).
- IB/hns: checking for IS_ERR() instead of NULL (fate#323912).
- arm64: sysreg: Fix unprotected macro argmuent in write_sysreg
  (fate#323912).
- efi/fb: Correct PCI_STD_RESOURCE_END usage (fate#323912).
- commit 8bc4586
* Fri Feb 23 2018 jthumshirn@suse.de
- nfit_test Make private definitions to command emulation
  (bsc#1082491).
- commit 05aa73b
* Fri Feb 23 2018 jthumshirn@suse.de
- Re-sort series.conf
- commit 5d633e1
* Fri Feb 23 2018 jkosina@suse.cz
- Update config files: KEXEC_VERIFY_SIG=n for x86 vanilla
- commit c240e03
* Fri Feb 23 2018 mkubecek@suse.cz
- bpf: fix stack_depth usage by test_bpf.ko (bsc#1081174
  bsc#1081380).
- bpf: track stack depth of classic bpf programs (bsc#1081174
  bsc#1081380).
- commit 78f0fd9
* Fri Feb 23 2018 mkubecek@suse.cz
- series.conf: refresh
  Ran series_sort.py (no effect on expanded tree).
- commit 8f7ddd5
* Fri Feb 23 2018 bp@suse.de
- EDAC, thunderx: Fix error handling path in thunderx_lmc_probe()
  (bsc#1057038).
- blacklist.conf:
- EDAC, thunderx: Fix a warning during l2c debugfs node creation
  (bsc#1057038).
- EDAC, sb_edac: Don't create a second memory controller if HA1
  is not present (bsc#1061721).
- EDAC, sb_edac: Classify memory mirroring modes (bsc#1061721).
- EDAC, sb_edac: Avoid creating SOCK memory controller
  (bsc#1061721).
- EDAC, sb_edac: Bump driver version and do some cleanups
  (bsc#1061721).
- EDAC, sb_edac: Check if ECC enabled when at least one DIMM is
  present (bsc#1061721).
- EDAC, sb_edac: Carve out dimm-populating loop (bsc#1061721).
- EDAC, sb_edac: Assign EDAC memory controller per h/w controller
  (bsc#1061721).
- EDAC, sb_edac: Don't use "Socket#" in the memory controller name
  (bsc#1061721).
- EDAC, sb_edac: Classify PCI-IDs by topology (bsc#1061721).
- EDAC, skx_edac: Handle systems with segmented PCI busses
  (bsc#1076447).
- EDAC, skx_edac: Fix detection of single-rank DIMMs
  (bsc#1076447).
- x86/cpu/amd: Limit cpu_core_id fixup to families older than F17h
  (bsc#1060229).
- commit 8fc298f
* Fri Feb 23 2018 hare@suse.de
- dm mpath: remove annoying message of 'blk_get_request()
  returned -11' (bsc#1077989).
- Refresh patches.suse/dm-mpath-accept-failed-paths.
- commit a7c32d7
* Fri Feb 23 2018 jthumshirn@suse.de
- acpi, nfit: fix register dimm error handling (bsc#1082491).
- acpi, nfit: fix health event notification (bsc#1082491).
- acpi/nfit: Issue Start ARS to retrieve existing records
  (bsc#1082491).
- acpi/nfit: Add support of NVDIMM memory error notification in
  ACPI 6.2 (bsc#1082491).
- commit 1a9ab53
* Fri Feb 23 2018 hare@suse.de
- scsi: bnx2fc: Simplify CPU hotplug code (bsc#1077989). - Refresh patches.drivers/scsi-bnx2i-simplify-cpu-hotplug-code.
- commit c6b20e3
* Fri Feb 23 2018 hare@suse.de
- scsi: scsi_dh: suppress errors from unsupported devices (bsc#1077989).
- scsi: scsi_dh: Return SCSI_DH_XX error code from ->attach() (bsc#1077989).
- scsi: fc: check for rport presence in fc_block_scsi_eh (bsc#1077989).
- scsi: scsi_transport_fc: Also check for NOTPRESENT in fc_remote_port_add() (bsc#1077989).
- scsi: scsi_transport_fc: set scsi_target_id upon rescan (bsc#1077989).
- commit ca27253
* Fri Feb 23 2018 jthumshirn@suse.de
- scsi: aacraid: Fix hang in kdump (bsc#1077989).
- scsi: aacraid: Check for PCI state of device in a generic way
  (bsc#1077989).
- commit 9736167
* Fri Feb 23 2018 hare@suse.de
- Drop superseded SUSE-specific patches
- Delete
  patches.drivers/qla2xxx-0040-Add-module-parameter-for-interrupt-mode.patch.
- Delete patches.fixes/scsi-Add-AIX-VDASD-to-blacklist.patch.
- Delete
  patches.fixes/scsi-Handle-power-on-reset-unit-attention.patch.
- Delete patches.fixes/scsi-Modify-HITACHI-OPEN-V-blacklist.patch.
- Delete
  patches.fixes/scsi-do-not-retry-invalid-function-error.patch.
- commit 2f21950
* Fri Feb 23 2018 jthumshirn@suse.de
- scsi: lpfc: Use after free in lpfc_rq_buf_free() (bsc#1077989).
- Refresh
  patches.drivers/scsi-lpfc-Fix-RQ-empty-firmware-trap.patch.
- commit dba777c
* Fri Feb 23 2018 hare@suse.de
- scsi: qedf: Fix error return code in __qedf_probe()
  (bsc#1077989).
- scsi: mpt3sas: Proper handling of set/clear of "ATA command
  pending" flag (bsc#1077989).
- scsi: fnic: add a space after %%p in printf format (bsc#1077989).
- scsi: devinfo: replace "Dell PV 650F" with "EMC CLARiiON"
  (bsc#1077989).
- scsi: dh: add new rdac devices (bsc#1077989).
- scsi: devinfo: apply to HP XP the same flags as Hitachi VSP
  (bsc#1077989).
- scsi: devinfo: Apply to HP-rebranded the same flags as Hitachi
  (bsc#1077989).
- scsi: pmcraid: use correct size unit when calling
  find_first_zero_bit() (bsc#1077989).
- scsi: ibmvscsis: add DRC indices to debug statements
  (bsc#1077989).
- block: fix blk_rq_append_bio (bsc#1077989).
- scsi: aacraid: Fix I/O drop during reset (bsc#1077989).
- scsi: aacraid: Prevent crash in case of free interrupt during
  scsi EH path (bsc#1077989).
- scsi: aacraid: Perform initialization reset only once
  (bsc#1077989).
- scsi: aacraid: Check for PCI state of device in a generic way
  (bsc#1077989).
- scsi: bnx2fc: Fix hung task messages when a cleanup response
  is not received during abort (bsc#1077989).
- cxlflash: get rid of pointless access_ok() (bsc#1077989).
- scsi: scsi_error: DID_SOFT_ERROR comment clean up (bsc#1077989).
- scsi: cxlflash: Derive pid through accessors (bsc#1077989).
- scsi: cxlflash: Allow cards without WWPN VPD to configure
  (bsc#1077989).
- scsi: cxlflash: Use derived maximum write same length
  (bsc#1077989).
- scsi: scsi_devinfo: Add scsi_devinfo_tbl.c (bsc#1077989).
- scsi: hpsa: bump driver version (bsc#1077989).
- scsi: hpsa: add enclosure logical identifier (bsc#1077989).
- scsi: hpsa: correct logical volume removal (bsc#1077989).
- scsi: hpsa: reduce warning messages on device removal
  (bsc#1077989).
- scsi: hpsa: update queue depth for externals (bsc#1077989).
- scsi: hpsa: correct smart path enabled (bsc#1077989).
- scsi: hpsa: change timeout for internal cmds (bsc#1077989).
- scsi: hpsa: update discovery polling (bsc#1077989).
- scsi: hpsa: add controller checkpoint (bsc#1077989).
- scsi: hpsa: clear tmpdevice in scan thread (bsc#1077989).
- scsi: hpsa: cleanup sas_phy structures in sysfs when unloading
  (bsc#1077989).
- scsi: hpsa: destroy sas transport properties before scsi_host
  (bsc#1077989).
- scsi: scsi_error: Handle power-on reset unit attention
  (bsc#1077989).
- scsi: scsi_error: Do not retry illegal function error
  (bsc#1077989).
- scsi: sd: change manage_start_stop to bool in sysfs interface
  (bsc#1077989).
- scsi: sd: change allow_restart to bool in sysfs interface
  (bsc#1077989).
- scsi: scsi: Export blacklist flags to sysfs (bsc#1077989).
- scsi: sd_zbc: Fix sd_zbc_read_zoned_characteristics()
  (bsc#1077989).
- scsi: sd_zbc: Use well defined macros (bsc#1077989).
- scsi: sd_zbc: Rearrange code (bsc#1077989).
- scsi: sd_zbc: Fix comments and indentation (bsc#1077989).
- scsi: sd_zbc: Move ZBC declarations to scsi_proto.h
  (bsc#1077989).
- scsi: libcxgbi: in case of vlan pass 0 as ifindex to find route
  (bsc#1077989).
- scsi: sd: Align maximum write same blocks to physical block size
  (bsc#1077989).
- scsi: csiostor: enable PCIe relaxed ordering if supported
  (bsc#1077989).
- scsi: libcxgbi: remove redundant check and close on csk
  (bsc#1077989).
- scsi: fcoe: open-code fcoe_destroy_work() for NETDEV_UNREGISTER
  (bsc#1077989).
- scsi: fcoe: separate out fcoe_vport_remove() (bsc#1077989).
- scsi: fcoe: move fcoe_interface_remove() out of
  fcoe_interface_cleanup() (bsc#1077989).
- scsi: bnx2i: Clean up unused pointers in bnx2i_hwi
  (bsc#1077989).
- block: Make q_usage_counter also track legacy requests
  (bsc#1077989).
- =?UTF-8?q?scsi:=20hpsa:=20Fix=20configured=5Flogical=5Fdr?=
  =?UTF-8?q?ive=5Fcount=C2=B7check?= (bsc#1077989).
- scsi: ibmvscsis: Fix write_pending failure path (bsc#1077989).
- scsi: libiscsi: Remove iscsi_destroy_session (bsc#1077989).
- scsi: libiscsi: Fix use-after-free race during
  iscsi_session_teardown (bsc#1077989).
- scsi: sd: Implement blacklist option for WRITE SAME w/ UNMAP
  (bsc#1077989).
- scsi: ILLEGAL REQUEST + ASC==27 => target failure (bsc#1077989).
- scsi: aacraid: Fix 2T+ drives on SmartIOC-2000 (bsc#1077989).
- scsi: Fix the kerneldoc for scsi_initialize_rq() (bsc#1077989).
- scsi: Use blk_mq_rq_to_pdu() to convert a request to a SCSI
  command pointer (bsc#1077989).
- scsi: Document which queue type a function is intended for
  (bsc#1077989).
- scsi: Convert a strncmp() call into a strcmp() call
  (bsc#1077989).
- scsi: Suppress gcc 7 fall-through warnings reported with W=1
  (bsc#1077989).
- scsi: ufs: reqs and tasks were put in the wrong order
  (bsc#1077989).
- scsi: pmcraid: fix duplicated code for different branches
  (bsc#1077989).
- scsi: sym53c8xx: Avoid undefined behaviour (bsc#1077989).
- scsi: virtio: virtio_scsi: Set can_queue to the length of the
  virtqueue (bsc#1077989).
- scsi: mvsas: replace kfree with scsi_host_put (bsc#1077989).
- scsi: esp_scsi: Always clear msg_out_len after MESSAGE OUT phase
  (bsc#1077989).
- scsi: esp_scsi: Avoid sending ABORT TASK SET messages
  (bsc#1077989).
- scsi: esp_scsi: Clean up control flow and dead code
  (bsc#1077989).
- scsi: libcxgbi: use ndev->ifindex to find route (bsc#1077989).
- scsi: mpt3sas: Fix memory allocation failure test in
  'mpt3sas_base_attach()' (bsc#1077989).
- scsi: mpt3sas: fix format overflow warning (bsc#1077989).
- scsi: sg: off by one in sg_ioctl() (bsc#1077989).
- scsi: cxgb4i: call neigh_event_send() to update MAC address
  (bsc#1077989).
- scsi: bnx2fc: Prevent recursive cpuhotplug locking
  (bsc#1077989).
- scsi: bnx2fc: Plug CPU hotplug race (bsc#1077989).
- ibmvscsis: Use tpgt passed in by user (bsc#1077989).
- ibmvscsis: Enable Logical Partition Migration Support
  (bsc#1077989).
- scsi: hpsa: fix spelling mistake: "encrypytion" -> "encryption"
  (bsc#1077989).
- scsi: hptiop: make function hptiop_iop_request_callback_itl
  static (bsc#1077989).
- scsi: esas2r: Replace semaphore fs_api_semaphore with mutex
  (bsc#1077989).
- scsi: esas2r: Replace semaphore fm_api_semaphore with mutex
  (bsc#1077989).
- scsi: libiscsi: use kvzalloc for iscsi_pool_init (bsc#1077989).
- scsi: ibmvscsi_tgt: remove use of class_attrs (bsc#1077989).
- commit eb5e851
* Fri Feb 23 2018 jslaby@suse.cz
- blacklist.conf: add some fixes from 12SP3
- commit 3559625
* Fri Feb 23 2018 ddiss@suse.de
- Update config files (bsc#1082443).
- commit ae8d93d
* Fri Feb 23 2018 ddiss@suse.de
- target/rbd: rebase and reapply LIO+RBD patch set (bsc#1082443).
- Refresh
  patches.drivers/ceph-osd_client-add-support-for-CEPH_OSD_OP_GETXATTR.patch.
- Refresh
  patches.drivers/libceph-add-scatterlist-messenger-data-type.patch.
- Refresh
  patches.drivers/libceph-add-support-for-CMPEXT-compare-extent-reques.patch.
- Refresh
  patches.drivers/libceph-add-support-for-write-same-requests.patch.
- Refresh patches.drivers/libceph-fix-pr_fmt-compile-issues.patch.
- Refresh
  patches.drivers/rbd-add-cmpsetattr-device-attribute-for-debugging.patch.
- Refresh
  patches.drivers/rbd-add-getxattr-device-attribute-for-debugging.patch.
- Refresh patches.drivers/rbd-add-lio-specific-data-area.patch.
- Refresh patches.drivers/rbd-add-num-ops-calculator-helper.patch.
- Refresh
  patches.drivers/rbd-add-rbd_dev_cmpsetxattr-helper.patch.
- Refresh patches.drivers/rbd-add-rbd_dev_getxattr-helper.patch.
- Refresh patches.drivers/rbd-add-rbd_dev_setxattr-helper.patch.
- Refresh
  patches.drivers/rbd-add-setxattr-device-attribute-for-debugging.patch.
- Refresh
  patches.drivers/rbd-add-support-for-COMPARE_AND_WRITE-CMPEXT.patch.
- Refresh
  patches.drivers/rbd-add-support-for-scatterlist-obj_request_type.patch.
- Refresh
  patches.drivers/rbd-add-support-for-writesame-requests.patch.
- Refresh patches.drivers/rbd-add-write-test-helper.patch.
- Refresh
  patches.drivers/rbd-export-some-functions-used-by-lio-rbd-backend.patch.
- Refresh
  patches.drivers/rbd-move-structs-used-by-lio-rbd-to-new-header.patch.
- Refresh
  patches.drivers/target-add-COMPARE_AND_WRITE-sg-creation-helper.patch.
- Refresh
  patches.drivers/target-add-compare-and-write-callback.patch.
- Refresh
  patches.drivers/target-add-lio-rbd-to-makefile-Kconfig.patch.
- Refresh patches.drivers/target-add-rbd-backend.patch.
- Refresh
  patches.drivers/target-compare-and-write-backend-driver-sense-handli.patch.
- Refresh
  patches.drivers/target-configfs-add-device-vendor_id-attribute.patch.
- Refresh
  patches.drivers/target-pr-add-backend-API-for-reservation-handling.patch.
- Refresh
  patches.drivers/target-pr-fix-core_scsi3_pr_seq_non-caller.patch.
- Refresh
  patches.drivers/target-pr-split-out-and-export-core_scsi3_pr_seq_non.patch.
- Refresh
  patches.drivers/target-rbd-SCSI3-check-conflict-support.patch.
- Refresh
  patches.drivers/target-rbd-add-SCSI2-reservation-entry-to-PR-info.patch.
- Refresh patches.drivers/target-rbd-add-pr_clear-support.patch.
- Refresh patches.drivers/target-rbd-add-pr_preempt-support.patch.
- Refresh
  patches.drivers/target-rbd-add-pr_read_reservation-support.patch.
- Refresh patches.drivers/target-rbd-add-pr_release-support.patch.
- Refresh
  patches.drivers/target-rbd-add-pr_report_capabilities-support.patch.
- Refresh patches.drivers/target-rbd-add-pr_reserve-support.patch.
- Refresh
  patches.drivers/target-rbd-add-stubbed-out-pr_read_full_status.patch.
- Refresh
  patches.drivers/target-rbd-add-stubbed-out-pr_register_and_move.patch.
- Refresh
  patches.drivers/target-rbd-add-support-for-PR-register-read-keys.patch.
- Refresh
  patches.drivers/target-rbd-fix-PR-info-memory-leaks.patch.
- Refresh
  patches.drivers/target-rbd-handle-SCSI2-reservation-release-on-reset.patch.
- Refresh
  patches.drivers/target-rbd-implement-SCSI2-reservation-handling.patch.
- Refresh
  patches.fixes/0001-rbd-drop-extra-rbd_img_request_get.patch.
- Refresh
  patches.fixes/0002-rbd-make-sure-pages-are-freed-by-libceph.patch.
- Refresh
  patches.fixes/libceph-fix-scatterlist-last_piece-calculation.patch.
- Refresh
  patches.fixes/libceph-use-upstream-write-same-opcode.patch.
- Refresh
  patches.fixes/rbd-copy-compare-and-write-osd-requests-before-resub.patch.
- Refresh
  patches.fixes/rbd-don-t-log-miscompare-as-an-error.patch.
- Refresh
  patches.fixes/rbd-handle-OBJ_REQUEST_SG-types-for-copyup.patch.
- Refresh
  patches.fixes/rbd-helper-to-copy-compare-and-write-osd-requests.patch.
- Refresh
  patches.fixes/rbd-truncate-objects-on-cmpext-short-reads.patch.
- Refresh
  patches.fixes/target-fix-tcm_rbd_gen_it_nexus-for-emulated-XCOPY-s.patch.
- Refresh
  patches.fixes/target-rbd-don-t-put-snap_context-twice.patch.
- Refresh patches.fixes/target-rbd-remove-caw_mutex-usage.patch.
- Refresh
  patches.suse/rbd-do-away-with-obj_request-in-cmpsetxattr.patch.
- Refresh
  patches.suse/rbd-do-away-with-obj_request-in-getxattr.patch.
- Refresh
  patches.suse/rbd-do-away-with-obj_request-in-setxattr.patch.
- Delete
  patches.drivers/libceph-support-bidirectional-requests.patch.
- Delete
  patches.drivers/target-rbd-fix-COMPARE-AND-WRITE-page-vector-leak.patch.
- Delete
  patches.fixes/ceph-memory-leak-in-ceph_direct_read_write-callback.patch.
- Delete
  patches.fixes/rbd-ensure-r_request-is-allocated-for-creatrunc.patch.
- Delete
  patches.fixes/rbd-fix-and-simplify-rbd_osd_req_format_rw.patch.
- Delete
  patches.suse/libceph-handle-writefull-for-OSD-op-extent-init.patch.
- commit 813747a
* Fri Feb 23 2018 neilb@suse.com
- seq_file: fix incomplete reset on read from zero offset
  (git-fixes).
- kernfs: fix regression in kernfs_fop_write caused by wrong type
  (git-fixes).
- jffs2: Fix use-after-free bug in jffs2_iget()'s error handling
  path (git-fixes).
- xprtrdma: Fix BUG after a device removal (git-fixes).
- xprtrdma: Fix calculation of ri_max_send_sges (git-fixes).
- xprtrdma: Fix "bytes registered" accounting (git-fixes).
- xprtrdma: Fix backchannel allocation of extra rpcrdma_reps
  (git-fixes).
- NFS: Fix a race between mmap() and O_DIRECT (git-fixes).
- NFS: reject request for id_legacy key without auxdata
  (git-fixes).
- nfs: Do not convert nfs_idmap_cache_timeout to jiffies
  (git-fixes).
- nfsd: fix panic in posix_unblock_lock called from
  nfs4_laundromat (git-fixes).
- lockd: lost rollback of set_grace_period() in lockd_down_net()
  (git-fixes).
- lockd: double unregister of inetaddr notifiers (git-fixes).
- nfs: Fix ugly referral attributes (git-fixes).
- NFS: Optimize fallocate by refreshing mapping when needed
  (bsc#1033587).
- commit 3cc1a0a
* Fri Feb 23 2018 mcgrof@suse.com
- kernel/sysctl_binary.c: check name array length in
  deprecated_sysctl_warning() (FATE#323821).
- commit da77fbb
* Fri Feb 23 2018 mcgrof@suse.com
- Refresh
  patches.drivers/0006-test_sysctl-add-simple-proc_dointvec-case.patch.
- commit 9426899
* Fri Feb 23 2018 jbohac@suse.cz
- x86/gart: Exclude GART aperture from vmcore (bsc#1046513).
- commit 3a49197
* Thu Feb 22 2018 mcgrof@suse.com
- scripts/sequence-patch.sh: bump patch version req to v2.7
  While at it also update the way we compute the version so a way
  which is much more easier to read and maintain. We borrow the
  kernel's scripts/ld-version.sh which has been in use for ages.
- commit 8fe4408
* Thu Feb 22 2018 msuchanek@suse.de
- Refresh patches.drivers/ibmvnic-Split-counters-for-scrq-pools-napi.patch.
  Add upstream commit hash
- commit 9eac9cb
* Thu Feb 22 2018 msuchanek@suse.de
- ibmvnic: Fix TX descriptor tracking (bsc#1081491).
- commit 87f9261
* Thu Feb 22 2018 jbohac@suse.cz
- kexec_file: Restrict at runtime if the kernel is locked down
  (fate#314486).
- kexec_file: split KEXEC_VERIFY_SIG into KEXEC_SIG and
  KEXEC_SIG_FORCE (fate#314486).
- Update config files.
- normalize return values of load_module with kernel lockdown
  patches.suse/0042-Enforce-module-signatures-if-the-kernel-is-locked-do.patch.
- Delete
  patches.suse/0047-kexec_file-Disable-at-runtime-if-securelevel-has-bee.patch.
- commit 61ff520
* Thu Feb 22 2018 rgoldwyn@suse.com
- userfaultfd: non-cooperative: fix fork use after free.
- commit 6637734
* Thu Feb 22 2018 jgross@suse.com
- xen/pvh*: Support > 32 VCPUs at domain restore (bnc#1065600).
- xen/vcpu: Simplify xen_vcpu related code (bnc#1065600).
- commit ed8f926
* Thu Feb 22 2018 msuchanek@suse.de
- mm, x86, powerpc: display pkey in smaps only if arch supports pkeys (FATE#322447, bsc#1078248).
- Refresh to current upstream submit
- Refresh patches.suse/mm-fix-KSM-data-corruption.patch.
- commit 6c82a45
* Thu Feb 22 2018 lpechacek@suse.com
- rpm/kernel-spec-macros: Try harder to detect Build Service environment (bsc#1078788)
- commit a5f1a4a
* Thu Feb 22 2018 hare@suse.de
- qla2xxx: ensure async flags are reset correctly (bsc#1081681).
- qla2xxx: do not check login_state if no loop id is assigned
  (bsc#1081681).
- qla2xxx: Fixup locking for session deletion (bsc#1081681).
- commit 9d633ab
* Thu Feb 22 2018 hare@suse.de
- qla2xxx: Fix incorrect tcm_qla2xxx_free_cmd use during TMR ABORT
  (v2) (bsc#1077989).
- commit eafbfa7
* Thu Feb 22 2018 hare@suse.de
- qla2xxx: Convert QLA_TGT_ABTS to TARGET_SCF_LOOKUP_LUN_FROM_TAG
  (bsc#1077989).
- Refresh
  patches.drivers/0071-scsi-qla2xxx-Fix-task-mgmt-handling-for-NPIV.patch.
- commit 0f758c5
* Thu Feb 22 2018 enadolski@suse.com
- btrfs: remove spurious WARN_ON(ref->count < 0) in
  find_parent_nodes (bsc#1081248).
- commit 8d9dca0
* Thu Feb 22 2018 hare@suse.de
- Refresh mainline tags
- Refresh
  patches.drivers/ibmvnic-Clean-RX-pool-buffers-during-device-close.patch.
- Refresh
  patches.drivers/ibmvnic-Fix-NAPI-structures-memory-leak.patch.
- Refresh
  patches.drivers/ibmvnic-Fix-login-buffer-memory-leaks.patch.
- Refresh
  patches.drivers/ibmvnic-Free-RX-socket-buffer-in-case-of-adapter-err.patch.
- Refresh
  patches.drivers/ibmvnic-Wait-until-reset-is-complete-to-set-carrier-.patch.
- commit 54182ed
* Thu Feb 22 2018 tiwai@suse.de
- crypto: skcipher - set walk.iv for zero-length inputs
  (bsc#1051510).
- commit fc489a6
* Thu Feb 22 2018 tiwai@suse.de
- rtlwifi: rtl8821ae: Fix connection lost problem correctly
  (bsc#1051510).
- Input: synaptics-rmi4 - unmask F03 interrupts when port is
  opened (bsc#1051510).
- crypto: sha3-generic - fixes for alignment and big endian
  operation (bsc#1051510).
- crypto: echainiv - Remove unused alg/spawn variable
  (bsc#1051510).
- crypto: ecdh - fix typo in KPP dependency of CRYPTO_ECDH
  (bsc#1051510).
- crypto: chacha20poly1305 - validate the digest size
  (bsc#1051510).
- crypto: rsa - fix buffer overread when stripping leading zeroes
  (bsc#1051510).
- pkcs7: return correct error code if pkcs7_check_authattrs()
  fails (bsc#1051510).
- crypto: skcipher - Fix skcipher_walk_aead_common (bsc#1051510).
- crypto: dh - Don't permit 'key' or 'g' size longer than 'p'
  (bsc#1051510).
- crypto: dh - Don't permit 'p' to be 0 (bsc#1051510).
- crypto: lrw - Check for incorrect cipher name (bsc#1051510).
- crypto: lrw - Fix an error handling path in 'create()'
  (bsc#1051510).
- pkcs7: Prevent NULL pointer dereference, since sinfo is not
  always set (bsc#1051510).
- KEYS: Fix the wrong index when checking the existence of second
  id (bsc#1051510).
- crypto: skcipher - Fix crash on zero-length input (bsc#1051510).
- crypto: xts - Fix an error handling path in 'create()'
  (bsc#1051510).
- commit d6282f2
* Thu Feb 22 2018 mbenes@suse.cz
- livepatch: send a fake signal periodically (fate#323487).
- commit 3f8b70f
* Thu Feb 22 2018 jthumshirn@suse.de
- s390/qeth: fix underestimated count of buffer elements
  (bnc#1082087, LTC#164529).
- commit 379f1f8
* Thu Feb 22 2018 mbrugger@suse.com
- arm64: entry: Apply BP hardening for suspicious interrupts
  from EL0 (bsc#1068032).
- arm64: entry: Apply BP hardening for high-priority synchronous
  exceptions (bsc#1068032).
- arm64: futex: Mask __user pointers prior to dereference
  (bsc#1068032).
- arm64: uaccess: Mask __user pointers for __arch_{clear,
  copy_*}_user (bsc#1068032).
- arm64: uaccess: Don't bother eliding access_ok checks in __{get,
  put}_user (bsc#1068032).
- arm64: uaccess: Prevent speculative use of the current
  addr_limit (bsc#1068032).
- arm64: entry: Ensure branch through syscall table is bounded
  under speculation (bsc#1068032).
- arm64: Use pointer masking to limit uaccess speculation
  (bsc#1068032).
- arm64: Make USER_DS an inclusive limit (bsc#1068032).
- arm64: Implement array_index_mask_nospec() (bsc#1068032).
- arm64: barrier: Add CSDB macros to control data-value prediction
  (bsc#1068032).
- arm64: move TASK_* definitions to <asm/processor.h>
  (bsc#1068032).
- commit 679bb40
* Thu Feb 22 2018 aaptel@suse.com
- CIFS: Fix NULL pointer deref on SMB2_tcon() failure
  (bsc#1071009).
- commit 6f343af
* Thu Feb 22 2018 lhenriques@suse.com
- quota: report root dir quota usage in statfs (FATE#323422).
- ceph: quota: add counter for snaprealms with quota
  (FATE#323422).
- ceph: quota: cache inode pointer in ceph_snap_realm
  (FATE#323422).
- ceph: fix root quota realm check (FATE#323422).
- ceph: don't check quota for snap inode (FATE#323422).
- ceph: quota: add quotas to the in-tree cephfs documentation
  (FATE#323422).
- ceph: quota: update MDS when max_bytes is approaching
  (FATE#323422).
- ceph: quota: support for ceph.quota.max_bytes (FATE#323422).
- ceph: quota: don't allow cross-quota renames (FATE#323422).
- ceph: quota: support for ceph.quota.max_files (FATE#323422).
- ceph: quota: add initial infrastructure to support cephfs quotas
  (FATE#323422).
- commit 06ea255
* Thu Feb 22 2018 msuchanek@suse.de
- ibmvnic: Split counters for scrq/pools/napi (bsc#1082223).
- ibmvnic: Correct goto target for tx irq initialization failure
  (bsc#1082223).
- ibmvnic: Allocate max queues stats buffers (bsc#1081498).
- ibmvnic: Make napi usage dynamic (bsc#1081498).
- ibmvnic: Free and re-allocate scrqs when tx/rx scrqs change
  (bsc#1081498).
- ibmvnic: Move active sub-crq count settings (bsc#1081498).
- ibmvnic: Rename active queue count variables (bsc#1081498).
- commit 11616b1
* Thu Feb 22 2018 tiwai@suse.de
- drm/i915/cnl: Sync PCI ID with Spec (FATE#322643 bsc#1055900).
- drm/i915/cnl: Fix PORT_TX_DW5/7 register address (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Remove alpha_support protection (FATE#322643
  bsc#1055900).
- drm/i915/cnl: WaPipeControlBefore3DStateSamplePattern
  (FATE#322643 bsc#1055900).
- drm/i915/dp: limit DP link rate based on VBT on CNL+
  (FATE#322643 bsc#1055900).
- drm/i915/dp: clean up source rate limiting for cnl (FATE#322643
  bsc#1055900).
- drm/i915/dp: abstract rate array length limiting (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Fix DP max rate for Cannonlake with port F
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Enable DDI-F on Cannonlake (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Add HPD support for Port F (FATE#322643
  bsc#1055900).
- drm/i915: For HPD connected port use hpd_pin instead of port
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Add right GMBUS pin number for HDMI on Port F
  (FATE#322643 bsc#1055900).
- drm/i915: Fix DPLCLKA_CFGCR0 bits for Port F (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Fix _CNL_PORT_TX_DW2_LN0_F definition (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Extend Wa 1178 to Aux F (FATE#322643 bsc#1055900).
- drm/i915/cnl: Add AUX-F support (FATE#322643 bsc#1055900).
- drm/i915/cnl: Add Cannonlake PCI IDs for another SKU
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Fix aux selection for WA 1178 (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Add Port F definition (FATE#322643 bsc#1055900).
- drm/i915/cnl: apply Display WA #1178 to fix type C dongles
  (FATE#322643 bsc#1055900).
- drm/i915/dmc: DMC 1.07 for Cannonlake (FATE#322643 bsc#1055900).
- commit 3d0b03e
* Thu Feb 22 2018 tiwai@suse.de
- ALSA: hda/realtek: PCI quirk for Fujitsu U7x7 (bsc#1052235).
- ALSA: hda/realtek - Enable Thinkpad Dock device for ALC298
  platform (bsc#1052235).
- ALSA: hda/realtek - Add headset mode support for Dell laptop
  (bsc#1052235).
- ALSA: hda - Fix headset mic detection problem for two Dell
  machines (bsc#1052235).
- ALSA: hda/realtek - update ALC215 depop optimize (bsc#1052235).
- ALSA: hda/realtek - Support headset mode for
  ALC215/ALC285/ALC289 (bsc#1052235).
- ALSA: hda/realtek - update ALC225 depop optimize (bsc#1052235).
- ALSA: hda - Clean up ALC299 init code (bsc#1052235).
- ALSA: hda - Fix yet remaining issue with vmaster 0dB
  initialization (bsc#1052235).
- ALSA: hda - silence uninitialized variable warning in
  activate_amp_in() (bsc#1052235).
- ALSA: hda - Fix incorrect TLV callback check introduced during
  set_fs() removal (bsc#1052235).
- ALSA: hda - Fix unbalance of i915 module refcount (bsc#1052235).
- ALSA: hda/realtek - Remove GPIO_MASK (bsc#1052235).
- ALSA: hda - Fix doubly initialization of i915 component
  (bsc#1052235).
- ALSA: hda - Minor code refactoring for Intel HDMI codec parsers
  (bsc#1052235).
- ALSA: hda - Bind with i915 component before codec binding
  (bsc#1052235).
- ALSA: hda - Skip card registration when no codec is found
  (bsc#1052235).
- ALSA: hda - Remove superfluous header inclusions (bsc#1052235).
- ALSA: hda - Fix a typo in comment (bsc#1052235).
- ALSA: hda - Remove the use of set_fs() (bsc#1052235).
- ALSA: hda - Remove the generic bind ctl helpers (bsc#1052235).
- ALSA: hda - Move bind-mixer switch codes to generic parser
  (bsc#1052235).
- ALSA: hda - Simplify bound-beep mute control for ALC268
  (bsc#1052235).
- commit d0f912f
* Thu Feb 22 2018 tiwai@suse.de
- ALSA: hda: Abort capability probe on invalid capability
  (bsc#1051510).
- ALSA: hda: Avoid racy recreation of widget kobjects
  (bsc#1051510).
- ALSA: hda: Fix potential race at unregistration and unsol events
  (bsc#1051510).
- commit 34b6b53
* Thu Feb 22 2018 tiwai@suse.de
- spi-nor: intel-spi: Fix broken software sequencing codes
  (bsc#1073836).
- commit ae5adb4
* Thu Feb 22 2018 nborisov@suse.com
- btrfs: Fix quota reservation leak on preallocated files
  (bsc#1079989).
- commit 8af1c31
* Thu Feb 22 2018 tiwai@suse.de
- KEYS: fix key refcount leak in keyctl_read_key() (bsc#1031717).
- KEYS: fix key refcount leak in keyctl_assume_authority()
  (bsc#1031717).
- KEYS: don't revoke uninstantiated key in request_key_auth_new()
  (bsc#1031717).
- KEYS: fix cred refcount leak in request_key_auth_new()
  (bsc#1031717).
- Input: uinput - avoid crash when sending FF request to device
  going away (bsc#1031717).
- r8169: Do not increment tx_dropped in TX ring cleaning
  (bsc#1031717).
- platform/x86: ideapad-laptop: Add several models to no_hw_rfkill
  (bsc#1051022).
- platform/x86: ideapad-laptop: Add IdeaPad V510-15IKB to
  no_hw_rfkill (bsc#1051022).
- platform/x86: ideapad-laptop: Add Y720-15IKBN to no_hw_rfkill
  (bsc#1051022).
- platform/x86: ideapad-laptop: Add Y520-15IKBN to no_hw_rfkill
  (bsc#1051022).
- commit 016b076
* Wed Feb 21 2018 tiwai@suse.de
- drm/i915: Fix DSI panels with v1 MIPI sequences without a
  DEASSERT sequence v3 (FATE#322643 bsc#1055900).
- drm/i915: Free memdup-ed DSI VBT data structures on
  driver_unload (FATE#322643 bsc#1055900).
- drm/i915: Add intel_bios_cleanup() function (FATE#322643
  bsc#1055900).
- drm/i915/vlv: Add cdclk workaround for DSI (FATE#322643
  bsc#1055900).
- drm/i915/gvt: fix one typo of render_mmio trace (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Support BAR0 8-byte reads/writes (FATE#322643
  bsc#1055900).
- drm/i915/gvt: add 0xe4f0 into gen9 render list (FATE#322643
  bsc#1055900).
- drm/i915: Lock out execlist tasklet while peeking inside for
  busy-stats (FATE#322643 bsc#1055900).
- drm/i915/breadcrumbs: Ignore unsubmitted signalers (FATE#322643
  bsc#1055900).
- drm/i915: Don't wake the device up to check if the engine is
  asleep (FATE#322643 bsc#1055900).
- commit 9b8a688
* Wed Feb 21 2018 tiwai@suse.de
- Add no-fix tags to cherry-picked ids in drm patches
- commit fbe9d22
* Wed Feb 21 2018 msuchanek@suse.de
- kernel-binary undefine unique_debug_names
  Some tools do not understand names like
  usr/lib/debug/boot/vmlinux-4.12.14-11.10-default-4.12.14-11.10.ppc64le.debug
- commit 2b90c1e
* Wed Feb 21 2018 tiwai@suse.de
- supported.conf: add drm_panel_orientation_quirks
- commit e6a774c
* Wed Feb 21 2018 mbrugger@suse.com
- Refresh
  patches.drivers/ibmvnic-Clean-RX-pool-buffers-during-device-close.patch.
- Refresh
  patches.drivers/ibmvnic-Fix-NAPI-structures-memory-leak.patch.
- Refresh
  patches.drivers/ibmvnic-Fix-login-buffer-memory-leaks.patch.
- Refresh
  patches.drivers/ibmvnic-Free-RX-socket-buffer-in-case-of-adapter-err.patch.
- Refresh
  patches.drivers/ibmvnic-Wait-until-reset-is-complete-to-set-carrier-.patch.
- commit f8e8ff0
* Wed Feb 21 2018 tiwai@suse.de
- Refresh
  patches.drivers/drm-i915-Move-dev_priv-mm.-un-bound_list-to-its-own-.
  Fix the regression with unblanaced list.
- commit 0ae1532
* Wed Feb 21 2018 msuchanek@suse.de
- ibmvnic: Keep track of supplementary TX descriptors
  (bsc#1081491).
- commit 5bf3dc8
* Wed Feb 21 2018 msuchanek@suse.de
- ibmvnic: Check for NULL skb's in NAPI poll routine (bsc#1081134,
  git-fixes).
- commit 092ca14
* Wed Feb 21 2018 msuchanek@suse.de
- Refresh sorted section.
- Refresh patches.drivers/ibmvnic-Clean-RX-pool-buffers-during-device-close.patch.
- Refresh patches.drivers/ibmvnic-Fix-NAPI-structures-memory-leak.patch.
- Refresh patches.drivers/ibmvnic-Fix-login-buffer-memory-leaks.patch.
- Refresh patches.drivers/ibmvnic-Free-RX-socket-buffer-in-case-of-adapter-err.patch.
- Refresh patches.drivers/ibmvnic-Wait-until-reset-is-complete-to-set-carrier-.patch.
- Refresh patches.drivers/scsi-lpfc-Add-WQ-Full-Logic-for-NVME-Target.patch.
- Refresh patches.drivers/scsi-lpfc-Allow-set-of-maximum-outstanding-SCSI-cmd-.patch.
- Refresh patches.drivers/scsi-lpfc-Fix-IO-failure-during-hba-reset-testing-wi.patch.
- Refresh patches.drivers/scsi-lpfc-Fix-PRLI-handling-when-topology-type-chang.patch.
- Refresh patches.drivers/scsi-lpfc-Fix-RQ-empty-firmware-trap.patch.
- Refresh patches.drivers/scsi-lpfc-Fix-SCSI-io-host-reset-causing-kernel-cras.patch.
- Refresh patches.drivers/scsi-lpfc-Fix-frequency-of-Release-WQE-CQEs.patch.
- Refresh patches.drivers/scsi-lpfc-Fix-header-inclusion-in-lpfc_nvmet.patch.
- Refresh patches.drivers/scsi-lpfc-Fix-issue_lip-if-link-is-disabled.patch.
- Refresh patches.drivers/scsi-lpfc-Fix-nonrecovery-of-NVME-controller-after-c.patch.
- Refresh patches.drivers/scsi-lpfc-Fix-soft-lockup-in-lpfc-worker-thread-duri.patch.
- Refresh patches.drivers/scsi-lpfc-Increase-CQ-and-WQ-sizes-for-SCSI.patch.
- Refresh patches.drivers/scsi-lpfc-Indicate-CONF-support-in-NVMe-PRLI.patch.
- Refresh patches.drivers/scsi-lpfc-Treat-SCSI-Write-operation-Underruns-as-an.patch.
- Refresh patches.drivers/scsi-lpfc-Update-11.4.0.7-modified-files-for-2018-Co.patch.
- Refresh patches.drivers/scsi-lpfc-Validate-adapter-support-for-SRIU-option.patch.
- Refresh patches.drivers/scsi-lpfc-correct-debug-counters-for-abort.patch.
- Refresh patches.drivers/scsi-lpfc-move-placement-of-target-destroy-on-driver.patch.
- Refresh patches.drivers/scsi-lpfc-update-driver-version-to-11.4.0.7.patch.
- commit d2121ce
* Wed Feb 21 2018 mfleming@suse.de
- cpufreq: schedutil: Reset cached_raw_freq when not in sync
  with next_freq (git-fixes).
- commit 45b8f64
* Wed Feb 21 2018 msuchanek@suse.de
- powerpc/eeh: Fix crashes in eeh_report_resume() (FATE#324970,
  bsc#1078720).
- commit a168aa8
* Wed Feb 21 2018 tiwai@suse.de
- blacklist.conf: add drm blacklists
- commit e3024ca
* Wed Feb 21 2018 tiwai@suse.de
- drm/i915: Avoid truncation before clamping userspace's priority
  value (FATE#322643 bsc#1055900).
- drm/i915/perf: Fix compiler warning for string truncation
  (FATE#322643 bsc#1055900).
- drm/ast: Load lut in crtc_commit (FATE#322643 bsc#1055900).
- commit 81092f7
* Wed Feb 21 2018 tiwai@suse.de
- drm: Fix PANEL_ORIENTATION_QUIRKS breaking the Kconfig DRM
  menuconfig (FATE#322643 bsc#1055900).
- Update config files.
- commit a55f11f
* Wed Feb 21 2018 tiwai@suse.de
- documentation/gpu/i915: fix docs build error after file rename
  (FATE#322643 bsc#1055900).
- drm: rcar-du: Don't set connector DPMS property (FATE#322643
  bsc#1055900).
- drm/fb_helper: Disable all crtc's when initial setup fails
  (FATE#322643 bsc#1055900).
- drm/fsl-dcu: Don't set connector DPMS property (FATE#322643
  bsc#1055900).
- commit 3c20f19
* Wed Feb 21 2018 tiwai@suse.de
- drm/i915: Hold rcu_read_lock when iterating over the radixtree
  (vma idr) (FATE#322643 bsc#1055900).
- Refresh
  patches.drivers/drm-i915-Reorder-context-close-to-avoid-calling-i915.
- commit dd5076b
* Wed Feb 21 2018 tiwai@suse.de
- drm/atomic: Check for busy planes/connectors before setting
  the commit (FATE#322643 bsc#1055900).
- drm/i915: Don't use BIT() in UAPI section (FATE#322643
  bsc#1055900).
- drm: Make __drm_object_property_get_value() static (FATE#322643
  bsc#1055900).
- drm: Make syncobj import/export functions static (FATE#322643
  bsc#1055900).
- commit 3c66d76
* Wed Feb 21 2018 tiwai@suse.de
- drm: rename u32 in __u32 in uapi (FATE#322643 bsc#1055900).
- drm: Shift wrap bug in create_in_format_blob() (FATE#322643
  bsc#1055900).
- drm: Fix kerneldoc for atomic_async_update (FATE#322643
  bsc#1055900).
- commit a2db442
* Wed Feb 21 2018 tiwai@suse.de
- dma-buf/sync_file: Allow multiple sync_files to wrap a single
  dma-fence (FATE#322643 bsc#1055900).
- commit dbff788
* Wed Feb 21 2018 tiwai@suse.de
- Re-enable downstream DRM patches
  Refresh
  patches.drivers/drm-mgag200-Add-command-line-option-to-specify-preferred-depth.patch.
- commit 61ea818
* Wed Feb 21 2018 tiwai@suse.de
- drm/i915/kbl: Change a KBL pci id to GT2 from GT1.5 (FATE#322643
  bsc#1055900).
- commit 46445eb
* Wed Feb 21 2018 tiwai@suse.de
- drm/i915/bios: add DP max link rate to VBT child device struct
  (FATE#322643 bsc#1055900).
- drm/i915/cnp: Properly handle VBT ddc pin out of bounds
  (FATE#322643 bsc#1055900).
- drm/i915/cnp: Ignore VBT request for know invalid DDC pin
  (FATE#322643 bsc#1055900).
- drm/i915/cmdparser: Do not check past the cmd length
  (FATE#322643 bsc#1055900).
- drm/i915/cmdparser: Check reg_table_count before derefencing
  (FATE#322643 bsc#1055900).
- drm/i915/bxt, glk: Increase PCODE timeouts during CDCLK freq
  changing (FATE#322643 bsc#1055900).
- drm/i915/gvt: Use KVM r/w to access guest opregion (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Fix aperture read/write emulation when enable
  x-no-mmap=on (FATE#322643 bsc#1055900).
- drm/i915/gvt: only reset execlist state of one engine during
  VM engine reset (FATE#322643 bsc#1055900).
- drm/i915/gvt: refine intel_vgpu_submission_ops as per engine
  ops (FATE#322643 bsc#1055900).
- drm/i915/ppgtt: Pin page directories before allocation
  (FATE#322643 bsc#1055900).
- drm/i915: Always run hangcheck while the GPU is busy
  (FATE#322643 bsc#1055900).
- Revert "drm/i915: mark all device info struct with __initconst"
  (FATE#322643 bsc#1055900).
- drm/i915/edp: Do not do link training fallback or prune modes
  on EDP (FATE#322643 bsc#1055900).
- drm/i915: Check for fused or unused pipes (FATE#322643
  bsc#1055900).
- drm/i915: Protect WC stash allocation against direct reclaim
  (FATE#322643 bsc#1055900).
- drm/i915: Always call to intel_display_set_init_power() in
  resume_early (FATE#322643 bsc#1055900).
- drm/i915/gvt: cancel scheduler timer when no vGPU exists
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: cancel virtual vblank timer when no vGPU exists
  (FATE#322643 bsc#1055900).
- drm/i915/pmu: Reconstruct active state on starting busy-stats
  (FATE#322643 bsc#1055900).
- drm/i915: Stop getting the fault address from RING_FAULT_REG
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Add uc_fini_wq in gem_init unwind path
  (FATE#322643 bsc#1055900).
- drm/i915: Fix using BIT_ULL() vs. BIT() for power domain masks
  (FATE#322643 bsc#1055900).
- drm/i915: Try EDID bitbanging on HDMI after failed read
  (FATE#322643 bsc#1055900).
- drm/i915/glk: Disable Guc and HuC on GLK (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Do not use I915_NUM_ENGINES to iterate over the
  mocs regs array (FATE#322643 bsc#1055900).
- drm/i915/gvt: validate gfn before set shadow page entry
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: add PLANE_KEYMAX regs to mmio track list
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Fix gen8/9_render_mmio_list[0] don't take effect
  (FATE#322643 bsc#1055900).
- drm/i915: Update DRIVER_DATE to 20171222 (FATE#322643
  bsc#1055900).
- drm/i915: Assert that the request is on the execution queue
  before being removed (FATE#322643 bsc#1055900).
- drm/i915/execlists: Show preemption progress in GEM_TRACE
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: move write protect handler out of mmio emulation
  function (FATE#322643 bsc#1055900).
- drm/i915/gvt: cleanup usage for typed mmio reg vs. offset
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: always use i915_reg_t for MMIO handler definition
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: load host render mocs once in mocs switch
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: refine mocs save restore policy (FATE#322643
  bsc#1055900).
- drm/i915/gvt: optimize for vGPU mmio switch (FATE#322643
  bsc#1055900).
- drm/i915/gvt: refine trace_render_mmio (FATE#322643
  bsc#1055900).
- drm/i915: Disable GMBUS clock gating around GMBUS transfers
  on gen9+ (FATE#322643 bsc#1055900).
- drm/i915: Clean up the PNV bit banging vs. GMBUS clock gating
  w/a (FATE#322643 bsc#1055900).
- drm/i915: No need to power up PG2 for GMBUS on BXT (FATE#322643
  bsc#1055900).
- drm/i915: Do not enable movntdqa optimization in hypervisor
  guest (FATE#322643 bsc#1055900).
- drm/i915: Dump device info at once (FATE#322643 bsc#1055900).
- drm/i915: Add pretty printer for runtime part of
  intel_device_info (FATE#322643 bsc#1055900).
- drm/i915: Update intel_device_info_runtime_init() parameter
  (FATE#322643 bsc#1055900).
- drm/i915: Move intel_device_info definitions to its own header
  (FATE#322643 bsc#1055900).
- drm/i915: Move opregion definitions to dedicated
  intel_opregion.h (FATE#322643 bsc#1055900).
- drm/i915: Move display related definitions to dedicated header
  (FATE#322643 bsc#1055900).
- drm/i915: Move some utility functions to i915_util.h
  (FATE#322643 bsc#1055900).
- drm/i915: Disable all planes for load detection, v2 (FATE#322643
  bsc#1055900).
- drm/i915/cfl: Adding more Coffee Lake PCI IDs (FATE#322643
  bsc#1055900).
- drm/i915: Tidy up GEM_TRACE around execlists (FATE#322643
  bsc#1055900).
- drm/i915: Avoid context dereference inside
  execlists_submission_tasklet (FATE#322643 bsc#1055900).
- drm/i915: Remove pointer indirection for hangcheck_state local
  (FATE#322643 bsc#1055900).
- drm/i915: Show if we consider the engine is idle in the GPU
  error state (FATE#322643 bsc#1055900).
- drm/i915: Implement WaDisableEarlyEOT (FATE#322643 bsc#1055900).
- drm/i915: Implement WaDisableVFclkgate (FATE#322643
  bsc#1055900).
- drm/i915: Add pretty printer for modparams (FATE#322643
  bsc#1055900).
- drm/i915: Convert intel_device_info_dump into pretty printer
  (FATE#322643 bsc#1055900).
- drm/i915: Add pretty printer for device info flags (FATE#322643
  bsc#1055900).
- drm/i915: Fix indentation for intel_ddi_clk_select (FATE#322643
  bsc#1055900).
- drm/i915: Add a strong mb to resetting the has-CS-interrupt bit
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Add support for horizontal plane flipping
  (FATE#322643 bsc#1055900).
- drm/i915/trace: add hw_id to gem requests trace points
  (FATE#322643 bsc#1055900).
- drm/i915: reorder field in gem_request tracepoints (FATE#322643
  bsc#1055900).
- drm/i915: Show IPEIR and IPEHR in the engine dump (FATE#322643
  bsc#1055900).
- drm/i915: Re-enable GGTT earlier after GPU reset (FATE#322643
  bsc#1055900).
- drm/i915: Unifying debugfs return codes for unsupported features
  (FATE#322643 bsc#1055900).
- drm/i915: Restore the kernel context after a GPU reset on an
  idle engine (FATE#322643 bsc#1055900).
- drm/i915: Skip an engine reset if it recovered before our
  preparations (FATE#322643 bsc#1055900).
- x86/gpu: add CFL to early quirks (FATE#322643 bsc#1055900).
- drm/i915: Allow internal page allocations to fail (FATE#322643
  bsc#1055900).
- drm/i915: Update DRIVER_DATE to 20171214 (FATE#322643
  bsc#1055900).
- drm/i915/gvt/fb_decoder: Fix out-of-bounds read (FATE#322643
  bsc#1055900).
- drm/i915/gvt: refine function emulate_mmio_read/write
  (FATE#322643 bsc#1055900).
- drm/i915/gvt/kvmgt: fill info for ROM/VGA region (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Rename file render.{c, h} to mmio_context.{c, h}
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Remove MMIO barrier in MMIO switch (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Select appropriate mmio list at initialization
  time (FATE#322643 bsc#1055900).
- drm/i915/gvt: Refine the ring mmio list definition (FATE#322643
  bsc#1055900).
- drm/i915/gvt: fix off-by-one comparison of ring_id (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Add missing breaks in switch statement
  (FATE#322643 bsc#1055900).
- drm/i915: properly init lockdep class (FATE#322643 bsc#1055900).
- drm/i915: make CS frequency read support missing more obvious
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Extract doorbell verification into a function
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Extract clients allocation to submission_init
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Extract doorbell creation from client allocation
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Call invalidate after changing the vfunc
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Extract guc_init from guc_init_hw (FATE#322643
  bsc#1055900).
- drm/i915/guc: Move GuC workqueue allocations outside of the
  mutex (FATE#322643 bsc#1055900).
- drm/i915/guc: Move shared data allocation away from submission
  path (FATE#322643 bsc#1055900).
- drm/i915: Unwind i915_gem_init() failure (FATE#322643
  bsc#1055900).
- drm/i915: Ratelimit request allocation under oom (FATE#322643
  bsc#1055900).
- drm/i915: Allow fence allocations to fail (FATE#322643
  bsc#1055900).
- drm/i915: Mark up potential allocation paths within
  i915_sw_fence as might_sleep (FATE#322643 bsc#1055900).
- drm/i915: Don't check #active_requests from
  i915_gem_wait_for_idle() (FATE#322643 bsc#1055900).
- drm/i915: Bump timeout for wait_for_engines() (FATE#322643
  bsc#1055900).
- drm/i915: Downgrade misleading "Memory usable" message
  (FATE#322643 bsc#1055900).
- drm/i915: Print an error message for a reset failure on gen2
  (FATE#322643 bsc#1055900).
- drm/i915: prefer resource_size_t for everything stolen
  (FATE#322643 bsc#1055900).
- drm/i915: give stolen_usable_size a more suitable home
  (FATE#322643 bsc#1055900).
- drm/i915: make mappable struct resource centric (FATE#322643
  bsc#1055900).
- drm/i915: make reserved struct resource centric (FATE#322643
  bsc#1055900).
- drm/i915: make dsm struct resource centric (FATE#322643
  bsc#1055900).
- drm/i915: nuke the duplicated stolen discovery (FATE#322643
  bsc#1055900).
- x86/early-quirks: export the stolen region as a resource
  (FATE#322643 bsc#1055900).
- drm/i915: Only report a wakeup if the waiter was truly asleep
  (FATE#322643 bsc#1055900).
- commit cd3b46b
* Wed Feb 21 2018 mhocko@suse.com
- mm: drop migrate type checks from has_unmovable_pages
  (bnc#1074195).
- commit 4ff7604
* Wed Feb 21 2018 tiwai@suse.de
- drm/i915: Keep a small stash of preallocated WC pages
  (FATE#322643 bsc#1055900).
- Refresh
  patches.drivers/drm-i915-Mark-vm_free_page-as-a-potential-sleeper-ag.
- Refresh
  patches.drivers/drm-i915-Only-free-the-oldest-stale-object-before-a-.
- commit 4f7f6f9
* Wed Feb 21 2018 tiwai@suse.de
- drm/i915: Use snprintf to avoid line-break when pretty-printing
  engines (FATE#322643 bsc#1055900).
- commit ac105dc
* Wed Feb 21 2018 tiwai@suse.de
- drm/i915: Add "panel orientation" property to the panel
  connector, v6 (FATE#322643 bsc#1055900).
- commit 71dce14
* Wed Feb 21 2018 tiwai@suse.de
- Update config files: new configs for drm / fb stuff
- commit 4865016
* Wed Feb 21 2018 tiwai@suse.de
- intel/atomic: Stop updating legacy fb parameters (FATE#322643
  bsc#1055900).
- drm/i915: Restore GT performance in headless mode with DMC
  loaded (FATE#322643 bsc#1055900).
- drm/i915/execlists: Cache ELSP register offset (FATE#322643
  bsc#1055900).
- drm/i915: Refactor common list iteration over GGTT vma
  (FATE#322643 bsc#1055900).
- drm/i915: Track GGTT writes on the vma (FATE#322643
  bsc#1055900).
- drm/i915: Remove vma from object on destroy, not close
  (FATE#322643 bsc#1055900).
- drm/i915/huc: Load HuC only if requested (FATE#322643
  bsc#1055900).
- commit e564912
* Wed Feb 21 2018 tiwai@suse.de
- drm/i915/guc: Combine enable_guc_loading|submission modparams
  (FATE#322643 bsc#1055900).
- drm/i915/uc: Don't use -EIO to report missing firmware
  (FATE#322643 bsc#1055900).
- drm/i915/uc: Don't fetch GuC firmware if no plan to use GuC
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Introduce USES_GUC_xxx helper macros (FATE#322643
  bsc#1055900).
- drm/i915/guc: Move firmware selection to init_early (FATE#322643
  bsc#1055900).
- drm/i915/huc: Move firmware selection to init_early (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Kick scheduler when new workload queued
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Convert macro queue_workload to a function
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Add framebuffer decoder support (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Add opregion support (FATE#322643 bsc#1055900).
- drm/i915/gvt: Alloc and Init guest opregion at vgpu creation
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Fix out-of-bounds buffer write into
  opregion->signature[] (FATE#322643 bsc#1055900).
- drm/i915/gvt: Cleanup unwanted public symbols (FATE#322643
  bsc#1055900).
- drm/i915: add platform tag to WA (FATE#322643 bsc#1055900).
- drm/i915: follow single notation for workaround number
  (FATE#322643 bsc#1055900).
- drm/i915: Taint (TAINT_WARN) the kernel if the GPU reset fails
  (FATE#322643 bsc#1055900).
- drm/i915/skl: DMC firmware for skylake v1.27 (FATE#322643
  bsc#1055900).
- drm/i915/cnl: only divide up base frequency with crystal source
  (FATE#322643 bsc#1055900).
- drm/i915: Update DRIVER_DATE to 20171201 (FATE#322643
  bsc#1055900).
- drm/i915: Remove unsafe i915.enable_rc6 (FATE#322643
  bsc#1055900).
- drm/i915: Sleep and retry a GPU reset if at first we don't
  succeed (FATE#322643 bsc#1055900).
- drm/i915: Interlaced DP output doesn't work on VLV/CHV
  (FATE#322643 bsc#1055900).
- drm/i915: Pass crtc state to intel_pipe_{enable,disable}()
  (FATE#322643 bsc#1055900).
- drm/i915: Wait for pipe to start on i830 as well (FATE#322643
  bsc#1055900).
- drm/i915: Fix has_audio readout for DDI A (FATE#322643
  bsc#1055900).
- drm/i915: Don't add the "force audio" property to DP connectors
  that don't support audio (FATE#322643 bsc#1055900).
- drm/i915: Disable DP audio for g4x (FATE#322643 bsc#1055900).
- drm/i915/selftests: Wake the device before executing requests
  on the GPU (FATE#322643 bsc#1055900).
- drm/i915: Set fake_vma.size as well as fake_vma.node.size for
  capture (FATE#322643 bsc#1055900).
- drm/i915: Tidy up signed/unsigned comparison (FATE#322643
  bsc#1055900).
- drm/i915: Enable IPS with only sprite plane visible too, v4
  (FATE#322643 bsc#1055900).
- drm/i915: Make ips_enabled a property depending on whether
  IPS is enabled, v3 (FATE#322643 bsc#1055900).
- drm/i915: Avoid PPS HW/SW state mismatch due to rounding
  (FATE#322643 bsc#1055900).
- drm/i915/glk: Apply WaProgramL3SqcReg1DefaultForPerf for GLK
  too (FATE#322643 bsc#1055900).
- drm/i915/guc: Change default GuC FW for KBL to v9.39
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Change default GuC FW for BXT to v9.29
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Change default GuC FW for SKL to v9.33
  (FATE#322643 bsc#1055900).
- drm/i915: Consolidate checks for engine stats availability
  (FATE#322643 bsc#1055900).
- drm/i915: Move engine->needs_cmd_parser to engine->flags
  (FATE#322643 bsc#1055900).
- drm/i915: Enable hotplug polling after registering the outputs
  (FATE#322643 bsc#1055900).
- drm/i915: Rename i915_gem_timelines_mark_idle (FATE#322643
  bsc#1055900).
- drm/i915: Rename shrinker init/cleanup to match driver
  initialisation phase (FATE#322643 bsc#1055900).
- drm/i915: Record default HW state in the GPU error state
  (FATE#322643 bsc#1055900).
- drm/i915: Flush everything on switching to the kernel_context
  (FATE#322643 bsc#1055900).
- drm/i915: hide unused intel_panel_set_backlight function
  (FATE#322643 bsc#1055900).
- drm/i915/fbdev: Serialise early hotplug events with async
  fbdev config (FATE#322643 bsc#1055900).
- drm/i915/guc: Use consistent name for scratch register count
  (FATE#322643 bsc#1055900).
- drm/i915: Use exponential backoff for wait_for() (FATE#322643
  bsc#1055900).
- drm/i915/guc: Tidy ELSP port assignment (FATE#322643
  bsc#1055900).
- drm/i915/guc: Advance over port[0] if set and not preempting
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Rename i915_guc_reg.h to intel_guc_reg.h
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Update header guard name of intel_guc_submission.h
  (FATE#322643 bsc#1055900).
- drm/i915: Move mi_set_context() into the legacy ringbuffer
  submission (FATE#322643 bsc#1055900).
- drm/i915: Unwind incomplete legacy context switches (FATE#322643
  bsc#1055900).
- drm/i915: remove stale comment from sanitize_encoder
  (FATE#322643 bsc#1055900).
- drm/i915: sync dp link status checks against atomic commmits
  (FATE#322643 bsc#1055900).
- drm/i915/dmc: DMC 1.04 for Kabylake (FATE#322643 bsc#1055900).
- drm/i915: Save/restore irq state for vlv_residency_raw()
  (FATE#322643 bsc#1055900).
- drm/i915: Remove success dmesg noise for intel_rotate_pages()
  (FATE#322643 bsc#1055900).
- drm/i915: Convert intel_rc6_residency_us to ns (FATE#322643
  bsc#1055900).
- drm/i915: Engine busy time tracking (FATE#322643 bsc#1055900).
- drm/i915: Wrap context schedule notification (FATE#322643
  bsc#1055900).
- drm/i915: Extract intel_get_cagf (FATE#322643 bsc#1055900).
- drm/i915/selftests: Avoid drm_gem_handle_create under
  struct_mutex (FATE#322643 bsc#1055900).
- drm/i915: Add rudimentary plane state verification (FATE#322643
  bsc#1055900).
- drm/i915: Use plane->get_hw_state() for initial plane fb readout
  (FATE#322643 bsc#1055900).
- drm/i915: Nuke crtc->plane (FATE#322643 bsc#1055900).
- drm/i915: Switch fbc over to for_each_new_intel_plane_in_state()
  (FATE#322643 bsc#1055900).
- drm/i915: Nuke ironlake_get_initial_plane_config() (FATE#322643
  bsc#1055900).
- drm/i915: Cleanup enum pipe/enum plane_id/enum i9xx_plane_id
  in initial fb readout (FATE#322643 bsc#1055900).
- drm/i915: Use enum i9xx_plane_id for the .get_fifo_size()
  hooks (FATE#322643 bsc#1055900).
- drm/i915: s/enum plane/enum i9xx_plane_id/ (FATE#322643
  bsc#1055900).
- drm/i915: Don't use GEN6_RC_VIDEO_FREQ on gen10+ (FATE#322643
  bsc#1055900).
- drm/i915/selftests: Declare we allocated the guc clients
  (FATE#322643 bsc#1055900).
- drm/i915: Remove i915.semaphores modparam (FATE#322643
  bsc#1055900).
- drm/i915: Move debugfs/i915_semaphore_status to i915_engine_info
  (FATE#322643 bsc#1055900).
- drm/i915: Disable semaphores on Sandybridge (FATE#322643
  bsc#1055900).
- drm/i915: Remove obsolete ringbuffer emission for gen8+
  (FATE#322643 bsc#1055900).
- drm/i915: Remove i915.enable_execlists module parameter
  (FATE#322643 bsc#1055900).
- drm/i915/execlists: Delay writing to ELSP until HW has processed
  the previous write (FATE#322643 bsc#1055900).
- drm/i915/selftest: Make guc clients static (FATE#322643
  bsc#1055900).
- drm/i915/perf: reuse timestamp frequency from device info
  (FATE#322643 bsc#1055900).
- drm/i915: Automatic i915_switch_context for legacy (FATE#322643
  bsc#1055900).
- drm/i915: Pull the unconditional GPU cache invalidation into
  request construction (FATE#322643 bsc#1055900).
- drm/i915/perf: replace .reg accesses with i915_mmio_reg_offset
  (FATE#322643 bsc#1055900).
- drm/i915/execlists: Assert that we don't get mixed IDLE_ACTIVE |
  COMPLETE events (FATE#322643 bsc#1055900).
- drm/i915/execlists: Reduce completed event mask to COMPLETE |
  PREEMPTED (FATE#322643 bsc#1055900).
- drm/i915/execlists: Listen to COMPLETE context event not
  ACTIVE_IDLE (FATE#322643 bsc#1055900).
- drm/fb-helper: Apply panel orientation connector prop to the
  primary plane, v6 (FATE#322643 bsc#1055900).
- drm: Add support for a panel-orientation connector property,
  v6 (FATE#322643 bsc#1055900).
- drm: Add panel orientation quirks, v6 (FATE#322643 bsc#1055900).
- fbcon: Add fbcon_rotate_hint to struct fb_info (FATE#322643
  bsc#1055900).
- drm/i915: Update DRIVER_DATE to 20171117 (FATE#322643
  bsc#1055900).
- drm/i915: Add a policy note for removing workarounds
  (FATE#322643 bsc#1055900).
- drm/i915/selftests: Report ENOMEM clearly for an allocation
  failure (FATE#322643 bsc#1055900).
- drm/i915: Calculate g4x intermediate watermarks correctly
  (FATE#322643 bsc#1055900).
- drm/i915: Calculate vlv/chv intermediate watermarks correctly,
  v3 (FATE#322643 bsc#1055900).
- drm/i915: Pass crtc_state to ips toggle functions, v2
  (FATE#322643 bsc#1055900).
- drm/i915: Pass idle crtc_state to intel_dp_sink_crc (FATE#322643
  bsc#1055900).
- drm/i915: Enable FIFO underrun reporting after initial fastset,
  v4 (FATE#322643 bsc#1055900).
- commit c55e1d3
* Wed Feb 21 2018 tiwai@suse.de
- drm/i915: Mark the userptr invalidate workqueue as
  WQ_MEM_RECLAIM (FATE#322643 bsc#1055900).
- drm/i915: Add might_sleep() check to wait_for() (FATE#322643
  bsc#1055900).
- drm/i915/selftests: Add a GuC doorbells selftest (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Let each vgpu has separate opregion memory
  (FATE#322643 bsc#1055900).
- Revert "drm/i915/gvt: Refine broken PPGTT scratch" (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Make gvt_vgpu_err use pr_err (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Don't dump partial state in cmd parser
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Reduce rcs mocs switch latency (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Add new debugfs tool mmio_diff (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Add mmio iterator
  intel_gvt_for_each_tracked_mmio() (FATE#322643 bsc#1055900).
- drm/i915/gvt: opregion virtualization for win guest (FATE#322643
  bsc#1055900).
- drm/i915/gvt: update CSB and CSB write pointer in virtual HWSP
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Refine broken PPGTT scratch (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Introduce ops->set_present() (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Introduce page table type of current level in
  GTT type enumerations (FATE#322643 bsc#1055900).
- drm/i915/gvt: Fix a bug of unexpectedly clear scratch page table
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Let the caller choose if a shadow page should
  be put into hash table (FATE#322643 bsc#1055900).
- drm/i915/gvt: Use I915_GTT_PAGE_SIZE (FATE#322643 bsc#1055900).
- drm/i915/gvt: Factor intel_vgpu_page_track (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Refine shadow batch buffer (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Refine find_bb_size() (FATE#322643 bsc#1055900).
- drm/i915/gvt: Use BIT() to make klockwork happy (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Add basic debugfs infrastructure (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Refactor vGPU type code in kvmgt part (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Move vGPU type related code into gvt file
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Move clean_workloads() into scheduler.c
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Introduce intel_vgpu_reset_submission (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Introduce vGPU submission ops (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Remove one extra declaration in scheduler.h
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Move common vGPU workload creation into
  scheduler.c (FATE#322643 bsc#1055900).
- drm/i915/gvt: Move common workload preparation into
  prepare_workload() (FATE#322643 bsc#1055900).
- drm/i915/gvt: Factor out prepare_workload() (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Factor out vGPU workload creation/destroy
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Use dyndbg for gvt debug info (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Add VM healthy check for submit_context
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Add VM healthy check for workload_thread
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Change the return type during command scan
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Do not allocate initial ring scan buffer
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Move ring scan buffers into intel_vgpu_submission
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Rename reserved ring buffer (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Fix a memory leak in cmd_parser.c (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Move tlb_handle_pending into intel_vgpu_submission
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Introduce intel_vgpu_submission (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Move workload cache init/clean into
  intel_vgpu_{setup, clean}_submission() (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Rename intel_vgpu_{init, clean}_gvt_context()
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Make elsp_dwords in the right order (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Add support for opregion virtualization
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Extend HDMI 2.0 support to CNL (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Simplify dco_fraction calculation (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Don't blindly replace qdiv (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Fix wrpll math for higher freqs (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Fix, simplify and unify wrpll variable sizes
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Remove useless conversion (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Remove spurious central_freq (FATE#322643
  bsc#1055900).
- drm/i915/selftests: exercise_ggtt may have nothing to do
  (FATE#322643 bsc#1055900).
- drm/i915: Don't sanitize frame start delay if the pipe is off
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Rename i915_guc_submission.c|h to
  intel_guc_submission.c|h (FATE#322643 bsc#1055900).
- drm/i915/guc: Rename i915_guc_client struct to intel_guc_client
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Update name and prototype of GuC submission
  interface functions (FATE#322643 bsc#1055900).
- drm/i915/guc: Update names of submission related static
  functions (FATE#322643 bsc#1055900).
- drm/i915: Update execlists tasklet naming (FATE#322643
  bsc#1055900).
- drm/i915: Prevent overflow of execbuf.buffer_count and
  num_cliprects (FATE#322643 bsc#1055900).
- drm/i915: Print the condition causing GEM_BUG_ON (FATE#322643
  bsc#1055900).
- drm/i915: Remove pre-production pooled-EU w/a for Broxton
  (FATE#322643 bsc#1055900).
- drm/i915: Make request's wait-for-space explicit (FATE#322643
  bsc#1055900).
- drm/i915/selftests: Increase size for mock ringbuffer
  (FATE#322643 bsc#1055900).
- drm/i915: Initialise entry in intel_ppat_get() for older
  compilers (FATE#322643 bsc#1055900).
- drm/i915/selftests: Markup __iomem for igt_gem_coherency
  (FATE#322643 bsc#1055900).
- drm/i915: Use ELK stolen memory reserved detection for ILK
  (FATE#322643 bsc#1055900).
- drm/i915: Make the report about a bogus stolen reserved area
  an error (FATE#322643 bsc#1055900).
- drm/i915: Check if the stolen memory "reserved" area is enabled
  or not (FATE#322643 bsc#1055900).
- drm/i915: Fix kerneldocs for intel_audio.c (FATE#322643
  bsc#1055900).
- drm/i915: Call uncore_suspend before platform suspend handlers
  (FATE#322643 bsc#1055900).
- drm/i915/selftests: Always initialise err (FATE#322643
  bsc#1055900).
- drm/i915: Resume GuC before using GEM (FATE#322643 bsc#1055900).
- drm/i915: Display WA #1185 WaDisableDARBFClkGating:cnl, glk
  (FATE#322643 bsc#1055900).
- drm/i915: Unconditionally apply the Broxton register workaround
  set (FATE#322643 bsc#1055900).
- drm/i915: Remove pre-production Broxton register workarounds
  (FATE#322643 bsc#1055900).
- drm/i915: Unify SLICE_UNIT_LEVEL_CLKGATE w/a for cnl
  (FATE#322643 bsc#1055900).
- drm/i915: fix 64bit divide (FATE#322643 bsc#1055900).
- drm/i915: Generalize transcoder looping (FATE#322643
  bsc#1055900).
- drm/i915/glk: Refactor handling of PLANE_COLOR_CTL for GLK+
  (FATE#322643 bsc#1055900).
- drm/i915: Introduce GEM proxy (FATE#322643 bsc#1055900).
- drm/i915: Object w/o backing storage is banned by -ENXIO
  (FATE#322643 bsc#1055900).
- drm/i915: Fix function name in comment (FATE#322643
  bsc#1055900).
- drm/i915: There is only one fault register from GEN8 onwards
  (FATE#322643 bsc#1055900).
- drm/i915: Clear per-engine fault register as early as possible
  (FATE#322643 bsc#1055900).
- drm/i915: expose command stream timestamp frequency to userspace
  (FATE#322643 bsc#1055900).
- drm/i915/perf: enable perf support on CNL (FATE#322643
  bsc#1055900).
- drm/i915: fix register naming (FATE#322643 bsc#1055900).
- drm/i915/perf: refactor perf setup (FATE#322643 bsc#1055900).
- drm/i915/perf: add support for Coffeelake GT3 (FATE#322643
  bsc#1055900).
- drm/i915/perf: complete whitelisting for OA programming on HSW
  (FATE#322643 bsc#1055900).
- drm/i915: Handle adjust better in intel_pipe_config_compare
  (FATE#322643 bsc#1055900).
- drm/i915: Check boolean options in intel_pipe_config_compare
  with its own macro (FATE#322643 bsc#1055900).
- drm/i915: Remove bogus ips_enabled check (FATE#322643
  bsc#1055900).
- drm/i915: Remove Gen9 WAs with no effect (FATE#322643
  bsc#1055900).
- drm/i915: Remove redundant intel_autoenable_gt_powersave()
  (FATE#322643 bsc#1055900).
- drm/i915: Update watermark state correctly in
  sanitize_watermarks (FATE#322643 bsc#1055900).
- drm/i915/selftests: Yet another forgotten mock_i915->mm
  initialiser (FATE#322643 bsc#1055900).
- commit ac7993e
* Wed Feb 21 2018 tiwai@suse.de
- drm/i915: Kerneldoc typo s/rps/rps_client/ (FATE#322643
  bsc#1055900).
- drm/i915: Stop caching the "golden" renderstate (FATE#322643
  bsc#1055900).
- drm/i915: Record the default hw state after reset upon load
  (FATE#322643 bsc#1055900).
- drm/i915: Mark the context state as dirty/written (FATE#322643
  bsc#1055900).
- drm/i915: Inline intel_modeset_gem_init() (FATE#322643
  bsc#1055900).
- drm/i915: Move intel_init_clock_gating() to i915_gem_init()
  (FATE#322643 bsc#1055900).
- drm/i915: Move GT powersaving init to i915_gem_init()
  (FATE#322643 bsc#1055900).
- drm/i915: Force the switch to the i915->kernel_context
  (FATE#322643 bsc#1055900).
- drm/i915: Define an engine class enum for the uABI (FATE#322643
  bsc#1055900).
- drm/i915/selftests: Initialise mock_i915->mm.obj_lock
  (FATE#322643 bsc#1055900).
- drm/i915: Restore the wait for idle engine after flushing
  interrupts (FATE#322643 bsc#1055900).
- drm/i915: Move irqs enabled assertion deeper for mock
  breadcrumbs (FATE#322643 bsc#1055900).
- drm/i915/selftests: Reduce the volume of the timeout message
  (FATE#322643 bsc#1055900).
- drm/i915: Update DRIVER_DATE to 20171109 (FATE#322643
  bsc#1055900).
- drm/i915: Mark up i915_vma_unbind() as a potential sleeper
  (FATE#322643 bsc#1055900).
- drm/i915: Mark vm_free_page() as a potential sleeper agent
  (FATE#322643 bsc#1055900).
- drm/i915: Use trace_printk to provide a death rattle for GEM
  (FATE#322643 bsc#1055900).
- drm/i915: Clean up DP code local variables and calling
  conventions (FATE#322643 bsc#1055900).
- drm/i915: Clean up PPS code calling conventions (FATE#322643
  bsc#1055900).
- drm/i915: Nuke intel_digital_port->port (FATE#322643
  bsc#1055900).
- drm/i915: Replace dig_port->port with encoder port for BXT
  DPLL selection (FATE#322643 bsc#1055900).
- drm/i915: Eliminate crtc->config usage from CRT code
  (FATE#322643 bsc#1055900).
- drm/i915: Pass crtc state to DPIO PHY functions (FATE#322643
  bsc#1055900).
- drm/i915: Eliminate some encoder->crtc usage from TV code
  (FATE#322643 bsc#1055900).
- drm/i915: Eliminate some encoder->crtc usage from SDVO code
  (FATE#322643 bsc#1055900).
- drm/i915: Eliminate some encoder->crtc usage from DSI code
  (FATE#322643 bsc#1055900).
- drm/i915: Eliminate some encoder->crtc usage from DP code
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Simplify programming of GUC_SHIM_CONTROL
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Drop legacy workarounds from guc_prepare_xfer
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Wait for ucode DMA transfer completion
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Split GuC firmware xfer function into clear steps
  (FATE#322643 bsc#1055900).
- drm/i915: Implement ReadHitWriteOnlyDisable (FATE#322643
  bsc#1055900).
- drm/i915: Include intel_engine_is_idle() status in engine
  pretty-printer (FATE#322643 bsc#1055900).
- drm/i915: Read ilk FDI PLL frequency once during initialisation
  (FATE#322643 bsc#1055900).
- drm/i915/selftests: Take rpm wakeref around partial tiling tests
  (FATE#322643 bsc#1055900).
- drm/i915/selftests: Take rpm wakeref around GGTT lowlevel tests
  (FATE#322643 bsc#1055900).
- drm/i915: Prevent unbounded wm results in g4x_compute_wm()
  (FATE#322643 bsc#1055900).
- drm/i915: Simplify onion for bxt_ddi_phy_init() (FATE#322643
  bsc#1055900).
- drm/i915: Silence compiler for csr_load_work_fn() (FATE#322643
  bsc#1055900).
- drm/i915: Silence smatch for cmdparser (FATE#322643
  bsc#1055900).
- drm/i915: Handle error-state modparams in dedicated functions
  (FATE#322643 bsc#1055900).
- drm/i915: Make GuC log part of the uC error state (FATE#322643
  bsc#1055900).
- drm/i915: Add Guc/HuC firmware details to error state
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Assert ctch->vma is allocated (FATE#322643
  bsc#1055900).
- drm/i915/guc: Assert guc->stage_desc_pool is allocated
  (FATE#322643 bsc#1055900).
- drm/i915/selftests: Hide dangerous tests (FATE#322643
  bsc#1055900).
- drm/i915: Assert vma->flags are updated correctly during binding
  (FATE#322643 bsc#1055900).
- drm/i915: Set up mocs tables before restarting the engines
  (FATE#322643 bsc#1055900).
- drm/i915: Warn in debug builds of incorrect usages of
  ptr_pack_bits (FATE#322643 bsc#1055900).
- drm/i915: ensure oa config uuid is null terminated (FATE#322643
  bsc#1055900).
- drm/i915: Flush the irq and tasklets before asserting engine
  is idle (FATE#322643 bsc#1055900).
- drm/i915: Use fallback forcewake if primary ack missing
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Add support for reset engine using GuC commands
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Rename the function that resets the GuC
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Clear terminated attribute bit on GuC preemption
  context (FATE#322643 bsc#1055900).
- drm/i915/cnl: Symmetric scalers for each pipe (FATE#322643
  bsc#1055900).
- drm/i915: Give more details for the active-when-parking warning
  for the engines (FATE#322643 bsc#1055900).
- drm/i915: Move parking-while-active warning to
  intel_engines_park() (FATE#322643 bsc#1055900).
- drm/i915: Check that the breadcrumb wasn't disarmed
  automatically before parking (FATE#322643 bsc#1055900).
- drm/i915/cnl: Remove unnecessary check in cnl_setup_private_ppat
  (FATE#322643 bsc#1055900).
- drm/i915: Remove most encoder->type uses from the audio code
  (FATE#322643 bsc#1055900).
- drm/i915: Pass around crtc and connector states for audio
  (FATE#322643 bsc#1055900).
- drm/i915: Replace "cc-option -Wno-foo" with "cc-disable-warning
  foo" (FATE#322643 bsc#1055900).
- drm/i915: Use intel_ddi_get_config() for MST (FATE#322643
  bsc#1055900).
- drm/i915: Pass a crtc state to ddi post_disable from MST code
  (FATE#322643 bsc#1055900).
- drm/i915: Eliminate pll->state usage from bxt_calc_pll_link()
  (FATE#322643 bsc#1055900).
- drm/i915: Nuke intel_ddi_get_encoder_port() (FATE#322643
  bsc#1055900).
- drm/i915: Stop frobbing with DDI encoder->type (FATE#322643
  bsc#1055900).
- drm/i915: Populate output_types from .get_config() (FATE#322643
  bsc#1055900).
- drm/i915: Parse max HDMI TMDS clock from VBT (FATE#322643
  bsc#1055900).
- drm/i915/vbt: Fix HDMI level shifter and max data rate bitfield
  sizes (FATE#322643 bsc#1055900).
- drm/i915: Clean up the mess around hdmi_12bpc_possible()
  (FATE#322643 bsc#1055900).
- drm/i915: Improve DP downstream HPD handling (FATE#322643
  bsc#1055900).
- drm/i915: Fix BXT lane latency optimal setting with MST
  (FATE#322643 bsc#1055900).
- drm/i915: Stop using encoder->type in
  intel_ddi_enable_transcoder_func() (FATE#322643 bsc#1055900).
- drm/i915: Start using output_types for DPLL selection
  (FATE#322643 bsc#1055900).
- drm/i915: Pass crtc state to intel_prepare_dp_ddi_buffers()
  (FATE#322643 bsc#1055900).
- drm/i915: Don't use encoder->type in
  intel_ddi_set_pipe_settings() (FATE#322643 bsc#1055900).
- drm/i915: Empty the ring before disabling (FATE#322643
  bsc#1055900).
- drm/i915/edp: clean up code and comments around eDP DPCD read
  (FATE#322643 bsc#1055900).
- drm/i915: Add -Wall -Wextra to our build, set warnings to full
  (FATE#322643 bsc#1055900).
- drm/i915: Include RING_MODE when dumping the engine state
  (FATE#322643 bsc#1055900).
- drm/i915/huc: Use helper function while waiting for DMA
  completion (FATE#322643 bsc#1055900).
- drm/i915/guc: Preemption! With GuC (FATE#322643 bsc#1055900).
- drm/i915: Rename helpers used for unwinding, use macro for
  can_preempt (FATE#322643 bsc#1055900).
- drm/i915/guc: Keep request->priority for its lifetime
  (FATE#322643 bsc#1055900).
- drm/i915: Add information needed to track engine preempt state
  (FATE#322643 bsc#1055900).
- drm/i915: Extract "emit write" part of emit breadcrumb functions
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Split guc_wq_item_append (FATE#322643
  bsc#1055900).
- drm/i915/guc: Add a second client, to be used for preemption
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Add preemption action to GuC firmware interface
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Allocate separate shared data object for GuC
  communication (FATE#322643 bsc#1055900).
- drm/i915/guc: Extract GuC stage desc pool creation into a helper
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Do not use 0 for GuC doorbell cookie (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Fix SSEU Device Status (FATE#322643 bsc#1055900).
- drm/i915/guc: Initialize GuC before restarting engines
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Always enable the breadcrumbs irq (FATE#322643
  bsc#1055900).
- drm/i915: Add a hook for making the engines idle (parking)
  and unparking (FATE#322643 bsc#1055900).
- drm/i915/cnl: Allow 2 pixel per clock on Cannonlake (FATE#322643
  bsc#1055900).
- Revert "drm/i915/selftests: Convert timers to use timer_setup()"
  (FATE#322643 bsc#1055900).
- commit dc0515f
* Wed Feb 21 2018 tiwai@suse.de
- drm/i915/selftests: Convert timers to use timer_setup()
  (FATE#322643 bsc#1055900).
- drm/i915: Use same test for eviction and submitting kernel
  context (FATE#322643 bsc#1055900).
- drm/i915: Call cond_resched() before repeating
  i915_gem_evict_something() (FATE#322643 bsc#1055900).
- drm/i915: Perform a central cdclk state sanity check
  (FATE#322643 bsc#1055900).
- drm/i915: Sanity check cdclk in vlv_set_cdclk() (FATE#322643
  bsc#1055900).
- drm/i915: Adjust system agent voltage on CNL if required by
  DDI ports (FATE#322643 bsc#1055900).
- drm/i915: Use cdclk_state->voltage on CNL (FATE#322643
  bsc#1055900).
- drm/i915: Use cdclk_state->voltage on BXT/GLK (FATE#322643
  bsc#1055900).
- drm/i915: Use cdclk_state->voltage on SKL/KBL/CFL (FATE#322643
  bsc#1055900).
- drm/i915: Use cdclk_state->voltage on BDW (FATE#322643
  bsc#1055900).
- drm/i915: Use cdclk_state->voltage on VLV/CHV (FATE#322643
  bsc#1055900).
- drm/i915: Start tracking voltage level in the cdclk state
  (FATE#322643 bsc#1055900).
- drm/i915: Clean up some cdclk switch statements (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Update the DMC version on CNL (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Get RC6 working (FATE#322643 bsc#1055900).
- drm/i915/cnl: Force DDI_A_4_LANES when needed (FATE#322643
  bsc#1055900).
- drm/i915: Synchronize irq before parking each engine
  (FATE#322643 bsc#1055900).
- drm/i915: Bump wait-times for the final CS interrupt before
  parking (FATE#322643 bsc#1055900).
- drm/i915: Fix deadlock in i830_disable_pipe() (FATE#322643
  bsc#1055900).
- drm/i915: Redo plane sanitation during readout (FATE#322643
  bsc#1055900).
- drm/i915: Add .get_hw_state() method for planes (FATE#322643
  bsc#1055900).
- drm/i915: Don't adjust priority on an already signaled fence
  (FATE#322643 bsc#1055900).
- drm/i915: Whitelist SLICE_COMMON_ECO_CHICKEN1 on Geminilake
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Fix stack-out-of-bounds bug in cmd parser
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Clear the shadow page table entry after post-sync
  (FATE#322643 bsc#1055900).
- drm/i915: Apply Display WA #1183 on skl, kbl, and cfl
  (FATE#322643 bsc#1055900).
- drm/i915: Put all non-blocking modesets onto an ordered wq
  (FATE#322643 bsc#1055900).
- drm/i915: Disable DC states around GMBUS on GLK (FATE#322643
  bsc#1055900).
- drm/i915/psr: Fix register name mess up (FATE#322643
  bsc#1055900).
- i915: Reject CCS modifiers for pipe C on Geminilake (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Fix pipe A enable as default for vgpu (FATE#322643
  bsc#1055900).
- drm/i915: Protect DDI port to DPLL map from theoretical race
  (FATE#322643 bsc#1055900).
- drm/i915/lpe: Remove double-encapsulation of info string
  (FATE#322643 bsc#1055900).
- drm/i915/fence: Use rcu to defer freeing of irq_work
  (FATE#322643 bsc#1055900).
- drm/i915: Stop listening to request resubmission from the
  signaler kthread (FATE#322643 bsc#1055900).
- drm/i915: Drop fb reference on load_detect_pipe failure path
  (FATE#322643 bsc#1055900).
- drm/i915: Flush pending GTT writes before unbinding (FATE#322643
  bsc#1055900).
- drm: rework delayed connector cleanup in connector_iter
  (bsc#1051510).
- drm/i915/gvt: set max priority for gvt context (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Don't mark vgpu context as inactive when preempted
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Limit read hw reg to active vgpu (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Export intel_gvt_render_mmio_to_ring_id()
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Emulate PCI expansion ROM base address register
  (FATE#322643 bsc#1055900).
- Revert "drm/i915: Display WA #1133 WaFbcSkipSegments:cnl, glk"
  (FATE#322643 bsc#1055900).
- drm/i915: Call i915_gem_init_userptr() before taking
  struct_mutex (FATE#322643 bsc#1055900).
- drm/i915/cnl: Mask previous DDI - PLL mapping (FATE#322643
  bsc#1055900).
- drm/i915: Fix vblank timestamp/frame counter jumps on gen2
  (FATE#322643 bsc#1055900).
- drm/i915: Skip switch-to-kernel-context on suspend when wedged
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Correct ADDR_4K/2M/1G_MASK definition (FATE#322643
  bsc#1055900).
- drm/i915/gvt: enabled pipe A default on creating vgpu
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Move request alloc to dispatch_workload path only
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: remove skl_misc_ctl_write handler (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Fix unsafe locking caused by spin_unlock_bh
  (FATE#322643 bsc#1055900).
- drm/i915: fix intel_backlight_device_register declaration
  (FATE#322643 bsc#1055900).
- drm/i915: Prevent zero length "index" write (FATE#322643
  bsc#1055900).
- drm/i915: Don't try indexed reads to alternate slave addresses
  (FATE#322643 bsc#1055900).
- drm/edid: Don't send non-zero YQ in AVI infoframe for HDMI
  1.x sinks (bsc#1051510).
- drm/i915: Fix init_clock_gating for resume (FATE#322643
  bsc#1055900).
- drm/i915: Clear breadcrumb node when cancelling signaling
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: ensure -ve return value is handled correctly
  (FATE#322643 bsc#1055900).
- drm/i915: Re-register PMIC bus access notifier on runtime resume
  (FATE#322643 bsc#1055900).
- drm/i915: Fix false-positive assert_rpm_wakelock_held in
  i915_pmic_bus_access_notifier v2 (FATE#322643 bsc#1055900).
- drm/i915: Reorder context-close to avoid calling
  i915_vma_close() under RCU (FATE#322643 bsc#1055900).
- drm/i915: Move init_clock_gating() back to where it was
  (FATE#322643 bsc#1055900).
- drm/i915: Prune the reservation shared fence array (FATE#322643
  bsc#1055900).
- drm/i915: Idle the GPU before shinking everything (FATE#322643
  bsc#1055900).
- drm/i915: Lock llist_del_first() vs llist_del_all() (FATE#322643
  bsc#1055900).
- drm/i915: Calculate ironlake intermediate watermarks correctly,
  v2 (FATE#322643 bsc#1055900).
- drm/i915: Disable lazy PPGTT page table optimization for vGPU
  (FATE#322643 bsc#1055900).
- drm/i915/execlists: Remove the priority "optimisation"
  (FATE#322643 bsc#1055900).
- drm/i915: Filter out spurious execlists context-switch
  interrupts (FATE#322643 bsc#1055900).
- drm/i915: Update DRIVER_DATE to 20171023 (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Map VBT DDC Pin to BSpec DDC Pin (FATE#322643
  bsc#1055900).
- drm/i915: Let's use more enum intel_dpll_id pll_id (FATE#322643
  bsc#1055900).
- drm/i915: Use existing DSI backlight ports info (FATE#322643
  bsc#1055900).
- drm/i915: Parse DSI backlight/cabc ports (FATE#322643
  bsc#1055900).
- drm/i915: Skip waking the device to service pwrite (FATE#322643
  bsc#1055900).
- drm/i915/crt: split compute_config hook by platforms
  (FATE#322643 bsc#1055900).
- drm/i915: remove g4x lowfreq_avail and has_pipe_cxsr
  (FATE#322643 bsc#1055900).
- drm/i915: Drop the redundant hdmi prefix/suffix from a lot of
  variables (FATE#322643 bsc#1055900).
- drm/i915: Unify error handling for missing DDI buf trans tables
  (FATE#322643 bsc#1055900).
- drm/i915: Centralize the SKL DDI A/E vs. B/C/D buf trans
  handling (FATE#322643 bsc#1055900).
- drm/i915: Kill off the BXT buf_trans default_index (FATE#322643
  bsc#1055900).
- drm/i915: Pass encoder type to cnl_ddi_vswing_sequence()
  explicitly (FATE#322643 bsc#1055900).
- drm/i915: Integrate BXT into intel_ddi_dp_voltage_max()
  (FATE#322643 bsc#1055900).
- drm/i915: Pass the level to intel_prepare_hdmi_ddi_buffers()
  (FATE#322643 bsc#1055900).
- drm/i915: Pass the encoder type explicitly to skl_set_iboost()
  (FATE#322643 bsc#1055900).
- drm/i915: Extract intel_ddi_get_buf_trans_hdmi() (FATE#322643
  bsc#1055900).
- drm/i915: Relocate intel_ddi_get_buf_trans_*() functions
  (FATE#322643 bsc#1055900).
- drm/i915: Flush the idle-worker for debugfs/i915_drop_caches
  (FATE#322643 bsc#1055900).
- drm/i915: adjust get_crtc_fence_y_offset() to use base.y
  instead of crtc.y (FATE#322643 bsc#1055900).
- drm/i915: Unify skylake plane disable (FATE#322643 bsc#1055900).
- drm/i915: Unify skylake plane update (FATE#322643 bsc#1055900).
- drm/i915: dspaddr_offset doesn't need to be more than local
  variable (FATE#322643 bsc#1055900).
- drm/i915: move adjusted_x/y from crtc to cache (FATE#322643
  bsc#1055900).
- drm/i915: Fixup userptr mmu notifier registration error handling
  (FATE#322643 bsc#1055900).
- drm/i915: No need for RING_MAX_NONPRIV_SLOTS space (FATE#322643
  bsc#1055900).
- drm/i915/uc: Add pretty printer for uc firmware (FATE#322643
  bsc#1055900).
- drm/i915: Handle drm-layer errors in intel_dp_add_mst_connector
  (FATE#322643 bsc#1055900).
- drm/i915: Remove mostly duplicated video DIP handling from
  PSR code (FATE#322643 bsc#1055900).
- commit 7e86bee
* Wed Feb 21 2018 tiwai@suse.de
- drm/i915: Add in-flight request details to intel_engine_dump()
  (FATE#322643 bsc#1055900).
- drm/i915: Skip HW reinitialisation on resume if still wedged
  (FATE#322643 bsc#1055900).
- drm/i915: Trim struct_mutex hold duration for
  i915_gem_free_objects (FATE#322643 bsc#1055900).
- drm/i915: Only free the oldest stale object before a fresh
  allocation (FATE#322643 bsc#1055900).
- drm/i915: Set our shrinker->batch to 4096 (~16MiB) (FATE#322643
  bsc#1055900).
- drm/i915: Move dev_priv->mm.[un]bound_list to its own lock
  (FATE#322643 bsc#1055900).
- drm/i915: Remove walk over obj->vma_list for the shrinker
  (FATE#322643 bsc#1055900).
- drm/i915: Drop debugfs/i915_gem_pin_display (FATE#322643
  bsc#1055900).
- drm/i915: Rename obj->pin_display to obj->pin_global
  (FATE#322643 bsc#1055900).
- drm/i915: Refactor testing obj->mm.pages (FATE#322643
  bsc#1055900).
- drm/i915/cnl: WaRsUseTimeoutMode (FATE#322643 bsc#1055900).
- drm/i915/huc: Move fw select function (FATE#322643 bsc#1055900).
- drm/i915/guc: Update Guc messages on load failure (FATE#322643
  bsc#1055900).
- drm/i915/uc: Unify firmware loading (FATE#322643 bsc#1055900).
- drm/i915: Update DMC firmware load error messages (FATE#322643
  bsc#1055900).
- drm/i915/uc: Add message with firmware url (FATE#322643
  bsc#1055900).
- drm/i915/uc: Improve debug messages in firmware fetch
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Pick better place for Guc final status message
  (FATE#322643 bsc#1055900).
- drm/i915/uc: Check all firmwares against WOPCM size (FATE#322643
  bsc#1055900).
- drm/i915/guc: Reorder functions in intel_guc_fw.c (FATE#322643
  bsc#1055900).
- drm/i915/guc: Rename intel_guc_loader.c to intel_guc_fw.c
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Move doc near related definitions (FATE#322643
  bsc#1055900).
- drm/i915/guc: Small fixups post code move (FATE#322643
  bsc#1055900).
- drm/i915/guc: Move GuC boot param initialization out of xfer
  (FATE#322643 bsc#1055900).
- drm/i915: Move intel_guc_wopcm_size to intel_guc.c (FATE#322643
  bsc#1055900).
- drm/i915: enable to read CSB and CSB write pointer from HWSP
  in GVT-g VM (FATE#322643 bsc#1055900).
- drm/i915: Always stop the rings before a missing GPU reset
  (FATE#322643 bsc#1055900).
- drm/i915: Keep the rings stopped until they have been
  re-initialized (FATE#322643 bsc#1055900).
- drm/i915: Stop asserting on set-wedged vs nop_submit_request
  ordering (FATE#322643 bsc#1055900).
- drm/i915: Split intel_enable_ddi() into DP and HDMI variants
  (FATE#322643 bsc#1055900).
- drm/i915: Plumb crtc_state etc. directly to
  intel_ddi_pre_enable_{dp,hdmi}() (FATE#322643 bsc#1055900).
- drm/i915: Split intel_disable_ddi() into DP vs. HDMI variants
  (FATE#322643 bsc#1055900).
- drm/i915: Remove useless eDP check from
  intel_ddi_pre_enable_dp() (FATE#322643 bsc#1055900).
- drm/i915: Split intel_ddi_post_disable() into DP vs. HDMI
  variants (FATE#322643 bsc#1055900).
- drm/i915: Inline the required bits of intel_ddi_post_disable()
  into intel_ddi_fdi_post_disable() (FATE#322643 bsc#1055900).
- drm/i915: Extract intel_disable_ddi_buf() (FATE#322643
  bsc#1055900).
- drm/i915: Extract intel_ddi_clk_disable() (FATE#322643
  bsc#1055900).
- drm/i915: Dump 'output_types' in crtc state dump (FATE#322643
  bsc#1055900).
- drm/i915: Replace *_reference/unreference() or *_ref/unref
  with _get/put() (FATE#322643 bsc#1055900).
- drm/i915: Get rid of hardcoded pipes (FATE#322643 bsc#1055900).
- drm/i915: Add retries for LSPCON detection (FATE#322643
  bsc#1055900).
- drm/i915: Don't give up waiting on INVALID_MODE (FATE#322643
  bsc#1055900).
- drm/i915/bdw: Fix DP_AUX_CH_CTL_TIME_OUT setting (FATE#322643
  bsc#1055900).
- drm/i915: Fix DP_AUX_CH_CTL_TIME_OUT naming (FATE#322643
  bsc#1055900).
- drm/i915/selftests: Wrap a timer into a i915_sw_fence
  (FATE#322643 bsc#1055900).
- drm/i915: Start tracking PSR state in crtc state (FATE#322643
  bsc#1055900).
- drm/i915: Update DRIVER_DATE to 20171012 (FATE#322643
  bsc#1055900).
- drm/i915: Simplify intel_sanitize_enable_ppgtt (FATE#322643
  bsc#1055900).
- drm/i915/userptr: Drop struct_mutex before cleanup (FATE#322643
  bsc#1055900).
- drm/i915/dp: limit sink rates based on rate (FATE#322643
  bsc#1055900).
- drm/i915/dp: centralize max source rate conditions more
  (FATE#322643 bsc#1055900).
- drm/i915: Allow PCH platforms fall back to BIOS LVDS mode
  (FATE#322643 bsc#1055900).
- drm/i915: Reuse normal state readout for LVDS/DVO fixed mode
  (FATE#322643 bsc#1055900).
- drm/i915: Use rcu instead of stop_machine in set_wedged
  (FATE#322643 bsc#1055900).
- drm/i915: Introduce separate status variable for RC6 and LLC
  ring frequency setup (FATE#322643 bsc#1055900).
- drm/i915: Create generic functions to control RC6, RPS
  (FATE#322643 bsc#1055900).
- drm/i915: Create generic function to setup LLC ring frequency
  table (FATE#322643 bsc#1055900).
- drm/i915: Rename intel_enable_rc6 to intel_rc6_enabled
  (FATE#322643 bsc#1055900).
- drm/i915: Name structure in dev_priv that contains RPS/RC6
  state as "gt_pm" (FATE#322643 bsc#1055900).
- drm/i915: Move rps.hw_lock to dev_priv and s/hw_lock/pcu_lock
  (FATE#322643 bsc#1055900).
- drm/i915: Name i915_runtime_pm structure in dev_priv as
  "runtime_pm" (FATE#322643 bsc#1055900).
- drm/i915: Separate RPS and RC6 handling for CHV (FATE#322643
  bsc#1055900).
- drm/i915: Separate RPS and RC6 handling for VLV (FATE#322643
  bsc#1055900).
- drm/i915: Separate RPS and RC6 handling for BDW (FATE#322643
  bsc#1055900).
- drm/i915: Remove superfluous IS_BDW checks and non-BDW changes
  from gen8_enable_rps (FATE#322643 bsc#1055900).
- drm/i915: Separate RPS and RC6 handling for gen6+ (FATE#322643
  bsc#1055900).
- drm/i915: Cleanup South Error Interrupts (FATE#322643
  bsc#1055900).
- drm/i915: Favor for_each_pipe() macro (FATE#322643 bsc#1055900).
- drm/i915: Fold IRQ pipe masks (FATE#322643 bsc#1055900).
- drm/i915: Remove I915_MAX_PIPES dependency for DDB allocation
  (FATE#322643 bsc#1055900).
- drm/i915: Don't relay on I915_MAX_PIPES (FATE#322643
  bsc#1055900).
- drm/i915: Nuke the bogus kernel doc for i9xx_disable_pll()
  (FATE#322643 bsc#1055900).
- drm/i915: Pass crtc state to i9xx_enable_pll() (FATE#322643
  bsc#1055900).
- drm/i915: Parametrize CBR_DPLLBMD_PIPE defines (FATE#322643
  bsc#1055900).
- drm/i915: Use enum pipe for PCH transcoders (FATE#322643
  bsc#1055900).
- drm/i915: Increase atomic update vblank evasion time with
  lockdep (FATE#322643 bsc#1055900).
- drm/i915: Use execlists_num_ports instead of size of array
  (FATE#322643 bsc#1055900).
- drm/i915: Preallocate our mmu notifier workequeu to unbreak
  cpu hotplug deadlock (FATE#322643 bsc#1055900).
- drm/i915/bios: don't pass bdb to parsers that don't parse VBT
  directly (FATE#322643 bsc#1055900).
- drm/i915/bios: parse SDVO device mapping from pre-parsed child
  devices (FATE#322643 bsc#1055900).
- drm/i915/bios: merge parse_device_mapping() into
  parse_general_definitions() (FATE#322643 bsc#1055900).
- drm/i915/bios: cleanup comments and useless return (FATE#322643
  bsc#1055900).
- drm/i915/bios: remove an unnecessary temp variable (FATE#322643
  bsc#1055900).
- drm/i915/bios: don't initialize fields based on vbt version
  (FATE#322643 bsc#1055900).
- drm/i915/bios: refactor parse general definitions (FATE#322643
  bsc#1055900).
- drm/i915: avoid division by zero on cnl_calc_wrpll_link
  (FATE#322643 bsc#1055900).
- drm/i915: add the BXT and CNL DPLL registers to
  pipe_config_compare (FATE#322643 bsc#1055900).
- drm/i915: Early rejection of mappable GGTT pin attempts for
  large bo (FATE#322643 bsc#1055900).
- drm/i915: Avoid evicting user fault mappable vma for
  pread/pwrite (FATE#322643 bsc#1055900).
- drm/i915: Try a minimal attempt to insert the whole object
  for relocations (FATE#322643 bsc#1055900).
- drm/i915: Check PIN_NONFAULT overlaps in evict_for_node
  (FATE#322643 bsc#1055900).
- drm/i915: Track user GTT faulting per-vma (FATE#322643
  bsc#1055900).
- drm/i915: Consolidate get_fence with pin_fence (FATE#322643
  bsc#1055900).
- drm/i915: Pin fence for iomap (FATE#322643 bsc#1055900).
- drm/i915: Provide an assert for when we expect forcewake to
  be held (FATE#322643 bsc#1055900).
- drm/i915/selftests: Hold the rpm wakeref for the reset tests
  (FATE#322643 bsc#1055900).
- drm/i915: Hold forcewake for the duration of reset+restart
  (FATE#322643 bsc#1055900).
- drm/i915/selftests: Pretty print engine state when requests
  fail to start (FATE#322643 bsc#1055900).
- drm/i915: Make i915_engine_info pretty printer to standalone
  (FATE#322643 bsc#1055900).
- drm/i915: Use intel_get_pipe_timings() and
  intel_mode_from_pipe_config() in intel_crtc_mode_get()
  (FATE#322643 bsc#1055900).
- commit 128dfbb
* Wed Feb 21 2018 tiwai@suse.de
- drm/i915/execlists: Add a comment for the extra MI_ARB_ENABLE
  (FATE#322643 bsc#1055900).
- drm/i915: Try harder to finish the idle-worker (FATE#322643
  bsc#1055900).
- drm/i915: Fix pointer-to-int conversion (FATE#322643
  bsc#1055900).
- drm/i915/huc: Fix includes in intel_huc.c (FATE#322643
  bsc#1055900).
- drm/i915: Unify uC variable types to avoid flooding
  checkpatch.pl (FATE#322643 bsc#1055900).
- drm/i915/crt: clean up encoder hook assignment (FATE#322643
  bsc#1055900).
- drm/i915: push DDI FDI link training on enable to CRT encoder
  (FATE#322643 bsc#1055900).
- drm/i915: push DDI and DSI underrun reporting on enable to
  encoder (FATE#322643 bsc#1055900).
- drm/i915: push DDI CRT underrun reporting on disable to encoder
  (FATE#322643 bsc#1055900).
- drm/i915: push DDI CRT underrun reporting on enable to encoder
  (FATE#322643 bsc#1055900).
- drm/i915/uc: Unify initialization of the uC firmware helper
  (FATE#322643 bsc#1055900).
- drm/i915/uc: Fix includes order (FATE#322643 bsc#1055900).
- drm/i915/guc: Move GuC core definitions into dedicated files
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Move GuC submission declarations into dedicated
  header (FATE#322643 bsc#1055900).
- drm/i915/guc: Move GuC log declarations into dedicated header
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Do not add an extra page for precaution in the
  Gen10 LRC size (FATE#322643 bsc#1055900).
- drm/i915: avoid potential uninitialized variable use
  (FATE#322643 bsc#1055900).
- drm/i915/selftests: fix check for intel IOMMU (FATE#322643
  bsc#1055900).
- drm/i915/selftests: Remember to create the fake preempt context
  (FATE#322643 bsc#1055900).
- drm/i915/mst: Use MST sideband message transactions for dpms
  control (FATE#322643 bsc#1055900).
- drm/i915/scheduler: Support user-defined priorities (FATE#322643
  bsc#1055900).
- drm/i915/execlists: Preemption! (FATE#322643 bsc#1055900).
- drm/i915: Expand I915_PARAM_HAS_SCHEDULER into a capability
  bitmask (FATE#322643 bsc#1055900).
- drm/i915/execlists: Keep request->priority for its lifetime
  (FATE#322643 bsc#1055900).
- drm/i915/execlists: Move bdw GPGPU w/a to emit_bb (FATE#322643
  bsc#1055900).
- drm/i915: Introduce a preempt context (FATE#322643 bsc#1055900).
- drm/i915/execlists: Distinguish the incomplete context notifies
  (FATE#322643 bsc#1055900).
- drm/i915/preempt: Default to disabled mid-command preemption
  levels (FATE#322643 bsc#1055900).
- drm/i915/preempt: Fix WaEnablePreemptionGranularityControlByUMD
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Move Guc early init into own function (FATE#322643
  bsc#1055900).
- drm/i915/huc: Move HuC declarations into dedicated header
  (FATE#322643 bsc#1055900).
- drm/i915/uc: Move uC fw helper code into dedicated files
  (FATE#322643 bsc#1055900).
- drm/i915/uc: Create intel_uc_init_mmio (FATE#322643
  bsc#1055900).
- drm/i915/uc: Drop unnecessary forward declaration (FATE#322643
  bsc#1055900).
- drm/i915: Make intel_uncore.h header self-contained (FATE#322643
  bsc#1055900).
- drm/i915: Remove defunct trace points (FATE#322643 bsc#1055900).
- drm/i915: Fix some tracepoints to capture full 64b (FATE#322643
  bsc#1055900).
- drm/i915: Remove WA_(SET|CLR)_BIT (FATE#322643 bsc#1055900).
- drm/i915: Move MMCD_MISC_CTRL from context w/a to standard
  (FATE#322643 bsc#1055900).
- drm/i915: Transform whitelisting WAs into a simple reg write
  (FATE#322643 bsc#1055900).
- drm/i915: Remove use_mmio_flip modparm, v2 (FATE#322643
  bsc#1055900).
- drm/i915: Skip vblank waits for cursor updates when watermarks
  dont need updating (FATE#322643 bsc#1055900).
- drm/i915: Unset legacy_cursor_update early in
  intel_atomic_commit, v3 (FATE#322643 bsc#1055900).
- drm/i915: Organize GLK_COLORS (FATE#322643 bsc#1055900).
- drm/i915: Organize GEN features inheritance (FATE#322643
  bsc#1055900).
- drm/i915/skl: Fix has_ipc on skl and document WaDisableIPC
  (FATE#322643 bsc#1055900).
- drm/i915/glk, cnl: Implement WaDisableScalarClockGating
  (FATE#322643 bsc#1055900).
- drm/i915: Add has_psr-flag to gen9lp (FATE#322643 bsc#1055900).
- drm/i915/gen8+: Init/reset display interrupts only if i915
  IRQs are enabled (FATE#322643 bsc#1055900).
- drm/i915/gen9+: Set same power state before hibernation image
  save/restore (FATE#322643 bsc#1055900).
- drm/i915/execlists: Cache the last priolist lookup (FATE#322643
  bsc#1055900).
- drm/i915: Give the invalid priority a magic name (FATE#322643
  bsc#1055900).
- drm/i915/execlists: Move request unwinding to a separate
  function (FATE#322643 bsc#1055900).
- drm/i915: Move i915_gem_restore_fences to i915_gem_resume
  (FATE#322643 bsc#1055900).
- drm/i915/selftests: Replace wmb() with i915_gem_chipset_flush()
  (FATE#322643 bsc#1055900).
- drm/i915: Update DRIVER_DATE to 20170929 (FATE#322643
  bsc#1055900).
- drm/i915: Also discard second CRC on gen8+ platforms
  (FATE#322643 bsc#1055900).
- drm/i915/psr: Set frames before SU entry for psr2 (FATE#322643
  bsc#1055900).
- drm/dp: Add defines for latency in sink (FATE#322643
  bsc#1055900).
- drm/i915: Allow optimized platform checks (FATE#322643
  bsc#1055900).
- drm/i915: Avoid using dev_priv->info.gen directly (FATE#322643
  bsc#1055900).
- i915: Use %%pS printk format for direct addresses (FATE#322643
  bsc#1055900).
- drm/i915/execlists: Notify context-out for lost requests
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Add support slice/subslice/eu configs (FATE#322643
  bsc#1055900).
- drm/i915: Compact device info access by a small re-ordering
  (FATE#322643 bsc#1055900).
- drm/i915: Add IS_PLATFORM macro (FATE#322643 bsc#1055900).
- drm/i915/selftests: Try to recover from a wedged GPU during
  reset tests (FATE#322643 bsc#1055900).
- drm/i915/huc: Reorganize HuC authentication (FATE#322643
  bsc#1055900).
- drm/i915: Fix default values of some modparams (FATE#322643
  bsc#1055900).
- drm/i915: Extend I915_PARAMS_FOR_EACH with default member value
  (FATE#322643 bsc#1055900).
- drm/i915: Make I915_PARAMS_FOR_EACH macro more flexible
  (FATE#322643 bsc#1055900).
- drm/i915: Enable scanline read based on frame timestamps
  (FATE#322643 bsc#1055900).
- drm/i915/execlists: Microoptimise
  execlists_cancel_port_request() (FATE#322643 bsc#1055900).
- drm/i915: Don't rmw PIPESTAT enable bits (FATE#322643
  bsc#1055900).
- drm/i915: Speed up DMC firmware loading (FATE#322643
  bsc#1055900).
- drm/i915/dp: Remove useless debug about TPS3 support
  (FATE#322643 bsc#1055900).
- drm/i915/dp: Fix buffer size for sink_irq_esi read (FATE#322643
  bsc#1055900).
- drm/i915/mst: Print active mst links after update (FATE#322643
  bsc#1055900).
- drm/i915/mst: Debug log connector name in destroy_connector()
  (FATE#322643 bsc#1055900).
- drm/i915/lrc: Skip no-op per-bb buffer on gen9 (FATE#322643
  bsc#1055900).
- drm/i915/lrc: Only enable per-context and per-bb buffers if set
  (FATE#322643 bsc#1055900).
- drm/i915: Make execlist port count variable (FATE#322643
  bsc#1055900).
- drm/i915: Add execlist_port_complete (FATE#322643 bsc#1055900).
- drm/i915: Wrap port cancellation into a function (FATE#322643
  bsc#1055900).
- drm/i915: Move execlist initialization into intel_engine_cs.c
  (FATE#322643 bsc#1055900).
- drm/i915: Make own struct for execlist items (FATE#322643
  bsc#1055900).
- drm/i915: Make i915_spin_request() static (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Add Gen10 LRC size (FATE#322643 bsc#1055900).
- drm/i915: Rename global i915 to i915_modparams (FATE#322643
  bsc#1055900).
- drm/i915: Confirm request->global_seqno after spin completion
  (FATE#322643 bsc#1055900).
- drm/i915: Check waiter->seqno carefully in case of preemption
  (FATE#322643 bsc#1055900).
- drm/i915: Only wake the waiter from the interrupt if passed
  (FATE#322643 bsc#1055900).
- drm/i915: Document the split in internal and public execbuf
  flags (FATE#322643 bsc#1055900).
- drm/i915: Reorganize .disable hooks for pre-DDI DP (FATE#322643
  bsc#1055900).
- drm/i915: Drop useless HAS_PSR() check (FATE#322643
  bsc#1055900).
- drm/i915: Stop engines before reset (FATE#322643 bsc#1055900).
- drm/i915/cfl: Remove alpha support protection (FATE#322643
  bsc#1055900).
- drm/i915/cnp: Display Wa #1179: WaHardHangonHotPlug (FATE#322643
  bsc#1055900).
- drm/i915: Shrink cnl_ddi_buf_trans (FATE#322643 bsc#1055900).
- drm/i915: Shrink bxt_ddi_buf_trans (FATE#322643 bsc#1055900).
- commit 50db074
* Wed Feb 21 2018 tiwai@suse.de
- drm/i915: Replace some spaces with tabs (FATE#322643
  bsc#1055900).
- drm/i915/fence: Avoid del_timer_sync() from inside a timer
  (FATE#322643 bsc#1055900).
- drm/i915/selftests: Only touch archdata.iommu when it exists
  (FATE#322643 bsc#1055900).
- drm/i915/cnp: Don't touch other PCH clock gating bits
  (FATE#322643 bsc#1055900).
- drm/i915: Do not enable DRRS when PSR is enabled (FATE#322643
  bsc#1055900).
- drm/i915/perf: add support for Coffeelake GT2 (FATE#322643
  bsc#1055900).
- drm/i915/perf: disable clk ratio reports on gen9 (FATE#322643
  bsc#1055900).
- drm/i915/selftests: Disable iommu for the mock device
  (FATE#322643 bsc#1055900).
- drm/i915: Return the correct score in i915_ppat_get()
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Cleanup adding GuC work items (FATE#322643
  bsc#1055900).
- drm/i915/guc: Simplify GuC doorbell logic (FATE#322643
  bsc#1055900).
- drm/i915/guc: Submit GuC workitems containing coalesced requests
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Remove obsolete comments and remove unused
  variable (FATE#322643 bsc#1055900).
- drm/i915/execlists: Unwind incomplete requests on resets
  (FATE#322643 bsc#1055900).
- drm/i915/execlists: Split insert_request() (FATE#322643
  bsc#1055900).
- drm/i915/execlists: Move insert_request() (FATE#322643
  bsc#1055900).
- drm/i915/execlists: Kick start request processing after a reset
  (FATE#322643 bsc#1055900).
- drm/i915: Cancel all ready but queued requests when wedging
  (FATE#322643 bsc#1055900).
- drm/i915: Reinstate GMBUS and AUX interrupts on gen4/g4x
  (FATE#322643 bsc#1055900).
- drm/i915: Remove duplicated irq_preinstall/uninstall hooks
  (FATE#322643 bsc#1055900).
- drm/i915: Clean up the HWSTAM mess (FATE#322643 bsc#1055900).
- drm/i915: Mask everything in ring HWSTAM on gen6+ in ringbuffer
  mode (FATE#322643 bsc#1055900).
- drm/i915: Extend private i915_param_named macro with description
  (FATE#322643 bsc#1055900).
- drm/i915: Introduce custom variant of module_param_named macro
  (FATE#322643 bsc#1055900).
- drm/i915: Rename lvds_use_ssc modparam to panel_use_ssc
  (FATE#322643 bsc#1055900).
- drm/i915: Mark the userptr invalidate workqueue as
  WQ_MEM_RECLAIM (FATE#322643 bsc#1055900).
- drm/i915/cnl: Change the macro name to
  DPLL_CFGCR0_DCO_FRACTION_SHIFT (FATE#322643 bsc#1055900).
- drm/i915: Gen3 HWSTAM is actually 32 bits (FATE#322643
  bsc#1055900).
- drm/i915: Rewrite GMCH irq handlers to avoid loops (FATE#322643
  bsc#1055900).
- drm/i915: Extract PIPESTAT irq handling into separate functions
  (FATE#322643 bsc#1055900).
- drm/i915: Remove NULL dev_priv checks from irq_uninstall
  (FATE#322643 bsc#1055900).
- drm/i915: Unify the appearance of gen3/4 irq_postistall hooks
  (FATE#322643 bsc#1055900).
- drm/i915: Eliminate PORT_HOTPLUG_EN setup from gen3/4
  irq_postinstall (FATE#322643 bsc#1055900).
- drm/i915: Setup EMR first on all gen2-4 (FATE#322643
  bsc#1055900).
- drm/i915: Introduce GEN2_IRQ_RESET/INIT (FATE#322643
  bsc#1055900).
- drm/i915: Use GEN3_IRQ_RESET/INIT on gen3/4 (FATE#322643
  bsc#1055900).
- drm/i915: s/GEN5/GEN3/ (FATE#322643 bsc#1055900).
- drm/i915: Clear pipestat consistently (FATE#322643 bsc#1055900).
- drm/i915: Don't enable/unmask flip interrupts (FATE#322643
  bsc#1055900).
- drm/i915: Remove the "INDEX" suffix from PPAT marcos
  (FATE#322643 bsc#1055900).
- drm/i915: Introduce private PAT management (FATE#322643
  bsc#1055900).
- drm/i915: Switch over to the LLC/eLLC hotspot avoidance hash
  mode for CCS (FATE#322643 bsc#1055900).
- drm/i915: Simplify i915_reg_read_ioctl (FATE#322643
  bsc#1055900).
- drm/i915: Introduce INTEL_GEN_MASK (FATE#322643 bsc#1055900).
- drm/i915: Refresh VLV/CHV PSR comments on HW PSR_state machine
  (FATE#322643 bsc#1055900).
- drm/i915/execlists: Read the context-status HEAD from the HWSP
  (FATE#322643 bsc#1055900).
- drm/i915/execlists: Read the context-status buffer from the HWSP
  (FATE#322643 bsc#1055900).
- drm/i915: Allow HW status page to be bound high (FATE#322643
  bsc#1055900).
- drm/i915/lrc: allocate separate page for HWSP (FATE#322643
  bsc#1055900).
- drm/i915/guc: Don't make assumptions while getting the lrca
  offset (FATE#322643 bsc#1055900).
- drm/i915/lrc: Clarify the format of the context image
  (FATE#322643 bsc#1055900).
- drm/i915/selftests: Use mul_u32_u32() for 32b x 32b -> 64b
  result (FATE#322643 bsc#1055900).
- drm/i915: Use mul_u32_u32() for 32b x 32b -> 64b result
  (FATE#322643 bsc#1055900).
- drm/i915: Squelch smatch warning for statement with no effect
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Small improvements to guc_wq_item_append
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Remove WQ_WORKLOAD_SHIFT define (FATE#322643
  bsc#1055900).
- drm/i915/guc: Name the default GuC scheduling policy
  (FATE#322643 bsc#1055900).
- drm/i915: Move the context descriptor to an inline helper
  (FATE#322643 bsc#1055900).
- drm/i915/dsi: Replace MIPI command error message with debug
  message (FATE#322643 bsc#1055900).
- drm/i915: Cleanup error paths through eb_lookup_vma()
  (FATE#322643 bsc#1055900).
- drm/i915/spt+: Don't reset invalid AUX channel interrupt bits
  in SDEIMR (FATE#322643 bsc#1055900).
- drm/i915: Name the IPS_PCODE_CONTROL bit (FATE#322643
  bsc#1055900).
- drm/i915: Nuke some bogus tabs from the pcode defines
  (FATE#322643 bsc#1055900).
- drm/i915: Factor out setup_private_pat() (FATE#322643
  bsc#1055900).
- drm/i915: Increase poll time for BDW FCLK_DONE (FATE#322643
  bsc#1055900).
- drm/i915/psr: Add enable_source vfunc (FATE#322643 bsc#1055900).
- drm/i915/psr: Add enable_sink vfunc (FATE#322643 bsc#1055900).
- drm/i915/psr: Add setup VSC vfunc (FATE#322643 bsc#1055900).
- drm/i915/psr: Re-org Activate after enable (FATE#322643
  bsc#1055900).
- drm/i915/psr: Move hsw_enable_source after enabling sink
  (FATE#322643 bsc#1055900).
- drm/i915/psr: Re-create a hsw_psr_enable_source (FATE#322643
  bsc#1055900).
- drm/i915/psr: Unify VSC setup functions (FATE#322643
  bsc#1055900).
- drm/i915/psr: Add activate vfunc (FATE#322643 bsc#1055900).
- drm/i915/psr: hsw_psr_activate (FATE#322643 bsc#1055900).
- drm/i915/psr: vfunc for disabling source (FATE#322643
  bsc#1055900).
- drm/i915/psr: Avoid any PSR stuff on platforms without support
  (FATE#322643 bsc#1055900).
- drm/i915: Only initialize partially filled pagetables
  (FATE#322643 bsc#1055900).
- drm/i915: Make PAT macros more robust (FATE#322643 bsc#1055900).
- drm/i915: Add a default case in gen7 hwsp switch-case
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Add support for PCIe extended configuration space
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Refine error handling for perform_bb_shadow
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Refine error handling in dispatch_workload
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Refine error handling for intel_vgpu_pin_mm
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Refine error handling for
  prepare_execlist_workload (FATE#322643 bsc#1055900).
- drm/i915/gvt: Add error handling for
  intel_gvt_scan_and_shadow_workload (FATE#322643 bsc#1055900).
- drm/i915/gvt: Separate cmd scan from request allocation
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Add emulation for BAR2 (aperture) with normal
  file RW approach (FATE#322643 bsc#1055900).
- drm/i915/kvmgt: Sanitize PCI bar emulation (FATE#322643
  bsc#1055900).
- drm/i915: Transform WaDisablePooledEuLoadBalancingFix into a
  simple register write (FATE#322643 bsc#1055900).
- drm/i915: Transform WaDisableDynamicCreditSharing into a simple
  register write (FATE#322643 bsc#1055900).
- drm/i915: Transform WaDisableGafsUnitClkGating into a simple
  reg write (FATE#322643 bsc#1055900).
- drm/i915: WaPushConstantDereferenceHoldDisable needs to modify
  a masked register (FATE#322643 bsc#1055900).
- drm/i915: Transform WaDisableI2mCycleOnWRPort into a simple
  reg write (FATE#322643 bsc#1055900).
- drm/i915: Transform WaInPlaceDecompressionHang into a simple
  reg write (FATE#322643 bsc#1055900).
- drm/i915: Apply the GTT write flush for all !llc machines
  (FATE#322643 bsc#1055900).
- i915: Fix obj size vs. alignment for drm_pci_alloc()
  (FATE#322643 bsc#1055900).
- drm/i915: Disable mmio debugging during user access (FATE#322643
  bsc#1055900).
- drm/i915/skl+: debugfs entry to control IPC (FATE#322643
  bsc#1055900).
- drm/i915/bxt+: Enable IPC support (FATE#322643 bsc#1055900).
- drm/i915/gen9+: Add has_ipc flag in device info structure
  (FATE#322643 bsc#1055900).
- commit 77f9c1e
* Wed Feb 21 2018 tiwai@suse.de
- drm/i915/cnl: Extend WM workaround with IPC for CNL (FATE#322643
  bsc#1055900).
- drm/i915/glk: IPC linetime watermark workaround for GLK
  (FATE#322643 bsc#1055900).
- drm/i915/gen10: Calculate and enable transition WM (FATE#322643
  bsc#1055900).
- drm/i915/skl+: Optimize WM calculation (FATE#322643
  bsc#1055900).
- drm/i915: Fixed point fixed16 wrapper cleanup (FATE#322643
  bsc#1055900).
- drm/i915: Disable snooping (userptr, set-cache-level) on gen4
  (FATE#322643 bsc#1055900).
- drm: Pass struct drm_file * to __drm_mode_object_find [v2]
  (FATE#322643 bsc#1055900).
- drm/i915: Update DRIVER_DATE to 20170907 (FATE#322643
  bsc#1055900).
- drm/i915/cnl:
  WaThrottleEUPerfToAvoidTDBackPressure:cnl(pre-prod) (FATE#322643
  bsc#1055900).
- drm/i915: Lift has-pinned-pages assert to caller of
  ____i915_gem_object_get_pages (FATE#322643 bsc#1055900).
- drm/i915: Display WA #1133 WaFbcSkipSegments:cnl, glk
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Allow the reg_read ioctl to read the RCS TIMESTAMP
  register (FATE#322643 bsc#1055900).
- drm/i915: Move device_info.has_snoop into the static tables
  (FATE#322643 bsc#1055900).
- drm/i915: Disable MI_STORE_DATA_IMM for i915g/i915gm
  (FATE#322643 bsc#1055900).
- drm/i915/cnp: Wa 1181: Fix Backlight issue (FATE#322643
  bsc#1055900).
- drm/i915: Constify load detect mode (FATE#322643 bsc#1055900).
- drm/i915: io unmap functions want __iomem (FATE#322643
  bsc#1055900).
- drm/i915: Wake up the device for the fbdev setup (FATE#322643
  bsc#1055900).
- drm/i915: Add interface to reserve fence registers for vGPU
  (FATE#322643 bsc#1055900).
- drm/i915: Use correct path to trace include (FATE#322643
  bsc#1055900).
- drm/i915: Eliminate crtc->state usage from
  intel_atomic_commit_tail and .crtc_update() (FATE#322643
  bsc#1055900).
- drm/i915: Eliminate crtc->state usage from
  intel_update_pipe_config() (FATE#322643 bsc#1055900).
- drm/i915: Eliminate obj->state usage from pre/post plane update
  (FATE#322643 bsc#1055900).
- drm/i915: Pass proper old/new states to
  intel_plane_atomic_check_with_state() (FATE#322643 bsc#1055900).
- drm/i915: rework IS_*_GT* macros (FATE#322643 bsc#1055900).
- drm/i915: mark all device info struct with __initconst
  (FATE#322643 bsc#1055900).
- drm/i915: add GT number to intel_device_info (FATE#322643
  bsc#1055900).
- drm/i915: Eliminate obj->state usage in g4x/vlv/chv wm
  computation (FATE#322643 bsc#1055900).
- drm/i915: Pass the crtc state explicitly to
  intel_pipe_update_start/end() (FATE#322643 bsc#1055900).
- drm/i915: Pass the new crtc state to color management code
  (FATE#322643 bsc#1055900).
- drm/i915: Consolidate max_cdclk_freq check in
  intel_crtc_compute_min_cdclk() (FATE#322643 bsc#1055900).
- drm/i915: Track minimum acceptable cdclk instead of "minimum
  dotclock" (FATE#322643 bsc#1055900).
- drm/i915/cnl: Fix DP max voltage (FATE#322643 bsc#1055900).
- drm/i915/cnl: Fix DDI hdmi level selection (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Move ddi buf trans related functions up
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Move voltage check into ddi buf trans functions
  (FATE#322643 bsc#1055900).
- drm/i915: Enable voltage swing before enabling DDI_BUF_CTL
  (FATE#322643 bsc#1055900).
- drm/i915: Align vswing sequences with old ddi buffer registers
  (FATE#322643 bsc#1055900).
- drm/i915: decouple gen9 and gen10 dp signal levels (FATE#322643
  bsc#1055900).
- drm/i915: Introduce intel_ddi_dp_level (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Avoid ioremap_wc on Cannonlake as well
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: WaDisableI2mCycleOnWRPort (FATE#322643
  bsc#1055900).
- drm/i915/cnl: WA FtrEnableFastAnisoL1BankingFix (FATE#322643
  bsc#1055900).
- drm/i915: Stop using long platform names on clock gating
  functions (FATE#322643 bsc#1055900).
- drm/i915: Discard the request queue if we fail to sleep before
  suspend (FATE#322643 bsc#1055900).
- drm/i915: Clear wedged status upon resume (FATE#322643
  bsc#1055900).
- drm/i915: Always sanity check engine state upon idling
  (FATE#322643 bsc#1055900).
- drm/i915: Don't use GPU relocations prior to cmdparser stalls
  (FATE#322643 bsc#1055900).
- drm/i915: Remove excess indent in intel_finish_reset() caught
  by sparse (FATE#322643 bsc#1055900).
- drm/i915: Beef up of Beef up the IPS vs. CRC workaround
  (FATE#322643 bsc#1055900).
- drm/i915/bios: amend edp block based on intel_vbt_decode
  (FATE#322643 bsc#1055900).
- drm/i915/bios: amend child device flags based on
  intel_vbt_decode (FATE#322643 bsc#1055900).
- drm/i915/bios: amend bdb_general_features (FATE#322643
  bsc#1055900).
- drm/i915/bios: split up iboost to hdmi and dp bitfields
  (FATE#322643 bsc#1055900).
- drm/i915: Fix FBC cfb stride programming for non X-tiled FB
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: don't hardcode DPCLKA_CFGCR0_DDI_CLK_SEL_SHIFT
  (FATE#322643 bsc#1055900).
- drm/i915/bios: drop the rest of the p_ prefixes from pointers
  (FATE#322643 bsc#1055900).
- drm/i915/bios: throw away unused DVO_* macros (FATE#322643
  bsc#1055900).
- drm/i915/bios: group device type definitions together
  (FATE#322643 bsc#1055900).
- drm/i915/bios: document child device config dvo_port values
  a bit better (FATE#322643 bsc#1055900).
- drm/i915/bios: throw away struct old_child_dev_config
  (FATE#322643 bsc#1055900).
- drm/i915/bios: throw away high level child device union
  (FATE#322643 bsc#1055900).
- drm/i915/bios: add legacy contents to common child device config
  (FATE#322643 bsc#1055900).
- drm/i915/bios: remove the raw version of child device config
  (FATE#322643 bsc#1055900).
- drm/i915/bios: document BDB versions of child device config
  fields (FATE#322643 bsc#1055900).
- drm/i915/bios: amend child device config parameters (FATE#322643
  bsc#1055900).
- drm/i915: Beef up the IPS vs. CRC workaround (FATE#322643
  bsc#1055900).
- drm/i915: Make some RPS functions static (FATE#322643
  bsc#1055900).
- drm/i915: Assert that the handle->vma lut is empty on object
  close (FATE#322643 bsc#1055900).
- drm/i915/cnl: WaForceContextSaveRestoreNonCoherent (FATE#322643
  bsc#1055900).
- drm/i915/cnl: WaPushConstantDereferenceHoldDisable (FATE#322643
  bsc#1055900).
- drm/i915/cfl: Coffee Lake works on Kaby Lake PCH (FATE#322643
  bsc#1055900).
- drm/i915/cnl: extract cnl_set_procmon_ref_values (FATE#322643
  bsc#1055900).
- drm/i915/cnl: simplify cnl_procmon_values handling (FATE#322643
  bsc#1055900).
- drm/i915: Boost GPU clocks if we miss the pageflip's vblank
  (FATE#322643 bsc#1055900).
- drm/i915: Constify states passed to enable/disable/etc. encoder
  hooks (FATE#322643 bsc#1055900).
- drm/i915: Plumb crtc_state to PSR enable/disable (FATE#322643
  bsc#1055900).
- drm/i915: Init infoframe vfuncs for DP encoders as well
  (FATE#322643 bsc#1055900).
- drm/i915: Move infoframe vfuncs into intel_digital_port
  (FATE#322643 bsc#1055900).
- drm/i915: Disable infoframes when shutting down DDI HDMI
  (FATE#322643 bsc#1055900).
- drm/i915: Check has_infoframes when enabling infoframes
  (FATE#322643 bsc#1055900).
- drm/i915: Re-enable per-engine reset for Broxton (FATE#322643
  bsc#1055900).
- drm/i915/dp: make is_edp non-static and rename to
  intel_dp_is_edp (FATE#322643 bsc#1055900).
- drm/i915/dp: rename intel_dp_is_edp to intel_dp_is_port_edp
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Apply large line width optimization (FATE#322643
  bsc#1055900).
- drm/i915/cnl: WaDisableEnhancedSBEVertexCaching (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Add
  WaDisableReplayBufferBankArbitrationOptimization (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Introduce initial Cannonlake Workarounds
  (FATE#322643 bsc#1055900).
- drm/dp/mst: Sideband message transaction to power up/down nodes
  (FATE#322643 bsc#1055900).
- drm/atomic: Fix freeing connector/plane state too early by
  tracking commits, v3 (FATE#322643 bsc#1055900).
- drm/atomic: Move drm_crtc_commit to drm_crtc_state, v4
  (FATE#322643 bsc#1055900).
- drm/atomic: Return commit in drm_crtc_commit_get for better
  annotation (FATE#322643 bsc#1055900).
- drm/i915: Always wait for flip_done, v2 (FATE#322643
  bsc#1055900).
- drm/dp: Add defines for DP SDP types (FATE#322643 bsc#1055900).
- drm/i915: Deconstruct struct sgt_dma initialiser (FATE#322643
  bsc#1055900).
- drm/i915: Reject unknown syncobj flags (FATE#322643
  bsc#1055900).
- drm/i915: Check incoming alignment for unfenced buffers (on
  i915gm) (FATE#322643 bsc#1055900).
- drm/i915: Hold rcu_read_lock when iterating over the radixtree
  (objects) (FATE#322643 bsc#1055900).
- drm/i915/edp: read edp display control registers unconditionally
  (FATE#322643 bsc#1055900).
- drm/i915: Do not rely on wm preservation for ILK watermarks
  (FATE#322643 bsc#1055900).
- commit 1559905
* Wed Feb 21 2018 tiwai@suse.de
- drm/i915: Cancel the modeset retry work during modeset cleanup
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Adding ACTHD mmio read handler (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Extract mmio_read_from_hw() common function
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Refine MMIO_RING_F() (FATE#322643 bsc#1055900).
- drm/i915/gvt: properly check per_ctx bb valid state (FATE#322643
  bsc#1055900).
- drm/i915/perf: fix perf enable/disable ioctls with 32bits
  userspace (FATE#322643 bsc#1055900).
- drm/i915: Use a mask when applying WaProgramL3SqcReg1Default
  (FATE#322643 bsc#1055900).
- drm/i915: Report -EFAULT before pwrite fast path into shmemfs
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Fix PLL initialization for HDMI (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Fix PLL mapping (FATE#322643 bsc#1055900).
- drm/i915: Use bdw_ddi_translations_fdi for Broadwell
  (FATE#322643 bsc#1055900).
- drm/i915: Fix eviction when the GGTT is idle but full
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Fix GPU hang after reusing vGPU instance across
  different guest OS (FATE#322643 bsc#1055900).
- drm/i915/bios: parse DDI ports also for CHV for HDMI DDC pin
  and DP AUX channel (FATE#322643 bsc#1055900).
- drm/i915: Read timings from the correct transcoder in
  intel_crtc_mode_get() (FATE#322643 bsc#1055900).
- drm/i915: Order two completing nop_submit_request (FATE#322643
  bsc#1055900).
- drm/i915: Silence compiler warning for hsw_power_well_enable()
  (FATE#322643 bsc#1055900).
- drm/i915: Use crtc_state_is_legacy_gamma in intel_color_check
  (FATE#322643 bsc#1055900).
- drm/i915/edp: Increase the T12 delay quirk to 1300ms
  (FATE#322643 bsc#1055900).
- drm/i915/edp: Get the Panel Power Off timestamp after panel
  is off (FATE#322643 bsc#1055900).
- drm/i915/glk: Fix DMC/DC state idleness calculation (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Reprogram DMC firmware after S3/S4 resume
  (FATE#322643 bsc#1055900).
- drm/i915: Fix DDI PHY init if it was already on (FATE#322643
  bsc#1055900).
- drm/i915/bios: ignore HDMI on port A (FATE#322643 bsc#1055900).
- drm/i915: remove redundant variable hw_check (FATE#322643
  bsc#1055900).
- drm/i915: always update ELD connector type after get modes
  (FATE#322643 bsc#1055900).
- drm/i915: Remove unused 'in_vbl' from i915_get_crtc_scanoutpos()
  (FATE#322643 bsc#1055900).
- drm/i915/cnp: set min brightness from VBT (FATE#322643
  bsc#1055900).
- Revert "drm/i915/bxt: Disable device ready before shutdown
  command" (bsc#1051510).
- drm/i915/bxt: set min brightness from VBT (FATE#322643
  bsc#1055900).
- drm/i915: Fix an error handling in 'intel_framebuffer_init()'
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Fix incorrect PCI BARs reporting (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Remove one duplicated MMIO (FATE#322643
  bsc#1055900).
- drm/i915: Re-enable GTT following a device reset (FATE#322643
  bsc#1055900).
- drm/i915: Annotate user relocs with __user (FATE#322643
  bsc#1055900).
- drm/i915: Silence sparse by using gfp_t (FATE#322643
  bsc#1055900).
- drm/i915: Add __rcu to radix tree slot pointer (FATE#322643
  bsc#1055900).
- drm/i915: Fix the missing PPAT cache attributes on CNL
  (FATE#322643 bsc#1055900).
- drm/i915: Fix enum pipe vs. enum transcoder for the PCH
  transcoder (FATE#322643 bsc#1055900).
- drm/i915: Make i2c lock ops static (FATE#322643 bsc#1055900).
- drm/i915: Make i9xx_load_ycbcr_conversion_matrix() static
  (FATE#322643 bsc#1055900).
- drm/i915/edp: Increase T12 panel delay to 900 ms to fix DP
  AUX CH timeouts (FATE#322643 bsc#1055900).
- drm/i915: Ignore duplicate VMA stored within the per-object
  handle LUT (FATE#322643 bsc#1055900).
- drm/i915: Skip fence alignemnt check for the CCS plane
  (FATE#322643 bsc#1055900).
- drm/i915: Treat fb->offsets[] as a raw byte offset instead of
  a linear offset (FATE#322643 bsc#1055900).
- drm/i915: Always wake the device to flush the GTT (FATE#322643
  bsc#1055900).
- drm/i915: Recreate vmapping even when the object is pinned
  (FATE#322643 bsc#1055900).
- drm/i915: Quietly cancel FBC activation if CRTC is turned off
  before worker (FATE#322643 bsc#1055900).
- i915: Use drm_syncobj_fence_get (FATE#322643 bsc#1055900).
- drm/syncobj: Add a race-free drm_syncobj_fence_get helper (v2)
  (FATE#322643 bsc#1055900).
- drm/syncobj: Rename fence_get to find_fence (FATE#322643
  bsc#1055900).
- drm/i915: Update DRIVER_DATE to 20170818 (FATE#322643
  bsc#1055900).
- drm/i915: Mark the GT as busy before idling the previous request
  (FATE#322643 bsc#1055900).
- drm/i915: Trivial grammar fix s/opt of/opt out of/ in comment
  (FATE#322643 bsc#1055900).
- drm/i915: Replace execbuf vma ht with an idr (FATE#322643
  bsc#1055900).
- drm/i915: Simplify eb_lookup_vmas() (FATE#322643 bsc#1055900).
- drm/i915: Convert execbuf to use struct-of-array packing for
  critical fields (FATE#322643 bsc#1055900).
- drm/i915: Check context status before looking up our obj/vma
  (FATE#322643 bsc#1055900).
- drm/i915: Don't use MI_STORE_DWORD_IMM on Sandybridge/vcs
  (FATE#322643 bsc#1055900).
- drm/i915: Stop touching forcewake following a gen6+ engine reset
  (FATE#322643 bsc#1055900).
- drm/i915: Split pin mapping into per platform functions
  (FATE#322643 bsc#1055900).
- drm/i915/opregion: let user specify override VBT via firmware
  load (FATE#322643 bsc#1055900).
- drm/i915/cnl: Reuse skl_wm_get_hw_state on Cannonlake
  (FATE#322643 bsc#1055900).
- drm/i915/gen10: implement gen 10 watermarks calculations
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Setup PAT Index (FATE#322643 bsc#1055900).
- drm/i915/edp: Allow alternate fixed mode for eDP if available
  (FATE#322643 bsc#1055900).
- drm/i915: Add support for drm syncobjs (FATE#322643
  bsc#1055900).
- drm/i915: Handle full s64 precision for wait-ioctl (FATE#322643
  bsc#1055900).
- drm/i915: Split obj->cache_coherent to track r/w (FATE#322643
  bsc#1055900).
- drm/i915/hsw+: Add support for multiple power well regs
  (FATE#322643 bsc#1055900).
- drm/i915: Work around GCC anonymous union initialization bug
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Fix guest i915 full ppgtt blocking issue
  (FATE#322643 bsc#1055900).
- drm/i915: Enable guest i915 full ppgtt functionality
  (FATE#322643 bsc#1055900).
- drm/i915: Disconnect 32 and 48 bit ppGTT support (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Add shadow context descriptor updating
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: expose vGPU context hw id (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Refine the intel_vgpu_reset_gtt reset function
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Add carefully checking in GTT walker paths
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Remove duplicated MMIO entries (FATE#322643
  bsc#1055900).
- drm/i915/gvt: take runtime pm when do early scan and shadow
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Replace duplicated code with exist function
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: To check whether workload scan and shadow has
  mutex hold (FATE#322643 bsc#1055900).
- drm/i915/gvt: Audit and shadow workload during ELSP writing
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Factor out scan and shadow from workload dispatch
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Optimize ring siwtch 2x faster again by light
  weight mmio access wrapper (FATE#322643 bsc#1055900).
- drm/i915/gvt: Optimize ring siwtch 2x faster by removing
  unnecessary POSTING_READ (FATE#322643 bsc#1055900).
- drm/i915/gvt: Use gvt_err to print the resource not enough error
  (FATE#322643 bsc#1055900).
- drm/i915/dp: Validate the compliance test link parameters
  (FATE#322643 bsc#1055900).
- drm/i915/dp: Generalize intel_dp_link_params function to accept
  arguments to be validated (FATE#322643 bsc#1055900).
- drm/i915: More surgically unbreak the modeset vs reset deadlock
  (FATE#322643 bsc#1055900).
- drm/i915: Push i915_sw_fence_wait into the nonblocking atomic
  commit (FATE#322643 bsc#1055900).
- drm/i915/gen9: Send all components in VF state (FATE#322643
  bsc#1055900).
- drm/i915/guc: Rename GuC irq trigger function (FATE#322643
  bsc#1055900).
- drm/i915: Add SW_SYNC to our recommend testing Kconfig
  (FATE#322643 bsc#1055900).
- drm/i915: Introduce intel_hpd_pin function (FATE#322643
  bsc#1055900).
- drm/i915: Simplify hpd pin to port (FATE#322643 bsc#1055900).
- drm/i915/cnl: Dump the right pll registers when dumping pipe
  config (FATE#322643 bsc#1055900).
- drm/i915/cnl: Add allowed DP rates for Cannonlake (FATE#322643
  bsc#1055900).
- drm/i915: make structure intel_sprite_plane_funcs static
  (FATE#322643 bsc#1055900).
- drm/i915/fbc: only update no_fbc_reason when active (FATE#322643
  bsc#1055900).
- commit bb1995e
* Wed Feb 21 2018 tiwai@suse.de
- drm/i915/gen10: fix WM latency printing (FATE#322643
  bsc#1055900).
- drm/i915/gen10: fix the gen 10 SAGV block time (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Enable SAGV for Cannonlake (FATE#322643
  bsc#1055900).
- drm/i915/gen10+: use the SKL code for reading WM latencies
  (FATE#322643 bsc#1055900).
- drm/i915: Avoid null dereference if mst_port is unset
  (FATE#322643 bsc#1055900).
- drm/i915/perf: Drop redundant check for perf.initialised on
  reset (FATE#322643 bsc#1055900).
- drm/i915/perf: Drop lockdep assert for i915_oa_init_reg_state()
  (FATE#322643 bsc#1055900).
- drm/i915/perf: Initialise dynamic sysfs group before creation
  (FATE#322643 bsc#1055900).
- drm/i915: enum i915_power_well_id is not proper kernel-doc
  (FATE#322643 bsc#1055900).
- drm/i915: Add format modifiers for Intel (FATE#322643
  bsc#1055900).
- drm/i915: Add render decompression support (FATE#322643
  bsc#1055900).
- drm/i915: Implement .get_format_info() hook for CCS (FATE#322643
  bsc#1055900).
- drm/i915: Supply the engine-id for our mock_engine()
  (FATE#322643 bsc#1055900).
- drm/i915/psr: Preserve SRD_CTL bit 29 on PSR init (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Removing missing DDI_E bits from CNL (FATE#322643
  bsc#1055900).
- drm/i915/selftests: Retarget igt_render_engine_reset_fallback()
  (FATE#322643 bsc#1055900).
- drm/i915/perf: Initialise the dynamic sysfs attr (FATE#322643
  bsc#1055900).
- drm/i915: enable WaDisableDopClkGating for skl (FATE#322643
  bsc#1055900).
- drm/i915: Fix PCH names for KBP and CNP (FATE#322643
  bsc#1055900).
- drm/i915/perf: Implement I915_PERF_ADD/REMOVE_CONFIG interface
  (FATE#322643 bsc#1055900).
- drm/i915: reorder NOA register definition to follow addresses
  (FATE#322643 bsc#1055900).
- drm/i915/perf: disable NOA logic when not used (FATE#322643
  bsc#1055900).
- drm/i915/perf: leave GDT_CHICKEN_BITS programming in configs
  (FATE#322643 bsc#1055900).
- drm/i915/perf: prune OA configs (FATE#322643 bsc#1055900).
- drm/i915: add const to bin_attribute (FATE#322643 bsc#1055900).
- drm/i915: Update DRIVER_DATE to 20170731 (FATE#322643
  bsc#1055900).
- drm/i915: Remove unused i915_err_print_instdone (FATE#322643
  bsc#1055900).
- drm/i915: Include mbox details for pcode read/write failures
  (FATE#322643 bsc#1055900).
- drm/i915/sdvo: Shut up state checker with hdmi cards on gen3
  (FATE#322643 bsc#1055900).
- drm/i915: Rework sdvo proxy i2c locking (FATE#322643
  bsc#1055900).
- drm/i915: Call the unlocked version of
  i915_gem_object_get_pages() (FATE#322643 bsc#1055900).
- drm/i915: Move i915_gem_object_phys_attach() (FATE#322643
  bsc#1055900).
- drm/i915: Pin the pages before acquiring struct_mutex for
  display (FATE#322643 bsc#1055900).
- drm/i915: Make i915_gem_object_phys_attach() use obj->mm.lock
  more appropriately (FATE#322643 bsc#1055900).
- drm/i915: Trim struct_mutex usage for kms (FATE#322643
  bsc#1055900).
- drm/i915: Handle msr read failure gracefully (FATE#322643
  bsc#1055900).
- drm/i915/fbc: add comments to the FBC auxiliary structs
  (FATE#322643 bsc#1055900).
- drm/i915: cleanup the CHICKEN_MISC_2 (re)definitions
  (FATE#322643 bsc#1055900).
- drm/i915/selftests: Fix kbuild error (FATE#322643 bsc#1055900).
- drm/i915: Squelch reset messages during selftests (FATE#322643
  bsc#1055900).
- drm/i915/selftest: Refactor reset locking (FATE#322643
  bsc#1055900).
- drm/i915: Don't touch fence->error when resetting an innocent
  request (FATE#322643 bsc#1055900).
- drm/i915: Enforce that CS packets are qword aligned (FATE#322643
  bsc#1055900).
- drm/i915/glk: set HDMI 2.0 identifier (FATE#322643 bsc#1055900).
- drm/i915: set colorspace for YCBCR420 outputs (FATE#322643
  bsc#1055900).
- drm/i915: prepare csc unit for YCBCR420 output (FATE#322643
  bsc#1055900).
- drm/i915: prepare pipe for YCBCR420 output (FATE#322643
  bsc#1055900).
- drm/i915: prepare scaler for YCBCR420 modeset (FATE#322643
  bsc#1055900).
- drm/i915: add config function for YCBCR420 outputs (FATE#322643
  bsc#1055900).
- drm/i915: Gather all the power well->domain mappings to one
  place (FATE#322643 bsc#1055900).
- drm/i915: Move hsw_power_well_enable() next to the rest of
  HSW helpers (FATE#322643 bsc#1055900).
- drm/i915/gen9+: Unify the HSW/BDW and GEN9+ power well helpers
  (FATE#322643 bsc#1055900).
- drm/i915/hsw+: Add has_fuses power well attribute (FATE#322643
  bsc#1055900).
- drm/i915/hsw, bdw: Wait for the power well disabled state
  (FATE#322643 bsc#1055900).
- drm/i915/hsw, bdw: Add irq_pipe_mask, has_vga power well
  attributes (FATE#322643 bsc#1055900).
- drm/i915/hsw+: Unify the hsw/bdw and gen9+ power well req/state
  macros (FATE#322643 bsc#1055900).
- drm/i915/hsw, bdw: Split power well set to enable/disable
  helpers (FATE#322643 bsc#1055900).
- drm/i915/hsw, bdw: Remove redundant state check during power
  well toggling (FATE#322643 bsc#1055900).
- drm/i915/gen9+: Remove redundant state check during power well
  toggling (FATE#322643 bsc#1055900).
- drm/i915/gen9+: Remove redundant power well state assert during
  enabling (FATE#322643 bsc#1055900).
- drm/i915/bxt, glk: Give a proper name to the power well struct
  phy field (FATE#322643 bsc#1055900).
- drm/i915: Check for duplicated power well IDs (FATE#322643
  bsc#1055900).
- drm/i915/hsw, bdw: Add an ID for the global display power well
  (FATE#322643 bsc#1055900).
- drm/i915/gen2: Add an ID for the display pipes power well
  (FATE#322643 bsc#1055900).
- drm/i915: Assign everywhere the always-on power well ID
  (FATE#322643 bsc#1055900).
- drm/i915: Unify power well ID enums (FATE#322643 bsc#1055900).
- drm/i915/chv: Add unique power well ID for the pipe A power well
  (FATE#322643 bsc#1055900).
- drm/i915: Simplify scaler init during CRTC HW readout
  (FATE#322643 bsc#1055900).
- drm/i915/selftests: Exercise independence of per-engine resets
  (FATE#322643 bsc#1055900).
- drm/i915: Disable per-engine reset for Broxton (FATE#322643
  bsc#1055900).
- drm/i915: Emit a user level message when resetting the GPU
  (or engine) (FATE#322643 bsc#1055900).
- drm/i915: Make i915_gem_context_mark_guilty() safe for unlocked
  updates (FATE#322643 bsc#1055900).
- drm/i915: Clear engine irq posted following a reset (FATE#322643
  bsc#1055900).
- drm/i915: Assert that machine is wedged for nop_submit_request
  (FATE#322643 bsc#1055900).
- drm/i915: Wake up waiters after setting the WEDGED bit
  (FATE#322643 bsc#1055900).
- drm/i915: Move idle checks before
  intel_engine_init_global_seqno() (FATE#322643 bsc#1055900).
- drm/i915: Clear execlist port[] before updating seqno on wedging
  (FATE#322643 bsc#1055900).
- drm/i915: Check the execlist queue for pending requests before
  declaring idle (FATE#322643 bsc#1055900).
- drm/i915: Check execlist/ring status during hangcheck
  (FATE#322643 bsc#1055900).
- drm/i915: Flush the execlist ports if idle (FATE#322643
  bsc#1055900).
- drm/i915: Serialize per-engine resets against new requests
  (FATE#322643 bsc#1055900).
- drm/i915: Reset context image on engines after triggering the
  reset (FATE#322643 bsc#1055900).
- drm/i915: Report execlists irq bit in debugfs (FATE#322643
  bsc#1055900).
- Revert "drm/i915: Add heuristic to determine better way to
  adjust brightness" (FATE#322643 bsc#1055900).
- Revert "drm/i915: Add option to support dynamic backlight via
  DPCD" (FATE#322643 bsc#1055900).
- drm/i915: Drop unpin stall in atomic_prepare_commit (FATE#322643
  bsc#1055900).
- drm/i915: Remove intel_flip_work infrastructure (FATE#322643
  bsc#1055900).
- drm/i915: adjust has_pending_fb_unpin to atomic (FATE#322643
  bsc#1055900).
- drm/i915: Rip out legacy page_flip completion/irq handling
  (FATE#322643 bsc#1055900).
- drm/i915: s/INTEL_INFO(dev_priv)->gen/INTEL_GEN(dev_priv)
  in i915_irq (FATE#322643 bsc#1055900).
- drm/i915: Nuke legacy flip queueing code (FATE#322643
  bsc#1055900).
- drm/i915: Pass enum pipe to
  intel_set_pch_fifo_underrun_reporting() (FATE#322643
  bsc#1055900).
- drm/i915/selftests: Mark contexts as lost during freeing of
  mock device (FATE#322643 bsc#1055900).
- drm/i915: unregister interfaces first in unload (FATE#322643
  bsc#1055900).
- drm/i915: Fix fbdev unload sequence (FATE#322643 bsc#1055900).
- drm/atomic-helper: Fix leak in disable_all (FATE#322643
  bsc#1055900).
- drm/i915/selftests: Attach a stub pm_domain (FATE#322643
  bsc#1055900).
- drm/i915: Drain the device workqueue on unload (FATE#322643
  bsc#1055900).
- drm/i915: More stolen quirking (FATE#322643 bsc#1055900).
- drm/i915: Explicit the connector name for DP link training
  result (FATE#322643 bsc#1055900).
- commit d7aac3c
* Wed Feb 21 2018 tiwai@suse.de
- drm/i915: Consistently use enum pipe for PCH transcoders
  (FATE#322643 bsc#1055900).
- drm/i915: Fix error checking/locking in perf/lookup_context()
  (FATE#322643 bsc#1055900).
- drm: Handle properties in the core for atomic drivers
  (FATE#322643 bsc#1055900).
- drm: Don't update property values for atomic drivers
  (FATE#322643 bsc#1055900).
- drm/i915: Use the drm_driver.dumb_destroy default (FATE#322643
  bsc#1055900).
- drm/fb-helper: pass physical dimensions to fbdev (FATE#322643
  bsc#1055900).
- drm: i915: remove dead code and pointless local lut storage
  (FATE#322643 bsc#1055900).
- drm/fb-helper: add new drm_setup_crtcs_fb() function
  (FATE#322643 bsc#1055900).
- drm/fb: Fix pointer dereference before null check (FATE#322643
  bsc#1055900).
- drm: Create a format/modifier blob (FATE#322643 bsc#1055900).
- drm: Plumb modifiers through plane init (FATE#322643
  bsc#1055900).
- drm: Fix warning when building docs for scdc_helper (FATE#322643
  bsc#1055900).
- drm/modes: Fix drm_mode_is_420_only() comment (FATE#322643
  bsc#1055900).
- drm/dumb-buffers: Add defaults for .dumb_map_offset and
  .dumb_destroy (FATE#322643 bsc#1055900).
- drm/gem: Add drm_gem_dumb_map_offset() (FATE#322643
  bsc#1055900).
- drm/atomic: implement drm_atomic_helper_commit_tail for
  runtime_pm users (FATE#322643 bsc#1055900).
- drm: Improve kerneldoc for drm_modeset_lock (FATE#322643
  bsc#1055900).
- drm/fb-helper: Support deferred setup (FATE#322643 bsc#1055900).
- drm/i915: Update DRIVER_DATE to 20170717 (FATE#322643
  bsc#1055900).
- drm/i915: Protect against deferred fbdev setup (FATE#322643
  bsc#1055900).
- drm/i915/fbdev: Always forward hotplug events (FATE#322643
  bsc#1055900).
- drm/i915/skl+: unify cpp value in WM calculation (FATE#322643
  bsc#1055900).
- drm/i915/skl+: WM calculation don't require height (FATE#322643
  bsc#1055900).
- drm/i915: Addition wrapper for fixed16.16 operation (FATE#322643
  bsc#1055900).
- drm/i915: cleanup fixed-point wrappers naming (FATE#322643
  bsc#1055900).
- drm/i915: Always perform internal fixed16 division in 64 bits
  (FATE#322643 bsc#1055900).
- drm/i915: take-out common clamping code of fixed16 wrappers
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Add missing type case (FATE#322643 bsc#1055900).
- drm/i915/cnl: Add max allowed Cannonlake DC (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Get DDI clock based on PLLs (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Inherit RPS stuff from previous platforms
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Gen10 render context size (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Don't trust VBT's alternate pin for port D for
  now (FATE#322643 bsc#1055900).
- drm/i915: Fix the kernel panic when using aliasing ppgtt
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Cannonlake color init (FATE#322643 bsc#1055900).
- drm/i915/cnl: Add force wake for gen10+ (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Fix comment about AUX IO power well enable/disable
  (FATE#322643 bsc#1055900).
- drm/i915/gen9+: Don't remove secondary power well requests
  (FATE#322643 bsc#1055900).
- drm/i915/bxt, glk: Fix assert on conditions for DC9 enabling
  (FATE#322643 bsc#1055900).
- drm/i915/skl: Don't disable misc IO power well during display
  uninit (FATE#322643 bsc#1055900).
- drm/i915/gen9+: Add 10 us delay after power well 1/AUX IO pw
  disabling (FATE#322643 bsc#1055900).
- drm/i915: Only free the oldest stale context before allocating
  (FATE#322643 bsc#1055900).
- drm/i915: Drop request retirement before reaping stale contexts
  (FATE#322643 bsc#1055900).
- drm/i915: Move stale context reaping to common
  i915_gem_context_create (FATE#322643 bsc#1055900).
- drm/i915: Check new context against kernel_context after
  reporting an error (FATE#322643 bsc#1055900).
- drm/i915: Setting pch_id for HSW/BDW in virtual environment
  (FATE#322643 bsc#1055900).
- drm: i915: sysfs: constify attribute_group structures
  (FATE#322643 bsc#1055900).
- drm/i915/edp: Add a T12 panel delay quirk to fix DP AUX CH
  timeouts (FATE#322643 bsc#1055900).
- drm/i915/skl+: Scaling not supported in IF-ID Interlace mode
  (FATE#322643 bsc#1055900).
- drm/i915/skl+: Check for supported plane configuration in
  Interlace mode (FATE#322643 bsc#1055900).
- drm/i915: Fix use-after-free of context during free_contexts
  (FATE#322643 bsc#1055900).
- drm/i915: Prevent kernel panic when reading/writing compliance
  debugfs files, v2 (FATE#322643 bsc#1055900).
- drm/i915: Update DRIVER_DATE to 20170703 (FATE#322643
  bsc#1055900).
- drm/i915: Avoid keeping waitboost active for signaling threads
  (FATE#322643 bsc#1055900).
- drm/i915: Drop flushing of the object free list/worker from
  i915_gem_suspend (FATE#322643 bsc#1055900).
- drm/i915: Cancel pending execlists irq handler upon idling
  (FATE#322643 bsc#1055900).
- drm/i915/selftests: Fix mutex imbalance for
  igt_render_engine_reset_fallback (FATE#322643 bsc#1055900).
- drm/i915/dp: Remove -1/+1 from t11_t12 for Gen9_LP/CNP case
  (FATE#322643 bsc#1055900).
- drm/i915/dp: Fix the t11_t12 panel power cycle delay from VBT
  read (FATE#322643 bsc#1055900).
- drm/i915: Add option to support dynamic backlight via DPCD
  (FATE#322643 bsc#1055900).
- drm/i915: Add heuristic to determine better way to adjust
  brightness (FATE#322643 bsc#1055900).
- drm/i915: Set PWM divider to match desired frequency in vbt
  (FATE#322643 bsc#1055900).
- drm/i915: Always use 9 bits of the LPC bridge device ID for
  PCH detection (FATE#322643 bsc#1055900).
- drm/i915: Clean up some expressions (FATE#322643 bsc#1055900).
- drm/i915: Document that PPT==CPT and WPT==LPT (FATE#322643
  bsc#1055900).
- drm/i915: s/Couar/Cougar/ (FATE#322643 bsc#1055900).
- drm/i915: Use HAS_PCH_CPT() everywhere (FATE#322643
  bsc#1055900).
- drm/i915: pass the vma to insert_entries (FATE#322643
  bsc#1055900).
- drm/i915: Cancel pending execlist tasklet upon wedging
  (FATE#322643 bsc#1055900).
- drm/i915: Assert the vma's active tracking is clear before free
  (FATE#322643 bsc#1055900).
- drm/i915: select CRC32 (FATE#322643 bsc#1055900).
- drm/i915: Enable Engine reset and recovery support (FATE#322643
  bsc#1055900).
- drm/i915/selftests: reset engine self tests (FATE#322643
  bsc#1055900).
- drm/i915: Export per-engine reset count info to debugfs
  (FATE#322643 bsc#1055900).
- drm/i915: Add engine reset count to error state (FATE#322643
  bsc#1055900).
- drm/i915: Add support for per engine reset recovery (FATE#322643
  bsc#1055900).
- drm/i915: Modify error handler for per engine hang recovery
  (FATE#322643 bsc#1055900).
- drm/i915: Update i915.reset to handle engine resets (FATE#322643
  bsc#1055900).
- drm/i915: Look for active requests earlier in the reset path
  (FATE#322643 bsc#1055900).
- drm/i915: Wait for concurrent global resets to complete
  (FATE#322643 bsc#1055900).
- drm/i915: Enable rcu-only context lookups (FATE#322643
  bsc#1055900).
- drm/i915: Allow contexts to be unreferenced locklessly
  (FATE#322643 bsc#1055900).
- drm/i915: Group all the global context information together
  (FATE#322643 bsc#1055900).
- drm/i915: Do not re-calculate num_rings locally (FATE#322643
  bsc#1055900).
- drm/i915: Simplify intel_engines_init (FATE#322643 bsc#1055900).
- drm/i915: Make intel_digital_port_connected() work for any port
  (FATE#322643 bsc#1055900).
- drm/syncobj: Fix kerneldoc (FATE#322643 bsc#1055900).
- drm/atomic: Allow drm_atomic_helper_swap_state to fail
  (FATE#322643 bsc#1055900).
- drm/i915: Handle drm_atomic_helper_swap_state failure
  (FATE#322643 bsc#1055900).
- drm/atomic: Change drm_atomic_helper_swap_state to return an
  error (FATE#322643 bsc#1055900).
- drm: Update docs around gem_free_object (FATE#322643
  bsc#1055900).
- drm: Don't complain too much about struct_mutex (FATE#322643
  bsc#1055900).
- drm: add helper functions for YCBCR420 handling (FATE#322643
  bsc#1055900).
- drm/edid: parse ycbcr 420 deep color information (FATE#322643
  bsc#1055900).
- drm/edid: parse YCBCR420 videomodes from EDID (FATE#322643
  bsc#1055900).
- drm: add helper to validate YCBCR420 modes (FATE#322643
  bsc#1055900).
- drm/edid: cleanup patch for CEA extended-tag macro (FATE#322643
  bsc#1055900).
- drm/edid: parse sink information before CEA blocks (FATE#322643
  bsc#1055900).
- drm/edid: complete CEA modedb(VIC 1-107) (FATE#322643
  bsc#1055900).
- drm/fb-helper: separate the fb_setcmap helper into atomic and
  legacy paths (FATE#322643 bsc#1055900).
- commit 963a693
* Wed Feb 21 2018 tiwai@suse.de
- drm/atomic-helper: update lut props directly in
  ..._legacy_gamma_set (FATE#322643 bsc#1055900).
- drm: rename, adjust and export drm_atomic_replace_property_blob
  (FATE#322643 bsc#1055900).
- drm/dp/mst: Use memchr_inv() instead of memcmp() against a
  zeroed array (FATE#322643 bsc#1055900).
- drm/atomic: Make private objs proper objects (FATE#322643
  bsc#1055900).
- drm/atomic: Remove pointless private object NULL state check
  (FATE#322643 bsc#1055900).
- drm/i915: Use correct iterator macro (FATE#322643 bsc#1055900).
- drm/atomic: Use new iterator macros in
  drm_atomic_helper_wait_for_flip_done (FATE#322643 bsc#1055900).
- drm/atomic: Use the new helpers in
  drm_atomic_helper_disable_all() (FATE#322643 bsc#1055900).
- drm/atomic: Use the correct iterator macro in atomic_remove_fb
  (FATE#322643 bsc#1055900).
- drm: inhibit drm drivers register to uninitialized drm core
  (FATE#322643 bsc#1055900).
- drm/fb-helper: remove drm_fb_helper_save_lut_atomic (FATE#322643
  bsc#1055900).
- drm/fb-helper: keep the .gamma_store updated in
  drm_fb_helper_setcmap (FATE#322643 bsc#1055900).
- drm/fb-helper: factor out pseudo-palette (FATE#322643
  bsc#1055900).
- drm/fb-helper: Split dpms handling into legacy and atomic paths
  (FATE#322643 bsc#1055900).
- drm/fb-helper: Stop using mode_config.mutex for internals
  (FATE#322643 bsc#1055900).
- drm/fb-helper: Push locking into
  restore_fbdev_mode_atomic|legacy (FATE#322643 bsc#1055900).
- drm/fb-helper: Push locking into pan_display_atomic|legacy
  (FATE#322643 bsc#1055900).
- drm/fb-helper: Drop locking from the vsync wait ioctl code
  (FATE#322643 bsc#1055900).
- drm/fb-helper: Push locking in fb_is_bound (FATE#322643
  bsc#1055900).
- drm/fb-helper: Add top-level lock (FATE#322643 bsc#1055900).
- drm/i915: Drop FBDEV #ifdev in mst code (FATE#322643
  bsc#1055900).
- drm/fb-helper: Push down modeset lock into FB helpers
  (FATE#322643 bsc#1055900).
- drm: Remove pending_read_domains and pending_write_domain
  (FATE#322643 bsc#1055900).
- drm/fb-helper: Remove drm_mode_config_fb (FATE#322643
  bsc#1055900).
- drm/atomic: initial support for asynchronous plane update
  (FATE#322643 bsc#1055900).
- drm/core: Fail atomic IOCTL with no CRTC state but with
  signaling (FATE#322643 bsc#1055900).
- drm/atomic-helper: Simplify commit tracking locking (FATE#322643
  bsc#1055900).
- drm/i915: Drop drm_vblank_cleanup (FATE#322643 bsc#1055900).
- drm: Add drm_atomic_helper_wait_for_flip_done() (FATE#322643
  bsc#1055900).
- drm: Check for drm_device->dev in drm_set_busid (FATE#322643
  bsc#1055900).
- drm: Convert CMA fbdev console suspend helpers to use bool
  (FATE#322643 bsc#1055900).
- drm: More links for gamma support helpers (FATE#322643
  bsc#1055900).
- drm/doc: Improve ioctl/fops docs a bit more (FATE#322643
  bsc#1055900).
- drm/pci: Deprecate drm_pci_init/exit completely (FATE#322643
  bsc#1055900).
- drm: Remove drm_driver->set_busid hook (FATE#322643
  bsc#1055900).
- drm/vblank: Consistent drm_crtc_ prefix (FATE#322643
  bsc#1055900).
- drm/vblank: _ioctl posfix for ioctl handler (FATE#322643
  bsc#1055900).
- drm/doc: vblank cleanup (FATE#322643 bsc#1055900).
- drm/i915: Clear lost context-switch interrupts across reset
  (FATE#322643 bsc#1055900).
- drm/i915/bxt: use NULL for GPIO connection ID (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Fix LSPCON support (FATE#322643 bsc#1055900).
- drm/i915: Initialize 'data' in intel_dsi_dcs_backlight.c
  (FATE#322643 bsc#1055900).
- drm/i915: Avoid the gpu reset vs. modeset deadlock (FATE#322643
  bsc#1055900).
- drm/i915: Suppress switch_mm emission between the same
  aliasing_ppgtt (FATE#322643 bsc#1055900).
- drm/i915: Return correct EDP voltage swing table for 0.85V
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Add slice and subslice information to debugfs
  (FATE#322643 bsc#1055900).
- drm/i915: remove unused function declaration (FATE#322643
  bsc#1055900).
- drm/i915: fix backlight invert for non-zero minimum brightness
  (FATE#322643 bsc#1055900).
- drm/i915/shrinker: Wrap need_resched() inside preempt-disable
  (FATE#322643 bsc#1055900).
- drm/i915/perf: fix flex eu registers programming (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Change the max length of mmio_reg_rw from 4 to 8
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Initialize MMIO Block with HW state (FATE#322643
  bsc#1055900).
- drm/i915/gvt: clean workload queue if error happened
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: change resetting to resetting_eng (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Extend KBL platform support in GVT-g (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Fix the vblank timer close issue after shutdown
  VMs in reverse (FATE#322643 bsc#1055900).
- drm/i915: Fix bad comparison in skl_compute_plane_wm
  (FATE#322643 bsc#1055900).
- drm/i915: Force CPU synchronisation even if userspace requests
  ASYNC (FATE#322643 bsc#1055900).
- drm/i915: Only skip updating execobject.offset after error
  (FATE#322643 bsc#1055900).
- drm/i915: Only mark the execobject as pinned on success
  (FATE#322643 bsc#1055900).
- drm/i915: Remove assertion from raw __i915_vma_unpin()
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Fix loadgen select programming on ddi vswing
  sequence (FATE#322643 bsc#1055900).
- drm/i915/selftests: Fix an error handling path in
  'mock_gem_device()' (FATE#322643 bsc#1055900).
- drm/i915: Unbreak gpu reset vs. modeset locking (FATE#322643
  bsc#1055900).
- drm/i915: Fix cursor updates on some platforms (FATE#322643
  bsc#1055900).
- drm/i915: Fix user ptr check size in eb_relocate_vma()
  (FATE#322643 bsc#1055900).
- drm: vblank: Fix vblank timestamp update (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Use fence error from GVT request for workload
  status (FATE#322643 bsc#1055900).
- drm/i915/gvt: remove scheduler_mutex in per-engine
  workload_thread (FATE#322643 bsc#1055900).
- drm/i915/gvt: Revert "drm/i915/gvt: Fix possible recursive
  locking issue" (FATE#322643 bsc#1055900).
- drm/i915/gvt: Audit the command buffer address (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Fix a memory leak in intel_gvt_init_gtt()
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Fix the CURSOR_COEFF_MASK used in DDI Vswing
  Programming (FATE#322643 bsc#1055900).
- drm/i915/cfl: Fix Workarounds (FATE#322643 bsc#1055900).
- drm/i915: Avoid undefined behaviour of "u32 >> 32" (FATE#322643
  bsc#1055900).
- drm/i915: Fix an error checking test (FATE#322643 bsc#1055900).
- drm/i915/gvt: Make function dpy_reg_mmio_readx safe (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Don't read ADPA_CRT_HOTPLUG_MONITOR from host
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Set initial PORT_CLK_SEL vreg for BDW (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Fix possible recursive locking issue (FATE#322643
  bsc#1055900).
- drm: Remove unused drm_file parameter to
  drm_syncobj_replace_fence() (FATE#322643 bsc#1055900).
- drm/i915: Clear execbuf's vma backpointer upon release
  (FATE#322643 bsc#1055900).
- drm/i915: Pass the right flags to i915_vma_move_to_active()
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Fix RMW on ddi vswing sequence (FATE#322643
  bsc#1055900).
- drm/i915: Update DRIVER_DATE to 20170619 (FATE#322643
  bsc#1055900).
- drm/i915/cfl: Introduce Coffee Lake workarounds (FATE#322643
  bsc#1055900).
- drm/i915: Store 9 bits of PCI Device ID for platforms with a
  LP PCH (FATE#322643 bsc#1055900).
- drm/i915: Stash a pointer to the obj's resv in the vma
  (FATE#322643 bsc#1055900).
- drm/i915: Async GPU relocation processing (FATE#322643
  bsc#1055900).
- drm/i915: Allow execbuffer to use the first object as the batch
  (FATE#322643 bsc#1055900).
- drm/i915: Wait upon userptr get-user-pages within execbuffer
  (FATE#322643 bsc#1055900).
- drm/i915: First try the previous execbuffer location
  (FATE#322643 bsc#1055900).
- drm/i915: Store a persistent reference for an object in the
  execbuffer cache (FATE#322643 bsc#1055900).
- drm/i915: Eliminate lots of iterations over the execobjects
  array (FATE#322643 bsc#1055900).
- drm/i915: Disable EXEC_OBJECT_ASYNC when doing relocations
  (FATE#322643 bsc#1055900).
- drm/i915: Pass vma to relocate entry (FATE#322643 bsc#1055900).
- drm/i915: Store a direct lookup from object handle to vma
  (FATE#322643 bsc#1055900).
- drm/i915: Fix retrieval of hangcheck stats (FATE#322643
  bsc#1055900).
- drm/i915: Store i915_gem_object_is_coherent() as a bit next
  to cache-dirty (FATE#322643 bsc#1055900).
- drm/i915: Mark CPU cache as dirty on every transition for CPU
  writes (FATE#322643 bsc#1055900).
- commit b736327
* Wed Feb 21 2018 tiwai@suse.de
- drm/i915: Make i915_vma_destroy() static (FATE#322643
  bsc#1055900).
- drm/i915: Actually attach the tv_format property to the SDVO
  connector (FATE#322643 bsc#1055900).
- drm/i915/gvt: Refine virtual reset function (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Fix GDRST vreg state after reset (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Tuning the size of MMIO hash lookup table to 2048
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Add helper for tuning MMIO hash table (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Make the MMIO attribute wrappers be inline
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Make mmio_attribute as type u8 to save 1.5MB
  memory (FATE#322643 bsc#1055900).
- drm/i915/gvt: Cleanup struct intel_gvt_mmio_info (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Optimize MMIO register handling for some large
  MMIO blocks (FATE#322643 bsc#1055900).
- drm/i915/gvt: add gtt_invalidate API to flush the GTT TLB
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Add runtime_pm get/put to proctect MMIO accessing
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: remove redundant -Wall (FATE#322643 bsc#1055900).
- drm/i915/gvt: Legacy HSW related MMIO handler clean up
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Trigger scheduling after context complete
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Support event based scheduling (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Delete gvt_dbg_cmd() in cmd_parser_exec()
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Change flood gvt dmesg into trace (FATE#322643
  bsc#1055900).
- drm/i915/gvt: clean up the unused last_ctx_submit_time of
  struct intel_vgpu (FATE#322643 bsc#1055900).
- drm/i915/gvt: add RING_INSTDONE and SC_INSTDONE mmio handler
  in GVT-g (FATE#322643 bsc#1055900).
- drm/i915/gvt: implement per-vm mmio switching optimization
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: refactor function intel_vgpu_submit_execlist
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: rewrite the trace gvt:gvt_command using trace
  style approach (FATE#322643 bsc#1055900).
- Revert "drm/i915/skl: New ddb allocation algorithm" (FATE#322643
  bsc#1055900).
- drm/i915/glk: Add cold boot sequence for GLK DSI (FATE#322643
  bsc#1055900).
- drm/i915/glk: Split GLK DSI device ready functionality
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: make function cnl_ddi_dp_set_dpll_hw_state static
  (FATE#322643 bsc#1055900).
- drm/i915: Remove pipe A quirk remnants (FATE#322643
  bsc#1055900).
- drm/i915: Drop pipe A quirk for Thinkapd T60 (FATE#322643
  bsc#1055900).
- drm/i915: Drop pipe A quirk for Toshiba Protege R205-S209
  (FATE#322643 bsc#1055900).
- drm/i915: Add i830 "pipes power well" (FATE#322643 bsc#1055900).
- drm/i915: Use a loop for the "three times for luck" DPLL
  procedure (FATE#322643 bsc#1055900).
- drm/i915: Split vma exec_link/evict_link (FATE#322643
  bsc#1055900).
- drm/i915: Use vma->exec_entry as our double-entry placeholder
  (FATE#322643 bsc#1055900).
- drm/i915: Amalgamate execbuffer parameter structures
  (FATE#322643 bsc#1055900).
- drm/i915/perf: add GLK support (FATE#322643 bsc#1055900).
- drm/i915/perf: add KBL support (FATE#322643 bsc#1055900).
- drm/i915: add KBL GT2/GT3 check macros (FATE#322643
  bsc#1055900).
- drm/i915/perf: remove perf.hook_lock (FATE#322643 bsc#1055900).
- drm/i915/perf: per-gen timebase for checking sample freq
  (FATE#322643 bsc#1055900).
- drm/i915/perf: Add more OA configs for BDW, CHV, SKL + BXT
  (FATE#322643 bsc#1055900).
- drm/i915/perf: Add OA unit support for Gen 8+ (FATE#322643
  bsc#1055900).
- drm/i915/perf: Add 'render basic' Gen8+ OA unit configs
  (FATE#322643 bsc#1055900).
- drm/i915/perf: rework mux configurations queries (FATE#322643
  bsc#1055900).
- drm/i915: expose _SUBSLICE_MASK GETPARM (FATE#322643
  bsc#1055900).
- drm/i915: expose _SLICE_MASK GETPARM (FATE#322643 bsc#1055900).
- drm/i915: Reinstate reservation_object zapping for batch_pool
  objects (FATE#322643 bsc#1055900).
- drm/i915: Spin for struct_mutex inside shrinker (FATE#322643
  bsc#1055900).
- drm/i915: Only restrict noreclaim in the early shrink passes
  (FATE#322643 bsc#1055900).
- drm/i915/cfl: Basic DDI plumbing for Coffee Lake (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Enable wrpll computation for CNL (FATE#322643
  bsc#1055900).
- drm/i915/cnl: LSPCON support is gen9+ (FATE#322643 bsc#1055900).
- drm/i915/cnl: Enable fifo underrun for Cannonlake (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Fix Cannonlake scaler mode programing (FATE#322643
  bsc#1055900).
- drm/i915: Use HAS_CSR instead of gen number on DMC load
  (FATE#322643 bsc#1055900).
- drm/i915/DMC/CNL: Load DMC on CNL (FATE#322643 bsc#1055900).
- drm/i915/cnl: Enable loadgen_select bit for vswing sequence
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Implement voltage swing sequence (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Add DDI Buffer translation tables for Cannonlake
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Add registers related to voltage swing sequences
  (FATE#322643 bsc#1055900).
- drm/i915: Add MMIO helper for 6 ports with different offsets
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Initialize PLLs (FATE#322643 bsc#1055900).
- drm/i915: Configure DPLL's for Cannonlake (FATE#322643
  bsc#1055900).
- drm/i915/cnl: DDI - PLL mapping (FATE#322643 bsc#1055900).
- drm/i915/cnl: Allow dynamic cdclk changes on CNL (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Implement CNL display init/unit sequence
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Implement .set_cdclk() for CNL (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Implement .get_display_clock_speed() for CNL
  (FATE#322643 bsc#1055900).
- drm/i915: Pass atomic state to backlight enable/disable/set
  callbacks (FATE#322643 bsc#1055900).
- drm/i915: Pass connector state to intel_panel_set_backlight_acpi
  (FATE#322643 bsc#1055900).
- drm/i915: Pass crtc_state and connector state to backlight
  enable/disable functions (FATE#322643 bsc#1055900).
- drm/i915/cfl: Coffee Lake reuses Kabylake DMC (FATE#322643
  bsc#1055900).
- drm/i915/huc: Load HuC on Coffee Lake (FATE#322643 bsc#1055900).
- drm/i915/guc: Load GuC on Coffee Lake (FATE#322643 bsc#1055900).
- drm/i915/cfl: Add Coffee Lake PCI IDs for U Sku (FATE#322643
  bsc#1055900).
- drm/i915/cfl: Add Coffee Lake PCI IDs for H Sku (FATE#322643
  bsc#1055900).
- drm/i915/cfl: Add Coffee Lake PCI IDs for S Skus (FATE#322643
  bsc#1055900).
- drm/i915/glk: Remove the alpha_support flag (FATE#322643
  bsc#1055900).
- drm/i915/cfl: Introduce Display workarounds for Coffee Lake
  (FATE#322643 bsc#1055900).
- drm/i915/cfl: Coffee Lake uses CNP PCH (FATE#322643
  bsc#1055900).
- drm/i915/cfl: Introduce Coffee Lake platform definition
  (FATE#322643 bsc#1055900).
- drm/i915: Remove the spin-request during execbuf await_request
  (FATE#322643 bsc#1055900).
- drm/i915: Skip adding the request to the signal tree is complete
  (FATE#322643 bsc#1055900).
- drm/i915: Report back whether the irq was armed when adding
  the waiter (FATE#322643 bsc#1055900).
- drm/i915: Check signaled state after enabling signaling
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Clear enable_guc_loading in case of init failure
  (FATE#322643 bsc#1055900).
- drm/i915: Move the unclaimed mmio detection into the powerwell
  for KMS (FATE#322643 bsc#1055900).
- drm/i915: Unify GT* and GT3 definitions (FATE#322643
  bsc#1055900).
- drm/i915: Remove unnecessary PORT3 definition (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Also need power well sanitize (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Add power wells for CNL (FATE#322643 bsc#1055900).
- drm/i915/gen10: Set value of Indirect Context Offset for gen10
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Cannonlake has same MOCS table than Skylake
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Configure EU slice power gating (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Cannonlake has 4 planes (3 sprites) per pipe
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: add IS_CNL_REVID macro (FATE#322643 bsc#1055900).
- drm/i915/cnl: Add Cannonlake PCI IDs for Y-skus (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Add Cannonlake PCI IDs for U-skus (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Cannonlake uses CNP PCH (FATE#322643 bsc#1055900).
- drm/i915/cnl: Introduce Cannonlake platform defition
  (FATE#322643 bsc#1055900).
- commit 35f6167
* Wed Feb 21 2018 tiwai@suse.de
- drm/i915: s/fbc_fc/fbc_false_color/ (FATE#322643 bsc#1055900).
- drm/i915: Implement fbc_status "Compressing" info for all
  platforms (FATE#322643 bsc#1055900).
- drm/i915: Remove dead code from runtime resume handler
  (FATE#322643 bsc#1055900).
- drm/i915/cnp: Panel Power sequence changes for CNP PCH
  (FATE#322643 bsc#1055900).
- drm/i915/cnp: add CNP gmbus support (FATE#322643 bsc#1055900).
- drm/i915/cnp: Backlight support for CNP (FATE#322643
  bsc#1055900).
- drm/i915/cnp: Get/set proper Raw clock frequency on CNP
  (FATE#322643 bsc#1055900).
- drm/i915/cnp: Add PCI ID for Cannonpoint LP PCH (FATE#322643
  bsc#1055900).
- drm/i915/cnp: Introduce Cannonpoint PCH (FATE#322643
  bsc#1055900).
- drm/i915: Allow kswapd to pause the device whilst reaping
  (FATE#322643 bsc#1055900).
- drm/i915: return the correct usable aperture size under gvt
  environment (FATE#322643 bsc#1055900).
- drm/i915: Check the ring is empty when declaring the engines
  are idle (FATE#322643 bsc#1055900).
- drm/i915/guc: Assert that we switch between known
  ggtt->invalidate functions (FATE#322643 bsc#1055900).
- drm/i915/dvo: fix debug logging on unknown DID (FATE#322643
  bsc#1055900).
- drm/i915/ddi: Avoid long delays during system suspend / eDP
  disabling (FATE#322643 bsc#1055900).
- drm/i915/glk: Fix dotclock calculation in
  skl_check_pipe_max_pixel_rate (FATE#322643 bsc#1055900).
- drm/i915/skl+: consider max supported plane pixel rate while
  scaling (FATE#322643 bsc#1055900).
- drm/i915/skl: New ddb allocation algorithm (FATE#322643
  bsc#1055900).
- drm/i915/guc: Fix doorbell id selection (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Return -EIO if host GuC submission is enabled
  when loading GVT-g (FATE#322643 bsc#1055900).
- drm/i915/gvt: Return -EIO if host enable_execlists not enabled
  when loading GVT-g (FATE#322643 bsc#1055900).
- drm/i915/gvt: Add gvt options sanitize function (FATE#322643
  bsc#1055900).
- drm/i915: Remove toplevel struct_mutex locking from
  debugfs/i915_drop_caches (FATE#322643 bsc#1055900).
- drm/i915: Add kerneldoc to describe i915_gem_object.vma_list
  (FATE#322643 bsc#1055900).
- drm/i915: Convert intel_sdvo connector properties to atomic
  (FATE#322643 bsc#1055900).
- drm/i915: Handle force_audio correctly in intel_sdvo
  (FATE#322643 bsc#1055900).
- drm/i915: Convert intel_hdmi connector properties to atomic
  (FATE#322643 bsc#1055900).
- drm/i915: Convert intel_dp properties to atomic, v2 (FATE#322643
  bsc#1055900).
- drm/i915: Make intel_dp->has_audio reflect hw state only
  (FATE#322643 bsc#1055900).
- drm/i915: Convert LVDS connector properties to atomic
  (FATE#322643 bsc#1055900).
- drm/i915: Convert DSI connector properties to atomic
  (FATE#322643 bsc#1055900).
- drm/i915: Add plumbing for digital connector state, v3
  (FATE#322643 bsc#1055900).
- drm/i915: Use per-connector scaling mode property (FATE#322643
  bsc#1055900).
- drm/i915: Use atomic scaling_mode instead of panel.fitting_mode
  (FATE#322643 bsc#1055900).
- drm/i915: Remove decoupled MMIO code (FATE#322643 bsc#1055900).
- drm: Reduce scope of 'state' variable (FATE#322643 bsc#1055900).
- drm: Remove duplicate forward declaration (FATE#322643
  bsc#1055900).
- drm: Add const to name field declaration in struct
  drm_prop_enum_list (FATE#322643 bsc#1055900).
- drm/syncobj: add sync_file interaction. (v1.2) (FATE#322643
  bsc#1055900).
- drm: introduce sync objects (v4) (FATE#322643 bsc#1055900).
- drm: remove writeq/readq function definitions (FATE#322643
  bsc#1055900).
- drm/doc: Polish irq helper documentation (FATE#322643
  bsc#1055900).
- drm: Extract drm_vblank.[hc] (FATE#322643 bsc#1055900).
- drm/atomic: Consitfy mode parameter to
  drm_atomic_set_mode_for_crtc() (FATE#322643 bsc#1055900).
- drm: better document how to send out the crtc disable event
  (FATE#322643 bsc#1055900).
- drm: Use vsnprintf extension %%ph (FATE#322643 bsc#1055900).
- drm/doc: move printf helpers out of drmP.h (FATE#322643
  bsc#1055900).
- drm: Use mode_valid() in atomic modeset (FATE#322643
  bsc#1055900).
- drm: Use new mode_valid() helpers in connector probe helper
  (FATE#322643 bsc#1055900).
- drm: Introduce drm_bridge_mode_valid() (FATE#322643
  bsc#1055900).
- drm: Add drm_{crtc/encoder/connector}_mode_valid() (FATE#322643
  bsc#1055900).
- drm: Remove drm_device->virtdev (FATE#322643 bsc#1055900).
- drm/i915: use drm_for_each_connector_iter() (FATE#322643
  bsc#1055900).
- drm/i915: Update DRIVER_DATE to 20170529 (FATE#322643
  bsc#1055900).
- drm/i915: Keep the forcewake timer alive for 1ms past the most
  recent use (FATE#322643 bsc#1055900).
- drm/i915/guc: capture GuC logs if FW fails to load (FATE#322643
  bsc#1055900).
- drm/i915/guc: Introduce buffer based cmd transport (FATE#322643
  bsc#1055900).
- drm/i915/guc: Disable send function on fini (FATE#322643
  bsc#1055900).
- drm: Add definition for eDP backlight frequency (FATE#322643
  bsc#1055900).
- drm/i915: Drop AUX backlight enable check for backlight control
  (FATE#322643 bsc#1055900).
- drm/i915: Consolidate #ifdef CONFIG_INTEL_IOMMU (FATE#322643
  bsc#1055900).
- drm/i915: Only GGTT vma may be pinned and prevent shrinking
  (FATE#322643 bsc#1055900).
- drm/i915: Convert i915_gem_object_ops->flags values to use BIT()
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Skip port assign on first iteration of GuC dequeue
  (FATE#322643 bsc#1055900).
- drm/i915: Remove misleading comment in request_alloc
  (FATE#322643 bsc#1055900).
- drm/i915/g33: Improve reset reliability (FATE#322643
  bsc#1055900).
- drm/i915/huc: Update GLK HuC version (FATE#322643 bsc#1055900).
- drm/i915: Check for allocation failure (FATE#322643
  bsc#1055900).
- drm/i915/guc: Remove action status and statistics from debugfs
  (FATE#322643 bsc#1055900).
- drm/i915/g4x: Improve gpu reset reliability (FATE#322643
  bsc#1055900).
- drm/i915/guc: Remove last submission result from debugfs
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Remove failed doorbell stat from debugfs
  (FATE#322643 bsc#1055900).
- drm/i915: Reorder media/render reset on g4x (FATE#322643
  bsc#1055900).
- drm/i915: Try harder to reset the GPU (FATE#322643 bsc#1055900).
- drm/i915/selftests: Pretend to be a gfx pci device (FATE#322643
  bsc#1055900).
- drm/i915: Check C for null pointer rather than B (FATE#322643
  bsc#1055900).
- drm/i915/skl+: use linetime latency if ddb size is not available
  (FATE#322643 bsc#1055900).
- drm/i915/skl+: Perform wm level calculations in separate
  function (FATE#322643 bsc#1055900).
- drm/i915/skl+: Watermark calculation cleanup (FATE#322643
  bsc#1055900).
- drm/i915/skl+: Fail the flip if ddb min requirement exceeds
  pipe allocation (FATE#322643 bsc#1055900).
- drm/i915/skl+: no need to memset again (FATE#322643
  bsc#1055900).
- drm/i915/skl: Fail the flip if no FB for WM calculation
  (FATE#322643 bsc#1055900).
- drm/i915/skl+: calculate pixel_rate & relative_data_rate in
  fixed point (FATE#322643 bsc#1055900).
- drm/i915: Use fixed_16_16 wrapper for division operation
  (FATE#322643 bsc#1055900).
- drm/i915: Add more wrapper for fixed_point_16_16 operations
  (FATE#322643 bsc#1055900).
- drm/i915: fix naming of fixed_16_16 wrapper (FATE#322643
  bsc#1055900).
- drm/i915: Don't force serialisation on marking up execlists
  irq posted (FATE#322643 bsc#1055900).
- drm/i915: Stop inlining the execlists IRQ handler (FATE#322643
  bsc#1055900).
- drm/i915/execlists: Reduce lock contention between
  schedule/submit_request (FATE#322643 bsc#1055900).
- drm/i915: Create a kmem_cache to allocate struct i915_priolist
  from (FATE#322643 bsc#1055900).
- drm/i915: Split execlist priority queue into rbtree + linked
  list (FATE#322643 bsc#1055900).
- drm/i915: Use a define for the default priority [0] (FATE#322643
  bsc#1055900).
- drm/i915: Don't mark an execlists context-switch when idle
  (FATE#322643 bsc#1055900).
- drm/i915/execlists: Pack the count into the low bits of the
  port.request (FATE#322643 bsc#1055900).
- drm/i915: Redefine ptr_pack_bits() and friends (FATE#322643
  bsc#1055900).
- drm/i915: Make ptr_unpack_bits() more function-like (FATE#322643
  bsc#1055900).
- drm/i915: Import the kfence selftests for i915_sw_fence
  (FATE#322643 bsc#1055900).
- drm/i915: Remove kref from i915_sw_fence (FATE#322643
  bsc#1055900).
- drm/i915/gen9: Reintroduce WaEnableYV12BugFixInHalfSliceChicken7
  (FATE#322643 bsc#1055900).
- gpu: drm: i915: compress logic into one line (FATE#322643
  bsc#1055900).
- commit 8d45858
* Wed Feb 21 2018 tiwai@suse.de
- gpu: drm: i915: remove dead code (FATE#322643 bsc#1055900).
- drm/i915/guc:fix spelling mistake: "adddress" -> "address"
  (FATE#322643 bsc#1055900).
- drm/i915/glk: Calculate high/low switch count for GLK
  (FATE#322643 bsc#1055900).
- drm/i915: Fixup 64bit divides in timelines selftest (FATE#322643
  bsc#1055900).
- drm/i915: Update DRIVER_DATE to 20170515 (FATE#322643
  bsc#1055900).
- drm/i915/perf: rate limit spurious oa report notice (FATE#322643
  bsc#1055900).
- drm/i915/perf: better pipeline aged/aging tail updates
  (FATE#322643 bsc#1055900).
- drm/i915/perf: improve invalid OA format debug message
  (FATE#322643 bsc#1055900).
- drm/i915/perf: improve tail race workaround (FATE#322643
  bsc#1055900).
- drm/i915/perf: no head/tail ref in gen7_oa_read (FATE#322643
  bsc#1055900).
- drm/i915/perf: avoid read back of head register (FATE#322643
  bsc#1055900).
- drm/i915/perf: avoid poll, read, EAGAIN busy loops (FATE#322643
  bsc#1055900).
- drm/i915/perf: fix gen7_append_oa_reports comment (FATE#322643
  bsc#1055900).
- drm/i915: Restore brightness level in aux backlight driver
  (FATE#322643 bsc#1055900).
- drm/i915: Set backlight mode before enable backlight
  (FATE#322643 bsc#1055900).
- drm/i915: Correctly enable backlight brightness adjustment
  via DPCD (FATE#322643 bsc#1055900).
- drm/i915: Fix cap check for intel_dp_aux_backlight driver
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Make scratch register base and count flexible
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Move notification code into virtual function
  (FATE#322643 bsc#1055900).
- drm/i915: Remove vma unpin in intel_plane_destroy (FATE#322643
  bsc#1055900).
- drm/i915: Fix hw state verifier access to crtc->state
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Dump the GuC stage descriptor pool in debugfs
  (FATE#322643 bsc#1055900).
- drm/i915: Fix __intel_wait_for_register_fw to not sleep in
  atomic (FATE#322643 bsc#1055900).
- drm/i915: Simplify cursor register write sequence (FATE#322643
  bsc#1055900).
- drm/i915: Relax 845/865 CURBASE alignemnt requirement to 32
  bytes (FATE#322643 bsc#1055900).
- drm/i915: Handle fb offset and src coordinates for cursors
  (FATE#322643 bsc#1055900).
- drm/i915: Fix gen3 physical cursor alignment requirements
  (FATE#322643 bsc#1055900).
- drm/i915: Support variable cursor height on ivb+ (FATE#322643
  bsc#1055900).
- drm/i915: Use fb->pitches[0] in cursor code (FATE#322643
  bsc#1055900).
- drm/i915: Generalize cursor size checks a bit (FATE#322643
  bsc#1055900).
- drm/i915: Split cursor check_plane into i845 and i9xx variants
  (FATE#322643 bsc#1055900).
- drm/i915: Drop useless posting reads from cursor commit
  (FATE#322643 bsc#1055900).
- drm/i915: Move cursor position and base handling into the
  platform specific functions (FATE#322643 bsc#1055900).
- drm/i915: Refactor CURPOS calculation (FATE#322643 bsc#1055900).
- drm/i915: Clean up cursor junk from intel_crtc (FATE#322643
  bsc#1055900).
- drm/i915: Refactor CURBASE calculation (FATE#322643
  bsc#1055900).
- drm/i915: Pass intel_plane and intel_crtc to plane hooks
  (FATE#322643 bsc#1055900).
- drm/i915: Parametrize cursor/primary pipe select bits
  (FATE#322643 bsc#1055900).
- drm/i915: Add support for sprites on g4x (FATE#322643
  bsc#1055900).
- drm/i915: Add g4x watermark tracepoint (FATE#322643
  bsc#1055900).
- drm/i915: Enable HPLL watermarks on g4x (FATE#322643
  bsc#1055900).
- drm/i915: Two stage watermarks for g4x (FATE#322643
  bsc#1055900).
- drm/i915: Apply the g4x TLB miss w/a to SR watermarks as well
  (FATE#322643 bsc#1055900).
- drm/i915: Refactor wm calculations (FATE#322643 bsc#1055900).
- drm/i915: Refactor the g4x TLB miss w/a to a helper (FATE#322643
  bsc#1055900).
- drm/i915: Fix the g4x watermark TLB miss workaround (FATE#322643
  bsc#1055900).
- drm/i915: Fix cursor 'cpp' in watermark calculatins for old
  platforms (FATE#322643 bsc#1055900).
- drm/i915: Document CxSR (FATE#322643 bsc#1055900).
- drm/i915: Make vlv/chv watermark debug print less cryptic
  (FATE#322643 bsc#1055900).
- drm/i915: Rename bunch of vlv_ watermark structures to g4x_
  (FATE#322643 bsc#1055900).
- drm/i915: s/vlv_num_wm_levels/intel_wm_num_levels/ (FATE#322643
  bsc#1055900).
- drm/i915: Drop the debug message from vlv_get_fifo_size()
  (FATE#322643 bsc#1055900).
- drm/i915: s/vlv_plane_wm_compute/vlv_raw_plane_wm_compute/
  etc (FATE#322643 bsc#1055900).
- drm/i915/lvds: Remove magic from PLL programming (FATE#322643
  bsc#1055900).
- drm/i915: Sanitize stolen memory size calculation (FATE#322643
  bsc#1055900).
- drm/i915: Check error return when converting pipe to connector
  (FATE#322643 bsc#1055900).
- drm/i915: Check error return when setting DMA mask (FATE#322643
  bsc#1055900).
- drm/i915/sdvo: Check error return from intel_sdvo_get_value()
  (FATE#322643 bsc#1055900).
- drm/i915/dp: Check error return during DPCD capability queries
  (FATE#322643 bsc#1055900).
- drm/i915/vlv: Fix port B PLL opamp initialization (FATE#322643
  bsc#1055900).
- drm/i915: Show dmc debug registers on Kabylake (FATE#322643
  bsc#1055900).
- drm/i915: Move uncore definitions into a separate header
  (FATE#322643 bsc#1055900).
- drm/i915: use memdup_user_nul (FATE#322643 bsc#1055900).
- drm/i915: Micro-optimise hotpath through intel_ring_begin()
  (FATE#322643 bsc#1055900).
- drm/i915: Report the ring->space from intel_ring_update_space()
  (FATE#322643 bsc#1055900).
- drm/i915: Avoid the branch in computing intel_ring_space()
  (FATE#322643 bsc#1055900).
- drm/i915: Use engine->context_pin() to report the intel_ring
  (FATE#322643 bsc#1055900).
- drm/i915: Implement dma_buf_ops->kmap (FATE#322643 bsc#1055900).
- drm/i915: Clean up the LPE audio platform data (FATE#322643
  bsc#1055900).
- drm/i915: Reorganize intel_lpe_audio_notify() arguments
  (FATE#322643 bsc#1055900).
- drm/i915: Remove hdmi_connected from LPE audio pdata
  (FATE#322643 bsc#1055900).
- drm/i915: Replace tmds_clock_speed and link_rate with just
  ls_clock (FATE#322643 bsc#1055900).
- drm/i915: Remove the unused pending_notify from LPE platform
  data (FATE#322643 bsc#1055900).
- drm/i915: Switch the global i915.semaphores check to a local
  predicate (FATE#322643 bsc#1055900).
- drm/i915: Do not record a successful syncpoint for a dma-await
  (FATE#322643 bsc#1055900).
- drm/i915: Rename intel_timeline.sync_seqno[] to .global_sync[]
  (FATE#322643 bsc#1055900).
- drm/i915: Squash repeated awaits on the same fence (FATE#322643
  bsc#1055900).
- drm/i915: Lift timeline ordering to await_dma_fence (FATE#322643
  bsc#1055900).
- drm/i915: Unwrap top level fence-array (FATE#322643
  bsc#1055900).
- drm/i915: Mark up clflushes as belonging to an unordered
  timeline (FATE#322643 bsc#1055900).
- drm/i915: Use wait_for_atomic_us when waiting for gt fifo
  (FATE#322643 bsc#1055900).
- drm/i915: Move the GTFIFODBG to the common mmio dbg framework
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Enable send function only after successful init
  (FATE#322643 bsc#1055900).
- drm/i915: Do not leak dev_priv->l3_parity.remap_info[]
  (FATE#322643 bsc#1055900).
- drm/i915: Update DRIVER_DATE to 20170502 (FATE#322643
  bsc#1055900).
- drm/i915: Capture CCID on ILK (FATE#322643 bsc#1055900).
- drm/i915: Reset ILK during GEM sanitization (FATE#322643
  bsc#1055900).
- drm/i915: Eliminate HAS_HW_CONTEXTS (FATE#322643 bsc#1055900).
- drm/i915: Sanitize engine context sizes (FATE#322643
  bsc#1055900).
- drm/i915/guc: Fix sleep under spinlock during reset (FATE#322643
  bsc#1055900).
- drm/i915: Defer context state allocation for legacy ring
  submission (FATE#322643 bsc#1055900).
- drm/i915: Rename gen8_(un)request_engine_reset to
  gen8_reset_engine_start/cancel (FATE#322643 bsc#1055900).
- drm/i915: Fix stale comment about I915_RESET_IN_PROGRESS flag
  (FATE#322643 bsc#1055900).
- drm/i915/glk: Don't allow 12 bpc when htotal is too big
  (FATE#322643 bsc#1055900).
- drm/i915: Skip waking the signaler when enabling before request
  submission (FATE#322643 bsc#1055900).
- drm/i915: Poison the request before emitting commands
  (FATE#322643 bsc#1055900).
- drm/i915: Report request restarts for both execlists/guc
  (FATE#322643 bsc#1055900).
- drm/i915: Include interesting seqno in the missed breadcrumb
  debug (FATE#322643 bsc#1055900).
- drm/i915: Avoid format string expansion from engine names
  (FATE#322643 bsc#1055900).
- drm/i915: Fix GCC 4.4 build issue with
  __intel_wait_for_register_fw (FATE#322643 bsc#1055900).
- commit 60934e6
* Wed Feb 21 2018 tiwai@suse.de
- drm/i915: Update DRIVER_DATE to 20170418 (FATE#322643
  bsc#1055900).
- drm/i915: Copy user requested buffers into the error state
  (FATE#322643 bsc#1055900).
- drm/i915: set "ret" correctly on error paths (FATE#322643
  bsc#1055900).
- drm/i915: Implement Link Rate fallback on Link training failure
  (FATE#322643 bsc#1055900).
- drm/i915/guc: write wopcm related register once during uc init
  (FATE#322643 bsc#1055900).
- drm/i915/dp: Validate cached link rate and lane count before
  retraining (FATE#322643 bsc#1055900).
- drm/i915: Wake device for emitting request during selftest
  (FATE#322643 bsc#1055900).
- drm/i915: Pretend the engine is always idle when mocking
  (FATE#322643 bsc#1055900).
- drm/i915: Add stub mmio read/write routines to mock device
  (FATE#322643 bsc#1055900).
- drm/i915: Treat WC a separate cache domain (FATE#322643
  bsc#1055900).
- drm/i915: Combine write_domain flushes to a single function
  (FATE#322643 bsc#1055900).
- drm/i915: Do not use lock all in hsw_trans_edp_pipe_A_crc_wa
  (FATE#322643 bsc#1055900).
- Revert "drm/i915: Lock mode_config.mutex in
  intel_display_resume." (FATE#322643 bsc#1055900).
- drm/i915: Convert intel DVO connector to atomic (FATE#322643
  bsc#1055900).
- drm/i915: Convert intel_crt connector properties to atomic
  (FATE#322643 bsc#1055900).
- drm/i915: Convert intel_dp_mst connector properties to atomic
  (FATE#322643 bsc#1055900).
- drm/i915: Remove unused dp properties for dp-mst (FATE#322643
  bsc#1055900).
- drm/i915: Convert intel_tv connector properties to atomic, v5
  (FATE#322643 bsc#1055900).
- drm/i915: Remove unused members from intel_tv.c (FATE#322643
  bsc#1055900).
- drm/i915/execlists: Document runtime pm for
  intel_lrc_irq_handler() (FATE#322643 bsc#1055900).
- drm/i915: Lie and treat all engines as idle if wedged
  (FATE#322643 bsc#1055900).
- drm/i915: Use the engine class to get the context size
  (FATE#322643 bsc#1055900).
- drm/i915: Bail if we do not setup the RCS engine (FATE#322643
  bsc#1055900).
- drm/i915/dp: read sink count to a temporary variable first
  (FATE#322643 bsc#1055900).
- drm/i915/dp: use readb and writeb calls for single byte DPCD
  access (FATE#322643 bsc#1055900).
- drm/i915/dp: localize link rate index variable more (FATE#322643
  bsc#1055900).
- drm/i915/mst: use max link not sink lane count (FATE#322643
  bsc#1055900).
- drm/i915/dp: add functions for max common link rate and lane
  count (FATE#322643 bsc#1055900).
- drm/i915/dp: don't call the link parameters sink parameters
  (FATE#322643 bsc#1055900).
- drm/i915/dp: do not limit rate seek when not needed (FATE#322643
  bsc#1055900).
- drm/i915/dp: cache common rates with sink rates (FATE#322643
  bsc#1055900).
- drm/i915/dp: use the sink rates array for max sink rates
  (FATE#322643 bsc#1055900).
- drm/i915: Rename intel_engine_cs.exec_id to uabi_id (FATE#322643
  bsc#1055900).
- drm/i915: Split the engine info table in two levels, using
  class + instance (FATE#322643 bsc#1055900).
- drm/i915: Generate the engine name based on the instance number
  (FATE#322643 bsc#1055900).
- drm/i915: Use the same vfunc for BSD2 ring init (FATE#322643
  bsc#1055900).
- drm/i915: Classify the engines in class + instance (FATE#322643
  bsc#1055900).
- drm/i915: Use safer intel_uncore_wait_for_register in ring-init
  (FATE#322643 bsc#1055900).
- drm/i915: Use __intel_uncore_wait_for_register_fw for
  sandybride_pcode_read (FATE#322643 bsc#1055900).
- drm/i915: Acquire uncore.lock over
  intel_uncore_wait_for_register() (FATE#322643 bsc#1055900).
- drm/i915: Stop sleeping from inside gen6_bsd_submit_request()
  (FATE#322643 bsc#1055900).
- drm/i915: Stop second guessing the caller for
  intel_uncore_wait_for_register() (FATE#322643 bsc#1055900).
- drm/i915: Don't allow overuse of __intel_wait_for_register_fw()
  (FATE#322643 bsc#1055900).
- drm/i915: Drop const qualifiers from params in
  wait_for_register() (FATE#322643 bsc#1055900).
- drm/i915: Use drm_i915_private directly from debugfs
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Use wait_for_register_fw() while waiting for
  MMIO response (FATE#322643 bsc#1055900).
- drm/i915: Extend intel_wait_for_register_fw() with fast timeout
  (FATE#322643 bsc#1055900).
- drm/i915: Fix type of timeout_ms parameter in
  intel_wait_for_register_fw() (FATE#322643 bsc#1055900).
- drm/i915: Insert cond_resched() into i915_gem_free_objects
  (FATE#322643 bsc#1055900).
- drm/i915: Break up long runs of freeing objects (FATE#322643
  bsc#1055900).
- drm/i915: Simplify shrinker locking (FATE#322643 bsc#1055900).
- drm/i915: Drain any freed objects prior to hibernation
  (FATE#322643 bsc#1055900).
- drm/i915: The shrinker already acquires struct_mutex, so call
  it unlocked (FATE#322643 bsc#1055900).
- i915: initialize the free_list of the fencing atomic_helper
  (FATE#322643 bsc#1055900).
- drm/i915: Advance ring->head fully when idle (FATE#322643
  bsc#1055900).
- drm/i915: Assert the engine is idle before overwiting the HWS
  (FATE#322643 bsc#1055900).
- drm/i915/GLK/HuC: Load HuC on GLK (FATE#322643 bsc#1055900).
- drm/i915/GuC/GLK: Load GuC on GLK (FATE#322643 bsc#1055900).
- drm/i915/glk: limit pixel clock to 99%% of cdclk workaround
  (FATE#322643 bsc#1055900).
- drm/i915/dp: generate and cache sink rate array for all DP,
  not just eDP 1.4 (FATE#322643 bsc#1055900).
- drm/i915/dp: cache source rates at init (FATE#322643
  bsc#1055900).
- drm/i915/dp: rename rate_to_index() to intel_dp_rate_index()
  and reuse (FATE#322643 bsc#1055900).
- drm/i915/dp: return errors from rate_to_index() (FATE#322643
  bsc#1055900).
- drm/i915/dp: use known correct array size in rate_to_index
  (FATE#322643 bsc#1055900).
- drm/i915: Enable atomic on VLV/CHV (FATE#322643 bsc#1055900).
- drm/i915: Use intel_wm_plane_visible() on VLV/CHV as well
  (FATE#322643 bsc#1055900).
- drm/i915: Check for id==PLANE_CURSOR instead of
  type==DRM_PLANE_TYPE_CURSOR (FATE#322643 bsc#1055900).
- drm/i915/guc: Use GUC prefix for CORE_FAMILY definitions
  (FATE#322643 bsc#1055900).
- drm/i915: Typo fix - 'pipe bpc' to 'pipe bpp' (FATE#322643
  bsc#1055900).
- drm/i915/huc: Simplify intel_huc_init_hw() (FATE#322643
  bsc#1055900).
- drm/i915: Remove user-triggerable WARN from
  i915_gem_object_create (FATE#322643 bsc#1055900).
- drm/i915: Onion unwind for intel_init_ring_common() (FATE#322643
  bsc#1055900).
- drm/i915: intel_ring.engine is unused (FATE#322643 bsc#1055900).
- drm/doc: Clarify mode_fixup vs. atomic_check a bit more
  (FATE#322643 bsc#1055900).
- drm/doc: Document adjusted/request modes a bit better
  (FATE#322643 bsc#1055900).
- drm: Add crtc/encoder/bridge->mode_valid() callbacks
  (FATE#322643 bsc#1055900).
- drm: Add DRM_MODE_ROTATE_ and DRM_MODE_REFLECT_ to UAPI
  (FATE#322643 bsc#1055900).
- drm: trivial documentation fix to drm_for_each_connector_iter
  (FATE#322643 bsc#1055900).
- drm: add missing declaration to drm_blend.h (FATE#322643
  bsc#1055900).
- drm/dp: Wait up all outstanding tx waiters (FATE#322643
  bsc#1055900).
- drm/dp: Read the tx msg state once after checking for an event
  (FATE#322643 bsc#1055900).
- drm/prime: Forward declare struct device (FATE#322643
  bsc#1055900).
- drm/vblank: Lock down vblank->hwmode more (FATE#322643
  bsc#1055900).
- drm/vblank: drop the mode argument from
  drm_calc_vbltimestamp_from_scanoutpos (FATE#322643 bsc#1055900).
- drm/vblank: Add FIXME comments about moving the vblank ts hooks
  (FATE#322643 bsc#1055900).
- drm/vblank: Switch to bool in_vblank_irq in get_vblank_timestamp
  (FATE#322643 bsc#1055900).
- drm/vblank: Switch drm_driver->get_vblank_timestamp to return
  a bool (FATE#322643 bsc#1055900).
- drm: Nerf the preclose callback for modern drivers (FATE#322643
  bsc#1055900).
- drm: Remove redundant NULL check during atomic plane commit
  (FATE#322643 bsc#1055900).
- drm/atomic: Add support for custom scaling mode properties,
  v2 (FATE#322643 bsc#1055900).
- drm/atomic: Handle picture_aspect_ratio in atomic core
  (FATE#322643 bsc#1055900).
- drm/prime: Introduce drm_gem_prime_import_dev (FATE#322643
  bsc#1055900).
- drm/i915: Track MST link bandwidth (FATE#322643 bsc#1055900).
- drm/atomic: fix doc to use new name for commit types
  (FATE#322643 bsc#1055900).
- drm: Make drm_atomic_replace_property_blob_from_id() more
  generic (FATE#322643 bsc#1055900).
- drm: drm_color_mgmt.h needs struct drm_crtc declaration
  (FATE#322643 bsc#1055900).
- drm/cec: Add CEC over Aux register definitions (FATE#322643
  bsc#1055900).
- drm: Add DPCD definitions for DP 1.4 DSC feature (FATE#322643
  bsc#1055900).
- drm/doc: Interlink color manager docs better (FATE#322643
  bsc#1055900).
- drm: fix spelling mistake: "committing" (FATE#322643
  bsc#1055900).
- commit bb6495e
* Wed Feb 21 2018 tiwai@suse.de
- Disable downstream DRM patches temporarily for upgrading the base codes
- commit bc652a8
* Tue Feb 20 2018 msuchanek@suse.de
- blacklist
  7a074fc08389 powerpc/64s: Fix ps3 build error due to tlbiel_all()
  015eb1b89e95 powerpc/mm/radix: Fix build error when RADIX_MMU=n
- commit 5a608da
* Tue Feb 20 2018 msuchanek@suse.de
- powerpc/64s/radix: Boot-time NULL pointer protection using a
  guard-PID (bsc#1055117).
- powerpc/64s: Improve local TLB flush for boot and MCE on POWER9
  (bsc#1055117).
- powerpc/64s: Initialize ISAv3 MMU registers before setting
  partition table (bsc#1055117).
- commit 67f5cce
* Tue Feb 20 2018 jack@suse.cz
- ext4: Fix offset overflow on 32-bit archs in ext4_iomap_begin()
  (bsc#1079747).
- commit bbceb80
* Tue Feb 20 2018 bp@suse.de
- objtool: Improve retpoline alternative handling (bsc#1068032
  CVE-2017-5754).
- objtool: Add support for alternatives at the end of a section
  (bsc#1068032 CVE-2017-5754).
- objtool: Warn on stripped section symbol (bsc#1068032
  CVE-2017-5754).
- x86/entry/64: Remove the SYSCALL64 fast path (bsc#1068032
  CVE-2017-5754).
- x86/entry/64: Push extra regs right away (bsc#1068032
  CVE-2017-5754).
- x86/asm: Move 'status' from thread_struct to thread_info
  (bsc#1068032 CVE-2017-5754).
- x86/speculation: Use Indirect Branch Prediction Barrier in
  context switch (bsc#1068032 CVE-2017-5754).
- x86/retpoline: Avoid retpolines for built-in __init functions
  (bsc#1068032 CVE-2017-5754).
- x86/spectre: Simplify spectre_v2 command line parsing
  (bsc#1068032 CVE-2017-5754).
- KVM: nVMX: Eliminate vmcs02 pool (bsc#1068032 CVE-2017-5754).
- KVM: VMX: introduce alloc_loaded_vmcs (bsc#1068032
  CVE-2017-5754).
- KVM: VMX: make MSR bitmaps per-VCPU (bsc#1068032 CVE-2017-5754).
- KVM/x86: Update the reverse_cpuid list to include CPUID_7_EDX
  (bsc#1068032 CVE-2017-5754).
- KVM/x86: Add IBPB support (bsc#1068032 CVE-2017-5754).
- KVM/VMX: Emulate MSR_IA32_ARCH_CAPABILITIES (bsc#1068032
  CVE-2017-5754).
- KVM/VMX: Allow direct access to MSR_IA32_SPEC_CTRL (bsc#1068032
  CVE-2017-5754).
- KVM/SVM: Allow direct access to MSR_IA32_SPEC_CTRL (bsc#1068032
  CVE-2017-5754).
- perf/x86/amd/power: Do not load AMD power module on !AMD
  platforms (git-fixes c7ab62bfbe0e).
- blacklist.conf:
- Delete
  patches.arch/x86-retpoline-simplify-vmexit_fill_rsb.patch.
- commit ac25421
* Tue Feb 20 2018 nborisov@suse.com
- Btrfs: fix kernel oops while reading compressed data
  (bsc#1081671).
- Refresh
  patches.suse/0023-block-switch-bios-to-blk_status_t.patch.
- commit 565ea00
* Tue Feb 20 2018 jthumshirn@suse.de
- scsi: megaraid_sas: Do not use 32-bit atomic request descriptor
  for Ventura controllers (bsc#1081737).
- commit 4e60173
* Tue Feb 20 2018 jthumshirn@suse.de
- Refresh
  patches.drivers/ibmvnic-Clean-RX-pool-buffers-during-device-close.patch.
- Refresh
  patches.drivers/ibmvnic-Fix-NAPI-structures-memory-leak.patch.
- Refresh
  patches.drivers/ibmvnic-Fix-login-buffer-memory-leaks.patch.
- Refresh
  patches.drivers/ibmvnic-Free-RX-socket-buffer-in-case-of-adapter-err.patch.
- Refresh
  patches.drivers/ibmvnic-Wait-until-reset-is-complete-to-set-carrier-.patch.
- commit ba71f73
* Tue Feb 20 2018 npajkovsky@suse.cz
- bsc#1053298 oracleasm
  patches.suse/0001-oracleasm-4.0-compat-changes.patch
- commit def7601
* Tue Feb 20 2018 neilb@suse.com
- nfs: fix a deadlock in nfs client initialization (bsc#1074198).
- commit 913cb84
* Tue Feb 20 2018 jroedel@suse.de
- blacklist.conf: da391d640c528bc5bb227ea5b39c882b75ac3167
  Comment-only fix
- commit be9480e
* Tue Feb 20 2018 jroedel@suse.de
- iommu/exynos: Remove initconst attribute to avoid potential
  kernel oops (bsc#975772).
- commit ad7bb7b
* Mon Feb 19 2018 jroedel@suse.de
- iommu/mediatek: Fix driver name (bsc#975772).
- iommu/vt-d: Use domain instead of cache fetching (bsc#975772).
- iommu/amd: Limit the IOVA page range to the specified addresses
  (bsc#975772).
- iommu/amd: Fix alloc_irq_index() increment (bsc#975772).
- iommu/amd: Enforce alignment for MSI IRQs (bsc#975772).
- iommu/amd: Add align parameter to alloc_irq_index()
  (bsc#975772).
- commit 69050a0
* Mon Feb 19 2018 mkubecek@suse.cz
- netfilter: xt_RATEEST: acquire xt_rateest_mutex for hash insert
  (bsc#1076830).
- netfilter: xt_cgroup: initialize info->priv in
  cgroup_mt_check_v1() (bsc#1076830).
- iscsi-target: make sure to wake up sleeping login worker
  (bsc#1076830).
- sctp: fix dst refcnt leak in sctp_v4_get_dst (bsc#1076830).
- media: ts2020: avoid integer overflows on 32 bit machines
  (bsc#1076830).
- Revert "defer call to mem_cgroup_sk_alloc()" (bsc#1076830).
- net: ipv6: send unsolicited NA after DAD (bsc#1076830).
- xfrm: Add SA to hardware at the end of xfrm_state_construct()
  (bsc#1076830).
- sctp: do not allow the v4 socket to bind a v4mapped v6 address
  (bsc#1076830).
- strparser: Call sock_owned_by_user_nocheck (bsc#1076830).
- sock: Add sock_owned_by_user_nocheck (bsc#1076830).
- sctp: add SCTP_CID_RECONF conversion in sctp_cname
  (bsc#1076830).
- tcp: invalidate rate samples during SACK reneging (bsc#1076830).
- Revert "tcp: must block bh in __inet_twsk_hashdance()"
  (bsc#1076830).
- tcp: add tcp_v4_fill_cb()/tcp_v4_restore_cb() (bsc#1076830).
- tipc: call tipc_rcv() only if bearer is up in tipc_udp_recv()
  (bsc#1076830).
- tcp/dccp: block bh before arming time_wait timer (bsc#1076830).
- sctp: set sender next_tsn for the old result with ctsn_ack_point
  plus 1 (bsc#1076830).
- tcp: when scheduling TLP, time of RTO should account for
  current ACK (bsc#1076830).
- ipvlan: NULL pointer dereference panic in ipvlan_port_destroy
  (bsc#1076830).
- route: update fnhe_expires for redirect when the fnhe exists
  (bsc#1076830).
- Refresh
  patches.fixes/route-also-update-fnhe_genid-when-updating-a-route-c.patch.
- sctp: check stream reset info len before making reconf chunk
  (bsc#1076830).
- l2tp: don't close sessions in l2tp_tunnel_destruct()
  (bsc#1076830).
- l2tp: initialise l2tp_eth sessions before registering them
  (bsc#1076830).
- l2tp: don't register sessions in l2tp_session_create()
  (bsc#1076830).
- sctp: fix a type cast warnings that causes a_rwnd gets the
  wrong value (bsc#1076830).
- sctp: fix some type cast warnings introduced by transport
  rhashtable (bsc#1076830).
- sctp: add the missing sock_owned_by_user check in
  sctp_icmp_redirect (bsc#1076830).
- net: call cgroup_sk_alloc() earlier in sk_clone_lock()
  (bsc#1076830).
- net: memcontrol: defer call to mem_cgroup_sk_alloc()
  (bsc#1076830).
- netfilter: x_tables: avoid stack-out-of-bounds read in
  xt_copy_counters_from_user (bsc#1076830).
- netfilter: ipset: pernet ops must be unregistered last
  (bsc#1076830).
- xfrm: Fix deletion of offloaded SAs on failure (bsc#1076830).
- packet: only test po->has_vnet_hdr once in packet_snd
  (bsc#1076830).
- net: dsa: Fix network device registration order (bsc#1076830).
- net: set tb->fast_sk_family (bsc#1076830).
- net: vrf: avoid gcc-4.6 warning (bsc#1076830).
- tcp/dccp: remove reqsk_put() from inet_child_forget()
  (bsc#1076830).
- tcp: fix a request socket leak (bsc#1076830).
- l2tp: pass tunnel pointer to ->session_create() (bsc#1076830).
- Refresh patches.fixes/l2tp-fix-l2tp_eth-module-loading.patch.
- l2tp: prevent creation of sessions on terminated tunnels
  (bsc#1076830).
  Refresh
  patches.fixes/l2tp-fix-race-condition-in-l2tp_tunnel_delete.patch.
- l2tp: hold tunnel used while creating sessions with netlink
  (bsc#1076830).
- tcp: fix possible deadlock in TCP stack vs BPF filter
  (bsc#1076830).
- tcp: fix xmit timer to only be reset if data ACKed/SACKed
  (bsc#1076830).
- netfilter: nf_ct_dccp/sctp: fix memory leak after netns cleanup
  (bsc#1076830).
- tcp: Add a tcp_filter hook before handle ack packet
  (bsc#1076830).
- vxlan: dont migrate permanent fdb entries during learn
  (bsc#1076830).
- commit f1b2d26
* Mon Feb 19 2018 msuchanek@suse.de
- powerpc/64s: Improve RFI L1-D cache flush fallback (bsc#1068032).
  Update to upstream patch.
- Refresh
  patches.arch/powerpc-pseries-rfi-flush-Call-setup_rfi_flush-after.patch.
- Refresh
  patches.arch/powerpc-xmon-Add-RFI-flush-related-fields-to-paca-du.patch.
- commit deca5e6
* Mon Feb 19 2018 msuchanek@suse.de
- Refresh RFI LPM migration patches with upstream status.
- Refresh patches.arch/powerpc-pseries-rfi-flush-Call-setup_rfi_flush-after.patch.
- rfi-flush: Move the logic to avoid a redo into the debugfs code
  (bsc#1068032).
- commit 42d34e2
* Mon Feb 19 2018 mbrugger@suse.com
- iommu/io-pgtable-arm-v7s: Need dma-sync while there is no
  QUIRK_NO_DMA (fate#321947).
- iommu/arm-smmu: Reintroduce locking around TLB sync operations
  (fate#321947).
- commit 0427583
* Mon Feb 19 2018 mbrugger@suse.com
- Reorder patches
- commit 0771c78
* Mon Feb 19 2018 msuchanek@suse.de
- powerpc/pseries: Check for zero filled ibm,dynamic-memory
  property (FATE#324825, bsc#1077428, bsc#1080789).
- commit ccf669c
* Mon Feb 19 2018 mfleming@suse.de
- cpumask: Make for_each_cpu_wrap() available on UP as well
  (git-fixes).
- commit e4d0ff0
* Mon Feb 19 2018 msuchanek@suse.de
- blacklist c1e150ceb61e powerpc/pseries: Add empty update_numa_cpu_lookup_table() for NUMA=n
  blacklist 82343484a2d4 powerpc/pseries: Fix build break for SPLPAR=n and CPU hotplug
- commit 2993802
* Mon Feb 19 2018 mgorman@suse.de
- mm: pin address_space before dereferencing it while isolating
  an LRU page (bnc#1081500).
- commit 93762be
* Mon Feb 19 2018 mkubecek@suse.cz
- series.conf: refresh
  Ran series_sort.py (no effect on expanded tree).
- Update upstream reference:
  patches.drivers/nvme_fc-cleanup-io-completion.patch.
  patches.drivers/nvme_fc-correct-abort-race-condition-on-resets.patch.
- Fix patch metadata:
  patches.drivers/scsi-qla2xxx-Fix-double-free-bug-after-firmware-time.patch.
- commit 24a578f
* Mon Feb 19 2018 lhenriques@suse.com
- ceph: improving efficiency of syncfs (FATE#324714).
- libceph: check kstrndup() return value (FATE#324714).
- ceph: try to allocate enough memory for reserved caps
  (FATE#324714).
- ceph: fix race of queuing delayed caps (FATE#324714).
- ceph: delete unreachable code in ceph_check_caps()
  (FATE#324714).
- ceph: limit rate of cap import/export error messages
  (FATE#324714).
- ceph: fix incorrect snaprealm when adding caps (FATE#324714).
- ceph: fix un-balanced fsc->writeback_count update (FATE#324714).
- ceph: track read contexts in ceph_file_info (FATE#324714).
- ceph: avoid dereferencing invalid pointer during cached readdir
  (FATE#324714).
- ceph: use atomic_t for ceph_inode_info::i_shared_gen
  (FATE#324714).
- ceph: cleanup traceless reply handling for rename (FATE#324714).
- ceph: voluntarily drop Fx cap for readdir request (FATE#324714).
- ceph: properly drop caps for setattr request (FATE#324714).
- ceph: voluntarily drop Lx cap for link/rename requests
  (FATE#324714).
- ceph: voluntarily drop Ax cap for requests that create new inode
  (FATE#324714).
- commit 33131fd
* Mon Feb 19 2018 mgorman@suse.de
- buffer: Avoid setting buffer bits that are already set
  (bnc#971975 VM performance -- buffers).
- commit ca2f72a
* Mon Feb 19 2018 jack@suse.cz
- iversion: Rename make inode_cmp_iversion{+raw} to
  inode_eq_iversion{+raw} (bsc#1081186).
- commit d89d8c5
* Mon Feb 19 2018 jack@suse.cz
- iversion: make inode_cmp_iversion{+raw} return bool instead
  of s64 (bsc#1081186).
- commit 625951e
* Mon Feb 19 2018 jack@suse.cz
- fs: handle inode->i_version more efficiently (bsc#1081186).
- commit b5b1ede
* Mon Feb 19 2018 jack@suse.cz
- btrfs: only dirty the inode in btrfs_update_time if something
  was changed (bsc#1081186).
- commit 509a5c3
* Mon Feb 19 2018 jack@suse.cz
- xfs: avoid setting XFS_ILOG_CORE if i_version doesn't need
  incrementing (bsc#1081186).
- commit f466f92
* Mon Feb 19 2018 jack@suse.cz
- fs: only set S_VERSION when updating times if necessary
  (bsc#1081186).
- commit 2f39cae
* Mon Feb 19 2018 jack@suse.cz
- IMA: switch IMA over to new i_version API (bsc#1081186).
- commit f5c04bb
* Mon Feb 19 2018 jack@suse.cz
- xfs: convert to new i_version API (bsc#1081186).
- commit e0e201b
* Mon Feb 19 2018 jack@suse.cz
- ufs: use new i_version API (bsc#1081186).
- commit bb021c0
* Mon Feb 19 2018 jack@suse.cz
- ocfs2: convert to new i_version API (bsc#1081186).
- commit 5b5fa6e
* Mon Feb 19 2018 jack@suse.cz
- nfsd: convert to new i_version API (bsc#1081186).
- commit ed53100
* Mon Feb 19 2018 jack@suse.cz
- nfs: convert to new i_version API (bsc#1081186).
- commit 55bd438
* Mon Feb 19 2018 jack@suse.cz
- ext4: convert to new i_version API (bsc#1081186).
- commit 437c1ef
* Mon Feb 19 2018 jack@suse.cz
- ext2: convert to new i_version API (bsc#1081186).
- commit 2cd1049
* Mon Feb 19 2018 jack@suse.cz
- exofs: switch to new i_version API (bsc#1081186).
- commit 225c244
* Mon Feb 19 2018 jack@suse.cz
- btrfs: convert to new i_version API (bsc#1081186).
- commit ae27f85
* Mon Feb 19 2018 jack@suse.cz
- afs: convert to new i_version API (bsc#1081186).
- commit 2fa658c
* Mon Feb 19 2018 jack@suse.cz
- affs: convert to new i_version API (bsc#1081186).
- commit 0a73f1a
* Mon Feb 19 2018 jack@suse.cz
- fat: convert to new i_version API (bsc#1081186).
- commit 75908ef
* Mon Feb 19 2018 jack@suse.cz
- fs: don't take the i_lock in inode_inc_iversion (bsc#1081186).
- commit 3ecc67b
* Mon Feb 19 2018 jack@suse.cz
- fs: new API for handling inode->i_version (bsc#1081186).
- commit 4e364de
* Mon Feb 19 2018 jack@suse.cz
- ntfs: remove i_version handling (bsc#1081186).
- commit 3636058
* Mon Feb 19 2018 jack@suse.cz
- lustre: don't set f_version in ll_readdir (bsc#1081186).
- commit 052b4c4
* Mon Feb 19 2018 jack@suse.cz
- ima: Use i_version only when filesystem supports it
  (bsc#1081186).
- commit 5e28e82
* Mon Feb 19 2018 jthumshirn@suse.de
- nvme-pci: Remap CMB SQ entries on every controller reset
  (FATE#323952, FATE#322506).
- commit 37d7f9b
* Mon Feb 19 2018 jack@suse.cz
- Fix up tags in
  patches.drivers/scsi-qla2xxx-Fix-double-free-bug-after-firmware-time.patch.
- commit 7dc8b66
* Mon Feb 19 2018 jthumshirn@suse.de
- Refresh patches.drivers/nvme_fc-cleanup-io-completion.patch.
- Refresh
  patches.drivers/nvme_fc-correct-abort-race-condition-on-resets.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-double-free-bug-after-firmware-time.patch.
- commit 54909a8
* Mon Feb 19 2018 mgalbraith@suse.de
- sched/rt: Up the root domain ref count when passing it around
  via IPIs (bnc#1022476).
- sched/rt: Use container_of() to get root domain in
  rto_push_irq_work_func() (bnc#1022476).
- hrtimer: Ensure POSIX compliance (relative CLOCK_REALTIME
  hrtimers) (bnc#1022476).
- hrtimer: Reset hrtimer cpu base proper on CPU hotplug
  (bnc#1022476).
- commit e19e122
* Fri Feb 16 2018 tiwai@suse.de
- blacklist.conf: Remove i915 entries
- commit c8a167f
* Fri Feb 16 2018 mbrugger@suse.com
- arm64: Update config files.
  enable ARCH_PROC_KCORE_TEXT
- commit 5f62bc2
* Fri Feb 16 2018 mbrugger@suse.com
- net: ethernet: cavium: Correct Cavium Thunderx NIC driver
  names accordingly to module name (fate#321947).
- iommu/arm-smmu-v3: Cope with duplicated Stream IDs
  (fate#321947).
- ACPICA: iasl: Update to IORT SMMUv3 disassembling (fate#321947).
- ACPI/IORT: numa: Add numa node mapping for smmuv3 devices
  (fate#321947).
- iommu/arm-smmu-v3: Remove io-pgtable spinlock (fate#321947).
- iommu/arm-smmu: Remove io-pgtable spinlock (fate#321947).
- iommu/io-pgtable-arm-v7s: Support lockless operation
  (fate#321947).
- iommu/io-pgtable-arm: Support lockless operation (fate#321947).
- iommu/io-pgtable: Introduce explicit coherency (fate#321947).
- iommu/io-pgtable-arm-v7s: Refactor split_blk_unmap
  (fate#321947).
- iommu/io-pgtable-arm: Improve split_blk_unmap (fate#321947).
- iommu/io-pgtable-arm-v7s: Check table PTEs more precisely
  (fate#321947).
- arm64: mm: select CONFIG_ARCH_PROC_KCORE_TEXT (fate#321947).
- fs/proc: kcore: use kcore_list type to check for vmalloc/module
  address (fate#321947).
- arm64: kernel: restrict /dev/mem read() calls to linear region
  (bsc#1081310).
- commit 4267f13
* Fri Feb 16 2018 tiwai@suse.de
- Preliminary roll-back of drm/i915 patches for the further updates
- commit dbb70d2
* Fri Feb 16 2018 jeffm@suse.com
- btrfs: use kvzalloc to allocate btrfs_fs_info (bsc#1059336).
- commit 1d89bd7
* Thu Feb 15 2018 mcgrof@suse.com
- xfs: stop searching for free slots in an inode chunk when there are none (bsc#1072739).
- commit 80d1325
* Thu Feb 15 2018 jack@suse.cz
- jfs: remove increment of i_version counter (bsc#1081186).
- commit 5e24fbb
* Thu Feb 15 2018 jack@suse.cz
- reiserfs: remove unneeded i_version bump (bsc#1081186).
- commit 5aba66b
* Thu Feb 15 2018 jack@suse.cz
- hpfs: don't bother with the i_version counter or f_version (bsc#1081186).
- commit 337ee72
* Thu Feb 15 2018 jack@suse.cz
- ecryptfs: remove unnecessary i_version bump (bsc#1081186).
- commit 2a56f3b
* Thu Feb 15 2018 jack@suse.cz
- f2fs: don't bother with inode->i_version (bsc#1081186).
- commit 13fcbd3
* Thu Feb 15 2018 jack@suse.cz
- nilfs2: remove inode->i_version initialization (bsc#1081186).
- commit 17fcbba
* Thu Feb 15 2018 jack@suse.cz
- orangefs: remove initialization of i_version (bsc#1081186).
- commit 5f1d1e2
* Thu Feb 15 2018 jack@suse.cz
- ceph: remove the bump of i_version (bsc#1081186).
- commit ea139ef
* Thu Feb 15 2018 mgorman@suse.de
- writeback: eliminate work item allocation in
  bd_start_writeback() (bnc#1081213).
- writeback: only allow one inflight and pending full flush
  (bnc#1081213).
- writeback: move nr_pages == 0 logic to one location
  (bnc#1081213).
- writeback: make wb_start_writeback() static (bnc#1081213).
- writeback: pass in '0' for nr_pages writeback in laptop mode
  (bnc#1081213).
- writeback: provide a wakeup_flusher_threads_bdi() (bnc#1081213).
- writeback: remove 'range_cyclic' argument for
  wb_start_writeback() (bnc#1081213).
- writeback: switch wakeup_flusher_threads() to cyclic writeback
  (bnc#1081213).
- fs: kill 'nr_pages' argument from wakeup_flusher_threads()
  (bnc#1081213).
- buffer: eliminate the need to call free_more_memory() in
  __getblk_slow() (bnc#971975 VM performance -- memory usage
  during reclaim).
- buffer: grow_dev_page() should use __GFP_NOFAIL for all cases
  (bnc#971975 VM performance -- memory usage during reclaim).
- buffer: have alloc_page_buffers() use __GFP_NOFAIL (bnc#971975
  VM performance -- memory usage during reclaim).
- commit ff7bae7
* Thu Feb 15 2018 mbrugger@suse.com
- Refresh
  patches.suse/arm64-Add-software-workaround-for-Falkor-erratum-104.patch.
- commit 709299d
* Thu Feb 15 2018 msuchanek@suse.de
- powerpc/mm/hash64: Zero PGD pages on allocation (FATE#322447,
  bsc#1078248).
- powerpc/mm/hash64: Store the slot information at the right
  offset for hugetlb (FATE#322447, bsc#1078248).
- powerpc/mm/hash64: Allocate larger PMD table if hugetlb config
  is enabled (FATE#322447, bsc#1078248).
- powerpc/mm: Fix crashes with 16G huge pages (FATE#322447,
  bsc#1078248).
- commit c53ee68
* Thu Feb 15 2018 msuchanek@suse.de
- powerpc/numa: Invalidate numa_cpu_lookup_table on cpu remove
  (FATE#323746, bsc#1079524).
- commit f1632b3
* Thu Feb 15 2018 agraf@suse.de
- KVM: s390: add vcpu stat counters for many instruction
  (bsc#1081178).
- KVM: s390: diagnoses are instructions as well (bsc#1081178).
- commit 801cf55
* Thu Feb 15 2018 msuchanek@suse.de
- powerpc/mm: Flush radix process translations when setting MMU
  type (bsc#1061840).
- commit 6d1b9f9
* Thu Feb 15 2018 msuchanek@suse.de
- powerpc/pseries: Enable RAS hotplug events later (FATE#322022,
  bsc#1065729).
- commit 445a309
* Thu Feb 15 2018 jeffm@suse.com
- btrfs: copy fsid to super_block s_uuid (bsc#1080774).
- commit 8d21561
* Thu Feb 15 2018 jthumshirn@suse.de
- scsi: lpfc: Update 11.4.0.7 modified files for 2018 Copyright
  (bsc#1080657).
- scsi: lpfc: update driver version to 11.4.0.7 (bsc#1080657).
- scsi: lpfc: Fix nonrecovery of NVME controller after cable swap
  (bsc#1080657).
- scsi: lpfc: Treat SCSI Write operation Underruns as an error
  (bsc#1080657).
- scsi: lpfc: Fix header inclusion in lpfc_nvmet (bsc#1080657).
- scsi: lpfc: Validate adapter support for SRIU option
  (bsc#1080657).
- scsi: lpfc: Fix SCSI io host reset causing kernel crash
  (bsc#1080657).
- scsi: lpfc: Indicate CONF support in NVMe PRLI (bsc#1080657).
- scsi: lpfc: Fix issue_lip if link is disabled (bsc#1080657).
- scsi: lpfc: Fix soft lockup in lpfc worker thread during LIP
  testing (bsc#1080657).
- scsi: lpfc: Allow set of maximum outstanding SCSI cmd limit
  for a target (bsc#1080657).
- scsi: lpfc: Fix RQ empty firmware trap (bsc#1080657).
- scsi: lpfc: Fix IO failure during hba reset testing with nvme io
  (bsc#1080657).
- scsi: lpfc: Fix PRLI handling when topology type changes
  (bsc#1080657).
- scsi: lpfc: Add WQ Full Logic for NVME Target (bsc#1080657).
- scsi: lpfc: correct debug counters for abort (bsc#1080657).
- scsi: lpfc: move placement of target destroy on driver detach
  (bsc#1080657).
- scsi: lpfc: Increase CQ and WQ sizes for SCSI (bsc#1080657).
- scsi: lpfc: Fix frequency of Release WQE CQEs (bsc#1080657).
- commit 7226e76
* Thu Feb 15 2018 ohering@suse.de
- hv_netvsc: Use the num_online_cpus() for channel limit
  (fate#323887).
- scsi: storvsc: missing error code in storvsc_probe()
  (fate#323887).
- uio_hv_generic: fix new type mismatch warnings (fate#323887).
- uio_hv_generic: fix type mismatch warnings (fate#323887).
- uio_hv_generic: add rescind support (fate#323887).
- uio_hv_generic: check that host supports monitor page
  (fate#323887).
- uio_hv_generic: create send and receive buffers (fate#323887).
- vmbus: add monitor_id and subchannel_id to sysfs per channel
  (fate#323887).
- uio_hv_generic: use ISR callback method (fate#323887).
- uio_hv_generic: use standard mmap for resources (fate#323887).
- uio_hv_generic: fix configuration comments (fate#323887).
- vmbus: make channel attributes static (fate#323887).
- hv_netvsc: empty current transmit aggregation if flow blocked
  (fate#323887).
- hv_netvsc: remove open_cnt reference count (fate#323887).
- hv_netvsc: pass netvsc_device to receive callback (fate#323887).
- hv_netvsc: simplify function args in receive status path
  (fate#323887).
- hv_netvsc: track memory allocation failures in ethtool stats
  (fate#323887).
- hv_netvsc: copy_to_send buf can be void (fate#323887).
- hv_netvsc: Fix the TX/RX buffer default sizes (fate#323887).
- hv_netvsc: Fix the receive buffer size limit (fate#323887).
- vmbus: make hv_get_ringbuffer_availbytes local (fate#323887).
- hv_netvsc: optimize initialization of RNDIS header
  (fate#323887).
- hv_netvsc: use reciprocal divide to speed up percent calculation
  (fate#323887).
- hv_netvsc: replace divide with mask when computing padding
  (fate#323887).
- hv_netvsc: don't need local xmit_more (fate#323887).
- hv_netvsc: drop unused macros (fate#323887).
- commit 72e1a3c
* Thu Feb 15 2018 ohering@suse.de
- add mainline tag to hv-X86_FEATURE_PCID patch
- commit 258a152
* Thu Feb 15 2018 tiwai@suse.de
- drm/vc4: Flush the caches before the bin jobs, as well
  (bsc#1051510).
- commit 81ad369
* Thu Feb 15 2018 tiwai@suse.de
- drm: rework delayed connector cleanup in connector_iter
  (bsc#1051510).
- commit cc83f2f
* Thu Feb 15 2018 tiwai@suse.de
- drm/i915: Always call to intel_display_set_init_power() in
  resume_early (bsc#1051510).
- commit f91d13e
* Thu Feb 15 2018 tiwai@suse.de
- drm/i915: Always run hangcheck while the GPU is busy
  (bsc#1051510).
- commit 09cdfcc
* Thu Feb 15 2018 tiwai@suse.de
- drm/i915/cmdparser: Check reg_table_count before derefencing
  (bsc#1051510).
- commit 3a43a70
* Thu Feb 15 2018 tiwai@suse.de
- drm: safely free connectors from connector_iter (bsc#1051510).
- commit 8a5bb42
* Thu Feb 15 2018 tiwai@suse.de
- drm/i915/lpe: Remove double-encapsulation of info string
  (bsc#1051510).
- commit c91a5f4
* Thu Feb 15 2018 tiwai@suse.de
- drm/qxl: reapply cursor after resetting primary (bsc#1051510).
- commit 579b46a
* Thu Feb 15 2018 tiwai@suse.de
- drm/i915/ppgtt: Pin page directories before allocation
  (bsc#1051510).
- commit ec22aec
* Thu Feb 15 2018 tiwai@suse.de
- drm/i915: Fix using BIT_ULL() vs. BIT() for power domain masks
  (bsc#1051510).
- commit 2fd6f13
* Thu Feb 15 2018 tiwai@suse.de
- drm/amdgpu: only check mmBIF_IOV_FUNC_IDENTIFIER on tonga/fiji
  (bsc#1051510).
- commit 9861962
* Thu Feb 15 2018 msuchanek@suse.de
- ibmvnic: Clean RX pool buffers during device close
  (bsc#1081134).
- ibmvnic: Free RX socket buffer in case of adapter error
  (bsc#1081134).
- ibmvnic: Fix NAPI structures memory leak (bsc#1081134).
- ibmvnic: Fix login buffer memory leaks (bsc#1081134).
- ibmvnic: Wait until reset is complete to set carrier on
  (bsc#1081134).
- commit 93a2616
* Thu Feb 15 2018 msuchanek@suse.de
- Refresh sorted section.
- Refresh patches.drivers/scsi-qla2xxx-Avoid-triggering-undefined-behavior-in-.patch.
- Refresh patches.drivers/scsi-qla2xxx-Fix-a-locking-imbalance-in-qlt_24xx_han.patch.
- Refresh patches.drivers/scsi-qla2xxx-Fix-double-free-bug-after-firmware-time.patch.
- Refresh patches.drivers/scsi-qla2xxx-Fix-incorrect-handle-for-abort-IOCB.patch.
- commit 83ae805
* Thu Feb 15 2018 tiwai@suse.de
- drm/i915: Drop fb reference on load_detect_pipe failure path
  (bsc#1051510).
- drm/i915: Replace *_reference/unreference() or *_ref/unref
  with _get/put() (bsc#1051510).
- commit c6b993a
* Thu Feb 15 2018 msuchanek@suse.de
- Refresh patches.drivers/scsi-qla2xxx-Fix-double-free-bug-after-firmware-time.patch.
- Refresh patches.drivers/scsi-qla2xxx-Fix-incorrect-handle-for-abort-IOCB.patch.
  fix commit hash
- commit 94790ed
* Thu Feb 15 2018 tiwai@suse.de
- drm/vc4: Fix NULL pointer dereference in vc4_save_hang_state()
  (bsc#1051510).
- commit 1603569
* Thu Feb 15 2018 tiwai@suse.de
- drm/i915/psr: Fix register name mess up (bsc#1051510).
- commit 6ce9707
* Thu Feb 15 2018 tiwai@suse.de
- drm/vc4: Move IRQ enable to PM path (bsc#1051510).
- commit 4fd629c
* Thu Feb 15 2018 tiwai@suse.de
- serial: 8250_uniphier: fix error return code in
  uniphier_uart_probe() (bsc#1051510).
- commit 5b3310e
* Thu Feb 15 2018 tiwai@suse.de
- drm/edid: kerneldoc for is_hdmi2_sink (bsc#1051510).
- commit 072edca
* Thu Feb 15 2018 tiwai@suse.de
- drm/i915/cnp: Properly handle VBT ddc pin out of bounds
  (bsc#1051510).
- drm/i915/cnp: Ignore VBT request for know invalid DDC pin
  (bsc#1051510).
- commit 1b039a5
* Thu Feb 15 2018 tiwai@suse.de
- drm/i915/glk: Disable Guc and HuC on GLK (bsc#1051510).
- commit b8eaf51
* Thu Feb 15 2018 tiwai@suse.de
- Add no-fix tag to i915 patches
- commit 1c45058
* Thu Feb 15 2018 tiwai@suse.de
- platform/x86: dell-laptop: Filter out spurious keyboard
  backlight change events (bsc#1051510).
- commit 104f7af
* Thu Feb 15 2018 tiwai@suse.de
- ASoC: au1x: Fix timeout tests in au1xac97c_ac97_read()
  (bsc#1051510).
- ASoC: Intel: sst: Fix the return value of
  'sst_send_byte_stream_mrfld()' (bsc#1051510).
- ASoC: rockchip: i2s: fix playback after runtime resume
  (bsc#1051510).
- ASoC: nuc900: Fix a loop timeout test (bsc#1051510).
- ASoC: amd: Add error checking to probe function (bsc#1051510).
- commit d9748ce
* Thu Feb 15 2018 tiwai@suse.de
- ALSA: hda - Reduce the suspend time consumption for ALC256
  (bsc#1051510).
- commit 6999499
* Thu Feb 15 2018 tiwai@suse.de
- ALSA: hda - Use IS_REACHABLE() for dependency on input
  (bsc#1051510).
- commit 016c820
* Thu Feb 15 2018 mbenes@suse.cz
- livepatch: Atomic replace and cumulative patches documentation
  (bsc#1071995 fate#323487).
- commit e40f006
* Thu Feb 15 2018 mbenes@suse.cz
- livepatch: Add atomic replace (bsc#1071995 fate#323487).
- commit bf08cda
* Thu Feb 15 2018 mbenes@suse.cz
- livepatch: Support separate list for replaced patches
  (bsc#1071995 fate#323487).
- commit 1f2a166
* Thu Feb 15 2018 mbenes@suse.cz
- livepatch: Allow to unpatch only functions of the given type
  (bsc#1071995 fate#323487).
- commit 9895789
* Thu Feb 15 2018 mbenes@suse.cz
- livepatch: Initial support for dynamic structures (bsc#1071995
  fate#323487).
- commit c46efc1
* Thu Feb 15 2018 mbenes@suse.cz
- livepatch: Free only structures with initialized kobject
  (bsc#1071995 fate#323487).
- commit c2ef814
* Thu Feb 15 2018 mbenes@suse.cz
- livepatch: Use lists to manage patches, objects and functions
  (bsc#1071995 fate#323487).
- commit 3385ca3
* Thu Feb 15 2018 bpoirier@suse.com
- Refresh patch order in sorted section
- Refresh
  patches.drivers/scsi-qla2xxx-Avoid-triggering-undefined-behavior-in-.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-a-locking-imbalance-in-qlt_24xx_han.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-double-free-bug-after-firmware-time.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-incorrect-handle-for-abort-IOCB.patch.
- commit cea0d55
* Wed Feb 14 2018 mbrugger@suse.com
- arm64: Kill PSCI_GET_VERSION as a variant-2 workaround
  (bsc#1068032).
- arm64: Add ARM_SMCCC_ARCH_WORKAROUND_1 BP hardening support
  (bsc#1068032).
- arm/arm64: smccc: Implement SMCCC v1.1 inline primitive
  (bsc#1068032).
- arm/arm64: smccc: Make function identifiers an unsigned quantity
  (bsc#1068032).
- firmware/psci: Expose SMCCC version through psci_ops
  (bsc#1068032).
- firmware/psci: Expose PSCI conduit (bsc#1068032).
- arm64: KVM: Add SMCCC_ARCH_WORKAROUND_1 fast handling
  (bsc#1068032).
- arm64: KVM: Report SMCCC_ARCH_WORKAROUND_1 BP hardening support
  (bsc#1068032).
- arm/arm64: KVM: Turn kvm_psci_version into a static inline
  (bsc#1068032).
- arm/arm64: KVM: Advertise SMCCC v1.1 (bsc#1068032).
- arm/arm64: KVM: Implement PSCI 1.0 support (bsc#1068032).
- arm/arm64: KVM: Add smccc accessors to PSCI code (bsc#1068032).
- arm/arm64: KVM: Add PSCI_VERSION helper (bsc#1068032).
- arm/arm64: KVM: Consolidate the PSCI include files
  (bsc#1068032).
- arm64: KVM: Increment PC after handling an SMC trap
  (bsc#1068032).
- arm: KVM: Fix SMCCC handling of unimplemented SMC/HVC calls
  (bsc#1068032).
- commit e769a19
* Wed Feb 14 2018 mbrugger@suse.com
- Refresh
  patches.suse/0019-arm64-KVM-Fix-SMCCC-handling-of-unimplemented-SMC-HV.patch.
- commit a856f51
* Wed Feb 14 2018 jthumshirn@suse.de
- scripts/git_sort/git_sort.py: Add mkp/4.17/scsi-queue
- commit 41390e8
* Wed Feb 14 2018 jthumshirn@suse.de
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-double-free-bug-after-firmware-time.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-incorrect-handle-for-abort-IOCB.patch.
  Upstream Commit IDs have changed due to re-base.
- commit 6cd1846
* Wed Feb 14 2018 jslaby@suse.cz
- pipe: avoid round_pipe_size() nr_pages overflow on 32-bit
  (bnc#1006867).
- commit e550396
* Wed Feb 14 2018 tiwai@suse.de
- futex: Prevent overflow by strengthen input validation
  (CVE-2018-6927,bsc#1080757).
- commit 6fd37c0
* Wed Feb 14 2018 jack@suse.cz
- ext4: reduce lock contention in __ext4_new_inode (bsc#1080989).
- commit bcf743f
* Wed Feb 14 2018 jack@suse.cz
- ext4: do not unnecessarily allocate buffer in recently_deleted()
  (bsc#1080989).
- commit 3ae1700
* Wed Feb 14 2018 jack@suse.cz
- ext4: cleanup goto next group (bsc#1080989).
- commit 13de627
* Wed Feb 14 2018 mbrugger@suse.com
- Fix series.conf sort-order
- commit 6668be5
* Tue Feb 13 2018 msuchanek@suse.de
- ibmvnic: Remove skb->protocol checks in ibmvnic_xmit
  (bsc#1080384).
- ibmvnic: Reset long term map ID counter (bsc#1080364).
- commit 8c6ee76
* Tue Feb 13 2018 msuchanek@suse.de
- powerpc/xmon: Dont register sysrq key when kernel param xmon=off
  (bsc#1072829).
- commit 3e326cd
* Tue Feb 13 2018 jthumshirn@suse.de
- nvme_fc: cleanup io completion (bsc#1079628).
- nvme_fc: correct abort race condition on resets (bsc#1079628).
- commit 3347e8d
* Tue Feb 13 2018 mgorman@suse.de
- sched/numa: Delay retrying placement for automatic NUMA balance
  after wake_affine (bnc#1064414).
- sched/fair: Consider SD_NUMA when selecting the most idle
  group to schedule on (bnc#1064414).
- sched/fair: Do not migrate due to a sync wakeup on exit
  (bnc#1064414).
- sched/fair: Do not migrate on wake_affine_weight if weights
  are equal (bnc#1064414).
- sched/fair: Defer calculation of prev_eff_load in wake_affine
  until needed (bnc#1064414).
- sched/fair: Avoid an unnecessary lookup of current CPU ID
  during wake_affine (bnc#1064414).
- commit 5c70670
* Tue Feb 13 2018 jthumshirn@suse.de
- scripts/git_sort/git_sort.py: add nvme/nvme-4.16-rc
- commit 40fc9c6
* Tue Feb 13 2018 msuchanek@suse.de
- KVM: PPC: Book3S PR: Fix svcpu copying with preemption enabled
  (bsc#1077761, git-fixes).
- commit b909d20
* Tue Feb 13 2018 jthumshirn@suse.de
- scsi: libsas: fix error when getting phy events (bsc#1061782).
- commit 7b1f578
* Tue Feb 13 2018 fdmanana@suse.com
- Btrfs: fix space leak after fallocate and zero range operations
  (fate#323233).
- commit 12996c5
* Tue Feb 13 2018 fdmanana@suse.com
- Btrfs: fix missing inode i_size update after zero range
  operation (fate#323233).
- commit a150fc9
* Tue Feb 13 2018 fdmanana@suse.com
- Refresh
  patches.suse/btrfs-add-support-for-fallocate-s-zero-range-operati.patch.
- commit 18b5788
* Tue Feb 13 2018 jthumshirn@suse.de
- scsi: libsas: Disable asynchronous aborts for SATA devices
  (bsc#1061782).
- commit fd6cd11
* Tue Feb 13 2018 jthumshirn@suse.de
- Re-sort series.conf
- commit 3e66481
* Tue Feb 13 2018 jthumshirn@suse.de
- Refresh
  patches.drivers/libnvdimm-fix-integer-overflow-static-analysis-warni.patch.
  Fix compiler warning due to bad backport.
- commit b178056
* Tue Feb 13 2018 mcgrof@suse.com
- xfs: write unmount record for ro mounts (bsc#1073401).
- xfs: toggle readonly state around xfs_log_mount_finish (bsc#1073401).
- commit d6cbdb2
* Mon Feb 12 2018 jthumshirn@suse.de
- libnvdimm, dax: fix 1GB-aligned namespaces vs physical
  misalignment (FATE#323731).
- libnvdimm, pfn: fix start_pad handling for aligned namespaces
  (FATE#323731).
- libnvdimm, pfn: make 'resource' attribute only readable by root
  (FATE#323731).
- libnvdimm, namespace: make 'resource' attribute only readable
  by root (FATE#323731).
- libnvdimm, region : make 'resource' attribute only readable
  by root (FATE#323731).
- libnvdimm: fix integer overflow static analysis warning
  (FATE#323731).
- commit 1f72f5a
* Mon Feb 12 2018 oneukum@suse.com
- usbip: fix stub_send_ret_submit() vulnerability to null
  transfer_buffer (bsc#1078669 CVE-2017-16914).
- commit 55a35d1
* Mon Feb 12 2018 jthumshirn@suse.de
- Refresh
  patches.drivers/ibmvnic-Ensure-that-buffers-are-NULL-after-free.patch.
- Refresh
  patches.drivers/ibmvnic-Fix-rx-queue-cleanup-for-non-fatal-resets.patch.
- Refresh
  patches.drivers/ibmvnic-queue-reset-when-CRQ-gets-closed-during-rese.patch.
- Refresh
  patches.suse/v2-2-9-arm64-kpti-Make-use-of-nG-dependent-on-arm64_kernel_unmapped_at_el0.patch.
- commit 44586d4
* Mon Feb 12 2018 tbogendoerfer@suse.de
- cxgb4: properly initialize variables (bsc#1064802 bsc#1066129).
- IB/core: Perform modify QP on real one (bsc#1046306
  FATE#322942).
- IB/hfi1: Fix infinite loop in 8051 command error path
  (bsc#1060463 FATE#323043).
- commit bfc5374
* Mon Feb 12 2018 mgorman@suse.de
- x86 / CPU: Avoid unnecessary IPIs in arch_freq_get_on_cpu()
  (bnc#1073583 cpufreq reporting).
- cpufreq: x86: Disable interrupts during MSRs reading
  (bnc#1073583 cpufreq reporting).
- commit f714afd
* Mon Feb 12 2018 jkosina@suse.cz
- README.BRANCH: remove Jeff Mahoney as temporary comaintainer
- commit 718ae6f
* Mon Feb 12 2018 mgorman@suse.de
- cpufreq: x86: Make scaling_cur_freq behave more as expected
  (bnc#1073583 cpufreq reporting).
- commit 7670904
* Mon Feb 12 2018 mgorman@suse.de
- x86: use common aperfmperf_khz_on_cpu() to calculate KHz using
  APERF/MPERF (bnc#1073583 cpufreq reporting).
- commit 529bfe4
* Mon Feb 12 2018 bp@suse.de
- x86/cpuid: Fix up "virtual" IBRS/IBPB/STIBP feature bits on
  Intel (bsc#1068032 CVE-2017-5754).
- x86/pti: Mark constant arrays as __initconst (bsc#1068032
  CVE-2017-5754).
- x86/microcode: Fix again accessing initrd after having been
  freed (git-fixes f26483eaedec).
- x86/tsc: Fix erroneous TSC rate on Skylake Xeon (bsc#1074873).
- commit 8d39e42
* Mon Feb 12 2018 tbogendoerfer@suse.de
- bnx2x: disable GSO where gso_size is too big for hardware
  (bsc#1079384).
- net: create skb_gso_validate_mac_len() (bsc#1079384).
- commit d647fd1
* Mon Feb 12 2018 tbogendoerfer@suse.de
- Re-sorted series.conf
- Refresh
  patches.drivers/ibmvnic-Ensure-that-buffers-are-NULL-after-free.patch.
- Refresh
  patches.drivers/ibmvnic-Fix-rx-queue-cleanup-for-non-fatal-resets.patch.
- Refresh
  patches.drivers/ibmvnic-queue-reset-when-CRQ-gets-closed-during-rese.patch.
- Refresh
  patches.suse/v2-2-9-arm64-kpti-Make-use-of-nG-dependent-on-arm64_kernel_unmapped_at_el0.patch.
- commit d67c239
* Mon Feb 12 2018 jthumshirn@suse.de
- blacklist.conf: Blacklist 007a61ae2f35 ("nvme: fix visibility of "uuid" ns
  attribute")
- commit 94a7b7f
* Sat Feb 10 2018 bp@suse.de
- Documentation/virtual/kvm: Add AMD Secure Encrypted
  Virtualization (SEV) (bsc#1063068).
- x86/CPU/AMD: Add the Secure Encrypted Virtualization CPU feature
  (bsc#1063068).
- kvm: svm: prepare for new bit definition in nested_ctl
  (bsc#1063068).
- kvm: svm: Add SEV feature definitions to KVM (bsc#1063068).
- KVM: SVM: Prepare to reserve asid for SEV guest (bsc#1063068).
- KVM: X86: Extend CPUID range to include new leaf (bsc#1063068).
- KVM: Introduce KVM_MEMORY_ENCRYPT_OP ioctl (bsc#1063068).
- KVM: Introduce KVM_MEMORY_ENCRYPT_{UN,}REG_REGION ioctl
  (bsc#1063068).
- crypto: ccp - Use devres interface to allocate PCI/iomap and
  cleanup (bsc#1063068).
- crypto: ccp - Introduce the AMD Secure Processor device
  (bsc#1063068).
- crypto: ccp - Abstract interrupt registeration (bsc#1063068).
- crypto: ccp - rename ccp driver initialize files as sp device
  (bsc#1063068).
- crypto: ccp - remove ccp_present() check from device initialize
  (bsc#1063068).
- crypto: ccp - remove duplicate module version and author entry
  (bsc#1063068).
- crypto: ccp: Build the AMD secure processor driver only with
  AMD CPU support (bsc#1063068).
- crypto: ccp: Define SEV userspace ioctl and command id
  (bsc#1063068).
- crypto: ccp: Define SEV key management command id (bsc#1063068).
- crypto: ccp: Add Platform Security Processor (PSP) device
  support (bsc#1063068).
- crypto: ccp: Add Secure Encrypted Virtualization (SEV) command
  support (bsc#1063068).
- crypto: ccp: Implement SEV_FACTORY_RESET ioctl command
  (bsc#1063068).
- crypto: ccp: Implement SEV_PLATFORM_STATUS ioctl command
  (bsc#1063068).
- crypto: ccp: Implement SEV_PEK_GEN ioctl command (bsc#1063068).
- crypto: ccp: Implement SEV_PDH_GEN ioctl command (bsc#1063068).
- crypto: ccp: Implement SEV_PEK_CSR ioctl command (bsc#1063068).
- crypto: ccp: Implement SEV_PEK_CERT_IMPORT ioctl command
  (bsc#1063068).
- crypto: ccp: Implement SEV_PDH_CERT_EXPORT ioctl command
  (bsc#1063068).
- KVM: X86: Add CONFIG_KVM_AMD_SEV (bsc#1063068).
- KVM: SVM: Reserve ASID range for SEV guest (bsc#1063068).
- KVM: SVM: Add sev module_param (bsc#1063068).
- KVM: Define SEV key management command id (bsc#1063068).
- KVM: SVM: Add KVM_SEV_INIT command (bsc#1063068).
- KVM: SVM: VMRUN should use associated ASID when SEV is enabled
  (bsc#1063068).
- KVM: SVM: Add support for KVM_SEV_LAUNCH_START command
  (bsc#1063068).
- KVM: SVM: Add support for KVM_SEV_LAUNCH_UPDATE_DATA command
  (bsc#1063068).
- KVM: SVM: Add support for KVM_SEV_LAUNCH_MEASURE command
  (bsc#1063068).
- KVM: SVM: Add support for SEV LAUNCH_FINISH command
  (bsc#1063068).
- KVM: SVM: Add support for SEV GUEST_STATUS command
  (bsc#1063068).
- KVM: SVM: Add support for SEV DEBUG_DECRYPT command
  (bsc#1063068).
- KVM: SVM: Add support for SEV DEBUG_ENCRYPT command
  (bsc#1063068).
- KVM: SVM: Add support for SEV LAUNCH_SECRET command
  (bsc#1063068).
- KVM: SVM: Pin guest memory when SEV is active (bsc#1063068).
- KVM: SVM: Clear C-bit from the page fault address (bsc#1063068).
- KVM: SVM: Do not install #UD intercept when SEV is enabled
  (bsc#1063068).
- KVM: X86: Restart the guest when insn_len is zero and SEV is
  enabled (bsc#1063068).
- Update config files.
- Refresh
  patches.arch/01-x86-retpoline-fill-rsb-on-context-switch-for-affected-cpus.patch.
- Refresh
  patches.arch/x86-cpufeatures-clean-up-spectre-v2-related-cpuid-flags.patch.
- Refresh
  patches.arch/x86-speculation-add-basic-ibpb-indirect-branch-prediction-barrier-support.patch.
- Refresh
  patches.drivers/ibmvnic-Ensure-that-buffers-are-NULL-after-free.patch.
- Refresh
  patches.drivers/ibmvnic-Fix-rx-queue-cleanup-for-non-fatal-resets.patch.
- Refresh
  patches.drivers/ibmvnic-queue-reset-when-CRQ-gets-closed-during-rese.patch.
- Refresh
  patches.suse/0002-objtool-x86-Add-several-functions-and-files-to-the-o.patch.
- Refresh
  patches.suse/v2-2-9-arm64-kpti-Make-use-of-nG-dependent-on-arm64_kernel_unmapped_at_el0.patch.
- scripts/git_sort/git_sort.py:
- commit 9adbb9d
* Sat Feb 10 2018 lduncan@suse.com
- qedi: Cleanup local str variable (bsc#1079977).
- qedi: Fix truncation of CHAP name and secret (bsc#1079977).
- scsi: qedi: Drop cqe response during connection recovery
  (bsc#1079977).
- scsi: qedi: Use zeroing allocator instead of allocator/memset
  (bsc#1079977).
- scsi: qedi: Fix a possible sleep-in-atomic bug in
  qedi_process_tmf_resp (bsc#1079977).
- cxgbit: Abort the TCP connection in case of data out timeout
  (bsc#1080021).
- scsi: qedi: Delete redundant variables (bsc#1079977).
- commit e417c01
* Fri Feb  9 2018 jeffm@suse.com
- config: resync arm64/vanilla
- commit e129956
* Fri Feb  9 2018 jdelvare@suse.de
- x86/acpi: Reduce code duplication in mp_override_legacy_irq()
  (bsc#1061680 bsc#1068984 bsc#1074099).
- x86/acpi: Handle SCI interrupts above legacy space gracefully
  (bsc#1061680 bsc#1068984 bsc#1074099).
- commit d3814df
* Fri Feb  9 2018 duwe@suse.de
- crypto: pcrypt - fix freeing pcrypt instances
  (bsc#1077402,CVE-2017-18075).
- commit 8e9d0d1
* Fri Feb  9 2018 jthumshirn@suse.de
- Refresh
  patches.drivers/scsi-qla2xxx-Add-XCB-counters-to-debugfs.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Add-ability-to-send-PRLO.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Add-ability-to-use-GPNFT-GNNFT-for-RSCN.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Add-boundary-checks-for-exchanges-to-be.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Add-lock-protection-around-host-lookup.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Add-option-for-use-reserve-exch-for-ELS.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Add-retry-limit-for-fabric-scan-logic.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Add-switch-command-to-simplify-fabric-d.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Allow-relogin-and-session-creation-afte.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Allow-target-mode-to-accept-PRLI-in-dua.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Chip-reset-uses-wrong-lock-during-IO-fl.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Clear-loop-id-after-delete.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Defer-processing-of-GS-IOCB-calls.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Delay-loop-id-allocation-at-login.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Don-t-call-dma_free_coherent-with-IRQ-d.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Enable-ATIO-interrupt-handshake-for-ISP.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-Firmware-dump-size-for-Extended-log.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-GPNFT-GNNFT-error-handling.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-NPIV-host-cleanup-in-target-mode.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-NULL-pointer-access-for-fcport-stru.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-NULL-pointer-crash-due-to-probe-fai.patch.
- Refresh patches.drivers/scsi-qla2xxx-Fix-PRLI-state-check.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-Relogin-being-triggered-too-fast.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-abort-command-deadlock-due-to-spinl.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-gpnid-error-processing.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-login-state-machine-freeze.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-login-state-machine-stuck-at-GPDB.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-logo-flag-for-qlt_free_session_done.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-memory-leak-in-dual-target-mode.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-queue-ID-for-async-abort-with-Multi.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-re-login-for-Nport-Handle-in-use.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-scan-state-field-for-fcport.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-session-cleanup-for-N2N.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-smatch-warning-in-qla25xx_delete_-r.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-system-crash-for-Notify-ack-timeout.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-system-crash-in-qlt_plogi_ack_unref.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-warning-during-port_name-debug-prin.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-warning-for-code-intentation-in-__q.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-warning-in-qla2x00_async_iocb_timeo.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Increase-verbosity-of-debug-messages-lo.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Migrate-switch-registration-commands-aw.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Move-session-delete-to-driver-work-queu.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Move-work-element-processing-out-of-DPC.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Prevent-multiple-active-discovery-comma.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Prevent-relogin-trigger-from-sending-to.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Properly-extract-ADISC-error-codes.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Reduce-the-use-of-terminate-exchange.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Reduce-trace-noise-for-Async-Events.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Relogin-to-target-port-on-a-cable-swap.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Remove-aborting-ELS-IOCB-call-issued-as.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Remove-session-creation-redundant-code.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Remove-unused-argument-from-qlt_schedul.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Replace-GPDB-with-async-ADISC-command.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Replace-fcport-alloc-with-qla2x00_alloc.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Retry-switch-command-on-time-out.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Serialize-GPNID-for-multiple-RSCN.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Serialize-session-deletion-by-using-wor.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Serialize-session-free-in-qlt_free_sess.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Skip-IRQ-affinity-for-Target-QPairs.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Suppress-gcc-7-fall-through-warnings.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Tweak-resource-count-dump.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Update-driver-version-to-10.00.00.03-k.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Update-driver-version-to-10.00.00.04-k.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Update-driver-version-to-10.00.00.05-k.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Use-IOCB-path-to-submit-Control-VP-MBX-.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Use-chip-reset-to-bring-down-laser-on-u.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Use-known-NPort-ID-for-Management-Serve.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Use-shadow-register-for-ISP27XX.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Use-zeroing-allocator-rather-than-alloc.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-remove-duplicate-includes.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-remove-redundant-assignment-of-d.patch.
- commit 8ad9d97
* Fri Feb  9 2018 jthumshirn@suse.de
- scsi: qla2xxx: Fix incorrect handle for abort IOCB
  (bsc#1077338).
- scsi: qla2xxx: Fix double free bug after firmware timeout
  (bsc#1077338).
- scsi: qla2xxx: Fix a locking imbalance in qlt_24xx_handle_els()
  (bsc#1077338).
- scsi: qla2xxx: Avoid triggering undefined behavior in
  qla2x00_mbx_completion() (bsc#1077338).
- commit 920953f
* Fri Feb  9 2018 jthumshirn@suse.de
- scripts/git_sort/git_sort.py: add mkp/scsi.git 4.16/scsi-fixes
- commit db9b61f
* Fri Feb  9 2018 jthumshirn@suse.de
- scsi: qla2xxx: Fix logo flag for qlt_free_session_done()
  (bsc#1077338).
- scsi: qla2xxx: Update driver version to 10.00.00.05-k
  (bsc#1077338).
- scsi: qla2xxx: Add XCB counters to debugfs (bsc#1077338).
- scsi: qla2xxx: Fix queue ID for async abort with Multiqueue
  (bsc#1077338).
- scsi: qla2xxx: Fix warning for code intentation in
  __qla24xx_handle_gpdb_event() (bsc#1077338).
- scsi: qla2xxx: Fix warning during port_name debug print
  (bsc#1077338).
- scsi: qla2xxx: Fix warning in qla2x00_async_iocb_timeout()
  (bsc#1077338).
- scsi: qla2xxx: Fix NULL pointer crash due to probe failure
  (bsc#1077338).
- scsi: qla2xxx: remove redundant assignment of d (bsc#1077338).
- scsi: qla2xxx: Use zeroing allocator rather than
  allocator/memset (bsc#1077338).
- scsi: qla2xxx: Update driver version to 10.00.00.04-k
  (bsc#1077338).
- scsi: qla2xxx: Serialize session free in qlt_free_session_done
  (bsc#1077338).
- scsi: qla2xxx: Serialize session deletion by using work_lock
  (bsc#1077338).
- scsi: qla2xxx: Remove unused argument from
  qlt_schedule_sess_for_deletion() (bsc#1077338).
- scsi: qla2xxx: Prevent relogin trigger from sending too many
  commands (bsc#1077338).
- scsi: qla2xxx: Prevent multiple active discovery commands per
  session (bsc#1077338).
- scsi: qla2xxx: Add retry limit for fabric scan logic
  (bsc#1077338).
- scsi: qla2xxx: Delay loop id allocation at login (bsc#1077338).
- scsi: qla2xxx: Increase verbosity of debug messages logged
  (bsc#1077338).
- scsi: qla2xxx: Allow relogin and session creation after reset
  (bsc#1077338).
- scsi: qla2xxx: Add ability to use GPNFT/GNNFT for RSCN handling
  (bsc#1077338).
- scsi: qla2xxx: Properly extract ADISC error codes (bsc#1077338).
- scsi: qla2xxx: Fix GPNFT/GNNFT error handling (bsc#1077338).
- scsi: qla2xxx: Remove session creation redundant code
  (bsc#1077338).
- scsi: qla2xxx: Migrate switch registration commands away from
  mailbox interface (bsc#1077338).
- scsi: qla2xxx: Fix login state machine freeze (bsc#1077338).
- scsi: qla2xxx: Reduce trace noise for Async Events
  (bsc#1077338).
- scsi: qla2xxx: Reduce the use of terminate exchange
  (bsc#1077338).
- scsi: qla2xxx: Add lock protection around host lookup
  (bsc#1077338).
- scsi: qla2xxx: Add switch command to simplify fabric discovery
  (bsc#1077338).
- scsi: qla2xxx: Use known NPort ID for Management Server login
  (bsc#1077338).
- scsi: qla2xxx: Fix session cleanup for N2N (bsc#1077338).
- scsi: qla2xxx: Tweak resource count dump (bsc#1077338).
- scsi: qla2xxx: Allow target mode to accept PRLI in dual mode
  (bsc#1077338).
- scsi: qla2xxx: Don't call dma_free_coherent with IRQ disabled
  (bsc#1077338).
- scsi: qla2xxx: Add ability to send PRLO (bsc#1077338).
- scsi: qla2xxx: Add option for use reserve exch for ELS
  (bsc#1077338).
- scsi: qla2xxx: Use shadow register for ISP27XX (bsc#1077338).
- scsi: qla2xxx: Enable ATIO interrupt handshake for ISP27XX
  (bsc#1077338).
- scsi: qla2xxx: Move work element processing out of DPC thread
  (bsc#1077338).
- scsi: qla2xxx: Replace GPDB with async ADISC command
  (bsc#1077338).
- scsi: qla2xxx: Fix Firmware dump size for Extended login and
  Exchange Offload (bsc#1077338).
- scsi: qla2xxx: Chip reset uses wrong lock during IO flush
  (bsc#1077338).
- scsi: qla2xxx: Add boundary checks for exchanges to be offloaded
  (bsc#1077338).
- scsi: qla2xxx: Use chip reset to bring down laser on unload
  (bsc#1077338).
- scsi: qla2xxx: Use IOCB path to submit Control VP MBX command
  (bsc#1077338).
- scsi: qla2xxx: Fix NULL pointer access for fcport structure
  (bsc#1077338).
- scsi: qla2xxx: Fix smatch warning in
  qla25xx_delete_{rsp|req}_que (bsc#1077338).
- scsi: qla2xxx: remove duplicate includes (bsc#1077338).
- scsi: qla2xxx: Suppress gcc 7 fall-through warnings
  (bsc#1077338).
- scsi: qla2xxx: Update driver version to 10.00.00.03-k
  (bsc#1077338).
- scsi: qla2xxx: Fix memory leak in dual/target mode
  (bsc#1077338).
- scsi: qla2xxx: Fix system crash in qlt_plogi_ack_unref
  (bsc#1077338).
- scsi: qla2xxx: Remove aborting ELS IOCB call issued as part
  of timeout (bsc#1077338).
- scsi: qla2xxx: Defer processing of GS IOCB calls (bsc#1077338).
- scsi: qla2xxx: Clear loop id after delete (bsc#1077338).
- scsi: qla2xxx: Fix scan state field for fcport (bsc#1077338).
- scsi: qla2xxx: Replace fcport alloc with qla2x00_alloc_fcport
  (bsc#1077338).
- scsi: qla2xxx: Fix abort command deadlock due to spinlock
  (bsc#1077338).
- scsi: qla2xxx: Fix PRLI state check (bsc#1077338).
- scsi: qla2xxx: Fix Relogin being triggered too fast
  (bsc#1077338).
- scsi: qla2xxx: Relogin to target port on a cable swap
  (bsc#1077338).
- scsi: qla2xxx: Fix NPIV host cleanup in target mode
  (bsc#1077338).
- scsi: qla2xxx: Fix login state machine stuck at GPDB
  (bsc#1077338).
- scsi: qla2xxx: Serialize GPNID for multiple RSCN (bsc#1077338).
- scsi: qla2xxx: Retry switch command on time out (bsc#1077338).
- scsi: qla2xxx: Fix re-login for Nport Handle in use
  (bsc#1077338).
- scsi: qla2xxx: Skip IRQ affinity for Target QPairs
  (bsc#1077338).
- scsi: qla2xxx: Move session delete to driver work queue
  (bsc#1077338).
- scsi: qla2xxx: Fix gpnid error processing (bsc#1077338).
- scsi: qla2xxx: Fix system crash for Notify ack timeout handling
  (bsc#1077338).
- scsi: qla2xxx: Fix oops in qla2x00_probe_one error path
  (bsc#1077338).
- scsi: qla2xxx: Fix system crash while triggering FW dump
  (bsc#1077338).
- commit e0a937c
* Fri Feb  9 2018 mkubecek@suse.cz
- tap: fix use-after-free (bsc#1076830).
- l2tp: don't use l2tp_tunnel_find() in l2tp_ip and l2tp_ip6
  (bsc#1076830).
- l2tp: fix l2tp_eth module loading (bsc#1076830).
- tipc: use only positive error codes in messages (bsc#1076830).
- tcp: fastopen: fix on syn-data transmit failure (bsc#1076830).
- sctp: do not mark sk dumped when inet_sctp_diag_fill returns
  err (bsc#1076830).
- media: rc: simplify ir_raw_event_store_edge() (bsc#1076830).
- l2tp: hold tunnel while handling genl tunnel updates
  (bsc#1076830).
- l2tp: hold tunnel while processing genl delete command
  (bsc#1076830).
- l2tp: initialise session's refcount before making it reachable
  (bsc#1076830).
- tcp: enable xmit timer fix by having TLP use time when RTO
  should fire (bsc#1076830).
- tcp: introduce tcp_rto_delta_us() helper for xmit timer fix
  (bsc#1076830).
- ipvlan: Fix 64-bit statistics seqcount initialization
  (bsc#1076830).
- commit 56fda6b
* Fri Feb  9 2018 agraf@suse.de
- Update config files (bsc#1080294)
- commit 54e4b16
* Fri Feb  9 2018 mkubecek@suse.cz
- netfilter: on sockopt() acquire sock lock only in the required
  scope (bsc#1076830).
- netfilter: ipt_CLUSTERIP: fix out-of-bounds accesses in
  clusterip_tg_check() (bsc#1076830).
- netfilter: x_tables: fix pointer leaks to userspace
  (bsc#1076830).
- tcp_bbr: fix pacing_gain to always be unity when using lt_bw
  (bsc#1076830).
- ipv6: Fix SO_REUSEPORT UDP socket with implicit sk_ipv6only
  (bsc#1076830).
- bridge: return boolean instead of integer in
  br_multicast_is_router (bsc#1076830).
- vxlan: Fix trailing semicolon (bsc#1076830).
- l2tp: fix missing print session offset info (bsc#1076830).
- xfrm: Fix xfrm_replay_overflow_offload_esn (bsc#1076830).
- rds: tcp: correctly sequence cleanup on netns deletion
  (bsc#1076830).
- rds: tcp: remove redundant function rds_tcp_conn_paths_destroy()
  (bsc#1076830).
- gso: validate gso_type in GSO handlers (bsc#1076830).
- tun: fix a memory leak for tfile->tx_array (bsc#1076830).
- mac80211_hwsim: validate number of different channels
  (bsc#1076830).
- sctp: reinit stream if stream outcnt has been change by sinit
  in sendmsg (bsc#1076830).
- esp: Fix GRO when the headers not fully in the linear part of
  the skb (bsc#1076830).
- xfrm: skip policies marked as dead while rehashing
  (bsc#1076830).
- tcp: remove buggy call to tcp_v6_restore_cb() (bsc#1076830).
- ipvlan: always use the current L2 addr of the master
  (bsc#1076830).
- tcp: do not mangle skb->cb in tcp_make_synack() (bsc#1076830).
- l2tp: check ps->sock before running pppol2tp_session_ioctl()
  (bsc#1076830).
- l2tp: fix race condition in l2tp_tunnel_delete (bsc#1076830).
- net: use inet6_rcv_saddr to compare sockets (bsc#1076830).
- tcp: remove two unused functions (bsc#1076830).
- xfrm_user: fix info leak in copy_user_offload() (bsc#1076830).
- l2tp: hold tunnel while handling genl TUNNEL_GET commands
  (bsc#1076830).
- l2tp: hold tunnel while looking up sessions in l2tp_netlink
  (bsc#1076830).
- tipc: reassign pointers after skb reallocation / linearization
  (bsc#1076830).
- tipc: remove subscription references only for pending timers
  (bsc#1076830).
- bridge: allow ext learned entries to change ports (bsc#1076830).
- net: reflect mark on tcp syn ack packets (bsc#1076830).
- rds: tcp: set linger to 1 when unloading a rds-tcp
  (bsc#1076830).
- rds: tcp: Set linger when rejecting an incoming conn in
  rds_tcp_accept_one (bsc#1076830).
- commit bd4b81f
* Fri Feb  9 2018 agraf@suse.de
- s390/perf: fix problem state detection (bsc#1077761).
- commit da7a2a3
* Fri Feb  9 2018 agraf@suse.de
- Run scripts/series_sort.py.
- commit 22e3d2b
* Fri Feb  9 2018 agraf@suse.de
- Update config files: Enable CONFIG_HISILICON_ERRATUM_161600802 on arm64
- commit cceb161
* Fri Feb  9 2018 msuchanek@suse.de
- ibmvnic: queue reset when CRQ gets closed during reset
  (bsc#1080263).
- commit 75132a4
* Fri Feb  9 2018 mbrugger@suse.com
- arm64: idmap: Use "awx" flags for .idmap.text .pushsection
  directives (bsc#1068032).
- Update config files.
- arm64: entry: Reword comment about post_ttbr_update_workaround
  (bsc#1068032).
- arm64: Force KPTI to be disabled on Cavium ThunderX
  (bsc#1068032).
- patches.suse/arm64-add-PTE_ADDR_MASK.patch: (bsc#1068032).
- arm64: kpti: Add ->enable callback to remap swapper using nG
  mappings (bsc#1068032).
- arm64: mm: Permit transitioning from Global to Non-Global
  without BBM (bsc#1068032).
- arm64: kpti: Make use of nG dependent on
  arm64_kernel_unmapped_at_el0() (bsc#1068032).
- arm64: Add software workaround for Falkor erratum 1041
  (bsc#1068032).
- commit 057a1ba
* Fri Feb  9 2018 agraf@suse.de
- arm64: Use physical counter for in-kernel reads when booted
  in EL2 (bsc#1077761).
- arm64: Implement arch_counter_get_cntpct to read the physical
  counter (bsc#1077761).
- commit 9467ba3
* Fri Feb  9 2018 jthumshirn@suse.de
- fix unbalanced page refcounting in bio_map_user_iov (bsc#1062568
  CVE-2017-12190).
- commit a42b8fb
* Fri Feb  9 2018 agraf@suse.de
- KVM: PPC: Book3S HV: Branch inside feature section
  (bsc#1077761).
- commit 3577581
* Fri Feb  9 2018 agraf@suse.de
- irqchip/gic-v4: Add forward definition of struct irq_domain_ops
  (FATE#323954).
- commit 286a0c1
* Fri Feb  9 2018 agraf@suse.de
- irqchip/gic-v3: pr_err() strings should end with newlines
  (FATE#323954).
- commit eac0d6c
* Fri Feb  9 2018 agraf@suse.de
- irqchip/gic-v3: Fix ppi-partitions lookup (FATE#323954).
- commit 8fafdca
* Fri Feb  9 2018 agraf@suse.de
- irqchip/gic-v4: Clear IRQ_DISABLE_UNLAZY again if mapping fails
  (FATE#323954).
- commit fe1e3f4
* Fri Feb  9 2018 agraf@suse.de
- KVM: arm/arm64: Check that system supports split eoi/deactivate
  (FATE#323954).
- commit 595c1eb
* Fri Feb  9 2018 agraf@suse.de
- arm64/sve: System register and exception syndrome definitions
  (FATE#323954).
- commit f07e79a
* Fri Feb  9 2018 agraf@suse.de
- irqchip/gic-v3-its: Fix VPE activate callback return value
  (FATE#323954).
- commit a04ec1d
* Fri Feb  9 2018 agraf@suse.de
- irqchip/gic: Deal with broken firmware exposing only 4kB of
  GICv2 CPU interface (FATE#323954).
- commit 01bd7b0
* Fri Feb  9 2018 agraf@suse.de
- irqchip/gic-v3-its: Setup VLPI properties at map time
  (FATE#323954).
- commit a21da0f
* Fri Feb  9 2018 agraf@suse.de
- irqchip/gic-v3-its: Update effective affinity on VPE mapping
  (FATE#323954).
- commit dc3a515
* Fri Feb  9 2018 agraf@suse.de
- irqchip/gic-v3-its: Only send VINVALL to a single ITS
  (FATE#323954).
- commit 5ecdea0
* Fri Feb  9 2018 agraf@suse.de
- irqchip/gic-v3-its: Limit scope of VPE mapping to be per ITS
  (FATE#323954).
- commit 413611f
* Fri Feb  9 2018 agraf@suse.de
- irqchip/gic-v3-its: Make its_send_vmapp operate on a single ITS
  (FATE#323954).
- commit 9941246
* Fri Feb  9 2018 agraf@suse.de
- irqchip/gic-v3-its: Make its_send_vinvall operate on a single
  ITS (FATE#323954).
- commit 70b8ac8
* Fri Feb  9 2018 agraf@suse.de
- irqchip/gic-v3-its: Make GICv4_ITS_LIST_MAX globally available
  (FATE#323954).
- commit 23467c3
* Fri Feb  9 2018 agraf@suse.de
- irqchip/gic-v3-its: Track per-ITS list number (FATE#323954).
- commit 4bd7058
* Fri Feb  9 2018 agraf@suse.de
- irqchip/gic-v3-its: Workaround HiSilicon Hip07 redistributor
  addressing (FATE#323954).
- Refresh
  patches.suse/arm64-Add-software-workaround-for-Falkor-erratum-104.patch.
- commit 0a26906
* Thu Feb  8 2018 brogers@suse.com
- supported.conf: add drivers/firmware/qemu_fw_cfg
  It enables ability for handling of guest crash analysis
  (KVM), along with other uses. (bsc#1077919)
- commit 36c01d0
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its: Pass its_node pointer to each command
  builder (FATE#323954).
- commit d719157
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3: Add support for Range Selector (RS) feature
  (FATE#323954).
- commit 706f089
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its: Add missing changes to support 52bit
  physical address (FATE#323954).
- commit e8e419f
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its: Fix the incorrect parsing of VCPU table size
  (FATE#323954).
- commit 511523a
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its: Fix the incorrect BUG_ON in
  its_init_vpe_domain() (FATE#323954).
- commit f0aa0ed
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v4: Fix building with ancient gcc (FATE#323954).
- commit 1d16c51
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3: Iterate over possible CPUs by
  for_each_possible_cpu() (FATE#323954).
- commit ebcfbbc
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic: Make irq_chip const (FATE#323954).
- commit 2d5ac36
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3: Advertise GICv4 support to KVM (FATE#323954).
- commit 40f9623
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v4: Enable low-level GICv4 operations (FATE#323954).
- commit 84b3f27
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v4: Add some basic documentation (FATE#323954).
- commit ec6f959
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v4: Add VLPI configuration interface (FATE#323954).
- commit 86e4f8e
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v4: Add VPE command interface (FATE#323954).
- commit 73856c3
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v4: Add per-VM VPE domain creation (FATE#323954).
- commit 187e199
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its: Set implementation defined bit to enable
  VLPIs (FATE#323954).
- commit 3df2699
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its: Allow doorbell interrupts to be
  injected/cleared (FATE#323954).
- commit 4a1320e
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its: Move pending doorbell after VMOVP
  (FATE#323954).
- commit 7bf8955
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its: Add device proxy for VPE management if
  !DirectLpi (FATE#323954).
- commit 7814bf0
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its: Make LPI allocation optional on device
  creation (FATE#323954).
- commit af01bb0
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its: Add VPE interrupt masking (FATE#323954).
- commit 3e0e018
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its: Add VPE affinity changes (FATE#323954).
- commit d562b75
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its: Add VPE invalidation hook (FATE#323954).
- commit 0ab99d4
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its: Add VPE scheduling (FATE#323954).
- commit 886a69b
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its: Add VPENDBASER/VPROPBASER accessors
  (FATE#323954).
- commit a555020
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its: Add VPE irq domainactivation (FATE#323954).
- commit 1e0a736
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its: Add VPE irq domain allocation/teardown
  (FATE#323954).
- commit 5012fa3
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its: Add VPE domain infrastructure (FATE#323954).
- commit b171b80
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its: Add VLPI configuration handling
  (FATE#323954).
- commit 1a53a79
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its: Add VLPI map/unmap operations (FATE#323954).
- commit 39bdd8c
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its: Add VLPI configuration hook (FATE#323954).
- commit 1df4f9e
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its: Add GICv4 ITS command definitions
  (FATE#323954).
- commit 754bd85
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v4: Add management structure definitions
  (FATE#323954).
- commit 3e4d038
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its: Generalize LPI configuration (FATE#323954).
- commit c322f9d
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its: Generalize device table allocation
  (FATE#323954).
- commit d807afe
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its: Rework LPI freeing (FATE#323954).
- commit f77ae34
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its: Split out pending table allocation
  (FATE#323954).
- commit 94bff76
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its: Allow use of indirect VCPU tables
  (FATE#323954).
- commit e7ee4bb
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its: Split out property table allocation
  (FATE#323954).
- commit af26837
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its: Implement irq_set_irqchip_state for pending
  state (FATE#323954).
- Refresh
  patches.suse/irqchip-gic-v3-its-Add-post-mortem-info-on-command-t.patch.
- commit 321d3a8
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its: Macro-ize its_send_single_command
  (FATE#323954).
- Refresh
  patches.suse/irqchip-gic-v3-Add-workaround-for-Synquacer-pre-ITS-558b0165.patch.
- Refresh
  patches.suse/irqchip-gic-v3-its-Add-post-mortem-info-on-command-t.patch.
- commit d80fdde
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its: Add probing for VLPI properties
  (FATE#323954).
- Refresh
  patches.suse/irqchip-gic-v3-Probe-device-ID-space-before-quirks-h.patch.
- Refresh
  patches.suse/irqchip-gic-v3-Add-workaround-for-Synquacer-pre-ITS-558b0165.patch
- commit a385b0d
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its: Move LPI definitions around (FATE#323954).
- commit 29c36a2
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3: Add VLPI/DirectLPI discovery (FATE#323954).
- commit 6babec0
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3: Add redistributor iterator (FATE#323954).
- commit ee41ab4
* Thu Feb  8 2018 agraf@suse.de
- genirq: Let irq_set_vcpu_affinity() iterate over hierarchy
  (FATE#323954).
- commit bb7657a
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its: Properly handle command queue wrapping
  (FATE#323954).
- commit b883322
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its: Report that effective affinity is a single
  target (FATE#323954).
- commit 6f8bd53
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3: Report that effective affinity is a single
  target (FATE#323954).
- commit 8954ba3
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic: Report that effective affinity is a single target
  (FATE#323954).
- commit 7ca4347
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its-platform-msi: Fix msi-parent parsing loop
  (FATE#323954).
- commit b0e243c
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its: Allow GIC ITS number more than MAX_NUMNODES
  (FATE#323954).
- commit 36735a4
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic: Ensure we have an ISB between ack and ->handle_irq
  (FATE#323954).
- commit f7f8f59
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its: Remove ACPICA version check for ACPI NUMA
  (FATE#323954).
- commit ad1cbf1
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3: Honor forced affinity setting (FATE#323954).
- commit 76565c7
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3: Report failures in gic_irq_domain_alloc
  (FATE#323954).
- commit a5ca30a
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v2: Report failures in gic_irq_domain_alloc
  (FATE#323954).
- commit cc989f5
* Thu Feb  8 2018 agraf@suse.de
- iommu/arm-smmu-v3: Enable ACPI based HiSilicon CMD_PREFETCH
  quirk(erratum 161010701) (FATE#323954).
- commit c2ed429
* Thu Feb  8 2018 agraf@suse.de
- arm64: Add MIDR values for Cavium cn83XX SoCs (FATE#323954).
- commit 3d86f32
* Thu Feb  8 2018 agraf@suse.de
- arm64: Add a facility to turn an ESR syndrome into a sysreg
  encoding (FATE#323954).
- commit b7a0ad9
* Thu Feb  8 2018 brogers@suse.com
- Update config files.
- commit 038084e
* Thu Feb  8 2018 agraf@suse.de
- ACPICA: Add support for new SRAT subtable (FATE#323954).
- commit 107759b
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its: Don't assume GICv3 hardware supports 16bit
  INTID (FATE#323954).
- commit 41c997a
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its: Add ACPI NUMA node mapping (FATE#323954).
- commit e83e0cc
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its-platform-msi: Make of_device_ids const
  (FATE#323954).
- commit ac4f6c8
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its: Make of_device_ids const (FATE#323954).
- commit cdca6a2
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gicv3-its: Skip irq affinity setting when target cpu
  is the same as current setting (FATE#323954).
- commit 8566246
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its: Fix MSI alias accounting (FATE#323954).
- commit 90ccab5
* Thu Feb  8 2018 agraf@suse.de
- genirq/irqdomain: Remove auto-recursive hierarchy support
  (FATE#323954).
- commit b4e692f
* Thu Feb  8 2018 agraf@suse.de
- irqchip/MSI: Use irq_domain_update_bus_token instead of an
  open coded access (FATE#323954).
- Refresh
  patches.suse/irqchip-gic-v3-Add-workaround-for-Synquacer-pre-ITS-558b0165.patch.
- commit c2912d8
* Thu Feb  8 2018 agraf@suse.de
- genirq/irqdomain: Add irq_domain_update_bus_token helper
  (FATE#323954).
- commit bbab0e5
* Thu Feb  8 2018 agraf@suse.de
- s390/mm: remove incorrect _REGION3_ENTRY_ORIGIN define
  (bsc#1077761).
- commit 7a77b31
* Thu Feb  8 2018 agraf@suse.de
- Add stubs to ignore effective IRQ affinity (FATE#323954).
- commit ffd094d
* Thu Feb  8 2018 brogers@suse.com
- s390: fix alloc_pgste check in init_new_context again
  (bsc#1077706).
- s390/kvm: avoid global config of vm.alloc_pgste=1 (bsc#1077706).
- commit 504a71f
* Thu Feb  8 2018 msuchanek@suse.de
- rpm/kernel-binary.spec.in: Also require m4 for build.
- commit 0d7b4b3
* Thu Feb  8 2018 msuchanek@suse.de
- ibmvnic: Ensure that buffers are NULL after free (bsc#1080014).
- ibmvnic: Fix rx queue cleanup for non-fatal resets
  (bsc#1080014).
- commit 9627b8d
* Thu Feb  8 2018 msuchanek@suse.de
- Refresh patches.drivers/ibmvnic-fix-empty-firmware-version-and-errors-cleanu.patch.
- commit 83a5eee
* Thu Feb  8 2018 agraf@suse.de
- Move ARM IOMMU patches to sorted section
- commit 3aa94a7
* Thu Feb  8 2018 jslaby@suse.cz
- Documentation: Document array_index_nospec (bsc#1068032
  CVE-2017-5753).
- array_index_nospec: Sanitize speculative array de-references
  (bsc#1068032 CVE-2017-5753).
- x86: Implement array_index_mask_nospec (bsc#1068032
  CVE-2017-5753).
- x86: Introduce barrier_nospec (bsc#1068032 CVE-2017-5753).
- x86: Introduce __uaccess_begin_nospec() and uaccess_try_nospec
  (bsc#1068032 CVE-2017-5753).
- x86/usercopy: Replace open coded stac/clac with
  __uaccess_{begin, end} (bsc#1068032 CVE-2017-5753).
- x86/syscall: Sanitize syscall table de-references under
  speculation (bsc#1068032 CVE-2017-5753).
- nl80211: Sanitize array index in parse_txq_params (bsc#1068032
  CVE-2017-5753).
- x86/spectre: Report get_user mitigation for spectre_v1
  (bsc#1068032 CVE-2017-5753).
- Refresh
  patches.arch/23-x86-retpoline-entry-convert-entry-assembler-indirect-jumps.patch.
- Refresh
  patches.suse/0002-objtool-x86-Add-several-functions-and-files-to-the-o.patch.
- Refresh
  patches.suse/0007-x86-entry-64-Add-unwind-hint-annotations.patch.
- Delete patches.suse/0001-Documentation-document-array_ptr.patch.
- Delete
  patches.suse/0002-asm-nospec-array_ptr-sanitize-speculative-array-de-r.patch.
- Delete
  patches.suse/0003-locking-barriers-introduce-new-observable-speculatio.patch.
- Delete patches.suse/0003-x86-implement-array_ptr_mask.patch.
- Delete
  patches.suse/0004-x86-introduce-__uaccess_begin_nospec-and-ifence.patch.
- Delete
  patches.suse/0005-x86-bpf-jit-prevent-speculative-execution-when-JIT-i.patch.
- Delete
  patches.suse/0006-uvcvideo-prevent-speculative-execution.patch.
- Delete
  patches.suse/0007-carl9170-prevent-speculative-execution.patch.
- Delete
  patches.suse/0007-x86-narrow-out-of-bounds-syscalls-to-sys_read-under-.patch.
- Delete
  patches.suse/0008-p54-prevent-speculative-execution.patch.
- Delete
  patches.suse/0009-qla2xxx-prevent-speculative-execution.patch.
- Delete
  patches.suse/0010-cw1200-prevent-speculative-execution.patch.
- Delete
  patches.suse/0010-nl80211-sanitize-array-index-in-parse_txq_params.patch.
- Delete
  patches.suse/0011-Thermal-int340x-prevent-speculative-execution.patch.
- Delete
  patches.suse/0012-ipv4-prevent-speculative-execution.patch.
- Delete
  patches.suse/0013-ipv6-prevent-speculative-execution.patch.
- Delete patches.suse/0014-fs-prevent-speculative-execution.patch.
- Delete
  patches.suse/0015-net-mpls-prevent-speculative-execution.patch.
- Delete
  patches.suse/0016-udf-prevent-speculative-execution.patch.
- Delete
  patches.suse/0017-userns-prevent-speculative-execution.patch.
  Replace spectre v1 by the upstream solution.
  /sys/devices/system/cpu/vulnerabilities/spectre_v1 now also has the
  proper text.
- commit fa33561
* Thu Feb  8 2018 bp@suse.de
- kprobes/x86: Blacklist indirect thunk functions for kprobes
  (bsc#1068032 CVE-2017-5754).
- kprobes/x86: Disable optimizing on the function jumps to
  indirect thunk (bsc#1068032 CVE-2017-5754).
- KVM: VMX: Make indirect call speculation safe (bsc#1068032
  CVE-2017-5754).
- KVM: x86: Make indirect calls in emulator speculation safe
  (bsc#1068032 CVE-2017-5754).
- module/retpoline: Warn about missing retpoline in module
  (bsc#1068032 CVE-2017-5754).
- retpoline: Introduce start/end markers of indirect thunk
  (bsc#1068032 CVE-2017-5754).
- x86/cpufeature: Blacklist SPEC_CTRL/PRED_CMD on early Spectre
  v2 microcodes (bsc#1068032 CVE-2017-5754).
- x86/cpufeatures: Add AMD feature bits for Speculation Control
  (bsc#1068032 CVE-2017-5754).
- x86/cpufeatures: Clean up Spectre v2 related CPUID flags
  (bsc#1068032 CVE-2017-5754).
- x86/msr: Add definitions for new speculation control MSRs
  (bsc#1068032 CVE-2017-5754).
- x86/pti: Do not enable PTI on CPUs which are not vulnerable
  to Meltdown (bsc#1068032 CVE-2017-5754).
- x86/retpoline: Optimize inline assembler for vmexit_fill_RSB
  (bsc#1068032 CVE-2017-5754).
- x86/retpoline: Simplify vmexit_fill_RSB() (bsc#1068032
  CVE-2017-5754).
- x86/speculation: Add basic IBPB (Indirect Branch Prediction
  Barrier) support (bsc#1068032 CVE-2017-5754).
- blacklist.conf:
- Refresh
  patches.arch/x86-bugs-drop-one-mitigation-from-dmesg.patch.
- Refresh
  patches.arch/x86-mce-make-machine-check-speculation-protected.patch.
- commit 4d56a2a
* Thu Feb  8 2018 jthumshirn@suse.de
- kernel: fix rwlock implementation (bnc#1079840, LTC#164371).
- commit bcb7294
* Thu Feb  8 2018 jthumshirn@suse.de
- fs/proc/kcore.c: use probe_kernel_read() instead of memcpy()
  (bsc#1079840).
- commit 45c8725
* Thu Feb  8 2018 hare@suse.de
- KVM: s390: add proper locking for CMMA migration bitmap (bsc#1079840).
- KVM: s390: prevent buffer overrun on memory hotplug during migration (bsc#1079840).
- KVM: s390: fix cmma migration for multiple memory slots (bsc#1079840).
- ata: pata_artop: remove redundant initialization of pio (bsc#1079840).
- blk-mq: attempt to fix atomic flag memory ordering
  (bsc#1079840).
- s390/guarded storage: fix possible memory corruption
  (bsc#1079840).
- s390/runtime instrumention: fix possible memory corruption
  (bsc#1079840).
- s390/mm: make pmdp_invalidate() do invalidation only
  (bsc#1079840).
- s390/perf: fix bug when creating per-thread event (bsc#1079840).
- block: Relax a check in blk_start_queue() (bsc#1079840).
- Documentation: DMA API: fix a typo in a function name
  (bsc#1079840).
- kernel-doc: describe the ``literal`` syntax (bsc#1079840).
- commit 51ba0ad
* Thu Feb  8 2018 jthumshirn@suse.de
- PCI: vmd: Remove IRQ affinity so we can allocate more IRQs
  (bsc#1079887).
- commit 2023869
* Thu Feb  8 2018 oneukum@suse.com
- usbip: fix stub_rx: get_pipe() to validate endpoint number
  (bsc#1078673 CVE-2017-16912).
- commit 32f2c09
* Thu Feb  8 2018 agraf@suse.de
- Update config files.
- commit 68baef6
* Thu Feb  8 2018 hare@suse.de
- scsi: megaraid_sas: NVMe passthrough command support
  (bsc#1077408).
- scsi: megaraid_sas: driver version upgrade (bsc#1077408).
- scsi: megaraid_sas: re-work DCMD refire code (bsc#1077408).
- scsi: megaraid_sas: Expose fw_cmds_outstanding through sysfs
  (bsc#1077408).
- scsi: megaraid_sas: Selectively apply stream detection based
  on IO type (bsc#1077408).
- scsi: megaraid_sas: Update LD map after populating drv_map
  driver map copy (bsc#1077408).
- scsi: megaraid_sas: Use megasas_wait_for_adapter_operational
  to detect controller state in IOCTL path (bsc#1077408).
- scsi: megaraid_sas: Avoid firing DCMDs while OCR is in progress
  (bsc#1077408).
- scsi: megaraid_sas: unload flag should be set after
  scsi_remove_host is called (bsc#1077408).
- scsi: megaraid_sas: Error handling for invalid ldcount provided
  by firmware in RAID map (bsc#1077408).
- scsi: megaraid_sas: Reset ldio_outstanding in megasas_resume
  (bsc#1077408).
- scsi: megaraid_sas: Return the DCMD status from
  megasas_get_seq_num (bsc#1077408).
- scsi: megaraid_sas: memset IOC INIT frame using correct size
  (bsc#1077408).
- scsi: megaraid_sas: zero out IOC INIT and stream detection
  memory (bsc#1077408).
- commit 60410e5
* Thu Feb  8 2018 hare@suse.de
- Drop non-standard megaraid_sas patches
- Delete
  patches.drivers/megaraid_sas-Fallback-to-older-scanning-if-not-disks.patch.
- Delete
  patches.drivers/megaraid_sas-boot-hangs-while-LD-is-offline.patch.
- commit 4400510
* Thu Feb  8 2018 hare@suse.de
- Refresh
  patches.drivers/ibmvnic-fix-empty-firmware-version-and-errors-cleanu.patch.
- commit b3b1ac0
* Thu Feb  8 2018 hare@suse.de
- blacklist.conf: ignore mac_esp patch (bsc#1077989)
- commit efe494e
* Thu Feb  8 2018 hare@suse.de
- Refresh patches.fixes/st-fix-blk_get_queue-usage.patch.
- commit 5541263
* Thu Feb  8 2018 jthumshirn@suse.de
- Refresh
  patches.drivers/ibmvnic-fix-empty-firmware-version-and-errors-cleanu.patch.
- commit b3e021a
* Thu Feb  8 2018 hare@suse.de
- scsi: libfc: fix ELS request handling (bsc#1077989).
- scsi: bfa: integer overflow in debugfs (bsc#1077989).
- scsi: aacraid: Fix controller initialization failure
  (bsc#1077989).
- scsi: scsi-mq: Always unprepare before requeuing a request
  (bsc#1077989).
- scsi: zfcp: add handling for FCP_RESID_OVER to the fcp ingress
  path (bsc#1077989).
- scsi: sun_esp: fix device reference leaks (bsc#1077989).
- commit e90d3ec
* Thu Feb  8 2018 neilb@suse.com
- Refresh
  patches.fixes/0003-NFSv4-always-set-NFS_LOCK_LOST-when-a-lock-is-lost.patch.
  Add git-commit tag
- commit 1ef434c
* Thu Feb  8 2018 agraf@suse.de
- KVM: s390: add proper locking for CMMA migration bitmap
  (bsc#1077761).
- commit 9a8fac9
* Thu Feb  8 2018 agraf@suse.de
- KVM: s390: wire up bpb feature (bsc#1077761).
- commit d14cb22
* Thu Feb  8 2018 agraf@suse.de
- KVM: PPC: Book3S: Provide information about hardware/firmware
  CVE workarounds (bsc#1077761).
- commit 1e687f0
* Thu Feb  8 2018 agraf@suse.de
- KVM/x86: Fix wrong macro references of X86_CR0_PG_BIT and
  X86_CR4_PAE_BIT in kvm_valid_sregs() (bsc#1077761).
- commit 0863a2e
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm64: Fix GICv4 init when called from vgic_its_create
  (bsc#1077761).
- commit 54f74da
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: Check pagesize when allocating a hugepage at
  Stage 2 (bsc#1077761).
- commit db3eec9
* Thu Feb  8 2018 agraf@suse.de
- KVM: x86: Add memory barrier on vmcs field lookup (bsc#1077761).
- commit 973bff3
* Thu Feb  8 2018 agraf@suse.de
- KVM: x86: emulate #UD while in guest mode (bsc#1077761).
- commit 9b6aa90
* Thu Feb  8 2018 agraf@suse.de
- x86: kvm: propagate register_shrinker return code (bsc#1077761).
- commit 39dc997
* Thu Feb  8 2018 agraf@suse.de
- KVM: PPC: Book3S PR: Fix WIMG handling under pHyp (bsc#1077761).
- commit d5a5c70
* Thu Feb  8 2018 agraf@suse.de
- KVM MMU: check pending exception before injecting APF
  (bsc#1077761).
- commit dbd1b43
* Thu Feb  8 2018 agraf@suse.de
- KVM: s390: prevent buffer overrun on memory hotplug during
  migration (bsc#1077761).
- commit ce5730c
* Thu Feb  8 2018 agraf@suse.de
- KVM: s390: fix cmma migration for multiple memory slots
  (bsc#1077761).
- commit 7f0eaab
* Thu Feb  8 2018 agraf@suse.de
- kvm: vmx: Scrub hardware GPRs at VM-exit (bsc#1077761).
- commit 3ae582d
* Thu Feb  8 2018 agraf@suse.de
- kvm: x86: fix RSM when PCID is non-zero (bsc#1077761).
- commit b9c326f
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: Fix timer enable flow (bsc#1077761).
- commit e5afd2e
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: Properly handle arch-timer IRQs after
  vtimer_save_state (bsc#1077761).
- commit c3b0312
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: timer: Don't set irq as forwarded if no usable
  GIC (bsc#1077761).
- commit f3c1476
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: Fix HYP unmapping going off limits
  (bsc#1077761).
- commit d158077
* Thu Feb  8 2018 agraf@suse.de
- arm64: kvm: Prevent restoring stale PMSCR_EL1 for vcpu
  (bsc#1077761).
- commit 4363ba1
* Thu Feb  8 2018 agraf@suse.de
- KVM/x86: Check input paging mode when cs.l is set (bsc#1077761).
- commit ccf0181
* Thu Feb  8 2018 agraf@suse.de
- kvm: x86: fix WARN due to uninitialized guest FPU state
  (bsc#1077761).
- commit 35f63bf
* Thu Feb  8 2018 agraf@suse.de
- KVM: X86: Fix load RFLAGS w/o the fixed bit (bsc#1077761).
- commit 6700cda
* Thu Feb  8 2018 agraf@suse.de
- KVM: MMU: Fix infinite loop when there is no available mmu page
  (bsc#1077761).
- commit 13275e4
* Thu Feb  8 2018 agraf@suse.de
- arm64: Add software workaround for Falkor erratum 1041
  (bsc#1077761).
- commit e4dbbd7
* Thu Feb  8 2018 agraf@suse.de
- KVM: x86: fix APIC page invalidation (bsc#1077761).
- commit 4c9f820
* Thu Feb  8 2018 agraf@suse.de
- KVM: s390: Fix skey emulation permission check (bsc#1077761).
- commit 2763160
* Thu Feb  8 2018 agraf@suse.de
- KVM: s390: mark irq_state.flags as non-usable (bsc#1077761).
- commit d864d9d
* Thu Feb  8 2018 agraf@suse.de
- KVM: s390: Remove redundant license text (bsc#1077761).
- commit ed05681
* Thu Feb  8 2018 agraf@suse.de
- KVM: s390: add SPDX identifiers to the remaining files
  (bsc#1077761).
- commit 592f87d
* Thu Feb  8 2018 agraf@suse.de
- KVM: VMX: fix page leak in hardware_setup() (bsc#1077761).
- commit a03952e
* Thu Feb  8 2018 agraf@suse.de
- KVM: VMX: remove I/O port 0x80 bypass on Intel hosts
  (bsc#1077761).
- commit 2c4af04
* Thu Feb  8 2018 agraf@suse.de
- x86,kvm: remove KVM emulator get_fpu / put_fpu (bsc#1077761).
- commit abbfb8e
* Thu Feb  8 2018 agraf@suse.de
- x86,kvm: move qemu/guest FPU switching out to vcpu_run
  (bsc#1077761).
- commit 473f3e5
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: Fix broken GICH_ELRSR big endian conversion
  (bsc#1077761).
- commit 36535a5
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: kvm_arch_destroy_vm cleanups (bsc#1077761).
- commit 3ac49a7
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: Fix spinlock acquisition in vgic_set_owner
  (bsc#1077761).
- commit 0be83be
* Thu Feb  8 2018 agraf@suse.de
- kvm: arm: don't treat unavailable HYP mode as an error
  (bsc#1077761).
- commit a44e98a
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: Avoid attempting to load timer vgic state
  without a vgic (bsc#1077761).
- commit d6f7f9c
* Thu Feb  8 2018 agraf@suse.de
- kvm: arm64: handle single-step of hyp emulated mmio instructions
  (bsc#1077761).
- commit 3b2c220
* Thu Feb  8 2018 agraf@suse.de
- kvm: arm64: handle single-step during SError exceptions
  (bsc#1077761).
- commit b1b7578
* Thu Feb  8 2018 agraf@suse.de
- kvm: arm64: handle single-step of userspace mmio instructions
  (bsc#1077761).
- commit fd1574f
* Thu Feb  8 2018 agraf@suse.de
- kvm: arm64: handle single-stepping trapped instructions
  (bsc#1077761).
- commit a578072
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: debug: Introduce helper for single-step
  (bsc#1077761).
- commit eedd8be
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: vgic-v4: Only perform an unmap for valid vLPIs
  (bsc#1077761).
- commit df09a13
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: vgic-its: Check result of allocation before use
  (bsc#1077761).
- commit 62a3243
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: vgic-its: Preserve the revious read from the
  pending table (bsc#1077761).
- commit 0f4fbdc
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: vgic: Preserve the revious read from the
  pending table (bsc#1077761).
- commit 4aa2aa4
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: vgic-irqfd: Fix MSI entry allocation
  (bsc#1077761).
- commit 901d4a5
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: VGIC: extend !vgic_is_initialized guard
  (bsc#1077761).
- commit 0b58110
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: Don't enable/disable physical timer access on
  VHE (bsc#1077761).
- commit 3a8bf70
* Thu Feb  8 2018 agraf@suse.de
- KVM: Let KVM_SET_SIGNAL_MASK work as advertised (bsc#1077761).
- commit c9e7305
* Thu Feb  8 2018 agraf@suse.de
- KVM: VMX: Fix vmx->nested freeing when no SMI handler
  (bsc#1077761).
- commit fc76735
* Thu Feb  8 2018 agraf@suse.de
- KVM: VMX: Fix rflags cache during vCPU reset (bsc#1077761).
- commit 0fa5b65
* Thu Feb  8 2018 agraf@suse.de
- KVM: X86: Fix softlockup when get the current kvmclock
  (bsc#1077761).
- commit ae72d3e
* Thu Feb  8 2018 agraf@suse.de
- KVM: lapic: Fixup LDR on load in x2apic (bsc#1077761).
- commit 6dfe4f7
* Thu Feb  8 2018 agraf@suse.de
- KVM: lapic: Split out x2apic ldr calculation (bsc#1077761).
- commit fbbbd35
* Thu Feb  8 2018 agraf@suse.de
- KVM: x86: Fix CPUID function for word 6 (80000001_ECX)
  (bsc#1077761).
- commit 77b9fea
* Thu Feb  8 2018 agraf@suse.de
- KVM: nVMX: Fix vmx_check_nested_events() return value in case
  an event was reinjected to L2 (bsc#1077761).
- commit 8723e44
* Thu Feb  8 2018 agraf@suse.de
- KVM: x86: ioapic: Preserve read-only values in the redirection
  table (bsc#1077761).
- commit 5afc781
* Thu Feb  8 2018 agraf@suse.de
- KVM: x86: ioapic: Clear Remote IRR when entry is switched to
  edge-triggered (bsc#1077761).
- commit 42ed301
* Thu Feb  8 2018 agraf@suse.de
- KVM: x86: ioapic: Remove redundant check for Remote IRR in
  ioapic_set_irq (bsc#1077761).
- commit e540bbf
* Thu Feb  8 2018 agraf@suse.de
- KVM: x86: ioapic: Don't fire level irq when Remote IRR set
  (bsc#1077761).
- commit 76995b3
* Thu Feb  8 2018 agraf@suse.de
- KVM: x86: ioapic: Fix level-triggered EOI and IOAPIC reconfigure
  race (bsc#1077761).
- commit 3f52b3a
* Thu Feb  8 2018 agraf@suse.de
- KVM: x86: inject exceptions produced by x86_decode_insn
  (bsc#1077761).
- commit 529f2d4
* Thu Feb  8 2018 agraf@suse.de
- KVM: x86: Allow suppressing prints on RDMSR/WRMSR of unhandled
  MSRs (bsc#1077761).
- commit de7dd6f
* Thu Feb  8 2018 agraf@suse.de
- KVM: x86: fix em_fxstor() sleeping while in atomic
  (bsc#1077761).
- commit 7dbd3d6
* Thu Feb  8 2018 agraf@suse.de
- KVM: nVMX: Fix mmu context after VMLAUNCH/VMRESUME failure
  (bsc#1077761).
- commit 0ae6cb9
* Thu Feb  8 2018 agraf@suse.de
- KVM: nVMX: Validate the IA32_BNDCFGS on nested VM-entry
  (bsc#1077761).
- commit 2fbfa04
* Thu Feb  8 2018 agraf@suse.de
- KVM: X86: Fix operand/address-size during instruction decoding
  (bsc#1077761).
- commit d6d9f45
* Thu Feb  8 2018 agraf@suse.de
- KVM: x86: Don't re-execute instruction when not passing CR2
  value (bsc#1077761).
- commit e06fcac
* Thu Feb  8 2018 agraf@suse.de
- KVM: x86: emulator: Return to user-mode on L1 CPL=0 emulation
  failure (bsc#1077761).
- commit 25a36b8
* Thu Feb  8 2018 agraf@suse.de
- KVM: x86: Exit to user-mode on #UD intercept when emulator
  requires (bsc#1077761).
- commit 7d63739
* Thu Feb  8 2018 agraf@suse.de
- KVM: nVMX/nSVM: Don't intercept #UD when running L2
  (bsc#1077761).
- commit 2d12ec9
* Thu Feb  8 2018 agraf@suse.de
- KVM: x86: pvclock: Handle first-time write to pvclock-page
  contains random junk (bsc#1077761).
- commit a009110
* Thu Feb  8 2018 agraf@suse.de
- kvm: vmx: Allow disabling virtual NMI support (bsc#1077761).
- Refresh
  patches.arch/18-x86-mm-kvm-teach-kvm-s-vmx-code-that-cr3-isn-t-a-constant.patch.
- Refresh
  patches.arch/18.2-kvm-nvmx-fix-host_cr3-host_cr4-cache.patch.
- commit e88d160
* Thu Feb  8 2018 agraf@suse.de
- kvm: vmx: Reinstate support for CPUs without virtual NMI
  (bsc#1077761).
- Refresh
  patches.arch/18-x86-mm-kvm-teach-kvm-s-vmx-code-that-cr3-isn-t-a-constant.patch.
- Refresh
  patches.arch/18.2-kvm-nvmx-fix-host_cr3-host_cr4-cache.patch.
- commit aab882b
* Thu Feb  8 2018 agraf@suse.de
- KVM: SVM: obey guest PAT (bsc#1077761).
- commit e2a37d5
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: Don't queue VLPIs on INV/INVALL (bsc#1077761).
- commit 06b20fe
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: Fix GICv4 ITS initialization issues
  (bsc#1077761).
- commit 3a973bd
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: GICv4: Theory of operations (bsc#1077761).
- commit 6853074
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: GICv4: Enable VLPI support (bsc#1077761).
- commit b1aeb7c
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: GICv4: Prevent userspace from changing doorbell
  affinity (bsc#1077761).
- commit ff6fe51
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: GICv4: Prevent a VM using GICv4 from being saved
  (bsc#1077761).
- commit 72575b0
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: GICv4: Enable virtual cpuif if VLPIs can be
  delivered (bsc#1077761).
- commit 36a8d5b
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: GICv4: Hook vPE scheduling into vgic flush/sync
  (bsc#1077761).
- commit aef44e6
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: GICv4: Use the doorbell interrupt as an
  unblocking source (bsc#1077761).
- commit 2e2478b
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: GICv4: Add doorbell interrupt handling
  (bsc#1077761).
- commit 4a7ec1c
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: GICv4: Use pending_last as a scheduling hint
  (bsc#1077761).
- commit ea6aa7c
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: GICv4: Handle INVALL applied to a vPE
  (bsc#1077761).
- commit 81503da
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: GICv4: Propagate property updates to VLPIs
  (bsc#1077761).
- commit e61dccd
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: GICv4: Handle MOVALL applied to a vPE
  (bsc#1077761).
- commit 87310a5
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: GICv4: Handle CLEAR applied to a VLPI
  (bsc#1077761).
- commit 4d71627
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: GICv4: Propagate affinity changes to the
  physical ITS (bsc#1077761).
- commit bed266d
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: GICv4: Unmap VLPI when freeing an LPI
  (bsc#1077761).
- commit 54f9ab4
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: GICv4: Handle INT command applied to a VLPI
  (bsc#1077761).
- commit dd48bea
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: GICv4: Wire mapping/unmapping of VLPIs in VFIO
  irq bypass (bsc#1077761).
- commit 0df7b76
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: GICv4: Add init/teardown of the per-VM vPE
  irq domain (bsc#1077761).
- commit f3fa7a9
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: GICv4: Add property field and per-VM predicate
  (bsc#1077761).
- commit b3cf419
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: vITS: Add a helper to update the affinity of
  an LPI (bsc#1077761).
- commit 67e2fb3
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: vITS: Add MSI translation helpers (bsc#1077761).
- commit 2cfbfd2
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: vgic: Move kvm_vgic_destroy call around
  (bsc#1077761).
- commit c72e631
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm: Select ARM_GIC_V3 and ARM_GIC_V3_ITS (bsc#1077761).
- commit 60f0eba
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: vgic: restructure kvm_vgic_(un)map_phys_irq
  (bsc#1077761).
- commit 17738e1
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: register irq bypass consumer on ARM/ARM64
  (bsc#1077761).
- commit eef5148
* Thu Feb  8 2018 agraf@suse.de
- KVM: s390: provide a capability for AIS state migration
  (bsc#1077761).
- commit a45393d
* Thu Feb  8 2018 agraf@suse.de
- KVM: s390: clear_io_irq() requests are not expected for adapter
  interrupts (bsc#1077761).
- commit c161531
* Thu Feb  8 2018 agraf@suse.de
- KVM: s390: abstract conversion between isc and enum irq_types
  (bsc#1077761).
- commit 51df92d
* Thu Feb  8 2018 agraf@suse.de
- KVM: s390: vsie: use common code functions for pinning
  (bsc#1077761).
- commit 307cbae
* Thu Feb  8 2018 agraf@suse.de
- KVM: s390: document memory ordering for kvm_s390_vcpu_wakeup
  (bsc#1077761).
- commit ebccffe
* Thu Feb  8 2018 agraf@suse.de
- KVM: PPC: Book3S HV: Cosmetic post-merge cleanups (bsc#1077761).
- commit 59839b5
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: Unify 32bit fault injection (bsc#1077761).
- commit 37ff111
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: vgic-its: Implement KVM_DEV_ARM_ITS_CTRL_RESET
  (bsc#1077761).
- commit 24e7c77
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: vgic-its: Free caches when GITS_BASER Valid
  bit is cleared (bsc#1077761).
- commit 00d0a4f
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: vgic-its: New helper functions to free the
  caches (bsc#1077761).
- commit ef1d37c
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: vgic-its: Remove kvm_its_unmap_device
  (bsc#1077761).
- commit 5660535
* Thu Feb  8 2018 agraf@suse.de
- arm/arm64: KVM: Load the timer state when enabling the timer
  (bsc#1077761).
- commit fee14c5
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: Rework kvm_timer_should_fire (bsc#1077761).
- commit 3f72f82
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: Get rid of kvm_timer_flush_hwstate
  (bsc#1077761).
- commit 979f853
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: Avoid phys timer emulation in vcpu entry/exit
  (bsc#1077761).
- commit 02b2fcf
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: Move phys_timer_emulate function (bsc#1077761).
- commit f3f29b2
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: Use kvm_arm_timer_set/get_reg for guest register
  traps (bsc#1077761).
- commit 8796db5
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: Support EL1 phys timer register access in
  set/get reg (bsc#1077761).
- commit 254a94f
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: Avoid timer save/restore in vcpu entry/exit
  (bsc#1077761).
- commit 73ba9e1
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: Set VCPU affinity for virt timer irq
  (bsc#1077761).
- commit 9327afa
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: Move timer save/restore out of the hyp code
  (bsc#1077761).
- commit 61110ab
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: Use separate timer for phys timer emulation
  (bsc#1077761).
- commit f6a35de
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: Move timer/vgic flush/sync under disabled irq
  (bsc#1077761).
- commit dc41fde
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: Rename soft timer to bg_timer (bsc#1077761).
- commit 9264d9d
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: Make timer_arm and timer_disarm helpers more
  generic (bsc#1077761).
- commit 2b2c5a2
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: Support calling vgic_update_irq_pending from
  irq context (bsc#1077761).
- commit 18a1bd2
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: Guard kvm_vgic_map_is_active against
  !vgic_initialized (bsc#1077761).
- commit ba7e655
* Thu Feb  8 2018 agraf@suse.de
- KVM: PPC: Book3S HV: Run HPT guests on POWER9 radix hosts
  (bsc#1077761).
- commit 13d7989
* Thu Feb  8 2018 agraf@suse.de
- KVM: PPC: Book3S HV: Allow for running POWER9 host in
  single-threaded mode (bsc#1077761).
- commit 04bf875
* Thu Feb  8 2018 agraf@suse.de
- KVM: PPC: Book3S: Fix gas warning due to using r0 as immediate 0
  (bsc#1077761).
- commit 375f419
* Thu Feb  8 2018 agraf@suse.de
- KVM: PPC: Book3S PR: Only install valid SLBs during
  KVM_SET_SREGS (bsc#1077761).
- commit 767b8b7
* Thu Feb  8 2018 agraf@suse.de
- KVM: PPC: Book3S PR: Enable in-kernel TCE handlers for PR KVM
  (bsc#1077761).
- commit 60c4ea7
* Thu Feb  8 2018 agraf@suse.de
- KVM: PPC: Book3S HV: Delete an error message for a failed
  memory allocation in kvmppc_allocate_hpt() (bsc#1077761).
- commit 8ad1a63
* Thu Feb  8 2018 agraf@suse.de
- KVM: PPC: BookE: Use vma_pages function (bsc#1077761).
- commit d6571ba
* Thu Feb  8 2018 agraf@suse.de
- KVM: PPC: Book3S HV: Use ARRAY_SIZE macro (bsc#1077761).
- commit 5cbbfdd
* Thu Feb  8 2018 agraf@suse.de
- KVM: PPC: Book3S HV: Handle unexpected interrupts better
  (bsc#1077761).
- commit 636eaa8
* Thu Feb  8 2018 agraf@suse.de
- KVM: X86: #GP when guest attempts to write MCi_STATUS register
  w/o 0 (bsc#1077761).
- commit 7d66248
* Thu Feb  8 2018 agraf@suse.de
- KVM: VMX: Fix VPID capability detection (bsc#1077761).
- commit d2fac0a
* Thu Feb  8 2018 agraf@suse.de
- KVM: nVMX: Fix EPT switching advertising (bsc#1077761).
- commit f7d3e41
* Thu Feb  8 2018 agraf@suse.de
- KVM: SVM: detect opening of SMI window using STGI intercept
  (bsc#1077761).
- commit b1d58d1
* Thu Feb  8 2018 agraf@suse.de
- KVM: x86: extend usage of RET_MMIO_PF_* constants (bsc#1077761).
- commit f9e03bb
* Thu Feb  8 2018 agraf@suse.de
- KVM: nSVM: fix SMI injection in guest mode (bsc#1077761).
- commit 906e480
* Thu Feb  8 2018 agraf@suse.de
- KVM: nSVM: refactor nested_svm_vmrun (bsc#1077761).
- commit f20f8d1
* Thu Feb  8 2018 agraf@suse.de
- KVM: nVMX: fix SMI injection in guest mode (bsc#1077761).
- commit 864bea5
* Thu Feb  8 2018 agraf@suse.de
- KVM: nVMX: set IDTR and GDTR limits when loading L1 host state
  (bsc#1077761).
- commit 9755543
* Thu Feb  8 2018 agraf@suse.de
- KVM: x86: introduce ISA specific smi_allowed callback
  (bsc#1077761).
- commit d5dea7a
* Thu Feb  8 2018 agraf@suse.de
- KVM: x86: introduce ISA specific SMM entry/exit callbacks
  (bsc#1077761).
- commit 504d250
* Thu Feb  8 2018 agraf@suse.de
- KVM: SVM: limit kvm_handle_page_fault to #PF handling
  (bsc#1077761).
- commit 078dc47
* Thu Feb  8 2018 agraf@suse.de
- KVM: SVM: unconditionally wake up VCPU on IOMMU interrupt
  (bsc#1077761).
- commit af2e0bd
* Thu Feb  8 2018 agraf@suse.de
- arch/x86: remove redundant null checks before kmem_cache_destroy
  (bsc#1077761).
- commit 790a8df
* Thu Feb  8 2018 agraf@suse.de
- KVM: VMX: Don't expose unrestricted_guest is enabled if ept
  is disabled (bsc#1077761).
- commit 7b71997
* Thu Feb  8 2018 agraf@suse.de
- KVM: X86: Processor States following Reset or INIT
  (bsc#1077761).
- commit 6a51165
* Thu Feb  8 2018 agraf@suse.de
- KVM: x86: thoroughly disarm LAPIC timer around TSC deadline
  switch (bsc#1077761).
- commit eca3693
* Thu Feb  8 2018 agraf@suse.de
- KVM: x86: really disarm lapic timer when clearing TMICT
  (bsc#1077761).
- commit 9623514
* Thu Feb  8 2018 agraf@suse.de
- KVM: x86: handle 0 write to TSC_DEADLINE MSR (bsc#1077761).
- commit 0be4ae2
* Thu Feb  8 2018 agraf@suse.de
- kvm, mm: account kvm related kmem slabs to kmemcg (bsc#1077761).
- commit a513a0a
* Thu Feb  8 2018 agraf@suse.de
- KVM: VMX: rename RDSEED and RDRAND vmx ctrls to reflect exiting
  (bsc#1077761).
- commit 8efad65
* Thu Feb  8 2018 agraf@suse.de
- KVM: x86: allow setting identity map addr with no vcpus only
  (bsc#1077761).
- commit 87d5593
* Thu Feb  8 2018 agraf@suse.de
- KVM: VMX: cleanup init_rmode_identity_map() (bsc#1077761).
- commit 4829c2a
* Thu Feb  8 2018 agraf@suse.de
- KVM: nVMX: no need to set ept/vpid caps to 0 (bsc#1077761).
- commit 5bfbc6a
* Thu Feb  8 2018 agraf@suse.de
- KVM: nVMX: no need to set vcpu->cpu when switching vmcs
  (bsc#1077761).
- commit 32ffbc8
* Thu Feb  8 2018 agraf@suse.de
- KVM: VMX: drop unnecessary function declarations (bsc#1077761).
- commit 724a966
* Thu Feb  8 2018 agraf@suse.de
- KVM: VMX: require INVEPT GLOBAL for EPT (bsc#1077761).
- commit a44c9d8
* Thu Feb  8 2018 agraf@suse.de
- KVM: VMX: call ept_sync_global() with enable_ept only
  (bsc#1077761).
- commit 7c47e21
* Thu Feb  8 2018 agraf@suse.de
- KVM: VMX: drop enable_ept check from ept_sync_context()
  (bsc#1077761).
- commit fbddd95
* Thu Feb  8 2018 agraf@suse.de
- KVM: x86: no need to inititalize vcpu members to 0
  (bsc#1077761).
- commit 9d148ad
* Thu Feb  8 2018 agraf@suse.de
- KVM: VMX: vmx_vcpu_setup() cannot fail (bsc#1077761).
- commit a5cab9a
* Thu Feb  8 2018 agraf@suse.de
- KVM: x86: drop BUG_ON(vcpu->kvm) (bsc#1077761).
- commit 6eb942e
* Thu Feb  8 2018 agraf@suse.de
- KVM: x86: mmu: free_page can handle NULL (bsc#1077761).
- commit 3f89823
* Thu Feb  8 2018 agraf@suse.de
- KVM: x86: mmu: returning void in a void function is strange
  (bsc#1077761).
- commit 6efd205
* Thu Feb  8 2018 agraf@suse.de
- KVM: LAPIC: Apply change to TDCR right away to the timer
  (bsc#1077761).
- commit 666609a
* Thu Feb  8 2018 agraf@suse.de
- KVM: LAPIC: Keep timer running when switching between one-shot
  and periodic mode (bsc#1077761).
- commit 55c6d5a
* Thu Feb  8 2018 agraf@suse.de
- KVM: LAPIC: Introduce limit_periodic_timer_frequency
  (bsc#1077761).
- commit 7c581b3
* Thu Feb  8 2018 agraf@suse.de
- KVM: LAPIC: Fix lapic timer mode transition (bsc#1077761).
- commit b52714f
* Thu Feb  8 2018 agraf@suse.de
- KVM: VMX: Don't expose PLE enable if there is no hardware
  support (bsc#1077761).
- commit 6186087
* Thu Feb  8 2018 agraf@suse.de
- KVM: PPC: Book3S HV: Handle host system reset in guest mode
  (bsc#1077761).
- commit 1118068
* Thu Feb  8 2018 agraf@suse.de
- Revert "KVM: PPC: Book3S HV: POWER9 does not require secondary
  thread management" (bsc#1077761).
- commit a334af4
* Thu Feb  8 2018 agraf@suse.de
- arm64/sve: KVM: Hide SVE from CPU features exposed to guests
  (bsc#1077761).
- commit de772e4
* Thu Feb  8 2018 agraf@suse.de
- arm64/sve: KVM: Treat guest SVE use as undefined instruction
  execution (bsc#1077761).
- commit 5fb9a5a
* Thu Feb  8 2018 agraf@suse.de
- arm64: KVM: Hide unsupported AArch64 CPU features from guests
  (bsc#1077761).
- commit 8bbe83e
* Thu Feb  8 2018 agraf@suse.de
- arm64: sysreg: Move SPE registers and PSB into common header
  files (bsc#1077761).
- commit c7d961a
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its: Add post-mortem info on command timeout
  (bsc#1077761).
- commit b376906
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3: Add workaround for Synquacer pre-ITS
  (bsc#1077761).
- commit 1ff37f4
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic: Make quirks matching conditional on init return
  value (bsc#1077761).
- commit 9f48672
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3: Probe device ID space before quirks handling
  (bsc#1077761).
- commit 61afdc5
* Wed Feb  7 2018 mgorman@suse.de
- Refresh
  patches.suse/sched-fair-Do-not-migrate-if-the-prev_cpu-is-idle.patch.
- Refresh
  patches.suse/sched-fair-Remove-unnecessary-parameters-from-wake_affine_idle.patch.
- Refresh
  patches.suse/sched-fair-Restructure-wake_affine-to-return-a-CPU-id.patch.
- Refresh
  patches.suse/sched-fair-Use-a-recently-used-CPU-as-an-idle-candidate-and-the-basis-for-SIS.patch.
- commit 6bb11d2
* Wed Feb  7 2018 rgoldwyn@suse.com
- apparmor: fix possible recursive lock warning in  __aa_create_ns
  (bsc#1079834).
- apparmor: fix ptrace label match when matching stacked labels
  (bsc#1079851).
- apparmor: fix regression in mount mediation when feature  set
  is pinned (bsc#1079828).
- Update
  patches.apparmor/apparmor-fix-oops-in-audit_signal_cb-hook.patch
  (bsc#1070227).
- commit d71c37d
* Wed Feb  7 2018 tbogendoerfer@suse.de
- IB/hfi1: Remove blind constants from 16B update (bsc#1060463
  FATE#323043).
- IB/hfi1: Remove dependence on qp->s_hdrwords (bsc#1060463
  FATE#323043).
- IB/hfi1: Add RQ/SRQ information to QP stats (bsc#1060463
  FATE#323043).
- commit 5e5aecf
* Wed Feb  7 2018 tbogendoerfer@suse.de
- RDMA/cma: Check existence of netdevice during port validation
  (bsc#1046306 FATE#322942).
- RDMA/cma: Introduce API to read GIDs for multiple transports
  (bsc#1046306 FATE#322942).
- RDMA/cma: Fix rdma_cm path querying for RoCE (bsc#1046306
  FATE#322942).
- RDMA/cma: Fix rdma_cm raw IB path setting for RoCE (bsc#1046306
  FATE#322942).
- RDMA/{cma, ucma}: Simplify and rename rdma_set_ib_paths
  (bsc#1046306 FATE#322942).
- RDMA/cma: Provide a function to set RoCE path record L2
  parameters (bsc#1046306 FATE#322942).
- RDMA/cma: Use the right net namespace for the rdma_cm_id
  (bsc#1046306 FATE#322942).
- RDMA/cma: Introduce and use helper functions to init work
  (bsc#1046306 FATE#322942).
- RDMA/cma: Avoid setting path record type twice (bsc#1046306
  FATE#322942).
- RDMA/cma: Simplify netdev check (bsc#1046306 FATE#322942).
- RDMA/cma: Set default GID type as RoCE when resolving RoCE route
  (bsc#1046306 FATE#322942).
- commit 82aa918
* Wed Feb  7 2018 agraf@suse.de
- s390/ctl_reg: move control register definitions to ctl_reg.h
  (bsc#1077761).
- commit 0ecc113
* Wed Feb  7 2018 agraf@suse.de
- s390/runtime_instrumentation: clean up struct runtime_instr_cb
  (bsc#1077761).
- commit 51c2ad5
* Wed Feb  7 2018 agraf@suse.de
- KVM: arm/arm64: vgic-its: Check GITS_BASER Valid bit before
  saving tables (bsc#1077761).
- commit c657664
* Wed Feb  7 2018 agraf@suse.de
- KVM: arm/arm64: vgic-its: Check CBASER/BASER validity before
  enabling the ITS (bsc#1077761).
- commit 3e240a3
* Wed Feb  7 2018 agraf@suse.de
- KVM: arm/arm64: vgic-its: Fix vgic_its_restore_collection_table
  returned value (bsc#1077761).
- commit f6dcef1
* Wed Feb  7 2018 agraf@suse.de
- KVM: arm/arm64: vgic-its: Fix return value for device table
  restore (bsc#1077761).
- commit e5ec1bc
* Wed Feb  7 2018 agraf@suse.de
- arm/arm64: kvm: Disable branch profiling in HYP code
  (bsc#1077761).
- commit bea11c5
* Wed Feb  7 2018 agraf@suse.de
- arm/arm64: kvm: Move initialization completion message
  (bsc#1077761).
- commit 32dee34
* Wed Feb  7 2018 agraf@suse.de
- arm/arm64: KVM: set right LR register value for 32 bit guest
  when inject abort (bsc#1077761).
- commit 1f9a389
* Wed Feb  7 2018 agraf@suse.de
- KVM: arm64: its: Fix missing dynamic allocation check in
  scan_its_table (bsc#1077761).
- commit b1a2351
* Wed Feb  7 2018 msuchanek@suse.de
- rpm/kernel-binary.spec.in: install ksym-provides tool (bsc#1077692).
- commit 679f5c5
* Wed Feb  7 2018 agraf@suse.de
- KVM: x86: Update APICv on APIC reset (bsc#1077761).
- commit 81a4412
* Wed Feb  7 2018 agraf@suse.de
- KVM: VMX: Do not fully reset PI descriptor on vCPU reset
  (bsc#1077761).
- commit 780175d
* Wed Feb  7 2018 agraf@suse.de
- KVM: nVMX: fix guest CR4 loading when emulating L2 to L1 exit
  (bsc#1077761).
- commit 6272cb9
* Wed Feb  7 2018 agraf@suse.de
- KVM: MMU: always terminate page walks at level 1 (bsc#1077761).
- commit 012351b
* Wed Feb  7 2018 agraf@suse.de
- KVM: nVMX: update last_nonleaf_level when initializing nested
  EPT (bsc#1077761).
- commit fba7c5e
* Wed Feb  7 2018 agraf@suse.de
- KVM: add X86_LOCAL_APIC dependency (bsc#1077761).
- commit b0c57c5
* Wed Feb  7 2018 agraf@suse.de
- kvm/x86: Avoid async PF preempting the kernel incorrectly
  (bsc#1077761).
- commit 33e3762
* Wed Feb  7 2018 agraf@suse.de
- kvm/x86: Handle async PF in RCU read-side critical sections
  (bsc#1077761).
- commit d538f32
* Wed Feb  7 2018 agraf@suse.de
- KVM: nVMX: Fix nested #PF intends to break L1's vmlauch/vmresume
  (bsc#1077761).
- commit e5c273a
* Wed Feb  7 2018 agraf@suse.de
- KVM: VMX: use cmpxchg64 (bsc#1077761).
- commit ccea3eb
* Wed Feb  7 2018 agraf@suse.de
- KVM: VMX: simplify and fix vmx_vcpu_pi_load (bsc#1077761).
- commit 9131f7c
* Wed Feb  7 2018 agraf@suse.de
- KVM: VMX: avoid double list add with VT-d posted interrupts
  (bsc#1077761).
- commit efab819
* Wed Feb  7 2018 agraf@suse.de
- KVM: VMX: extract __pi_post_block (bsc#1077761).
- commit 6de20b1
* Wed Feb  7 2018 agraf@suse.de
- KVM: PPC: Book3S HV: Check for updated HDSISR on P9 HDSI
  exception (bsc#1077761).
- commit 1bf0fea
* Wed Feb  7 2018 agraf@suse.de
- KVM: x86: Fix the NULL pointer parameter in check_cr_write()
  (bsc#1077761).
- commit ac5bf85
* Wed Feb  7 2018 agraf@suse.de
- Revert "KVM: Don't accept obviously wrong gsi values via
  KVM_IRQFD" (bsc#1077761).
- commit 7ff728f
* Wed Feb  7 2018 agraf@suse.de
- kvm: nVMX: Handle deferred early VMLAUNCH/VMRESUME failure
  properly (bsc#1077761).
- commit 3210b1f
* Wed Feb  7 2018 agraf@suse.de
- kvm: vmx: Handle VMLAUNCH/VMRESUME failure properly
  (bsc#1077761).
- commit 23509b2
* Wed Feb  7 2018 agraf@suse.de
- kvm: nVMX: Remove nested_vmx_succeed after successful VM-entry
  (bsc#1077761).
- commit 8fb1583
* Wed Feb  7 2018 agraf@suse.de
- KVM: Don't accept obviously wrong gsi values via KVM_IRQFD
  (bsc#1077761).
- commit 9441090
* Wed Feb  7 2018 msuchanek@suse.de
- rpm/kernel-binary.spec.in: require bison for build.
  linux-next tends to have outdated generated files so it needs bison to
  regenerate them.
- commit 4ad1ede
* Wed Feb  7 2018 agraf@suse.de
- KVM: trace events: update list of exit reasons (bsc#1077761).
- commit ebca120
* Wed Feb  7 2018 agraf@suse.de
- KVM: X86: Don't block vCPU if there is pending exception
  (bsc#1077761).
- commit c6a59bd
* Wed Feb  7 2018 agraf@suse.de
- KVM: x86: fix clang build (bsc#1077761).
- commit bde54e4
* Wed Feb  7 2018 agraf@suse.de
- KVM: fix rcu warning on VM_CREATE errors (bsc#1077761).
- commit 8b38d86
* Wed Feb  7 2018 agraf@suse.de
- KVM: x86: Fix handling of pending signal on uninitialized AP
  (bsc#1077761).
- commit f17cb3c
* Wed Feb  7 2018 agraf@suse.de
- KVM: PPC: Book3S HV: Protect updates to spapr_tce_tables list
  (bsc#1077761).
- commit 4fb91d2
* Wed Feb  7 2018 agraf@suse.de
- KVM: PPC: Book3S HV: Fix invalid use of register expression
  (bsc#1077761).
- commit 3d56d7a
* Wed Feb  7 2018 agraf@suse.de
- KVM: PPC: Book3S HV: Fix H_REGISTER_VPA VPA size validation
  (bsc#1077761).
- commit dd5bcf7
* Wed Feb  7 2018 agraf@suse.de
- KVM: PPC: Book3S HV: Fix setting of storage key in H_ENTER
  (bsc#1077761).
- commit 41b5422
* Wed Feb  7 2018 agraf@suse.de
- KVM: PPC: e500mc: Fix a NULL dereference (bsc#1077761).
- commit ece8d3c
* Wed Feb  7 2018 agraf@suse.de
- KVM: PPC: e500: Fix some NULL dereferences on error
  (bsc#1077761).
- commit b7887fb
* Wed Feb  7 2018 agraf@suse.de
- KVM: arm/arm64: Support uaccess of GICC_APRn (bsc#1077761).
- commit 9a096e3
* Wed Feb  7 2018 agraf@suse.de
- KVM: arm/arm64: Extract GICv3 max APRn index calculation
  (bsc#1077761).
- commit ebeb5d5
* Wed Feb  7 2018 agraf@suse.de
- KVM: arm/arm64: vITS: Drop its_ite->lpi field (bsc#1077761).
- commit 5cf62bb
* Wed Feb  7 2018 agraf@suse.de
- KVM: arm/arm64: vgic: constify seq_operations and
  file_operations (bsc#1077761).
- commit dafbaeb
* Wed Feb  7 2018 agraf@suse.de
- KVM: arm/arm64: Fix guest external abort matching (bsc#1077761).
- commit 403db45
* Wed Feb  7 2018 agraf@suse.de
- KVM: s390: vsie: cleanup mcck reinjection (bsc#1077761).
- commit a25bb09
* Wed Feb  7 2018 agraf@suse.de
- KVM: s390: use WARN_ON_ONCE only for checking (bsc#1077761).
- commit 10b882b
* Wed Feb  7 2018 agraf@suse.de
- KVM: s390: guestdbg: fix range check (bsc#1077761).
- commit e525cc4
* Wed Feb  7 2018 agraf@suse.de
- KVM: s390: we are always in czam mode (bsc#1077761).
- commit 2e46f1e
* Wed Feb  7 2018 msuchanek@suse.de
- Add ksym-provides tool (bsc#1077692).
- commit ee8ebe0
* Wed Feb  7 2018 agraf@suse.de
- KVM: s390: sthyi: remove invalid guest write access
  (bsc#1077761).
- patches.arch/s390-sles15-00-10-01-kernel-sthyi-reorganize-sthyi-implementation.patch:
  (FATE#324258, LTC#160415, bsc#1068273).
- commit 0a9d7cd
* Wed Feb  7 2018 tbogendoerfer@suse.de
- mlx5: fix mlx5_get_vector_affinity to start from completion
  vector 0 (bsc#1046303 FATE#322944).
- IB/core: Avoid a potential OOPs for an unused optional parameter
  (bsc#1046306 FATE#322942).
- IB/core: Map iWarp AH type to undefined in rdma_ah_find_type
  (bsc#1046306 FATE#322942).
- IB/hfi1: Fix for potential refcount leak in hfi1_open_file()
  (bsc#1060463 FATE#323043).
- RDMA/bnxt_re: Fix an error code in bnxt_qplib_create_srq()
  (bsc#1050244 FATE#322915).
- net_sched: gen_estimator: fix lockdep splat (bsc#1056787).
- i40e: fix reported mask for ntuple filters (bsc#1056658
  FATE#322188).
- igb: Free IRQs when device is hotplugged (bsc#1056651
  FATE#322191).
- net/mlx5: Separate ingress/egress namespaces for each vport
  (bsc#1046303 FATE#322944).
- net/mlx5: Fix ingress/egress naming mistake (bsc#1046303
  FATE#322944).
- net/mlx5e: E-Switch, Use the name of static array instead of
  its address (bsc#1046303 FATE#322944).
- net/mlx4_en: Change default QoS settings (bsc#1046299
  FATE#322947).
- net/mlx4_core: Cleanup FMR unmapping flow (bsc#1046300
  FATE#322946).
- RDMA/mlx5: Avoid memory leak in case of XRCD dealloc failure
  (bsc#1046305 FATE#322943).
- IB/umad: Fix use of unprotected device pointer (bsc#1046306
  FATE#322942).
- i40iw: Free IEQ resources (bsc#1058659 FATE#322535).
- i40iw: Remove limit on re-posting AEQ entries to HW (bsc#1058659
  FATE#322535).
- RDMA/core: Clarify rdma_ah_find_type (bsc#1046306 FATE#322942).
- IB/mlx4: Fix incorrectly releasing steerable UD QPs when have
  only ETH ports (bsc#1046302 FATE#322945).
- IB/srpt: Remove an unused structure member (bsc#1046306
  FATE#322942).
- IB/core: Fix two kernel warnings triggered by rxe registration
  (bsc#1046306 FATE#322942).
- i40iw: Fix the connection ORD value for loopback (bsc#1058659
  FATE#322535).
- i40iw: Validate correct IRD/ORD connection parameters
  (bsc#1058659 FATE#322535).
- i40iw: Fix sequence number for the first partial FPDU
  (bsc#1058659 FATE#322535).
- i40iw: Selectively teardown QPs on IP addr change event
  (bsc#1058659 FATE#322535).
- i40iw: Correct Q1/XF object count equation (bsc#1058659
  FATE#322535).
- IB/SA: Check dlid before SA agent queries for ClassPortInfo
  (bsc#1046306 FATE#322942).
- IB/umem: Fix use of npages/nmap fields (bsc#1046306
  FATE#322942).
- RDMA/cma: Use correct size when writing netlink stats
  (bsc#1046306 FATE#322942).
- RDMA/iwpm: Fix uninitialized error code in iwpm_send_mapinfo()
  (bsc#1046306 FATE#322942).
- IB/mlx5: revisit -Wmaybe-uninitialized warning (bsc#1046305
  FATE#322943).
- commit 5f2318b
* Wed Feb  7 2018 agraf@suse.de
- KVM: s390: Multiple Epoch Facility support (bsc#1077761).
- patches.arch/s390-sles15-00-10-01-kernel-sthyi-reorganize-sthyi-implementation.patch:
  (FATE#324258, LTC#160415, bsc#1068273).
- commit 69d2bea
* Wed Feb  7 2018 agraf@suse.de
- kvm: nVMX: Validate the virtual-APIC address on nested VM-entry
  (bsc#1077761).
- commit 02cdfc0
* Wed Feb  7 2018 agraf@suse.de
- KVM: nVMX: Fix trying to cancel vmlauch/vmresume (bsc#1077761).
- commit d7cc599
* Wed Feb  7 2018 agraf@suse.de
- KVM: X86: Fix loss of exception which has not yet been injected
  (bsc#1077761).
- commit 0c65010
* Wed Feb  7 2018 agraf@suse.de
- KVM: VMX: use kvm_event_needs_reinjection (bsc#1077761).
- commit c9110ef
* Wed Feb  7 2018 agraf@suse.de
- KVM: MMU: speedup update_permission_bitmask (bsc#1077761).
- commit 6c779fb
* Wed Feb  7 2018 agraf@suse.de
- KVM: MMU: Expose the LA57 feature to VM (bsc#1077761).
- commit 6626022
* Wed Feb  7 2018 agraf@suse.de
- KVM: MMU: Add 5 level EPT & Shadow page table support
  (bsc#1077761).
- commit 02cce94
* Wed Feb  7 2018 agraf@suse.de
- KVM: MMU: Rename PT64_ROOT_LEVEL to PT64_ROOT_4LEVEL
  (bsc#1077761).
- commit 5957c99
* Wed Feb  7 2018 agraf@suse.de
- KVM: MMU: check guest CR3 reserved bits based on its physical
  address width (bsc#1077761).
- commit 74530a7
* Wed Feb  7 2018 agraf@suse.de
- KVM: x86: Add return value to kvm_cpuid() (bsc#1077761).
- commit 2260172
* Wed Feb  7 2018 agraf@suse.de
- kvm: vmx: Raise #UD on unsupported XSAVES/XRSTORS (bsc#1077761).
- commit 1ca81c7
* Wed Feb  7 2018 agraf@suse.de
- kvm: vmx: Raise #UD on unsupported RDSEED (bsc#1077761).
- commit 416b7c0
* Wed Feb  7 2018 agraf@suse.de
- kvm: vmx: Raise #UD on unsupported RDRAND (bsc#1077761).
- commit d990f93
* Wed Feb  7 2018 agraf@suse.de
- KVM: VMX: cache secondary exec controls (bsc#1077761).
- commit aee234d
* Wed Feb  7 2018 agraf@suse.de
- KVM: VMX: always require WB memory type for EPT (bsc#1077761).
- commit 004c65c
* Wed Feb  7 2018 agraf@suse.de
- KVM: VMX: cleanup EPTP definitions (bsc#1077761).
- commit a0416af
* Wed Feb  7 2018 agraf@suse.de
- KVM: x86: fix use of L1 MMIO areas in nested guests
  (bsc#1077761).
- commit 5c78d98
* Wed Feb  7 2018 agraf@suse.de
- KVM: x86: Avoid guest page table walk when gpa_available is set
  (bsc#1077761).
- commit 9101925
* Wed Feb  7 2018 agraf@suse.de
- KVM: x86: simplify ept_misconfig (bsc#1077761).
- commit c81e473
* Wed Feb  7 2018 agraf@suse.de
- kvm: avoid uninitialized-variable warnings (bsc#1077761).
- commit 138f617
* Wed Feb  7 2018 agraf@suse.de
- kvm: x86: Disallow illegal IA32_APIC_BASE MSR values
  (bsc#1077761).
- commit 41bb0d9
* Wed Feb  7 2018 agraf@suse.de
- KVM: MMU: Bail out immediately if there is no available mmu page
  (bsc#1077761).
- commit a95ac0e
* Wed Feb  7 2018 agraf@suse.de
- KVM: MMU: Fix softlockup due to mmu_lock is held too long
  (bsc#1077761).
- commit 2e9e45e
* Wed Feb  7 2018 agraf@suse.de
- KVM: nVMX: validate eptp pointer (bsc#1077761).
- commit b202868
* Wed Feb  7 2018 agraf@suse.de
- kvm: nVMX: Add support for fast unprotection of nested guest
  page tables (bsc#1077761).
- commit dbe7eff
* Wed Feb  7 2018 agraf@suse.de
- KVM: X86: Fix residual mmio emulation request to userspace
  (bsc#1077761).
- commit ba3cd5b
* Wed Feb  7 2018 agraf@suse.de
- KVM: arm: implements the kvm_arch_vcpu_in_kernel()
  (bsc#1077761).
- commit bc61a6f
* Wed Feb  7 2018 agraf@suse.de
- KVM: s390: implements the kvm_arch_vcpu_in_kernel()
  (bsc#1077761).
- commit ccf0426
* Wed Feb  7 2018 agraf@suse.de
- KVM: X86: implement the logic for spinlock optimization
  (bsc#1077761).
- commit cd89a32
* Wed Feb  7 2018 agraf@suse.de
- KVM: add spinlock optimization framework (bsc#1077761).
- commit 9be0d73
* Wed Feb  7 2018 agraf@suse.de
- KVM: x86: use general helpers for some cpuid manipulation
  (bsc#1077761).
- commit 7c96559
* Wed Feb  7 2018 agraf@suse.de
- KVM: x86: generalize guest_cpuid_has_ helpers (bsc#1077761).
- commit 6253831
* Wed Feb  7 2018 agraf@suse.de
- KVM: x86: X86_FEATURE_NRIPS is not scattered anymore
  (bsc#1077761).
- commit 8fc76c4
* Wed Feb  7 2018 agraf@suse.de
- KVM: nVMX: Emulate EPTP switching for the L1 hypervisor
  (bsc#1077761).
- commit 41af192
* Wed Feb  7 2018 agraf@suse.de
- KVM: nVMX: Enable VMFUNC for the L1 hypervisor (bsc#1077761).
- commit 03e08c3
* Wed Feb  7 2018 agraf@suse.de
- KVM: vmx: Enable VMFUNCs (bsc#1077761).
- commit febad7f
* Wed Feb  7 2018 agraf@suse.de
- KVM: nVMX: get rid of nested_release_page* (bsc#1077761).
- commit 8dfa692
* Wed Feb  7 2018 agraf@suse.de
- KVM: nVMX: get rid of nested_get_page() (bsc#1077761).
- commit 18480de
* Wed Feb  7 2018 agraf@suse.de
- KVM: nVMX: INVPCID support (bsc#1077761).
- commit c42b719
* Wed Feb  7 2018 agraf@suse.de
- KVM: hyperv: support HV_X64_MSR_TSC_FREQUENCY and
  HV_X64_MSR_APIC_FREQUENCY (bsc#1077761).
- commit 3211c0a
* Wed Feb  7 2018 agraf@suse.de
- KVM: PPC: Book3S HV: POWER9 does not require secondary thread
  management (bsc#1077761).
- commit c66a49a
* Wed Feb  7 2018 agraf@suse.de
- powerpc/mm: Update definitions of DSISR bits (bsc#1077761).
- commit 67bca61
* Wed Feb  7 2018 agraf@suse.de
- arm64: Remove the !CONFIG_ARM64_HW_AFDBM alternative code paths
  (bsc#1077761).
- commit 6e5f833
* Wed Feb  7 2018 agraf@suse.de
- kvm/x86: Avoid clearing the C-bit in rsvd_bits() (bsc#1077761).
- commit 420d917
* Wed Feb  7 2018 agraf@suse.de
- KVM: update to new mmu_notifier semantic v2 (bsc#1077761).
- commit 20cbd84
* Wed Feb  7 2018 agraf@suse.de
- KVM: PPC: Book3S: Fix race and leak in
  kvm_vm_ioctl_create_spapr_tce() (bsc#1077761).
- commit 7e876d5
* Wed Feb  7 2018 agraf@suse.de
- KVM: arm/arm64: vgic: Use READ_ONCE fo cmpxchg (bsc#1077761).
- commit 0963889
* Wed Feb  7 2018 agraf@suse.de
- KVM: arm/arm64: PMU: Fix overflow interrupt injection
  (bsc#1077761).
- commit 0e13c71
* Wed Feb  7 2018 agraf@suse.de
- KVM: arm/arm64: Fix bug in advertising KVM_CAP_MSI_DEVID
  capability (bsc#1077761).
- commit f588e1d
* Wed Feb  7 2018 agraf@suse.de
- KVM: nVMX: Fix interrupt window request with "Acknowledge
  interrupt on exit" (bsc#1077761).
- commit 96a9aa1
* Wed Feb  7 2018 agraf@suse.de
- KVM: nVMX: mark vmcs12 pages dirty on L2 exit (bsc#1077761).
- commit d690017
* Wed Feb  7 2018 agraf@suse.de
- kvm: nVMX: don't flush VMCS12 during VMXOFF or VCPU teardown
  (bsc#1077761).
- commit 7f92ce5
* Wed Feb  7 2018 agraf@suse.de
- KVM: nVMX: do not pin the VMCS12 (bsc#1077761).
- commit 9c1a723
* Wed Feb  7 2018 agraf@suse.de
- KVM: avoid using rcu_dereference_protected (bsc#1077761).
- commit d8f2f42
* Wed Feb  7 2018 agraf@suse.de
- KVM: X86: init irq->level in kvm_pv_kick_cpu_op (bsc#1077761).
- commit daa60bc
* Wed Feb  7 2018 agraf@suse.de
- KVM: X86: Fix loss of pending INIT due to race (bsc#1077761).
- commit 0c6ceeb
* Wed Feb  7 2018 agraf@suse.de
- KVM: nVMX: fixes to nested virt interrupt injection
  (bsc#1077761).
- commit a1131d2
* Wed Feb  7 2018 agraf@suse.de
- KVM: nVMX: do not fill vm_exit_intr_error_code in prepare_vmcs12
  (bsc#1077761).
- commit 483e7f3
* Wed Feb  7 2018 agraf@suse.de
- KVM: LAPIC: Fix reentrancy issues with preempt notifiers
  (bsc#1077761).
- commit 1f7a6ad
* Wed Feb  7 2018 agraf@suse.de
- KVM: s390: take srcu lock when getting/setting storage keys
  (bsc#1077761).
- commit 4f1fa14
* Wed Feb  7 2018 agraf@suse.de
- KVM: nVMX: Fix loss of L2's NMI blocking state (bsc#1077761).
- commit b30d4e0
* Wed Feb  7 2018 agraf@suse.de
- KVM: nVMX: Fix posted intr delivery when vcpu is in guest mode
  (bsc#1077761).
- Refresh
  patches.arch/0002-kvm-vmx-remove-warn_on_once-in-kvm_vcpu_trigger_posted_interrupt.
- commit 1d74271
* Wed Feb  7 2018 agraf@suse.de
- x86: irq: Define a global vector for nested posted interrupts
  (bsc#1077761).
- commit 1a7d98c
* Wed Feb  7 2018 agraf@suse.de
- KVM: x86: do mask out upper bits of PAE CR3 (bsc#1077761).
- commit 2851b3a
* Wed Feb  7 2018 agraf@suse.de
- KVM: VMX: remove unused field (bsc#1077761).
- commit c2fa409
* Wed Feb  7 2018 agraf@suse.de
- kvm: x86: hyperv: avoid livelock in oneshot SynIC timers
  (bsc#1077761).
- commit e399bf8
* Wed Feb  7 2018 agraf@suse.de
- KVM: VMX: Fix invalid guest state detection after task-switch
  emulation (bsc#1077761).
- commit 2f44a61
* Wed Feb  7 2018 agraf@suse.de
- x86: add MULTIUSER dependency for KVM (bsc#1077761).
- commit 12a5533
* Wed Feb  7 2018 agraf@suse.de
- KVM: nVMX: Disallow VM-entry in MOV-SS shadow (bsc#1077761).
- commit 77d8ab1
* Wed Feb  7 2018 agraf@suse.de
- KVM: nVMX: track NMI blocking state separately for each VMCS
  (bsc#1077761).
- Refresh
  patches.arch/18.2-kvm-nvmx-fix-host_cr3-host_cr4-cache.patch.
- commit 080adef
* Wed Feb  7 2018 agraf@suse.de
- KVM: x86: masking out upper bits (bsc#1077761).
- commit 78f98d2
* Wed Feb  7 2018 agraf@suse.de
- kvm: x86: hyperv: make VP_INDEX managed by userspace
  (bsc#1077761).
- commit b7577ef
* Wed Feb  7 2018 agraf@suse.de
- KVM: async_pf: Let guest support delivery of async_pf from
  guest mode (bsc#1077761).
- Refresh
  patches.arch/0003-kvm-async_pf-fix-df-due-to-inject-page-not-present-and-page-ready-exceptions-simultaneously.
- commit 421024f
* Wed Feb  7 2018 agraf@suse.de
- KVM: async_pf: Force a nested vmexit if the injected #PF is
  async_pf (bsc#1077761).
  Refresh
  patches.arch/0003-kvm-async_pf-fix-df-due-to-inject-page-not-present-and-page-ready-exceptions-simultaneously.
- commit 0c8c65c
* Wed Feb  7 2018 agraf@suse.de
- KVM: async_pf: Add L1 guest async_pf #PF vmexit handler
  (bsc#1077761).
- commit 05fcb6b
* Wed Feb  7 2018 agraf@suse.de
- KVM: x86: Simplify kvm_x86_ops->queue_exception parameter list
  (bsc#1077761).
- commit b0fb424
* Wed Feb  7 2018 agraf@suse.de
- kvm: x86: hyperv: add KVM_CAP_HYPERV_SYNIC2 (bsc#1077761).
- commit 56fe2cc
* Wed Feb  7 2018 agraf@suse.de
- KVM: x86: make backwards_tsc_observed a per-VM variable
  (bsc#1077761).
- commit c612bf5
* Wed Feb  7 2018 agraf@suse.de
- KVM: SVM: handle singlestep exception when skipping emulated
  instructions (bsc#1077761).
- Refresh patches.arch/0007-kvm-svm-enable-virtual-gif-feature.
- Refresh
  patches.arch/kvm-svm-delete-avic_vm_id_bitmap-2-megabyte-static-array.
- commit 77f3e25
* Wed Feb  7 2018 msuchanek@suse.de
- blacklist acb1feab320e powerpc/64: Don't trace irqs-off at interrupt
  return to soft-disabled context
- commit ef64ee1
* Wed Feb  7 2018 jslaby@suse.cz
- Refresh
  patches.suse/0002-futex-futex_wake_op-fix-sign_extend32-sign-bits.patch.
  Update upstream status.
- commit a44be7b
* Wed Feb  7 2018 jslaby@suse.cz
- x86/dumpstack: Avoid uninitlized variable (git-fixes).
- commit 7668118
* Wed Feb  7 2018 tbogendoerfer@suse.de
- net/mlx5e: IPoIB, Use correct timestamp in child receive flow
  (bsc#1075020).
- net/mlx5: Update ptp_clock_event foreach PPS event
  (bsc#1075020).
- IB/ipoib: Fix lockdep issue found on ipoib_ib_dev_heavy_flush
  (bsc#1075020).
- commit 6acdbe8
* Wed Feb  7 2018 tbogendoerfer@suse.de
- net/mlx5e: IPoIB, Modify rdma netdev allocate and free to
  support PKEY (bsc#1075020).
- net/mlx5e: IPoIB, Add PKEY child interface ethtool ops
  (bsc#1075020).
- net/mlx5e: IPoIB, Add PKEY child interface ndos (bsc#1075020).
- net/mlx5e: IPoIB, Add PKEY child interface nic profile
  (bsc#1075020).
- net/mlx5e: IPoIB, Use hash-table to map between QPN to child
  netdev (bsc#1075020).
- net/mlx5e: IPoIB, Support for setting PKEY index to underlay QP
  (bsc#1075020).
- IB/ipoib: Add ability to set PKEY index to lower device driver
  (bsc#1075020).
- IB/ipoib: Grab rtnl lock on heavy flush when calling
  ndo_open/stop (bsc#1075020).
- net/mlx5: Support for attaching multiple underlay QPs to root
  flow table (bsc#1075020).
- net/mlx5e: IPoIB, Move underlay QP init/uninit to separate
  functions (bsc#1075020).
- net/mlx5: PTP code migration to driver core section
  (bsc#1075020).
  Refresh
  patches.drivers/Revert-mlx5-move-affinity-hints-assignments-to-gener.patch.
- net/mlx5: File renaming towards ptp core implementation
  (bsc#1075020).
- commit e473354
* Wed Feb  7 2018 agraf@suse.de
- Move KVM patches to sorted section
  Refresh
  patches.arch/0001-kvm-nVMX-Don-t-allow-L2-to-access-the-hardware-CR8.patch.
- commit 5d643b3
* Wed Feb  7 2018 jthumshirn@suse.de
- s390/zcrypt: externalize AP queue interrupt control
  (FATE#324118, LTC#158322).
- s390/zcrypt: externalize AP config info query (FATE#324118,
  LTC#158322).
- s390/zcrypt: externalize test AP queue (FATE#324118,
  LTC#158322).
- commit 0c2b243
* Tue Feb  6 2018 msuchanek@suse.de
- rfi-flush: Switch to new linear fallback flush (bsc#1068032).
  Refresh patches.arch/powerpc-xmon-Add-RFI-flush-related-fields-to-paca-du.patch.
- commit 0b9f66c
* Tue Feb  6 2018 msuchanek@suse.de
- powerpc/radix: Remove trace_tlbie call from radix__flush_tlb_all
  (bsc#1055117, fate#323286, git-fixes).
- commit e6674e9
* Tue Feb  6 2018 tbogendoerfer@suse.de
- iw_cxgb4: Change error/warn prints to pr_debug (bsc#1079355).
- iser-target: avoid reinitializing rdma contexts for isert
  commands (bsc#1079355).
- iw_cxgb4: Only validate the MSN for successful completions
  (bsc#1079355).
- commit f364c92
* Tue Feb  6 2018 tbogendoerfer@suse.de
- cxgb4: add geneve offload support for T6 (bsc#1074220).
- cxgb4: implement ndo_features_check (bsc#1074220).
- cxgb4: add support for vxlan segmentation offload (bsc#1074220).
- cxgb4: implement udp tunnel callbacks (bsc#1074220).
- cxgb4: add data structures to support vxlan (bsc#1074220).
- IB/qib: Fix comparison error with qperf compare/swap test
  (bsc#1027067 FATE#322649).
- commit a50f30f
* Tue Feb  6 2018 mgorman@suse.de
- cpufreq: intel_pstate: Add Skylake servers support (bnc#1068680
  Update schedutil and intel_pstate to default to load-based
  policy).
- cpufreq: intel_pstate: Replace bxt_funcs with core_funcs
  (bnc#1068680 Update schedutil and intel_pstate to default to
  load-based policy).
- commit 5047ebd
* Tue Feb  6 2018 mgorman@suse.de
- Refresh
  patches.suse/mm-numa-do-not-trap-faults-on-shared-data-section-pages.patch.
- commit 8c37e01
* Tue Feb  6 2018 msuchanek@suse.de
- ibmvnic: fix empty firmware version and errors cleanup
  (bsc#1079038).
- commit 0b2f959
* Tue Feb  6 2018 msuchanek@suse.de
- Refresh sorted section.
- Refresh patches.drivers/ibmvnic-Wait-for-device-response-when-changing-MAC.patch.
- Refresh patches.drivers/ibmvnic-fix-firmware-version-when-no-firmware-level-.patch.
- Refresh patches.drivers/scsi-cxlflash-Reset-command-ioasc.patch.
- Refresh patches.fixes/ipvlan-remove-excessive-packet-scrubbing.patch.
- commit f04d16a
* Tue Feb  6 2018 pmladek@suse.com
- printk: Never set console_may_schedule in console_trylock()
  (bnc#744692, bnc#789311, bsc#1078391).
- commit d2af2e6
* Tue Feb  6 2018 pmladek@suse.com
- printk: Hide console waiter logic into helpers (bnc#744692,
  bnc#789311, bsc#1078391).
- commit 9d02b3e
* Tue Feb  6 2018 pmladek@suse.com
- printk: Add console owner and waiter logic to load balance
  console writes (bnc#744692, bnc#789311, bsc#1078391).
- commit 5d9e509
* Tue Feb  6 2018 pmladek@suse.com
- Remove the SUSE-specific print-softlockup fix (bnc#744692, bnc#789311)
  It is going to be replaced by the upstream solution using console waiter
  logic.
- Delete
  patches.suse/printk-Switch-to-the-sync-mode-when-an-emergency-mes.patch.
- Delete patches.suse/printk-default-to-async-printing.patch.
- Delete patches.suse/printk-fix-suspend-hang.patch.
- Delete patches.suse/printk-make-async.patch.
- Delete patches.suse/printk-make-kthread-priority-normal.patch.
- Delete patches.suse/printk-make-synchronous-param-rw.patch.
- Delete patches.suse/printk-make-wakeup-klogd-async-fixup.patch.
- Delete patches.suse/printk-make-wakeup-klogd-async.patch.
- Delete
  patches.suse/printk-xen-Force-printk-sync-mode-when-migrating-Xen.patch.
- commit 3ed9739
* Tue Feb  6 2018 tbogendoerfer@suse.de
- cxgb4: add new T5 and T6 device id's (bsc#1079352).
- scsi: libcxgbi: use GFP_ATOMIC in cxgbi_conn_alloc_pdu()
  (bsc#1079355).
- commit e0eecbf
* Tue Feb  6 2018 msuchanek@suse.de
- powerpc/pseries: Add Initialization of VF Bars (FATE#324970,
  bsc#1078720).
- powerpc/pseries/pci: Associate PEs to VFs in configure SR-IOV
  (FATE#324970, bsc#1078720).
- powerpc/eeh: Add EEH notify resume sysfs (FATE#324970,
  bsc#1078720).
- powerpc/eeh: Add EEH operations to notify resume (FATE#324970,
  bsc#1078720).
- powerpc/pseries: Set eeh_pe of EEH_PE_VF type (FATE#324970,
  bsc#1078720).
- PCI/AER: Add uevents in AER and EEH error/resume (FATE#324970,
  bsc#1078720).
- powerpc/eeh: Update VF config space after EEH (FATE#324970,
  bsc#1078720).
- PCI/IOV: Add pci_vf_drivers_autoprobe() interface (FATE#324970,
  bsc#1078720).
- powerpc/pseries: Add pseries SR-IOV Machine dependent calls
  (FATE#324970, bsc#1078720).
- powerpc/pci: Separate SR-IOV Calls (FATE#324970, bsc#1078720).
- PCI: Remove reset argument from pci_iov_{add,remove}_virtfn()
  (FATE#324970, bsc#1078720).
- commit 57512c6
* Tue Feb  6 2018 jthumshirn@suse.de
- Refresh
  patches.drivers/nvme-don-t-free-uuid-pointer-before-printing-it.patch.
- Refresh
  patches.drivers/nvme-fabrics-fix-memory-leak-when-parsing-host-ID-op.patch.
- Refresh
  patches.drivers/nvme-fabrics-protect-against-module-unload-during-cr.patch.
- Refresh
  patches.drivers/nvme-fix-comment-typos-in-nvme_create_io_queues.patch.
- Refresh
  patches.drivers/nvme-fix-subsystem-multiple-controllers-support-chec.patch.
- Refresh
  patches.drivers/nvme-host-delete_work-and-reset_work-on-separate-wor.patch.
- Refresh
  patches.drivers/nvme-modify-the-debug-level-for-setting-shutdown-tim.patch.
- Refresh
  patches.drivers/nvme-pci-Fix-queue-double-allocations.patch.
- Refresh
  patches.drivers/nvme-pci-Suspend-queues-after-deleting-them.patch.
- Refresh
  patches.drivers/nvme-pci-allocate-device-queues-storage-space-at-pro.patch.
- Refresh
  patches.drivers/nvme-pci-clean-up-CMB-initialization.patch.
- Refresh
  patches.drivers/nvme-pci-clean-up-SMBSZ-bit-definitions.patch.
- Refresh
  patches.drivers/nvme-pci-don-t-open-code-nvme_reset_ctrl.patch.
- Refresh
  patches.drivers/nvme-pci-fix-NULL-pointer-reference-in-nvme_alloc_ns.patch.
- Refresh
  patches.drivers/nvme-pci-introduce-RECONNECTING-state-to-mark-initia.patch.
- Refresh
  patches.drivers/nvme-pci-remove-an-unnecessary-initialization-in-HMB.patch.
- Refresh patches.drivers/nvme-pci-serialize-pci-resets.patch.
- Refresh
  patches.drivers/nvme-rdma-remove-redundant-boolean-for-inline_data.patch.
- Refresh
  patches.drivers/nvme-take-refcount-on-transport-module.patch.
- Refresh
  patches.drivers/nvme_fcloop-disassocate-local-port-structs.patch.
- Refresh
  patches.drivers/nvme_fcloop-fix-abort-race-condition.patch.
- Refresh
  patches.drivers/nvme_fcloop-refactor-host-target-io-job-access.patch.
- Refresh
  patches.drivers/nvme_fcloop-rework-to-remove-xxx_IN_ISR-feature-flag.patch.
- Refresh
  patches.drivers/nvmet-fix-error-flow-in-nvmet_alloc_ctrl.patch.
- Refresh
  patches.drivers/nvmet-lower-log-level-for-each-queue-creation.patch.
- Refresh
  patches.drivers/nvmet-rdma-lowering-log-level-for-chatty-debug-messa.patch.
- Refresh
  patches.drivers/nvmet-rdma-removed-queue-cleanup-from-module-exit.patch.
- Refresh patches.drivers/nvmet-rearrange-nvmet_ctrl_free.patch.
- Refresh
  patches.drivers/nvmet-release-a-ns-reference-in-nvmet_req_uninit-if-.patch.
- nvme-fc: correct hang in nvme_ns_remove() (bsc#1075811).
- nvme-fc: fix rogue admin cmds stalling teardown (bsc#1075811).
- commit dc349bb
* Tue Feb  6 2018 jthumshirn@suse.de
- nvme-pci: introduce RECONNECTING state to mark initializing
  procedure (FATE#323952, FATE#322506).
- nvme-rdma: remove redundant boolean for inline_data
  (FATE#323952, FATE#322506).
- nvme: don't free uuid pointer before printing it (FATE#323952,
  FATE#322506).
- nvme-pci: Suspend queues after deleting them (FATE#323952,
  FATE#322506).
- nvme-pci: Fix queue double allocations (FATE#323952,
  FATE#322506).
- nvme-pci: clean up SMBSZ bit definitions (FATE#323952,
  FATE#322506).
- nvme-pci: clean up CMB initialization (FATE#323952,
  FATE#322506).
- nvmet: release a ns reference in nvmet_req_uninit if needed
  (FATE#323952, FATE#322506).
- nvme-fabrics: fix memory leak when parsing host ID option
  (FATE#323952, FATE#322506).
- nvme: fix comment typos in nvme_create_io_queues (FATE#323952,
  FATE#322506).
- nvme: host delete_work and reset_work on separate workqueues
  (FATE#323952, FATE#322506).
- nvme-pci: allocate device queues storage space at probe
  (FATE#323952, FATE#322506).
- nvme-pci: serialize pci resets (FATE#323952, FATE#322506).
- nvme: fix subsystem multiple controllers support check
  (FATE#323952, FATE#322506).
- nvme: take refcount on transport module (FATE#323952,
  FATE#322506).
- nvme-pci: fix NULL pointer reference in nvme_alloc_ns
  (FATE#323952, FATE#322506).
- nvme: modify the debug level for setting shutdown timeout
  (FATE#323952, FATE#322506).
- nvme-pci: don't open-code nvme_reset_ctrl (FATE#323952,
  FATE#322506).
- nvmet: rearrange nvmet_ctrl_free() (FATE#323952, FATE#322506).
- nvmet: fix error flow in nvmet_alloc_ctrl() (FATE#323952,
  FATE#322506).
- nvme-pci: remove an unnecessary initialization in HMB code
  (FATE#323952, FATE#322506).
- nvme-fabrics: protect against module unload during create_ctrl
  (FATE#323952, FATE#322506).
- nvme_fcloop: refactor host/target io job access (FATE#323952,
  FATE#322506).
- nvme_fcloop: rework to remove xxx_IN_ISR feature flags
  (FATE#323952, FATE#322506).
- nvme_fcloop: disassocate local port structs (FATE#323952,
  FATE#322506).
- nvme_fcloop: fix abort race condition (FATE#323952,
  FATE#322506).
- nvmet: lower log level for each queue creation (FATE#323952,
  FATE#322506).
- nvmet-rdma: lowering log level for chatty debug messages
  (FATE#323952, FATE#322506).
- nvmet-rdma: removed queue cleanup from module exit (FATE#323952,
  FATE#322506).
- commit be5f8ed
* Tue Feb  6 2018 jthumshirn@suse.de
- nvme-pci: check segement valid for SGL use (FATE#323952,
  FATE#322506).
- nvme-pci: move use_sgl initialization to nvme_init_iod()
  (FATE#323952, FATE#322506).
- Refresh
  patches.drivers/nvme-pci-take-sglist-coalescing-in-dma_map_sg-into-a.patch.
- commit ccc76c3
* Tue Feb  6 2018 msuchanek@suse.de
- powerpc/pseries: Fix cpu hotplug crash with memoryless nodes
  (FATE#323746, bsc#1079524).
- powerpc/numa: Ensure nodes initialized for hotplug (FATE#323746,
  bsc#1079524).
- powerpc/numa: Use ibm,max-associativity-domains to discover
  possible nodes (FATE#323746, bsc#1079524).
- commit a5a5351
* Tue Feb  6 2018 jthumshirn@suse.de
- nvme-fabrics: initialize default host->id in nvmf_host_default()
  (FATE#323952, FATE#322506).
- nvme-fcloop: avoid possible uninitialized variable warning
  (FATE#323952, FATE#322506).
- nvme-rdma: fix concurrent reset and reconnect (FATE#323952,
  FATE#322506).
- nvme: fix sector units when going between formats (FATE#323952,
  FATE#322506).
- nvme: setup streams after initializing namespace head
  (FATE#323952, FATE#322506).
- nvme: check hw sectors before setting chunk sectors
  (FATE#323952, FATE#322506).
- nvme: call blk_integrity_unregister after queue is cleaned up
  (FATE#323952, FATE#322506).
- nvme: set discard_alignment to zero (FATE#323952, FATE#322506).
- nvme-pci: fix NULL pointer dereference in nvme_free_host_mem()
  (FATE#323952, FATE#322506).
- nvme-rdma: fix memory leak during queue allocation (FATE#323952,
  FATE#322506).
- commit 4cd5e8f
* Tue Feb  6 2018 jthumshirn@suse.de
- nvme: Suppress static analyis warning (FATE#323952,
  FATE#322506).
- Refresh
  patches.drivers/nvme-mpath-fix-last-path-removal-during-traffic.patch.
- commit 8ff7b73
* Tue Feb  6 2018 jthumshirn@suse.de
- nvme-rdma: Use mr pool (FATE#323952, FATE#322506).
- nvme-rdma: Check remotely invalidated rkey matches our expected
  rkey (FATE#323952, FATE#322506).
- nvme-rdma: wait for local invalidation before completing a
  request (FATE#323952, FATE#322506).
- nvme-rdma: don't complete requests before a send work request
  has completed (FATE#323952, FATE#322506).
- nvme-rdma: don't suppress send completions (FATE#323952,
  FATE#322506).
- nvme-pci: add quirk for delay before CHK RDY for WDC SN200
  (FATE#323952, FATE#322506).
- nvme: fix spelling mistake: "requeing" -> "requeuing"
  (FATE#323952, FATE#322506).
- nvme-pci: avoid hmb desc array idx out-of-bound when hmmaxd set
  (FATE#323952, FATE#322506).
- nvme-pci: disable APST on Samsung SSD 960 EVO + ASUS PRIME
  B350M-A (FATE#323952, FATE#322506).
- commit 98c37e8
* Tue Feb  6 2018 jthumshirn@suse.de
- Refresh
  patches.drivers/ibmvnic-Wait-for-device-response-when-changing-MAC.patch.
- Refresh
  patches.drivers/ibmvnic-fix-firmware-version-when-no-firmware-level-.patch.
- Refresh patches.drivers/scsi-cxlflash-Reset-command-ioasc.patch.
- Refresh
  patches.fixes/ipvlan-remove-excessive-packet-scrubbing.patch.
  Re-sort series.conf
- commit ff52d23
* Tue Feb  6 2018 bpoirier@suse.com
- Refresh patch order in sorted section
- Refresh
  patches.drivers/ibmvnic-Wait-for-device-response-when-changing-MAC.patch.
- Refresh
  patches.drivers/ibmvnic-fix-firmware-version-when-no-firmware-level-.patch.
- Refresh patches.drivers/scsi-cxlflash-Reset-command-ioasc.patch.
- Refresh
  patches.fixes/ipvlan-remove-excessive-packet-scrubbing.patch.
- scripts/git_sort/git_sort.py:
- scripts/git_sort/tests/test_git_sort.py:
- commit afdc520
* Mon Feb  5 2018 mbenes@suse.cz
- livepatch: Remove immediate feature (bsc#1071995 fate#323487).
  From upstream klp tree, branch for-4.16/remove-immediate.
- commit b4083e7
* Mon Feb  5 2018 mbenes@suse.cz
- livepatch: add locking to force and signal functions
  (bsc#1071995 fate#323487).
  Coming from upstream klp tree, branch for-4.16/signal-sysfs-force-v2.
- commit a2bfaf3
* Mon Feb  5 2018 mbenes@suse.cz
- livepatch: force transition to finish (bsc#1071995 fate#323487).
  Coming from upstream klp tree, branch for-4.16/signal-sysfs-force-v2.
- commit 15e3f65
* Mon Feb  5 2018 mbenes@suse.cz
- livepatch: send a fake signal to all blocking tasks (bsc#1071995
  fate#323487).
  Fake signal support. Coming from upstream klp tree, branch
  for-4.16/signal-sysfs-force-v2.
- commit c16c12d
* Mon Feb  5 2018 tbogendoerfer@suse.de
- iser-target: Fix possible use-after-free in connection
  establishment error (bsc#1046306 FATE#322942).
- net/mlx5e: Check support before TC swap in ETS init (bsc#1046303
  FATE#322944).
- net/mlx5e: Add error print in ETS init (bsc#1046303
  FATE#322944).
- IB/core: Fix unable to change lifespan entry for hw_counters
  (bsc#1046306 FATE#322942).
- commit 14a58fe
* Mon Feb  5 2018 tbogendoerfer@suse.de
- Re-sorted with series_sort
- Refresh
  patches.drivers/ibmvnic-Wait-for-device-response-when-changing-MAC.patch.
- Refresh
  patches.drivers/ibmvnic-fix-firmware-version-when-no-firmware-level-.patch.
- Refresh patches.drivers/scsi-cxlflash-Reset-command-ioasc.patch.
- Refresh
  patches.fixes/ipvlan-remove-excessive-packet-scrubbing.patch.
- commit 6db6f83
* Mon Feb  5 2018 oneukum@suse.com
- usbip: fix stub_rx: harden CMD_SUBMIT path to handle malicious
  input (bsc#1078672 CVE-2017-16913).
- commit 317c5b6
* Mon Feb  5 2018 oneukum@suse.com
- ahci: Add Intel Cannon Lake PCH-H PCI ID (bsc#1079088
  FATE#321195 FATE#322631).
- commit 1ad2ccd
* Mon Feb  5 2018 bp@suse.de
- x86/cpufeatures: Add Intel feature bits for Speculation Control
  (bsc#1068032 CVE-2017-5754).
- commit f45d5d3
* Mon Feb  5 2018 oneukum@suse.com
- Refresh
  patches.drivers/ibmvnic-Wait-for-device-response-when-changing-MAC.patch.
- Refresh
  patches.drivers/ibmvnic-fix-firmware-version-when-no-firmware-level-.patch.
- Refresh patches.drivers/scsi-cxlflash-Reset-command-ioasc.patch.
- Refresh
  patches.fixes/ipvlan-remove-excessive-packet-scrubbing.patch.
- commit 41ae0d8
* Mon Feb  5 2018 bp@suse.de
- x86/cpufeatures: Add CPUID_7_EDX CPUID leaf (bsc#1068032
  CVE-2017-5754).
- commit 914add9
* Mon Feb  5 2018 bp@suse.de
- x86/bugs: Drop one "mitigation" from dmesg (bsc#1068032
  CVE-2017-5754).
- commit 53d0557
* Mon Feb  5 2018 bp@suse.de
- blacklist.conf:
- commit f67c619
* Mon Feb  5 2018 tbogendoerfer@suse.de
- enic: add wq clean up budget (bsc#1075697).
- commit 245a193
* Mon Feb  5 2018 ghe@suse.com
- ocfs2: try a blocking lock before return AOP_TRUNCATED_PAGE
  (bsc#1073440).
- commit 26c40f8
* Mon Feb  5 2018 neilb@suse.com
- NFS: Add a cond_resched() to nfs_commit_release_pages()
  (bsc#1077779).
- commit 012a157
* Sun Feb  4 2018 neilb@suse.com
- nfsd: auth: Fix gid sorting when rootsquash enabled
  (CVE-2018-1000028, bsc#1078287).
- commit dda492e
* Fri Feb  2 2018 lduncan@suse.com
- rbd: set max_segments to USHRT_MAX (bsc#1078861).
- rbd: reacquire lock should update lock owner client id
  (bsc#1078873).
- netfilter: uapi: correct UNTRACKED conntrack state bit number
  (bsc#1078865).
- scsi: libiscsi: fix shifting of DID_REQUEUE host byte
  (bsc#1078875).
- commit 9a95b4e
* Fri Feb  2 2018 lduncan@suse.com
- ASN.1: fix out-of-bounds read when parsing indefinite length
  item (bsc#1078868).
- ASN.1: check for error from ASN1_OP_END__ACT actions
  (bsc#1078867).
- KEYS: fix NULL pointer dereference during ASN.1 parsing
  (bsc#1078866).
- KEYS: fix out-of-bounds read during ASN.1 parsing (bsc#1078862).
- commit 49124a8
* Fri Feb  2 2018 lduncan@suse.com
- lib/digsig: fix dereference of NULL user_key_payload
  (bsc#1078860).
- commit e74597f
* Fri Feb  2 2018 msuchanek@suse.de
- Update config files.
- commit 9008ce2
* Fri Feb  2 2018 jkosina@suse.cz
- README.BRANCH: make Jeff co-maintainer during my absence
- commit a8ed74e
* Fri Feb  2 2018 bp@suse.de
- x86/retpoline: Remove the esp/rsp thunk (bsc#1068032
  CVE-2017-5754).
- x86/intel_rdt/cqm: Prevent use after free (fate#323965).
- commit e562833
* Fri Feb  2 2018 msuchanek@suse.de
- ibmvnic: fix firmware version when no firmware level has been
  provided by the VIOS server (bsc#1079038).
- commit 3aa382e
* Fri Feb  2 2018 ohering@suse.de
- x86/hyper-v: stop suppressing X86_FEATURE_PCID (bsc#1077499).
- commit d007750
* Thu Feb  1 2018 msuchanek@suse.de
- ibmvnic: Wait for device response when changing MAC
  (bsc#1078681).
- commit 4a4b78c
* Thu Feb  1 2018 msuchanek@suse.de
- blacklist 070e004912fe powerpc/4xx: Fix compile error with 64K pages on 40x, 44x
- commit cafc1fc
* Thu Feb  1 2018 msuchanek@suse.de
- scsi: cxlflash: Reset command ioasc (fate#322239, git-fixes).
- commit 930f93e
* Thu Feb  1 2018 agraf@suse.de
- KVM: x86: take slots_lock in kvm_free_pit (bsc#1077761).
- commit 5c47320
* Thu Feb  1 2018 agraf@suse.de
- kvm: vmx: Properly handle machine check during VM-entry
  (bsc#1077761).
- commit 630935e
* Thu Feb  1 2018 agraf@suse.de
- KVM: x86: update master clock before computing kvmclock_offset
  (bsc#1077761).
- commit 5546449
* Thu Feb  1 2018 agraf@suse.de
- kvm: nVMX: Shadow "high" parts of shadowed 64-bit VMCS fields
  (bsc#1077761).
- commit 9c9cd12
* Thu Feb  1 2018 agraf@suse.de
- Move patches.fixes/kvm-nvmx-fix-nested_vmx_check_msr_bitmap_controls into sorted section
- commit 597672f
* Thu Feb  1 2018 agraf@suse.de
- kvm: nVMX: Validate the I/O bitmaps on nested VM-entry
  (bsc#1077761).
- commit ae097f9
* Thu Feb  1 2018 agraf@suse.de
- kvm: nVMX: Don't set vmcs12 to "launched" when VMLAUNCH fails
  (bsc#1077761).
- commit fb500c7
* Thu Feb  1 2018 agraf@suse.de
- KVM: use correct accessor function for __kvm_memslots
  (bsc#1077761).
- commit e6f2939
* Thu Feb  1 2018 agraf@suse.de
- KVM: mark memory slots as rcu (bsc#1077761).
- commit a4d1b3d
* Thu Feb  1 2018 agraf@suse.de
- KVM: mark kvm->busses as rcu protected (bsc#1077761).
- commit ba3fd3a
* Thu Feb  1 2018 agraf@suse.de
- KVM: use rcu access function for irq routing (bsc#1077761).
- commit d866df7
* Thu Feb  1 2018 agraf@suse.de
- KVM: mark vcpu->pid pointer as rcu protected (bsc#1077761).
- commit f2e0948
* Thu Feb  1 2018 agraf@suse.de
- KVM: vmx: expose more information for
  KVM_INTERNAL_ERROR_DELIVERY_EV exits (bsc#1077761).
- commit 0622f81
* Thu Feb  1 2018 agraf@suse.de
- kvm: avoid unused variable warning for UP builds (bsc#1077761).
- commit 2e79598
* Thu Feb  1 2018 agraf@suse.de
- x86: kvm: mmu: use ept a/d in vmcs02 iff used in vmcs12
  (bsc#1077761).
- commit b81235c
* Thu Feb  1 2018 agraf@suse.de
- kvm: x86: mmu: allow A/D bits to be disabled in an mmu
  (bsc#1077761).
- commit aa98336
* Thu Feb  1 2018 agraf@suse.de
- x86: kvm: mmu: make spte mmio mask more explicit (bsc#1077761).
- commit 05b622d
* Thu Feb  1 2018 agraf@suse.de
- x86: kvm: mmu: dead code thanks to access tracking
  (bsc#1077761).
- commit 8c29652
* Thu Feb  1 2018 agraf@suse.de
- KVM: PPC: Book3S HV: Add capability to report possible virtual
  SMT modes (bsc#1077761).
- commit ff30e98
* Thu Feb  1 2018 agraf@suse.de
- KVM: PPC: Book3S HV: Virtualize doorbell facility on POWER9
  (bsc#1077761).
- commit 73e258b
* Thu Feb  1 2018 agraf@suse.de
- KVM: PPC: Book3S HV: Allow userspace to set the desired SMT mode
  (bsc#1077761).
- commit ef28960
* Thu Feb  1 2018 agraf@suse.de
- KVM: PPC: Book3S HV: Context-switch HFSCR between host and
  guest on POWER9 (bsc#1077761).
- commit f4ba5c4
* Thu Feb  1 2018 agraf@suse.de
- KVM: PPC: Book3S HV: Enable guests to use large decrementer
  mode on POWER9 (bsc#1077761).
- commit 5e26c30
* Thu Feb  1 2018 agraf@suse.de
- KVM: x86: remove ignored type attribute (bsc#1077761).
- commit f488813
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm/arm64: Signal SIGBUS when stage2 discovers hwpoison
  memory (bsc#1077761).
- commit 94ecc41
* Thu Feb  1 2018 agraf@suse.de
- arm64/kvm: vgic: use SYS_DESC() (bsc#1077761).
- commit 35d3070
* Thu Feb  1 2018 agraf@suse.de
- arm64/kvm: sysreg: fix typo'd SYS_ICC_IGRPEN*_EL1 (bsc#1077761).
- commit 4396c4d
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm64: Log an error if trapping a write-to-read-only
  GICv3 access (bsc#1077761).
- commit f14efa3
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm64: Log an error if trapping a read-from-write-only
  GICv3 access (bsc#1077761).
- commit e878ccd
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm64: vgic-v3: Log which GICv3 system registers are
  trapped (bsc#1077761).
- commit c2ec271
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm64: Enable GICv3 common sysreg trapping via command-line
  (bsc#1077761).
- commit 83b2209
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm64: vgic-v3: Add ICV_PMR_EL1 handler (bsc#1077761).
- commit b32111f
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm64: vgic-v3: Add ICV_CTLR_EL1 handler (bsc#1077761).
- commit c6056fb
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm64: vgic-v3: Add ICV_RPR_EL1 handler (bsc#1077761).
- commit 4d8e18a
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm64: vgic-v3: Add ICV_DIR_EL1 handler (bsc#1077761).
- commit dc81a76
* Thu Feb  1 2018 agraf@suse.de
- arm64: Add workaround for Cavium Thunder erratum 30115
  (bsc#1077761).
- Refresh
  patches.drivers/0003-iommu-arm-smmu-v3-Add-workaround-for-Cavium-ThunderX.patch.
- Refresh
  patches.drivers/0004-iommu-arm-smmu-v3-Add-workaround-for-Cavium-ThunderX.patch.
- commit 672e3a4
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm64: Enable GICv3 Group-0 sysreg trapping via
  command-line (bsc#1077761).
- commit a43257d
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm64: vgic-v3: Enable trapping of Group-0 system registers
  (bsc#1077761).
- commit 6704cd7
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm64: vgic-v3: Add misc Group-0 handlers (bsc#1077761).
- commit f366ea5
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm64: vgic-v3: Add ICV_IGNREN0_EL1 handler (bsc#1077761).
- commit 843e1f8
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm64: vgic-v3: Add ICV_BPR0_EL1 handler (bsc#1077761).
- commit 4da31c6
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm64: Enable GICv3 Group-1 sysreg trapping via
  command-line (bsc#1077761).
- commit 11e3aa3
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm64: vgic-v3: Enable trapping of Group-1 system registers
  (bsc#1077761).
- commit 98ed82e
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm64: vgic-v3: Add ICV_HPPIR1_EL1 handler (bsc#1077761).
- commit ae8c87c
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm64: vgic-v3: Add ICV_AP1Rn_EL1 handler (bsc#1077761).
- commit 43c6bc4
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm64: vgic-v3: Add ICV_EOIR1_EL1 handler (bsc#1077761).
- commit ceeaa18
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm64: vgic-v3: Add ICV_IAR1_EL1 handler (bsc#1077761).
- commit 12da559
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm64: vgic-v3: Add ICV_IGRPEN1_EL1 handler (bsc#1077761).
- commit e1b4ec3
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm64: vgic-v3: Add ICV_BPR1_EL1 handler (bsc#1077761).
- commit 559ee43
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm64: vgic-v3: Add hook to handle guest GICv3 sysreg
  accesses at EL2 (bsc#1077761).
- commit 08361be
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm64: Make kvm_condition_valid32() accessible from EL2
  (bsc#1077761).
- commit accb6b5
* Thu Feb  1 2018 aaptel@suse.com
- CIFS: dump IPC tcon in debug proc file (bsc#1071306).
- commit e844d61
* Thu Feb  1 2018 aaptel@suse.com
- CIFS: use tcon_ipc instead of use_ipc parameter of SMB2_ioctl
  (bsc#1071306).
- commit 31e7d7b
* Thu Feb  1 2018 aaptel@suse.com
- CIFS: make IPC a regular tcon (bsc#1071306).
- commit baba794
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm/arm64: vgic-v3: Add accessors for the ICH_APxRn_EL2
  registers (bsc#1077761).
- commit e0e50a9
* Thu Feb  1 2018 lhenriques@suse.com
- xfs: reinit btree pointer on attr tree inactivation walk
  (bsc#1078787).
- commit 00accea
* Thu Feb  1 2018 tbogendoerfer@suse.de
- cxgb4: make symbol pedits static (bsc#1064802 bsc#1066129).
- nfp: fix error return code in nfp_pci_probe() (bsc#1055968).
- IB/core: Fix ib_wc structure size to remain in 64 bytes boundary
  (bsc#1046306 FATE#322942).
- net/mlx5: Fix race for multiple RoCE enable (bsc#1046303
  FATE#322944).
- RDMA/cma: Mark end of CMA ID messages (bsc#1046306 FATE#322942).
- RDMA/vmw_pvrdma: Add UAR SRQ macros in ABI header file
  (bsc#1046306 FATE#322942).
- iw_cxgb4: make pointer reg_workq static (bsc#1064802
  bsc#1066129).
- net/mlx5e: Fix ETS BW check (bsc#1075360).
- commit 76cecfb
* Thu Feb  1 2018 tbogendoerfer@suse.de
- Re-sorted series and Updated patch-mainline
- Refresh
  patches.drivers/IB-CM-Change-sgid-to-IB-GID-when-handling-CM-request.patch.
- Refresh
  patches.drivers/IB-hfi1-Mask-the-path-bits-with-the-LMC-for-16B-RC-A.patch.
- Refresh
  patches.drivers/IB-hfi1-Use-4096-for-default-active-MTU-in-query_qp.patch.
- Refresh
  patches.drivers/RDMA-bnxt_re-Add-SRQ-support-for-Broadcom-adapters.patch.
- Refresh
  patches.drivers/RDMA-bnxt_re-Add-support-for-MRs-with-Huge-pages.patch.
- Refresh
  patches.drivers/RDMA-bnxt_re-Add-support-for-query-firmware-version.patch.
- Refresh
  patches.drivers/RDMA-bnxt_re-Enable-RoCE-on-virtual-functions.patch.
- Refresh
  patches.drivers/RDMA-bnxt_re-expose-detailed-stats-retrieved-from-HW.patch.
- Refresh patches.drivers/bnxt_en-Add-ETH_RESET_AP-support.patch.
- Refresh
  patches.drivers/bnxt_en-Don-t-print-Link-speed-1-no-longer-supported.patch.
- Refresh
  patches.drivers/bnxt_en-Uninitialized-variable-in-bnxt_tc_parse_acti.patch.
- Refresh patches.drivers/bnxt_en-Use-NETIF_F_GRO_HW.patch.
- Refresh patches.drivers/cxgb4-RSS-table-is-4k-for-T6.patch.
- Refresh patches.drivers/cxgb4-collect-HMA-memory-dump.patch.
- Refresh patches.drivers/cxgb4-collect-MC-memory-dump.patch.
- Refresh
  patches.drivers/cxgb4-collect-PCIe-configuration-logs.patch.
- Refresh
  patches.drivers/cxgb4-collect-TX-rate-limit-info-in-UP-CIM-logs.patch.
- Refresh
  patches.drivers/cxgb4-collect-egress-and-ingress-SGE-queue-contexts.patch.
- Refresh
  patches.drivers/cxgb4-collect-on-chip-memory-information.patch.
- Refresh
  patches.drivers/cxgb4-skip-TX-and-RX-payload-regions-in-memory-dumps.patch.
- Refresh
  patches.drivers/ibmvnic-Don-t-handle-RX-interrupts-when-not-up.patch.
- Refresh
  patches.drivers/ibmvnic-Include-header-descriptor-support-for-ARP-pa.patch.
- Refresh
  patches.drivers/ibmvnic-Increase-maximum-number-of-RX-TX-queues.patch.
- Refresh
  patches.drivers/ibmvnic-Rename-IBMVNIC_MAX_TX_QUEUES-to-IBMVNIC_MAX_.patch.
- Refresh
  patches.drivers/lpfc-Adjust-default-value-of-lpfc_nvmet_mrq.patch.
- Refresh
  patches.drivers/lpfc-Beef-up-stat-counters-for-debug.patch.
- Refresh
  patches.drivers/lpfc-Correct-driver-deregistrations-with-host-n.patch.
- Refresh
  patches.drivers/lpfc-Driver-fails-to-detect-direct-attach-stora.patch.
- Refresh
  patches.drivers/lpfc-Expand-WQE-capability-of-every-NVME-hardwa.patch.
- Refresh
  patches.drivers/lpfc-FLOGI-failures-are-reported-when-connected.patch.
- Refresh
  patches.drivers/lpfc-Fix-EOVERFLOW-behavior-for-NVMET-and-defer.patch.
- Refresh patches.drivers/lpfc-Fix-NVME-LS-abort_xri.patch.
- Refresh
  patches.drivers/lpfc-Fix-SCSI-LUN-discovery-when-SCSI-and-NVME-.patch.
- Refresh
  patches.drivers/lpfc-Fix-crash-after-bad-bar-setup-on-driver-at.patch.
- Refresh
  patches.drivers/lpfc-Fix-crash-during-driver-unload-with-runnin.patch.
- Refresh
  patches.drivers/lpfc-Fix-display-for-debugfs-queInfo.patch.
- Refresh
  patches.drivers/lpfc-Fix-driver-handling-of-nvme-resources-duri.patch.
- Refresh
  patches.drivers/lpfc-Fix-infinite-wait-when-driver-unregisters-.patch.
- Refresh
  patches.drivers/lpfc-Fix-issues-connecting-with-nvme-initiator.patch.
- Refresh
  patches.drivers/lpfc-Fix-ndlp-ref-count-for-pt2pt-mode-issue-RS.patch.
- Refresh
  patches.drivers/lpfc-Fix-random-heartbeat-timeouts-during-heavy.patch.
- Refresh patches.drivers/lpfc-Fix-receive-PRLI-handling.patch.
- Refresh
  patches.drivers/lpfc-Handle-XRI_ABORTED_CQE-in-soft-IRQ.patch.
- Refresh
  patches.drivers/lpfc-Increase-SCSI-CQ-and-WQ-sizes.patch.
- Refresh
  patches.drivers/lpfc-Linux-LPFC-driver-does-not-process-all-RSC.patch.
- Refresh
  patches.drivers/lpfc-Raise-maximum-NVME-sg-list-size-for-256-el.patch.
- Refresh
  patches.drivers/lpfc-correct-port-registrations-with-nvme_fc.patch.
- Refresh
  patches.drivers/lpfc-correct-sg_seg_cnt-attribute-min-vs-defaul.patch.
- Refresh
  patches.drivers/lpfc-don-t-dereference-localport-before-it-has-.patch.
- Refresh
  patches.drivers/lpfc-fix-a-couple-of-minor-indentation-issues.patch.
- Refresh patches.drivers/lpfc-small-sg-cnt-cleanup.patch.
- Refresh
  patches.drivers/lpfc-update-driver-version-to-11.4.0.5.patch.
- Refresh
  patches.drivers/lpfc-update-driver-version-to-11.4.0.6.patch.
- Refresh
  patches.drivers/net-Disable-GRO_HW-when-generic-XDP-is-installed-on-.patch.
- Refresh patches.drivers/net-Introduce-NETIF_F_GRO_HW.patch.
- Refresh
  patches.drivers/net-ethtool-add-support-for-reset-of-AP-inside-NIC-i.patch.
- Refresh
  patches.drivers/scsi-libiscsi-allow-sd_shutdown-on-bad-transport.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-recursion-while-sending-terminate-e.patch.
- commit f6992cb
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm/arm64: Don't assume initialized vgic when setting
  PMU IRQ (bsc#1077761).
- commit e46c7d2
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm/arm64: Disallow userspace control of in-kernel IRQ
  lines (bsc#1077761).
- commit 17a802a
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm/arm64: Check if irq lines to the GIC are already used
  (bsc#1077761).
- commit c6c6bff
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm/arm64: Introduce an allocator for in-kernel irq lines
  (bsc#1077761).
- commit 3904963
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm/arm64: Allow setting the timer IRQ numbers from
  userspace (bsc#1077761).
- commit 46f128d
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm/arm64: Move timer IRQ default init to arch_timer.c
  (bsc#1077761).
- commit e809754
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm/arm64: Move irq_is_ppi() to header file (bsc#1077761).
- commit e5a67f0
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm: Handle VCPU device attributes in guest.c
  (bsc#1077761).
- commit 550f6bb
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm64: Allow creating the PMU without the in-kernel GIC
  (bsc#1077761).
- commit ed17f94
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm/arm64: timer: remove request-less vcpu kick
  (bsc#1077761).
- commit c014526
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm/arm64: PMU: remove request-less vcpu kick
  (bsc#1077761).
- commit fd61d9a
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm/arm64: use vcpu requests for irq injection
  (bsc#1077761).
- commit 9f686bf
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm/arm64: change exit request to sleep request
  (bsc#1077761).
- commit e8990de
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm/arm64: optimize VCPU RUN (bsc#1077761).
- commit 5d5c02d
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm/arm64: use vcpu requests for power_off (bsc#1077761).
- commit 3b24c3f
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm/arm64: replace pause checks with vcpu request checks
  (bsc#1077761).
- commit 1df0a22
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm/arm64: properly use vcpu requests (bsc#1077761).
- commit c19d6ba
* Thu Feb  1 2018 agraf@suse.de
- KVM: add kvm_request_pending (bsc#1077761).
- commit 7d071ca
* Thu Feb  1 2018 agraf@suse.de
- KVM: improve arch vcpu request defining (bsc#1077761).
- commit fcdd37e
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm/arm64: Use uaccess functions for GICv3 {sc}active
  (bsc#1077761).
- commit a6aa308
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm/arm64: Simplify active_change_prepare and plug race
  (bsc#1077761).
- commit 5f251f5
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm/arm64: Separate guest and uaccess writes to dist
  {sc}active (bsc#1077761).
- commit 06c1e27
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm/arm64: Allow GICv2 to supply a uaccess register
  function (bsc#1077761).
- commit a828f2c
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm64: Restore host physical timer access on hyp_panic()
  (bsc#1077761).
- commit 3c9a486
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm: Restore banked registers and physical timer access
  on hyp_panic() (bsc#1077761).
- commit 81c5b15
* Thu Feb  1 2018 agraf@suse.de
- KVM: LAPIC: Fix lapic timer injection delay (bsc#1077761).
- commit 2887434
* Thu Feb  1 2018 agraf@suse.de
- KVM: lapic: reorganize restart_apic_timer (bsc#1077761).
- commit b3c54e2
* Thu Feb  1 2018 agraf@suse.de
- KVM: lapic: reorganize start_hv_timer (bsc#1077761).
- commit d1ec16e
* Thu Feb  1 2018 agraf@suse.de
- KVM: s390: avoid packed attribute (bsc#1077761).
- Refresh
  patches.drivers/kvm-Inject-machine-check-into-the-nested-guest.patch.
- commit 0fb9b38
* Thu Feb  1 2018 agraf@suse.de
- KVM: S390: add new group for flic (bsc#1077761).
- commit 957f3a8
* Thu Feb  1 2018 agraf@suse.de
- KVM: s390: implement instruction execution protection for
  emulated ifetch (bsc#1077761).
- commit 9f7e596
* Thu Feb  1 2018 agraf@suse.de
- kvm: nVMX: Check memory operand to INVVPID (bsc#1077761).
- commit a142483
* Thu Feb  1 2018 agraf@suse.de
- KVM: explain missing kvm_put_kvm in case of failure
  (bsc#1077761).
- commit f859907
* Thu Feb  1 2018 agraf@suse.de
- KVM: Replaces symbolic permissions with numeric (bsc#1077761).
- commit c981562
* Thu Feb  1 2018 agraf@suse.de
- KVM: nVMX: Don't update vmcs12->xss_exit_bitmap on nested
  VM-exit (bsc#1077761).
- commit 334fe01
* Thu Feb  1 2018 agraf@suse.de
- KVM: x86: avoid large stack allocations in em_fxrstor
  (bsc#1077761).
- commit 2980e35
* Thu Feb  1 2018 agraf@suse.de
- KVM: white space cleanup in nested_vmx_setup_ctls_msrs()
  (bsc#1077761).
- commit 4ba3a7c
* Thu Feb  1 2018 agraf@suse.de
- KVM: Tidy the whitespace in nested_svm_check_permissions()
  (bsc#1077761).
- commit 8351f67
* Thu Feb  1 2018 agraf@suse.de
- s390: rename struct psw_bits members (bsc#1077761).
- commit b1352ea
* Thu Feb  1 2018 agraf@suse.de
- s390: rename psw_bits enums (bsc#1077761).
- commit df2b8ca
* Thu Feb  1 2018 msuchanek@suse.de
- Refresh patches.arch/powerpc-pseries-rfi-flush-Call-setup_rfi_flush-after.patch.
  Fix return value
- commit b1d44b2
* Wed Jan 31 2018 jslaby@suse.cz
- ftrace, orc, x86: Handle ftrace dynamically allocated
  trampolines (bnc#1058115).
- objtool: Fix seg fault caused by missing parameter
  (bnc#1058115).
- objtool: Move synced files to their original relative locations
  (bnc#1058115).
- objtool: Fix seg fault with clang-compiled objects
  (bnc#1058115).
- objtool: Move kernel headers/code sync check to a script
  (bnc#1058115).
- tracing: Update stack trace skipping for ORC unwinder
  (bnc#1058115).
- objtool: Fix 64-bit build on 32-bit host (bnc#1058115).
- objtool: Fix Clang enum conversion warning (bnc#1058115).
- objtool: Fix cross-build (bnc#1058115).
- tools/objtool/Makefile: don't assume sync-check.sh is executable
  (bnc#1058115).
- x86/ftrace: Add one more ENDPROC annotation (bnc#1058115).
- x86/ftrace: Fix ORC unwinding from ftrace handlers
  (bnc#1058115).
- x86/stacktrace: Make zombie stack traces reliable (bnc#1058115).
- Refresh
  patches.arch/10-x86-dumpstack-handle-stack-overflow-on-all-stacks.patch.
- Refresh
  patches.arch/11-x86-entry-rename-sysenter_stack-to-cpu_entry_area_entry_stack.patch.
- Refresh
  patches.arch/24-x86-retpoline-ftrace-convert-ftrace-assembler-indirect-jumps.patch.
- Refresh
  patches.suse/0002-x86-stacktrace-make-clear-the-success-paths.patch.
  Update ORC to the upstream status.
- commit 3cd5617
* Wed Jan 31 2018 msuchanek@suse.de
- include/linux/mm.h: fix typo in VM_MPX definition (FATE#322447,
  bsc#1078248).
- commit 981f4b2
* Wed Jan 31 2018 msuchanek@suse.de
- Update config files.
- commit c74eda6
* Wed Jan 31 2018 msuchanek@suse.de
- selftests/powerpc: Add core file test for Protection Key
  register (FATE#322447, bsc#1078248).
- selftests/powerpc: Add ptrace tests for Protection Key register
  (FATE#322447, bsc#1078248).
- selftests/vm: Fix deadlock in protection_keys.c (FATE#322447,
  bsc#1078248).
- selftests/vm: sub-page allocator (FATE#322447, bsc#1078248).
- selftests/vm: testcases must restore pkey-permissions
  (FATE#322447, bsc#1078248).
- selftests/vm: detect write violation on a mapped
  access-denied-key page (FATE#322447, bsc#1078248).
- selftests/vm: associate key on a mapped page and detect write
  violation (FATE#322447, bsc#1078248).
- selftests/vm: associate key on a mapped page and detect access
  violation (FATE#322447, bsc#1078248).
- selftests/vm: fix an assertion in test_pkey_alloc_exhaust()
  (FATE#322447, bsc#1078248).
- selftests/vm: powerpc implementation to check support for pkey
  (FATE#322447, bsc#1078248).
- selftests/vm: clear the bits in shadow reg when a pkey is freed
  (FATE#322447, bsc#1078248).
- selftests/vm: powerpc implementation for generic abstraction
  (FATE#322447, bsc#1078248).
- selftests/vm: generic cleanup (FATE#322447, bsc#1078248).
- selftests/vm: pkey register should match shadow pkey
  (FATE#322447, bsc#1078248).
- selftests/vm: introduce two arch independent abstraction
  (FATE#322447, bsc#1078248).
- selftests/vm: fix alloc_random_pkey() to make it really random
  (FATE#322447, bsc#1078248).
- selftests/vm: clear the bits in shadow reg when a pkey is freed
  (FATE#322447, bsc#1078248).
- selftests/vm: fixed bugs in pkey_disable_clear() (FATE#322447,
  bsc#1078248).
- selftests/vm: fix the wrong assert in pkey_disable_set()
  (FATE#322447, bsc#1078248).
- selftests/vm: generic function to handle shadow key register
  (FATE#322447, bsc#1078248).
- selftests/vm: typecast the pkey register (FATE#322447,
  bsc#1078248).
- selftests/vm: move generic definitions to header file
  (FATE#322447, bsc#1078248).
- selftests/vm: rename all references to pkru to a generic name
  (FATE#322447, bsc#1078248).
- selftests/x86: Move protecton key selftest to arch neutral
  directory (FATE#322447, bsc#1078248).
- x86/pkeys/selftests: Fix protection keys write() warning
  (FATE#322447, bsc#1078248).
- x86/pkeys/selftests: Rename 'si_pkey' to 'siginfo_pkey'
  (FATE#322447, bsc#1078248).
- selftests/x86/protection_keys: Fix syscall NR redefinition
  warnings (FATE#322447, bsc#1078248).
- signal/testing: Don't look for __SI_FAULT in userspace
  (FATE#322447, bsc#1078248).
- Documentation/vm: PowerPC specific updates to memory protection
  keys (FATE#322447, bsc#1078248).
- Documentation/x86: Move protecton key documentation to arch
  neutral directory (FATE#322447, bsc#1078248).
- mm, x86: display pkey in smaps only if arch supports pkeys
  (FATE#322447, bsc#1078248).
- Refresh patches.suse/mm-fix-KSM-data-corruption.patch.
- powerpc: sys_pkey_mprotect() system call (FATE#322447,
  bsc#1078248).
- powerpc: sys_pkey_alloc() and sys_pkey_free() system calls
  (FATE#322447, bsc#1078248).
- powerpc: Enable pkey subsystem (FATE#322447, bsc#1078248).
- powerpc/ptrace: Add memory protection key regset (FATE#322447,
  bsc#1078248).
- powerpc: Deliver SEGV signal on pkey violation (FATE#322447,
  bsc#1078248).
- powerpc: introduce get_mm_addr_key() helper (FATE#322447,
  bsc#1078248).
- powerpc: Handle exceptions caused by pkey violation
  (FATE#322447, bsc#1078248).
- powerpc: implementation for arch_vma_access_permitted()
  (FATE#322447, bsc#1078248).
- powerpc: check key protection for user page access (FATE#322447,
  bsc#1078248).
- powerpc: helper to validate key-access permissions of a pte
  (FATE#322447, bsc#1078248).
- powerpc: Program HPTE key protection bits (FATE#322447,
  bsc#1078248).
- powerpc: map vma key-protection bits to pte key bits
  (FATE#322447, bsc#1078248).
- powerpc: implementation for arch_override_mprotect_pkey()
  (FATE#322447, bsc#1078248).
- powerpc: ability to associate pkey to a vma (FATE#322447,
  bsc#1078248).
- powerpc: introduce execute-only pkey (FATE#322447, bsc#1078248).
- powerpc: store and restore the pkey state across context
  switches (FATE#322447, bsc#1078248).
- powerpc: ability to create execute-disabled pkeys (FATE#322447,
  bsc#1078248).
- powerpc: implementation for arch_set_user_pkey_access()
  (FATE#322447, bsc#1078248).
- powerpc: cleanup AMR, IAMR when a key is allocated or freed
  (FATE#322447, bsc#1078248).
- powerpc: helper functions to initialize AMR, IAMR and UAMOR
  registers (FATE#322447, bsc#1078248).
- powerpc: helper function to read, write AMR, IAMR, UAMOR
  registers (FATE#322447, bsc#1078248).
- powerpc: track allocation status of all pkeys (FATE#322447,
  bsc#1078248).
- powerpc: initial pkey plumbing (FATE#322447, bsc#1078248).
- mm, powerpc, x86: introduce an additional vma bit for powerpc
  pkey (FATE#322447, bsc#1078248).
- mm, powerpc, x86: define VM_PKEY_BITx bits if
  CONFIG_ARCH_HAS_PKEYS is enabled (FATE#322447, bsc#1078248).
- powerpc: capture the PTE format changes in the dump pte report
  (FATE#322447, bsc#1078248).
- powerpc: use helper functions to get and set hash slots
  (FATE#322447, bsc#1078248).
- powerpc: Swizzle around 4K PTE bits to free up bit 5 and bit 6
  (FATE#322447, bsc#1078248).
- powerpc: shifted-by-one hidx value (FATE#322447, bsc#1078248).
- powerpc: Free up four 64K PTE bits in 64K backed HPTE pages
  (FATE#322447, bsc#1078248).
- powerpc: Free up four 64K PTE bits in 4K backed HPTE pages
  (FATE#322447, bsc#1078248).
- powerpc: introduce pte_get_hash_gslot() helper (FATE#322447,
  bsc#1078248).
- powerpc: introduce pte_set_hidx() helper (FATE#322447,
  bsc#1078248).
- powerpc/mm/book3s/64: Add proper pte access check helper
  (FATE#322447, bsc#1078248).
- powerpc/mm: Don't lose "major" fault indication on retry
  (FATE#322447, bsc#1078248).
- powerpc/mm: Set fault flags earlier (FATE#322447, bsc#1078248).
- powerpc/mm: Evaluate user_mode(regs) only once in
  do_page_fault() (FATE#322447, bsc#1078248).
- powerpc/mm: Remove a redundant test in do_page_fault()
  (FATE#322447, bsc#1078248).
- powerpc/mm: Only call store_updates_sp() on stores in
  do_page_fault() (FATE#322447, bsc#1078248).
- powerpc: Fix DABR match on hash based systems (FATE#322447,
  bsc#1078248).
- powerpc/64s: Replace CONFIG_PPC_STD_MMU_64 with
  CONFIG_PPC_BOOK3S_64 (FATE#322447, bsc#1078248).
- powerpc/mm: Update bits used to skip hash_page (FATE#322447,
  bsc#1078248).
- powerpc/mm: Update definitions of DSISR bits (FATE#322447,
  bsc#1078248).
- x86,mpx: make mpx depend on x86-64 to free up VMA flag
  (FATE#322447, bsc#1078248).
- commit 90fbf25
* Wed Jan 31 2018 yousaf.kaukab@suse.com
- arm64: Branch predictor hardening for Cavium ThunderX2
  (bsc#1068032).
- commit c0ea639
* Wed Jan 31 2018 mgorman@suse.de
- Refresh
  patches.fixes/mm-Batch-radix-tree-operations-when-truncating-pages.patch.
- Refresh
  patches.fixes/mm-Factor-out-checks-and-accounting-from-__delete_fr.patch.
- Refresh
  patches.fixes/mm-Factor-out-page-cache-page-freeing-into-a-separat.patch.
- Refresh
  patches.fixes/mm-Move-accounting-updates-before-page_cache_tree_de.patch.
- Refresh
  patches.fixes/mm-Move-clearing-of-page-mapping-to-page_cache_tree_.patch.
- Refresh patches.fixes/mm-Refactor-truncate_complete_page.patch.
- Refresh
  patches.fixes/mm-Speedup-cancel_dirty_page-for-clean-pages.patch.
- Refresh
  patches.suse/sched-Only-immediately-migrate-tasks-due-to-interrupts-if-prev-and-target-CPUs-share-cache.patch.
- Refresh
  patches.suse/sched-wait-fix-add_wait_queue-behavior-change.patch.
- commit c2de752
* Wed Jan 31 2018 jthumshirn@suse.de
- scsi: qla2xxx: Initialize Work element before requesting IRQs
  (bsc#1050313).
- scsi: qla2xxx: Fix uninitialized work element (bsc#1050313).
- commit 20470eb
* Wed Jan 31 2018 jthumshirn@suse.de
- Refresh
  patches.drivers/block-Provide-blk_status_t-decoding-for-path-errors.patch.
- Refresh patches.drivers/dm-mpath-Use-blk_path_error.patch.
- Refresh
  patches.drivers/nvme-Add-more-command-status-translation.patch.
- Refresh
  patches.drivers/nvme-add-tracepoint-for-nvme_complete_rq.patch.
- Refresh
  patches.drivers/nvme-add-tracepoint-for-nvme_setup_cmd.patch.
- Refresh
  patches.drivers/nvme-also-expose-the-namespace-identification-sysfs-.patch.
- Refresh
  patches.drivers/nvme-fix-visibility-of-uuid-ns-attribute.patch.
- Refresh
  patches.drivers/nvme-introduce-a-nvme_ns_ids-structure.patch.
- Refresh
  patches.drivers/nvme-multipath-Consult-blk_status_t-for-failover.patch.
- Refresh patches.drivers/nvme-multipath-Use-blk_path_error.patch.
- Refresh patches.drivers/nvme-track-shared-namespaces.patch.
- Refresh
  patches.drivers/nvmet-fc-cleanup-nvmet-add_port-remove_port.patch.
  Re-sort series.conf
- commit 2edda93
* Tue Jan 30 2018 lhenriques@suse.com
- Refresh
  patches.fixes/ceph-drop-negative-child-dentries-before-try-pruning-inode-s-alias.patch.
- commit 66812af
* Tue Jan 30 2018 lhenriques@suse.com
- libceph: don't WARN() if user tries to add invalid key
  (FATE#324714).
- ceph: silence sparse endianness warning in encode_caps_cb
  (FATE#324714).
- ceph: present consistent fsid, regardless of arch endianness
  (FATE#324714).
- ceph: clean up spinlocking and list handling around
  cleanup_cap_releases() (FATE#324714).
- ceph: remove unused and redundant variable dropping
  (FATE#324714).
- ceph: mark expected switch fall-throughs (FATE#324714).
- ceph: -EINVAL on decoding failure in ceph_mdsc_handle_fsmap()
  (FATE#324714).
- ceph: disable cached readdir after dropping positive dentry
  (FATE#324714).
- ceph: fix bool initialization/comparison (FATE#324714).
- ceph: handle 'session get evicted while there are file locks'
  (FATE#324714).
- ceph: optimize flock encoding during reconnect (FATE#324714).
- ceph: make lock_to_ceph_filelock() static (FATE#324714).
- ceph: keep auth cap when inode has flocks or posix locks
  (FATE#324714).
- commit b22d2c0
* Tue Jan 30 2018 lhenriques@suse.com
- ceph: unlock dangling spinlock in try_flush_caps()
  (FATE#324714).
- ceph: fix __choose_mds() for LSSNAP request (FATE#324714).
- ceph: properly queue cap snap for newly created snap realm
  (FATE#324714).
- ceph: avoid panic in create_session_open_msg() if utsname()
  returns NULL (FATE#324714).
- libceph: don't allow bidirectional swap of pg-upmap-items
  (FATE#324714).
- ceph: stop on-going cached readdir if mds revokes FILE_SHARED
  cap (FATE#324714).
- ceph: wait on writeback after writing snapshot data
  (FATE#324714).
- ceph: fix capsnap dirty pages accounting (FATE#324714).
- ceph: ignore wbc->range_{start,end} when write back snapshot
  data (FATE#324714).
- ceph: fix "range cyclic" mode writepages (FATE#324714).
- ceph: cleanup local variables in ceph_writepages_start()
  (FATE#324714).
- ceph: optimize pagevec iterating in ceph_writepages_start()
  (FATE#324714).
- ceph: make writepage_nounlock() invalidate page that beyonds
  EOF (FATE#324714).
- ceph: properly get capsnap's size in get_oldest_context()
  (FATE#324714).
- ceph: remove stale check in ceph_invalidatepage() (FATE#324714).
- ceph: queue cap snap only when snap realm's context changes
  (FATE#324714).
- ceph: handle race between vmtruncate and queuing cap snap
  (FATE#324714).
- ceph: fix message order check in handle_cap_export()
  (FATE#324714).
- ceph: fix NULL pointer dereference in ceph_flush_snaps()
  (FATE#324714).
- ceph: adjust 36 checks for NULL pointers (FATE#324714).
- ceph: delete an unnecessary return statement in
  update_dentry_lease() (FATE#324714).
- ceph: ENOMEM pr_err in __get_or_create_frag() is redundant
  (FATE#324714).
- ceph: check negative offsets in ceph_llseek() (FATE#324714).
- ceph: more accurate statfs (FATE#324714).
- ceph: properly set snap follows for cap reconnect (FATE#324714).
- ceph: don't use CEPH_OSD_FLAG_ORDERSNAP (FATE#324714).
- ceph: include snapc in debug message of write (FATE#324714).
- ceph: make sure flushsnap messages are sent in proper order
  (FATE#324714).
- ceph: fix -EOLDSNAPC handling (FATE#324714).
- ceph: send LSSNAP request to auth mds of directory inode
  (FATE#324714).
- ceph: don't fill readdir cache for LSSNAP reply (FATE#324714).
- ceph: cleanup ceph_readdir_prepopulate() (FATE#324714).
- ceph: new cap message flags indicate if there is pending capsnap
  (FATE#324714).
- ceph: nuke startsync op (FATE#324714).
- ceph: validate correctness of some mount options (FATE#324714).
- ceph: limit osd write size (FATE#324714).
- ceph: limit osd read size to CEPH_MSG_MAX_DATA_LEN
  (FATE#324714).
- ceph: remove unused cap_release_safety mount option
  (FATE#324714).
- commit a10585c
* Tue Jan 30 2018 lhenriques@suse.com
- libceph: make RECOVERY_DELETES feature create a new interval
  (FATE#324714).
- libceph: upmap semantic changes (FATE#324714).
- crush: assume weight_set != null imples weight_set_size > 0
  (FATE#324714).
- libceph: fallback for when there isn't a pool-specific
  choose_arg (FATE#324714).
- libceph: don't call ->reencode_message() more than once per
  message (FATE#324714).
- libceph: make encode_request_*() work with r_mempool requests
  (FATE#324714).
- libceph: potential NULL dereference in ceph_msg_data_create()
  (FATE#324714).
- libceph: don't call encode_request_finish() on MOSDBackoff
  messages (FATE#324714).
- libceph: use alloc_pg_mapping() in __decode_pg_upmap_items()
  (FATE#324714).
- libceph: set -EINVAL in one place in crush_decode()
  (FATE#324714).
- libceph: NULL deref on osdmap_apply_incremental() error path
  (FATE#324714).
- libceph: fix old style declaration warnings (FATE#324714).
- libceph: advertise support for NEW_OSDOP_ENCODING and
  SERVER_LUMINOUS (FATE#324714).
- libceph: osd_state is 32 bits wide in luminous (FATE#324714).
- crush: remove an obsolete comment (FATE#324714).
- crush: crush_init_workspace starts with struct crush_work
  (FATE#324714).
- libceph, crush: per-pool crush_choose_arg_map for
  crush_do_rule() (FATE#324714).
- crush: implement weight and id overrides for straw2
  (FATE#324714).
- libceph: apply_upmap() (FATE#324714).
- libceph: compute actual pgid in ceph_pg_to_up_acting_osds()
  (FATE#324714).
- libceph: pg_upmap[_items] infrastructure (FATE#324714).
- libceph: ceph_decode_skip_* helpers (FATE#324714).
- libceph: kill __{insert,lookup,remove}_pg_mapping()
  (FATE#324714).
- libceph: introduce and switch to decode_pg_mapping()
  (FATE#324714).
- libceph: don't pass pgid by value (FATE#324714).
- libceph: respect RADOS_BACKOFF backoffs (FATE#324714).
- libceph: make DEFINE_RB_* helpers more general (FATE#324714).
- libceph: avoid unnecessary pi lookups in calc_target()
  (FATE#324714).
- libceph: use target pi for calc_target() calculations
  (FATE#324714).
- libceph: always populate t->target_{oid,oloc} in calc_target()
  (FATE#324714).
- libceph: make sure need_resend targets reflect latest map
  (FATE#324714).
- libceph: delete from need_resend_linger before
  check_linger_pool_dne() (FATE#324714).
- libceph: resend on PG splits if OSD has RESEND_ON_SPLIT
  (FATE#324714).
- libceph: drop need_resend from calc_target() (FATE#324714).
- libceph: MOSDOp v8 encoding (actual spgid + full hash)
  (FATE#324714).
- libceph: ceph_connection_operations::reencode_message() method
  (FATE#324714).
- libceph: encode_{pgid,oloc}() helpers (FATE#324714).
- libceph: introduce ceph_spg, ceph_pg_to_primary_shard()
  (FATE#324714).
- libceph: new pi->last_force_request_resend (FATE#324714).
- libceph: foldreq->last_force_resend into ceph_osd_request_target
  (FATE#324714).
- libceph: support SERVER_JEWEL feature bits (FATE#324714).
- libceph: advertise support for OSD_POOLRESEND (FATE#324714).
- libceph: handle non-empty dest in ceph_{oloc,oid}_copy()
  (FATE#324714).
- libceph: new features macros (FATE#324714).
- libceph: remove ceph_sanitize_features() workaround
  (FATE#324714).
- ceph: update ceph_dentry_info::lease_session when necessary
  (FATE#324714).
- ceph: new mount option that specifies fscache uniquifier
  (FATE#324714).
- ceph: avoid accessing freeing inode in ceph_check_delayed_caps()
  (FATE#324714).
- ceph: avoid invalid memory dereference in the middle of umount
  (FATE#324714).
- ceph: getattr before read on ceph.* xattrs (FATE#324714).
- ceph: don't re-send interrupted flock request (FATE#324714).
- ceph: cleanup writepage_nounlock() (FATE#324714).
- ceph: redirty page when writepage_nounlock() skips unwritable
  page (FATE#324714).
- ceph: remove useless page->mapping check in writepage_nounlock()
  (FATE#324714).
- ceph: update the 'approaching max_size' code (FATE#324714).
- ceph: re-request max size after importing caps (FATE#324714).
- ceph: ensure RNG is seeded before using (FATE#324714).
- commit f96ea6d
* Tue Jan 30 2018 mhocko@suse.com
- Documentation/kernel-parameters.txt: Update 'memmap=' boot
  option description (bnc#1077917).
- Update
  patches.suse/0001-x86-KASLR-Parse-all-memmap-boot-option-entries.patch
  (bnc#1071680, bnc#1077917, fate#323473).
- Update
  patches.suse/0002-x86-KASLR-Handle-the-memory-limit-specified-by-the-m.patch
  (bnc#1071680, bnc#1077917, fate#323473).
- commit 139f441
* Tue Jan 30 2018 mkubecek@suse.cz
- RDS: Heap OOB write in rds_message_alloc_sgs() (CVE-2018-5332
  bsc#1075621).
- commit 8848928
* Tue Jan 30 2018 mkubecek@suse.cz
- RDS: null pointer dereference in rds_atomic_free_op
  (CVE-2018-5333 bsc#1075617).
- commit 4d458e8
* Tue Jan 30 2018 mkubecek@suse.cz
- net: Fix double free and memory corruption in get_net_ns_by_id()
  (CVE-2017-15129 bsc#1074839).
- commit 249e5ac
* Tue Jan 30 2018 mkubecek@suse.cz
- net: ipv4: emulate READ_ONCE() on ->hdrincl bit-field in
  raw_sendmsg() (CVE-2017-17712 bsc#1073229).
- net: ipv4: fix for a race condition in raw_sendmsg
  (CVE-2017-17712 bsc#1073229).
- commit 34b8075
* Tue Jan 30 2018 mgorman@suse.de
- sched/fair: Use a recently used CPU as an idle candidate and
  the basis for SIS (bnc#1066110).
- sched/fair: Do not migrate if the prev_cpu is idle
  (bnc#1066110).
- sched/fair: Restructure wake_affine to return a CPU id
  (bnc#1066110).
- sched/fair: Remove unnecessary parameters from wake_affine_idle
  (bnc#1066110).
- sched/fair: Sync task util before slow-path wakeup
  (bnc#1066110).
- commit f574d1e
* Tue Jan 30 2018 mkubecek@suse.cz
- ipvlan: remove excessive packet scrubbing (bsc#1070799).
- commit 0cc2da1
* Tue Jan 30 2018 mkubecek@suse.cz
- tipc: improve link resiliency when rps is activated
  (bsc#1068038).
- commit edad3d6
* Tue Jan 30 2018 mkubecek@suse.cz
- series.conf: refresh
  (ran series_sort.py)
- Refresh
  patches.drivers/nvme-also-expose-the-namespace-identification-sysfs-.patch.
  patches.drivers/nvme-fix-visibility-of-uuid-ns-attribute.patch.
  patches.drivers/nvme-introduce-a-nvme_ns_ids-structure.patch.
  patches.drivers/nvme-track-shared-namespaces.patch.
- Update upstream reference:
  patches.drivers/block-Provide-blk_status_t-decoding-for-path-errors.patch.
  patches.drivers/dm-mpath-Use-blk_path_error.patch.
  patches.drivers/nvme-Add-more-command-status-translation.patch.
  patches.drivers/nvme-add-tracepoint-for-nvme_complete_rq.patch.
  patches.drivers/nvme-add-tracepoint-for-nvme_setup_cmd.patch.
  patches.drivers/nvme-multipath-Consult-blk_status_t-for-failover.patch.
  patches.drivers/nvme-multipath-Use-blk_path_error.patch.
  patches.drivers/nvmet-fc-cleanup-nvmet-add_port-remove_port.patch.
- commit 8073960
* Mon Jan 29 2018 jeffm@suse.com
- btrfs: fix btrfs_evict_inode to handle abnormal inodes correctly (bsc#1078019).
- commit 776dc75
* Mon Jan 29 2018 jeffm@suse.com
- Btrfs: fix unexpected return value of bio_readpage_error
  (bsc#1067598).
- commit 30d5aee
* Mon Jan 29 2018 hare@suse.de
- scsi: lpfc: fix a couple of minor indentation issues
  (bsc#1076693,bsc#1076672).
- scsi: lpfc: don't dereference localport before it has been
  null checked (bsc#1076693,bsc#1076672).
- scsi: lpfc: correct sg_seg_cnt attribute min vs default
  (bsc#1076693,bsc#1076672).
- commit 5817551
* Mon Jan 29 2018 hare@suse.de
- scsi: lpfc: update driver version to 11.4.0.6 (bsc#1076693).
- scsi: lpfc: Beef up stat counters for debug (bsc#1076693).
- scsi: lpfc: Fix infinite wait when driver unregisters a remote
  NVME port (bsc#1076693).
- scsi: lpfc: Fix issues connecting with nvme initiator
  (bsc#1076693).
- scsi: lpfc: Fix SCSI LUN discovery when SCSI and NVME enabled
  (bsc#1076693).
- scsi: lpfc: Increase SCSI CQ and WQ sizes (bsc#1076693).
- scsi: lpfc: Fix receive PRLI handling (bsc#1076693).
- scsi: lpfc: Fix -EOVERFLOW behavior for NVMET and defer_rcv
  (bsc#1076693).
- scsi: lpfc: Fix random heartbeat timeouts during heavy IO
  (bsc#1076693).
- commit 89d95b9
* Mon Jan 29 2018 jthumshirn@suse.de
- nvme: add tracepoint for nvme_complete_rq (FATE#323952,
  FATE#322506).
- nvme: add tracepoint for nvme_setup_cmd (FATE#323952,
  FATE#322506).
- commit 870ce83
* Mon Jan 29 2018 hare@suse.de
- Update patch header for ibmvnic patches
- Refresh
  patches.drivers/ibmvnic-Allocate-and-request-vpd-in-init_resources.patch.
- Refresh
  patches.drivers/ibmvnic-Modify-buffer-size-and-number-of-queues-on-f.patch.
- Refresh
  patches.drivers/ibmvnic-Revert-to-previous-mtu-when-unsupported-valu.patch.
- commit ac37059
* Mon Jan 29 2018 hare@suse.de
- scsi: lpfc: update driver version to 11.4.0.5 (bsc#1076693).
- scsi: lpfc: small sg cnt cleanup (bsc#1076693).
- scsi: lpfc: Fix driver handling of nvme resources during unload
  (bsc#1076693).
- scsi: lpfc: Fix crash during driver unload with running nvme
  traffic (bsc#1076693).
- scsi: lpfc: Correct driver deregistrations with host nvme
  transport (bsc#1076693).
- scsi: lpfc: correct port registrations with nvme_fc
  (bsc#1076693).
- scsi: lpfc: Linux LPFC driver does not process all RSCNs
  (bsc#1076693).
- scsi: lpfc: Fix ndlp ref count for pt2pt mode issue RSCN
  (bsc#1076693).
- scsi: lpfc: Adjust default value of lpfc_nvmet_mrq
  (bsc#1076693).
- scsi: lpfc: Fix display for debugfs queInfo (bsc#1076693).
- scsi: lpfc: Driver fails to detect direct attach storage array
  (bsc#1076693).
- scsi: lpfc: Raise maximum NVME sg list size for 256 elements
  (bsc#1076693).
- scsi: lpfc: Fix NVME LS abort_xri (bsc#1076693).
- scsi: lpfc: Fix crash after bad bar setup on driver attachment
  (bsc#1076693).
- scsi: lpfc: Handle XRI_ABORTED_CQE in soft IRQ (bsc#1076693).
- scsi: lpfc: Expand WQE capability of every NVME hardware queue
  (bsc#1076693).
- scsi: lpfc: FLOGI failures are reported when connected to a
  private loop (bsc#1076693).
- commit 1f4d880
* Mon Jan 29 2018 tbogendoerfer@suse.de
- net/mlx5e: Keep updating ethtool statistics when the interface
  is down (bsc#1046303 FATE#322944).
- commit 4075ba4
* Mon Jan 29 2018 msuchanek@suse.de
- KEYS: Fix race between updating and finding a negative key
  (CVE-2017-15951, bsc#1065615, bsc#1071927).
- KEYS: don't let add_key() update an uninstantiated key
  (CVE-2017-15951, bsc#1065615, bsc#1071927).
- commit d6cb5a2
* Mon Jan 29 2018 tbogendoerfer@suse.de
- net/mlx5: Fix memory leak in bad flow of mlx5_alloc_irq_vectors
  (bsc#1046303 FATE#322944).
- commit c5e8efb
* Mon Jan 29 2018 mhocko@suse.com
- mm/mprotect: add a cond_resched() inside change_pmd_range()
  (bnc#1077871).
- commit e2d94df
* Mon Jan 29 2018 jthumshirn@suse.de
- Refresh
  patches.drivers/nvme-fix-visibility-of-uuid-ns-attribute.patch.
  Fix upstream commit-id.
- commit 4210304
* Mon Jan 29 2018 mkubecek@suse.cz
- blacklist.conf: add 040ee69226f8
- commit bc8f9b1
* Mon Jan 29 2018 mkubecek@suse.cz
- ipv6: ip6_make_skb() needs to clear cork.base.dst (bsc#1076830).
- xfrm: Use __skb_queue_tail in xfrm_trans_queue (bsc#1076830).
- tcp/dccp: fix other lockdep splats accessing ireq_opt
  (bsc#1076830).
- tcp/dccp: fix lockdep splat in inet_csk_route_req()
  (bsc#1076830).
- udp: fix bcast packet reception (bsc#1076830).
- vti: fix NULL dereference in xfrm_input() (bsc#1076830).
- sctp: Fix a big endian bug in sctp_diag_dump() (bsc#1076830).
- commit 08c4a13
* Mon Jan 29 2018 mkubecek@suse.cz
- Update upstream reference:
  patches.drivers/ibmvnic-Allocate-and-request-vpd-in-init_resources.patch.
  patches.drivers/ibmvnic-Modify-buffer-size-and-number-of-queues-on-f.patch.
  patches.drivers/ibmvnic-Revert-to-previous-mtu-when-unsupported-valu.patch.
- commit 3fd778c
* Sun Jan 28 2018 mcgrof@suse.com
- xfs: validate sb_logsunit is a multiple of the fs blocksize (bsc#1077513).
- commit b3bd89b
* Fri Jan 26 2018 yousaf.kaukab@suse.com
- config: arm64: enable ARM64_HW_AFDBM and ARM64_PAN
- commit 45aa9c3
* Fri Jan 26 2018 hare@suse.de
- lpfc: Fix hard lock up NMI in els timeout handling
  (bsc#1076672).
- commit 203b3e9
* Fri Jan 26 2018 hare@suse.de
- lpfc: tie in to new dev_loss_tmo interface in nvme transport
  (bsc#1076672).
- commit ccb6905
* Fri Jan 26 2018 hare@suse.de
- scsi: qla2xxx: Fix recursion while sending terminate exchange
  (bsc#1076093).
- commit e94594b
* Fri Jan 26 2018 tbogendoerfer@suse.de
- qed* - bump drivers to version 8.10.10.55 (bsc#1050536
  FATE#322898 bsc#1050538 FATE#322897).
- commit c7852cd
* Thu Jan 25 2018 msuchanek@suse.de
- powerpc: Don't preempt_disable() in show_cpuinfo()
  (bsc#1065729).
- commit 54d3151
* Thu Jan 25 2018 msuchanek@suse.de
- genirq/msi: Fix populating multiple interrupts (bsc#1070194).
- genirq: Track whether the trigger type has been set
  (bsc#1070194).
- genirq: Fix for_each_action_of_desc() macro (bsc#1070194).
- genirq: Make sparse_irq_lock protect what it should protect
  (bsc#1070194).
- powerpc/xmon: Check before calling xive functions (FATE#322438,
  bsc#1065729).
- powerpc/powernv/cpufreq: Fix the frequency read by /proc/cpuinfo
  (bsc#1065729).
- powerpc/jprobes: Disable preemption when triggered through
  ftrace (bsc#1065729).
- KVM: PPC: Book3S HV: Always flush TLB in
  kvmppc_alloc_reset_hpt() (bsc#1061840).
- KVM: PPC: Book3S HV: Fix use after free in case of multiple
  resize requests (bsc#1061840).
- KVM: PPC: Book3S HV: Drop prepare_done from struct
  kvm_resize_hpt (bsc#1061840).
- genirq/msi: Fix populating multiple interrupts (bsc#1070194).
- genirq: Track whether the trigger type has been set
  (bsc#1070194).
- genirq: Fix for_each_action_of_desc() macro (bsc#1070194).
- genirq: Make sparse_irq_lock protect what it should protect
  (bsc#1070194).
- powerpc/xmon: Check before calling xive functions (FATE#322438,
  bsc#1065729).
- powerpc/powernv/cpufreq: Fix the frequency read by /proc/cpuinfo
  (bsc#1065729).
- powerpc/jprobes: Disable preemption when triggered through
  ftrace (bsc#1065729).
- KVM: PPC: Book3S HV: Always flush TLB in
  kvmppc_alloc_reset_hpt() (bsc#1061840).
- KVM: PPC: Book3S HV: Fix use after free in case of multiple
  resize requests (bsc#1061840).
- KVM: PPC: Book3S HV: Drop prepare_done from struct
  kvm_resize_hpt (bsc#1061840).
- commit 265931d
* Thu Jan 25 2018 mcgrof@suse.com
- fs: Avoid invalidation in interrupt context in dio_complete() (bsc#1073407 bsc#1069135).
- Refresh patches.suse/0023-block-switch-bios-to-blk_status_t.patch.
- commit 4cb0a08
* Thu Jan 25 2018 yousaf.kaukab@suse.com
- arm64: Move BP hardening to check_and_switch_context
  (bsc#1068032).
- commit 45ddc1d
* Thu Jan 25 2018 tbogendoerfer@suse.de
- RDMA/bnxt_re: Add SRQ support for Broadcom adapters (bsc#1050244
  FATE#322915).
- RDMA/bnxt_re: expose detailed stats retrieved from HW
  (bsc#1050244 FATE#322915).
- RDMA/bnxt_re: Add support for MRs with Huge pages (bsc#1050244
  FATE#322915).
- RDMA/bnxt_re: Add support for query firmware version
  (bsc#1050244 FATE#322915).
- RDMA/bnxt_re: Enable RoCE on virtual functions (bsc#1050244
  FATE#322915).
- RDMA/bnxt_re: Add SRQ support for Broadcom adapters (bsc#1050244
  FATE#322915).
- RDMA/bnxt_re: expose detailed stats retrieved from HW
  (bsc#1050244 FATE#322915).
- RDMA/bnxt_re: Add support for MRs with Huge pages (bsc#1050244
  FATE#322915).
- RDMA/bnxt_re: Add support for query firmware version
  (bsc#1050244 FATE#322915).
- RDMA/bnxt_re: Enable RoCE on virtual functions (bsc#1050244
  FATE#322915).
- commit 75e0deb
* Thu Jan 25 2018 tbogendoerfer@suse.de
- be2net: restore properly promisc mode after queues
  reconfiguration (bsc#1050252 FATE#322920).
- net/mlx5e: Fix fixpoint divide exception in
  mlx5e_am_stats_compare (bsc#1071289).
- be2net: restore properly promisc mode after queues
  reconfiguration (bsc#1050252 FATE#322920).
- net/mlx5e: Fix fixpoint divide exception in
  mlx5e_am_stats_compare (bsc#1071289).
- commit 8395ca0
* Thu Jan 25 2018 jslaby@suse.cz
- Documentation: document array_ptr (bsc#1068032 CVE-2017-5753).
- asm/nospec, array_ptr: sanitize speculative array de-references
  (bsc#1068032 CVE-2017-5753).
- x86: implement array_ptr_mask() (bsc#1068032 CVE-2017-5753).
- x86: introduce __uaccess_begin_nospec and ifence (bsc#1068032
  CVE-2017-5753).
- x86, __get_user: use __uaccess_begin_nospec (bsc#1068032
  CVE-2017-5753).
- x86, get_user: use pointer masking to limit speculation
  (bsc#1068032 CVE-2017-5753).
- x86: narrow out of bounds syscalls to sys_read under speculation
  (bsc#1068032 CVE-2017-5753).
- vfs, fdtable: prevent bounds-check bypass via speculative
  execution (bsc#1068032 CVE-2017-5753).
- kvm, x86: update spectre-v1 mitigation (bsc#1068032
  CVE-2017-5753).
- nl80211: sanitize array index in parse_txq_params (bsc#1068032
  CVE-2017-5753).
- KVM: x86: Add memory barrier on vmcs field lookup (bsc#1068032
  CVE-2017-5753).
- Refresh
  patches.arch/23-x86-retpoline-entry-convert-entry-assembler-indirect-jumps.patch.
- Refresh
  patches.suse/0002-objtool-x86-Add-several-functions-and-files-to-the-o.patch.
- Refresh
  patches.suse/0003-locking-barriers-introduce-new-observable-speculatio.patch.
- Refresh
  patches.suse/0007-x86-entry-64-Add-unwind-hint-annotations.patch.
- Refresh
  patches.suse/0014-fs-prevent-speculative-execution.patch.
  Usee array_ptr on x86. This should put things back to normal.
- commit 469e0d1
* Thu Jan 25 2018 oneukum@suse.com
- PCI: Do not allocate more buses than available in parent
  (FATE#323948).
- Refresh
  patches.drivers/0001-thunderbolt-tb-fix-use-after-free-in-tb_activate_pci.patch.
- commit 4836e10
* Thu Jan 25 2018 tbogendoerfer@suse.de
- Delete
  patches.suse/net-mlx5-Fix-fixpoint-divide-exception-in-mlx5e_am_s.patch.
  replace with upstreamed patch
- commit 4970de8
* Wed Jan 24 2018 msuchanek@suse.de
- powerpc/pseries: rfi-flush: Call setup_rfi_flush() after LPM migration (bsc#1068032).
  Really fix the migration patch
- Delete patches.arch/powerpc-rfi-flush-Make-setup_rfi_flush-not-__init.patch.
- Delete patches.arch/powerpc-rfi-flush-prevent-crash-when-changing-flush-.patch.
- commit 4efb860
* Wed Jan 24 2018 msuchanek@suse.de
- Fix build error in drmem.c (bsc#1077428).
- commit 522031e
* Wed Jan 24 2018 msuchanek@suse.de
- Move fadump patches to powerpc section.
- commit d2c2ae6
* Wed Jan 24 2018 msuchanek@suse.de
- powerpc/pseries: Enable support of ibm,dynamic-memory-v2
  (bsc#1077428).
- powerpc/drmem: Add support for ibm, dynamic-memory-v2 property
  (bsc#1077428).
- powerpc: Move of_drconf_cell struct to asm/drmem.h
  (bsc#1077428).
- powerpc/pseries: Update memory hotplug code to use drmem LMB
  array (bsc#1077428).
- powerpc/numa: Update numa code use walk_drmem_lmbs
  (bsc#1077428).
- powerpc/mm: Separate ibm, dynamic-memory data from DT format
  (bsc#1077428).
- powerpc/numa: Look up associativity array in
  of_drconf_to_nid_single (bsc#1077428).
- powerpc/numa: Look up device node in of_get_usable_memory()
  (bsc#1077428).
- powerpc/numa: Look up device node in of_get_assoc_arrays()
  (bsc#1077428).
- powerpc/pseries: Enable support of ibm,dynamic-memory-v2
  (bsc#1077428).
- powerpc/drmem: Add support for ibm, dynamic-memory-v2 property
  (bsc#1077428).
- powerpc: Move of_drconf_cell struct to asm/drmem.h
  (bsc#1077428).
- powerpc/pseries: Update memory hotplug code to use drmem LMB
  array (bsc#1077428).
- powerpc/numa: Update numa code use walk_drmem_lmbs
  (bsc#1077428).
- powerpc/mm: Separate ibm, dynamic-memory data from DT format
  (bsc#1077428).
- powerpc/numa: Look up associativity array in
  of_drconf_to_nid_single (bsc#1077428).
- powerpc/numa: Look up device node in of_get_usable_memory()
  (bsc#1077428).
- powerpc/numa: Look up device node in of_get_assoc_arrays()
  (bsc#1077428).
- commit 25a4560
* Wed Jan 24 2018 mgorman@suse.de
- mm: numa: do not trap faults on shared data section pages
  (Automatic NUMA Balancing (fate#315482)).
- commit ccce19f
* Wed Jan 24 2018 mcgrof@suse.com
- fs: invalidate page cache after end_io() in dio completion (bsc#1073407 bsc#1069135).
- fs: Fix page cache inconsistency when mixing buffered and AIO DIO (bsc#1073407 bsc#1069135).
- commit fcc82bf
* Tue Jan 23 2018 msuchanek@suse.de
- Refresh
  patches.drivers/ibmvnic-Allocate-and-request-vpd-in-init_resources.patch.
- Refresh
  patches.drivers/ibmvnic-Modify-buffer-size-and-number-of-queues-on-f.patch.
- Refresh
  patches.drivers/ibmvnic-Revert-to-previous-mtu-when-unsupported-valu.patch.
  Add commit hash
- commit 917e6ff
* Tue Jan 23 2018 msuchanek@suse.de
- powerpc/64s: Wire up cpu_show_meltdown() (bsc#1068032).
- commit 066f80a
* Tue Jan 23 2018 oneukum@suse.com
- CDC-ACM: apply quirk for card reader (bsc#1060279).
- commit b9670bb
* Mon Jan 22 2018 bp@suse.de
- x86/mce: Make machine check speculation protected (bsc#1068032
  CVE-2017-5754).
- commit 6961313
* Mon Jan 22 2018 msuchanek@suse.de
- ibmvnic: Allocate and request vpd in init_resources
  (bsc#1076872).
- ibmvnic: Revert to previous mtu when unsupported value requested
  (bsc#1076872).
- ibmvnic: Modify buffer size and number of queues on failover
  (bsc#1076872).
- commit 2ae4beb
* Mon Jan 22 2018 msuchanek@suse.de
- ibmvnic: Fix IPv6 packet descriptors (bsc#1076899).
- ibmvnic: Fix IP offload control buffer (bsc#1076899).
- commit b164618
* Mon Jan 22 2018 msuchanek@suse.de
- Refresh
  patches.drivers/nvmet-fc-cleanup-nvmet-add_port-remove_port.patch.
- commit 04a2099
* Mon Jan 22 2018 yousaf.kaukab@suse.com
- arm64: Turn on KPTI only on CPUs that need it (bsc#1076187).
- arm64: kpti: Fix the interaction between ASID switching and
  software PAN (bsc#1068032).
- arm64: SW PAN: Update saved ttbr0 value on enter_lazy_tlb
  (bsc#1068032).
- arm64: SW PAN: Point saved ttbr0 at the zero page when switching
  to init_mm (bsc#1068032).
- arm64: KVM: Fix SMCCC handling of unimplemented SMC/HVC calls
  (bsc#1068032).
- arm64: cputype: Add MIDR values for Cavium ThunderX2 CPUs
  (bsc#1068032).
- arm64: Implement branch predictor hardening for Falkor
  (bsc#1068032).
- arm64: Implement branch predictor hardening for affected
  Cortex-A CPUs (bsc#1068032).
- drivers/firmware: Expose psci_get_version through psci_ops
  structure (bsc#1068032).
- arm64: cputype: Add missing MIDR values for Cortex-A72 and
  Cortex-A75 (bsc#1068032).
- arm64: KVM: Make PSCI_VERSION a fast path (bsc#1068032).
- arm64: KVM: Use per-CPU vector when BP hardening is enabled
  (bsc#1068032).
- arm64: Add skeleton to harden the branch predictor against
  aliasing attacks (bsc#1068032).
- arm64: Move post_ttbr_update_workaround to C code (bsc#1068032).
- arm64: cpufeature: Pass capability structure to ->enable
  callback (bsc#1068032).
- arm64: Take into account ID_AA64PFR0_EL1.CSV3 (bsc#1068032).
- arm64: Kconfig: Reword UNMAP_KERNEL_AT_EL0 kconfig entry
  (bsc#1068032).
- arm64: use RET instruction for exiting the trampoline
  (bsc#1068032).
- arm64: Define cputype macros for Falkor CPU (bsc#1068032).
- arm64: entry.S: convert elX_irq (bsc#1068032).
- arm64: entry.S convert el0_sync (bsc#1068032).
- arm64: entry.S: convert el1_sync (bsc#1068032).
- arm64: entry.S: Remove disable_dbg (bsc#1068032).
- commit ff2c728
* Mon Jan 22 2018 bp@suse.de
- x86: Use __nostackprotect for sme_encrypt_kernel (fate#322123).
- commit 26b52c7
* Mon Jan 22 2018 jthumshirn@suse.de
- scsi: fnic: do not call host reset from command abort
  (bsc#1075700).
- commit d6f2a44
* Mon Jan 22 2018 bp@suse.de
- x86/mm: Rework wbinvd, hlt operation in stop_this_cpu()
  (fate#322123).
- x86/mm: Encrypt the initrd earlier for BSP microcode update
  (fate#322123).
- x86/mm: Prepare sme_encrypt_kernel() for PAGE aligned encryption
  (fate#322123).
- x86/mm: Centralize PMD flags in sme_encrypt_kernel()
  (fate#322123).
- x86/mm: Use a struct to reduce parameters for SME PGD mapping
  (fate#322123).
- x86/mm: Clean up register saving in the __enc_copy() assembly
  code (fate#322123).
- commit 1891f37
* Mon Jan 22 2018 yousaf.kaukab@suse.com
- config: arm64: enable HARDEN_BRANCH_PREDICTOR
- commit 4d0bfd9
* Mon Jan 22 2018 tbogendoerfer@suse.de
- RDMA/mlx5: Fix out-of-bound access while querying AH
  (bsc#1046305 FATE#322943).
- IB/hfi1: Prevent a NULL dereference (bsc#1060463 FATE#323043).
- nfp: use the correct index for link speed table (bsc#1055968).
- net/mlx5e: Don't override netdev features field unless in
  error flow (bsc#1046303 FATE#322944).
- net/mlx5: Fix error handling in load one (bsc#1046303
  FATE#322944).
- net/mlx5: Fix mlx5_get_uars_page to return error code
  (bsc#1046303 FATE#322944).
- net/mlx5: Fix get vector affinity helper function (bsc#1046303
  FATE#322944 bsc#1075185).
- {net,ib}/mlx5: Don't disable local loopback multicast traffic
  when needed (bsc#1046303 FATE#322944).
- commit f819e2e
* Mon Jan 22 2018 msuchanek@suse.de
- rpm/mkspec-dtb: Remove COPYING file (bsc#1076905).
  It conflicts between different versions of dtb package.
- commit 0e5fcf9
* Mon Jan 22 2018 jthumshirn@suse.de
- scsi: core: check for device state in __scsi_remove_target()
  (bsc#1071302).
- scsi: fixup kernel warning during rmmod() (bsc#1071302).
- commit df49e29
* Mon Jan 22 2018 jthumshirn@suse.de
- Refresh
  patches.drivers/block-Provide-blk_status_t-decoding-for-path-errors.patch.
- Refresh patches.drivers/dm-mpath-Use-blk_path_error.patch.
- Refresh
  patches.drivers/nvme-Add-more-command-status-translation.patch.
- Refresh
  patches.drivers/nvme-multipath-Consult-blk_status_t-for-failover.patch.
- Refresh patches.drivers/nvme-multipath-Use-blk_path_error.patch.
- Refresh
  patches.drivers/nvme-pci-take-sglist-coalescing-in-dma_map_sg-into-a.patch.
  Re-sort series.conf
- commit b506849
* Mon Jan 22 2018 bpoirier@suse.com
- Delete
  patches.suse/e1000e-Avoid-receiver-overrun-interrupt-bursts.patch.
  See bsc#1075428 comment 24.
  A workaround is being discussed upstream. Remove this patch for now. I'll
  re-add it once the workaround lands upstream.
- commit 5a22940
* Sun Jan 21 2018 bp@suse.de
- module: Add retpoline tag to VERMAGIC (bsc#1068032
  CVE-2017-5754).
- x86/cpufeature: Move processor tracing out of scattered features
  (bsc#1068032 CVE-2017-5754).
- objtool: Improve error message for bad file argument
  (bsc#1068032 CVE-2017-5754).
- objtool: Fix seg fault with gold linker (bsc#1068032
  CVE-2017-5754).
- x86/retpoline: Add LFENCE to the retpoline/RSB filling RSB
  macros (bsc#1068032 CVE-2017-5754).
- x86/retpoline: Fill RSB on context switch for affected CPUs
  (bsc#1068032 CVE-2017-5754).
- commit ffce37e
* Sat Jan 20 2018 bp@suse.de
- x86/retpoline: Remove compile time warning (bsc#1068032
  CVE-2017-5754).
- Update config files.
- x86/retpoline: Fill return stack buffer on vmexit (bsc#1068032
  CVE-2017-5754).
- x86/retpoline/xen: Convert Xen hypercall indirect jumps
  (bsc#1068032 CVE-2017-5754).
- x86/retpoline/hyperv: Convert assembler indirect jumps
  (bsc#1068032 CVE-2017-5754).
- x86/retpoline/ftrace: Convert ftrace assembler indirect jumps
  (bsc#1068032 CVE-2017-5754).
- x86/retpoline/entry: Convert entry assembler indirect jumps
  (bsc#1068032 CVE-2017-5754).
- x86/retpoline/crypto: Convert crypto assembler indirect jumps
  (bsc#1068032 CVE-2017-5754).
- x86/spectre: Add boot time option to select Spectre v2
  mitigation (bsc#1068032 CVE-2017-5754).
- x86/retpoline: Add initial retpoline support (bsc#1068032
  CVE-2017-5754).
- objtool: Allow alternatives to be ignored (bsc#1068032
  CVE-2017-5754).
- objtool: Detect jumps to retpoline thunks (bsc#1068032
  CVE-2017-5754).
- x86/alternatives: Fix optimize_nops() checking (bsc#1068032
  CVE-2017-5754).
- sysfs/cpu: Fix typos in vulnerability documentation (bsc#1068032
  CVE-2017-5754).
- x86/cpu: Implement CPU vulnerabilites sysfs functions
  (bsc#1068032 CVE-2017-5754).
- sysfs/cpu: Add vulnerability folder (bsc#1068032 CVE-2017-5754).
- x86/cpufeatures: Add X86_BUG_SPECTRE_V (bsc#1068032
  CVE-2017-5754).
- x86/Documentation: Add PTI description (bsc#1068032
  CVE-2017-5754).
- x86/pti: Unbreak EFI old_memmap (bsc#1068032 CVE-2017-5754).
- x86/pti: Rename BUG_CPU_INSECURE to BUG_CPU_MELTDOWN
  (bsc#1068032 CVE-2017-5754).
- x86/alternatives: Add missing '\n' at end of ALTERNATIVE inline
  asm (bsc#1068032 CVE-2017-5754).
- x86/mm: Map cpu_entry_area at the same place on 4/5 level
  (bsc#1068032 CVE-2017-5754).
- x86/mm: Set MODULES_END to 0xffffffffff000000 (bsc#1068032
  CVE-2017-5754).
- x86/dumpstack: Print registers for first stack frame
  (bsc#1068032 CVE-2017-5754).
- x86/cpu, x86/pti: Do not enable PTI on AMD processors
  (bsc#1068032 CVE-2017-5754).
- x86/pti: Enable PTI by default (bsc#1068032 CVE-2017-5754).
- x86/ldt: Make LDT pgtable free conditional (bsc#1068032
  CVE-2017-5754).
- x86/mm: Remove preempt_disable/enable() from
  __native_flush_tlb() (bsc#1068032 CVE-2017-5754).
- x86/smpboot: Remove stale TLB flush invocations (bsc#1068032
  CVE-2017-5754).
- commit 1c37e0f
* Sat Jan 20 2018 bp@suse.de
- x86/cpu/AMD: Make LFENCE a serializing instruction (bsc#1068032
  CVE-2017-5753).
- x86/cpu/AMD: Use LFENCE_RDTSC in preference to MFENCE_RDTSC
  (bsc#1068032 CVE-2017-5753).
- Delete
  patches.suse/0001-x86-cpu-AMD-Make-the-LFENCE-instruction-serialized.patch.
- Delete
  patches.suse/0002-x86-cpu-AMD-Remove-now-unused-definition-of-MFENCE_R.patch.
- commit 739d51a
* Fri Jan 19 2018 mkubecek@suse.cz
- ipv6: fix possible mem leaks in ipv6_make_skb() (bsc#1076830).
- sctp: Replace use of sockets_allocated with specified macro
  (bsc#1076830).
- xfrm: Reinject transport-mode packets through tasklet
  (bsc#1076830).
- xfrm: Fix xfrm_input() to verify state is valid when (encap_type
  < 0) (bsc#1076830).
- openvswitch: Fix pop_vlan action for double tagged frames
  (bsc#1076830).
- tcp: fix potential underestimation on rcv_rtt (bsc#1076830).
- netfilter: xt_bpf: add overflow checks (bsc#1076830).
- tcp md5sig: Use skb's saddr when replying to an incoming segment
  (bsc#1076830).
- fou: fix some member types in guehdr (bsc#1076830).
- sctp: make sure stream nums can match optlen in
  sctp_setsockopt_reset_streams (bsc#1076830).
- tcp: use current time in tcp_rcv_space_adjust() (bsc#1076830).
- tcp: use IPCB instead of TCP_SKB_CB in inet_exact_dif_match()
  (bsc#1076830).
- net/packet: fix a race in packet_bind() and packet_notifier()
  (bsc#1076830).
- packet: fix crash in fanout_demux_rollover() (bsc#1076830).
- ipv6: Do not consider linkdown nexthops during multipath
  (bsc#1076830).
- route: also update fnhe_genid when updating a route cache
  (bsc#1076830).
- ipv6: avoid zeroing per cpu data again (bsc#1076830).
- tcp: fix tcp_fastretrans_alert warning (bsc#1076830).
- net: vrf: correct FRA_L3MDEV encode type (bsc#1076830).
- tcp: fix tcp_mtu_probe() vs highest_sack (bsc#1076830).
- xfrm: Fix GSO for IPsec with GRE tunnel (bsc#1076830).
- xfrm: Clear sk_dst_cache when applying per-socket policy
  (bsc#1076830).
- tap: double-free in error path in tap_open() (bsc#1076830).
- packet: avoid panic in packet_getsockopt() (bsc#1076830).
- tcp/dccp: fix ireq->opt races (bsc#1076830).
- netfilter: xt_bpf: Fix XT_BPF_MODE_FD_PINNED mode of
  'xt_bpf_info_v1' (bsc#1076830).
- netfilter: nf_tables: fix update chain error (bsc#1076830).
- netfilter: xt_socket: Restore mark from full sockets only
  (bsc#1076830).
- xfrm: Fix negative device refcount on offload failure
  (bsc#1076830).
- udp: perform source validation for mcast early demux
  (bsc#1076830).
- IPv4: early demux can return an error code (bsc#1076830).
- udpv6: Fix the checksum computation when HW checksum does not
  apply (bsc#1076830).
- sctp: fix an use-after-free issue in sctp_sock_dump
  (bsc#1076830).
- ip_tunnel: fix ip tunnel lookup in collect_md mode
  (bsc#1076830).
- ip_tunnel: fix setting ttl and tos value in collect_md mode
  (bsc#1076830).
- netfilter: ipvs: fix the issue that sctp_conn_schedule drops
  non-INIT packet (bsc#1076830).
- xfrm: Clear RX SKB secpath xfrm_offload (bsc#1076830).
- ip/options: explicitly provide net ns to __ip_options_echo()
  (bsc#1076830).
- net/netfilter/nf_conntrack_core: Fix net_conntrack_lock()
  (bsc#1076830).
- xfrm_user: fix info leak in build_aevent() (bsc#1076830).
- xfrm_user: fix info leak in xfrm_notify_sa() (bsc#1076830).
- netfilter: nf_tables: Fix nft limit burst handling
  (bsc#1076830).
- netfilter: ipt_CLUSTERIP: fix use-after-free of proc entry
  (bsc#1076830).
- esp: Fix error handling on layer 2 xmit (bsc#1076830).
- net/packet: Fix Tx queue selection for AF_PACKET (bsc#1076830).
- netfilter: ebt_nflog: fix unexpected truncated packet
  (bsc#1076830).
- commit a12e319
* Fri Jan 19 2018 msuchanek@suse.de
- powerpc/rfi-flush: prevent crash when changing flush type to
  fallback after system boot (bsc#1068032).
- commit 8b07c66
* Fri Jan 19 2018 mkubecek@suse.cz
- tcp: refresh tcp_mstamp from timers callbacks (bsc#1061739).
- tcp: refresh tp timestamp before tcp_mtu_probe() (bsc#1061739).
- tcp: do tcp_mstamp_refresh before retransmits on TSQ handler
  (bsc#1061739).
- tcp: fix TCP_SYNCNT flakes (bsc#1061739).
- tcp: fix tcp_probe_timer() for TCP_USER_TIMEOUT (bsc#1061739).
- tcp: fix tcp_rearm_rto() (bsc#1061739).
- tcp: switch TCP TS option (RFC 7323) to 1ms clock (bsc#1061739).
- tcp: replace misc tcp_time_stamp to tcp_jiffies32 (bsc#1061739).
- tcp_lp: cache tcp_time_stamp (bsc#1061739).
- tcp_westwood: use tcp_jiffies32 instead of tcp_time_stamp
  (bsc#1061739).
- tcp: use tcp_jiffies32 in __tcp_oow_rate_limited()
  (bsc#1061739).
- tcp: uses jiffies_32 to feed tp->chrono_start (bsc#1061739).
- tcp: use tcp_jiffies32 to feed probe_timestamp (bsc#1061739).
- tcp: use tcp_jiffies32 for rcv_tstamp and lrcvtime
  (bsc#1061739).
- tcp: bic, cubic: use tcp_jiffies32 instead of tcp_time_stamp
  (bsc#1061739).
- tcp_bbr: use tcp_jiffies32 instead of tcp_time_stamp
  (bsc#1061739).
- tcp: use tcp_jiffies32 to feed tp->snd_cwnd_stamp (bsc#1061739).
- tcp: use tcp_jiffies32 to feed tp->lsndtime (bsc#1061739).
- dccp: do not use tcp_time_stamp (bsc#1061739).
- tcp: introduce tcp_jiffies32 (bsc#1061739).
- tcp: use tp->tcp_mstamp in output path (bsc#1061739).
- commit a53ef41
* Fri Jan 19 2018 mkubecek@suse.cz
- Update upstream reference:
  patches.drivers/nvme-pci-take-sglist-coalescing-in-dma_map_sg-into-a.patch.
- commit 5fce852
* Fri Jan 19 2018 jkosina@suse.cz
- s390: add ppa to system call and program check path
  (bsc#1068032).
- commit 0642e4e
* Fri Jan 19 2018 jthumshirn@suse.de
- nvme-pci: take sglist coalescing in dma_map_sg into account
  (FATE#323952, FATE#322506).
- commit d73f2b8
* Fri Jan 19 2018 tiwai@suse.de
- Update config files: refresh arm64, ppc64le and s390x configs
  Some configs got removed from default but only in vanilla:
  CONFIG_TREE_RCU_TRACE and CONFIG_PPC_ICSWX*
- commit b9e21dc
* Thu Jan 18 2018 tiwai@suse.de
- Update config files: fix x86_64/vanilla build breakage
- commit 9c77b4d
* Thu Jan 18 2018 bp@suse.de
- x86/pti: Make unpoison of pgd for trusted boot work for real
  (bsc#1068032 CVE-2017-5754).
- blacklist.conf:
- commit 3bf8f4e
* Thu Jan 18 2018 bp@suse.de
- x86,perf: Disable intel_bts when PTI (bsc#1068032
  CVE-2017-5754).
- Update config files.
- x86/pti: Fix !PCID and sanitize defines (bsc#1068032
  CVE-2017-5754).
- x86/mm/pti: Remove dead logic in pti_user_pagetable_walk*()
  (bsc#1068032 CVE-2017-5754).
- x86/tboot: Unbreak tboot with PTI enabled (bsc#1068032
  CVE-2017-5754).
- x86/tlb: Drop the _GPL from the cpu_tlbstate export (bsc#1068032
  CVE-2017-5754).
- x86/events/intel/ds: Use the proper cache flush method for
  mapping ds buffers (bsc#1068032 CVE-2017-5754).
- x86/pti: Switch to kernel CR3 at early in entry_SYSCALL_compat()
  (bsc#1068032 CVE-2017-5754).
- x86/pti: Make sure the user/kernel PTEs match (bsc#1068032
  CVE-2017-5754).
- x86/ldt: Plug memory leak in error path (bsc#1068032
  CVE-2017-5754).
- x86/ldt: Make the LDT mapping RO (bsc#1068032 CVE-2017-5754).
- x86/mm/dump_pagetables: Allow dumping current pagetables
  (bsc#1068032 CVE-2017-5754).
- x86/mm/dump_pagetables: Check user space page table for WX pages
  (bsc#1068032 CVE-2017-5754).
- x86/mm/dump_pagetables: Add page table directory to the debugfs
  VFS hierarchy (bsc#1068032 CVE-2017-5754).
- x86/mm/pti: Add Kconfig (bsc#1068032 CVE-2017-5754).
- x86/dumpstack: Indicate in Oops whether PTI is configured and
  enabled (bsc#1068032 CVE-2017-5754).
- x86/mm: Clarify the whole ASID/kernel PCID/user PCID naming
  (bsc#1068032 CVE-2017-5754).
- x86/mm: Use INVPCID for __native_flush_tlb_single() (bsc#1068032
  CVE-2017-5754).
- x86/mm: Optimize RESTORE_CR3 (bsc#1068032 CVE-2017-5754).
- x86/mm: Use/Fix PCID to optimize user/kernel switches
  (bsc#1068032 CVE-2017-5754).
- x86/mm: Abstract switching CR3 (bsc#1068032 CVE-2017-5754).
- x86/mm: Allow flushing for future ASID switches (bsc#1068032
  CVE-2017-5754).
- x86/pti: Map the vsyscall page if needed (bsc#1068032
  CVE-2017-5754).
- x86/pti: Put the LDT in its own PGD if PTI is on (bsc#1068032
  CVE-2017-5754).
- x86/mm/64: Make a full PGD-entry size hole in the memory map
  (bsc#1068032 CVE-2017-5754).
- x86/events/intel/ds: Map debug buffers in cpu_entry_area
  (bsc#1068032 CVE-2017-5754).
- x86/cpu_entry_area: Add debugstore entries to cpu_entry_area
  (bsc#1068032 CVE-2017-5754).
- x86/mm/pti: Map ESPFIX into user space (bsc#1068032
  CVE-2017-5754).
- x86/mm/pti: Share entry text PMD (bsc#1068032 CVE-2017-5754).
- irq: Make the irqentry text section unconditional (bsc#1068032
  CVE-2017-5754).
- x86/entry: Align entry text section to PMD boundary (bsc#1068032
  CVE-2017-5754).
- x86/mm/pti: Share cpu_entry_area with user space page tables
  (bsc#1068032 CVE-2017-5754).
- x86/mm/pti: Force entry through trampoline when PTI active
  (bsc#1068032 CVE-2017-5754).
- x86/mm/pti: Add functions to clone kernel PMDs (bsc#1068032
  CVE-2017-5754).
- x86/mm/pti: Populate user PGD (bsc#1068032 CVE-2017-5754).
- x86/mm/pti: Allocate a separate user PGD (bsc#1068032
  CVE-2017-5754).
- x86/mm/pti: Allow NX poison to be set in p4d/pgd (bsc#1068032
  CVE-2017-5754).
- x86/mm/pti: Add mapping helper functions (bsc#1068032
  CVE-2017-5754).
- x86/pti: Add the pti= cmdline option and documentation
  (bsc#1068032 CVE-2017-5754).
- x86/mm/pti: Add infrastructure for page table isolation
  (bsc#1068032 CVE-2017-5754).
- drivers/misc/intel/pti: Rename the header file to free up the
  namespace (bsc#1068032 CVE-2017-5754).
- x86/mm/pti: Prepare the x86/entry assembly code for entry/exit
  CR3 switching (bsc#1068032 CVE-2017-5754).
- x86/mm/pti: Disable global pages if PAGE_TABLE_ISOLATION=y
  (bsc#1068032 CVE-2017-5754).
- x86/cpufeatures: Add X86_BUG_CPU_INSECURE (bsc#1068032
  CVE-2017-5754).
- commit b8791ed
* Thu Jan 18 2018 msuchanek@suse.de
- powerpc/rfi-flush: Add DEBUG_RFI config option (bsc#1068032).
- commit ff01a26
* Thu Jan 18 2018 jroedel@suse.de
- KVM: Fix stack-out-of-bounds read in write_mmio (CVE-2017-17741
  bsc#1073311).
- commit a0834ee
* Thu Jan 18 2018 jroedel@suse.de
- x86/platform/uv/BAU: Replace hard-coded values with MMR
  definitions (bsc#1076263 #fate#322814).
- x86/platform/UV: Fix UV4A BAU MMRs (bsc#1076263 #fate#322814).
- x86/platform/UV: Fix GAM MMR references in the UV x2apic code
  (bsc#1076263 #fate#322814).
- x86/platform/UV: Fix GAM MMR changes in UV4A (bsc#1076263
  [#]fate#322814).
- x86/platform/UV: Add references to access fixed UV4A HUB MMRs
  (bsc#1076263 #fate#322814).
- x86/platform/UV: Update uv_mmrs.h to prepare for UV4A fixes
  (bsc#1076263 #fate#322814).
- commit fe3d886
* Wed Jan 17 2018 mhocko@suse.com
- x86/boot/KASLR: Prefer mirrored memory regions for the kernel
  physical address (bnc#1071680, fate#323473).
- x86/KASLR: Parse all 'memmap=' boot option entries (bnc#1071680,
  fate#323473).
- x86/boot/KASLR: Wrap e820 entries walking code into new function
  process_e820_entries() (bnc#1071680, fate#323473).
- x86/KASLR: Handle the memory limit specified by the 'memmap='
  and 'mem=' boot options (bnc#1071680, fate#323473).
- x86/boot/KASLR: Switch to pass struct mem_vector to
  process_e820_entry() (bnc#1071680, fate#323473).
- x86/boot/KASLR: Rename process_e820_entry() into
  process_mem_region() (bnc#1071680, fate#323473).
- efi: Introduce efi_early_memdesc_ptr to get pointer to memmap
  descriptor (bnc#1071680, fate#323473).
- Refresh
  patches.suse/0003-x86-KASLR-public-the-function-for-getting-random-lon.patch.
- commit 08d4ed7
* Wed Jan 17 2018 msuchanek@suse.de
- Update supported.conf
  + drivers/rpmsg/rpmsg_core
- commit 3bebef7
* Wed Jan 17 2018 msuchanek@suse.de
- powerpc/rfi-flush: Make setup_rfi_flush() not __init
  (bsc#1068032).
- commit 475655a
* Wed Jan 17 2018 tiwai@suse.de
- serial: 8250_pci: Add Amazon PCI serial device ID (bsc#1076416).
- commit a5ea307
* Wed Jan 17 2018 tbogendoerfer@suse.de
- net/mlx5: Fix fixpoint divide exception in
  mlx5e_am_stats_compare (bsc#1071289).
- commit 3a609ef
* Wed Jan 17 2018 msuchanek@suse.de
- powerpc/pseries: include linux/types.h in asm/hvcall.h
  (bsc#1068032).
- commit cf01f3a
* Wed Jan 17 2018 msuchanek@suse.de
- powerpc/64s: Allow control of RFI flush via debugfs (bsc#1068032).
- Refresh patches.arch/powerpc-rfi-flush-Move-the-logic-to-avoid-a-redo-int.patch.
  Also remove the sysfs interface of the same now that there is upstream
  solution.
- commit c30bac4
* Wed Jan 17 2018 rjschwei@suse.com
- kernel-obs-build.spec.in: enable xfs module
  This allows the public cloud team to build images with XFS
  as root filesystem
- commit 95a2d6f
* Wed Jan 17 2018 msuchanek@suse.de
- powerpc/xmon: Add RFI flush related fields to paca dump
  (bsc#1068032).
- commit 87bb47e
* Wed Jan 17 2018 msuchanek@suse.de
- macros.kernel-source: pass -f properly in module subpackage (boo#1076393).
- commit 66bd9b8
* Wed Jan 17 2018 oneukum@suse.com
- iwlwifi: pcie: fix DMA memory mapping / unmapping (FATE#322675).
- commit ce89961
* Wed Jan 17 2018 oneukum@suse.com
- Refresh
  patches.drivers/ibmvnic-Fix-pending-MAC-address-changes.patch.
- commit 4c95b8e
* Wed Jan 17 2018 msuchanek@suse.de
- Refresh patches.drivers/ibmvnic-Fix-pending-MAC-address-changes.patch.
  Add commit hash
- commit b83a6a8
* Wed Jan 17 2018 tiwai@suse.de
- ALSA: pcm: Remove yet superfluous WARN_ON() (bsc#1051510).
- commit 10af5fa
* Wed Jan 17 2018 tiwai@suse.de
- ALSA: hda - Apply the existing quirk to iMac 14,1 (bsc#1051510).
- ALSA: hda - Apply headphone noise quirk for another Dell XPS
  13 variant (bsc#1051510).
- commit 82d50bd
* Wed Jan 17 2018 tiwai@suse.de
- Move the sound patch to sorted section
  Also refreshed the upstreamed patch tags
- commit affe9a9
* Wed Jan 17 2018 bp@suse.de
- s390/mm: use generic mm_hooks (bsc#1068032 CVE-2017-5754).
- commit 565b1ca
* Tue Jan 16 2018 bp@suse.de
- Refresh
  patches.arch/21-x86-cpu_entry_area-move-it-to-a-separate-unit.patch.
- commit b987a74
* Tue Jan 16 2018 bp@suse.de
- x86/kaslr: Fix the vaddr_end mess (bsc#1068032 CVE-2017-5754).
- blacklist.conf:
- init: Invoke init_espfix_bsp() from mm_init() (bsc#1068032
  CVE-2017-5754).
- x86/cpu_entry_area: Move it out of the fixmap (bsc#1068032
  CVE-2017-5754).
- x86/cpu_entry_area: Move it to a separate unit (bsc#1068032
  CVE-2017-5754).
- x86/mm: Create asm/invpcid.h (bsc#1068032 CVE-2017-5754).
- x86/mm: Put MMU to hardware ASID translation in one place
  (bsc#1068032 CVE-2017-5754).
- x86/mm: Remove hard-coded ASID limit checks (bsc#1068032
  CVE-2017-5754).
- x86/mm: Move the CR3 construction functions to tlbflush.h
  (bsc#1068032 CVE-2017-5754).
- x86/mm: Add comments to clarify which TLB-flush functions are
  supposed to flush what (bsc#1068032 CVE-2017-5754).
- x86/mm: Remove superfluous barriers (bsc#1068032 CVE-2017-5754).
- x86/mm: Use __flush_tlb_one() for kernel memory (bsc#1068032
  CVE-2017-5754).
- x86/microcode: Dont abuse the TLB-flush interface (bsc#1068032
  CVE-2017-5754).
- x86/uv: Use the right TLB-flush API (bsc#1068032 CVE-2017-5754).
- x86/entry: Rename SYSENTER_stack to CPU_ENTRY_AREA_entry_stack
  (bsc#1068032 CVE-2017-5754).
- x86/doc: Remove obvious weirdnesses from the x86 MM layout
  documentation (bsc#1068032 CVE-2017-5754).
- x86/mm/64: Improve the memory map documentation (bsc#1068032
  CVE-2017-5754).
- x86/ldt: Prevent LDT inheritance on exec (bsc#1068032
  CVE-2017-5754).
- x86/ldt: Rework locking (bsc#1068032 CVE-2017-5754).
- x86/ldt/64: Refresh DS and ES when modify_ldt changes an entry
  (bsc#1068032 CVE-2017-5754).
- arch, mm: Allow arch_dup_mmap() to fail (bsc#1068032
  CVE-2017-5754).
- x86/vsyscall/64: Warn and fail vsyscall emulation in NATIVE mode
  (bsc#1068032 CVE-2017-5754).
- x86/vsyscall/64: Explicitly set _PAGE_USER in the pagetable
  hierarchy (bsc#1068032 CVE-2017-5754).
- x86/mm/dump_pagetables: Make the address hints correct and
  readable (bsc#1068032 CVE-2017-5754).
- x86/mm/dump_pagetables: Check PAGE_PRESENT for real (bsc#1068032
  CVE-2017-5754).
- commit 7f3f7c7
* Tue Jan 16 2018 tiwai@suse.de
- ALSA: seq: Make ioctls race-free (CVE-2018-1000004,bsc#1076017).
- commit 971e9f4
* Tue Jan 16 2018 msuchanek@suse.de
- scsi: sr: wait for the medium to become ready (bsc#1048585).
- cdrom: wait for tray to close (bsc#1048585).
- cdrom: factor out common open_for_* code (bsc#1048585).
- delay: add poll_event_interruptible (bsc#1048585).
- commit 4aae228
* Tue Jan 16 2018 lpechacek@suse.com
- x86/intel_rdt: Fix a silent failure when writing zero value
  schemata (fate#324327).
- x86/intel_rdt: Add diagnostics when making directories
  (fate#324327).
- x86/intel_rdt: Add diagnostics when writing the cpus file
  (fate#324327).
- x86/intel_rdt: Add diagnostics when writing the tasks file
  (fate#324327).
- x86/intel_rdt: Add diagnostics when writing the schemata file
  (fate#324327).
- x86/intel_rdt: Add framework for better RDT UI diagnostics
  (fate#324327).
- commit 14b8e33
* Tue Jan 16 2018 jslaby@suse.cz
- x86/cpuid: Replace set/clear_bit32() (fate#324438).
- x86/cpufeatures: Enable new SSE/AVX/AVX512 CPU features
  (fate#324438).
- x86/cpuid: Prevent out of bound access in do_clear_cpu_cap()
  (fate#324438).
- x86/cpuid: Add generic table for CPUID dependencies
  (fate#324438).
- commit 02ab826
* Tue Jan 16 2018 jlee@suse.com
- Update config files.
  Disabled CONFIG_EFI_SECURE_BOOT_LOCK_DOWN. (bsc#1075051)
- commit 29e80d3
* Tue Jan 16 2018 mkubecek@suse.cz
- bpf: fix two missing target_size settings in
  bpf_convert_ctx_access (bsc#1073928).
- commit 7f7bbde
* Tue Jan 16 2018 tiwai@suse.de
- Re-sort previous bcache patches in the sorted section
- commit fb5ff24
* Tue Jan 16 2018 colyli@suse.de
- bcache: check return value of register_shrinker (bsc#1076110).
- bcache: recover data from backing when data is clean
  (bsc#1076110, bsc#1043652).
- bcache: Fix building error on MIPS (bsc#1076110).
- bcache: add a comment in journal bucket reading (bsc#1076110).
- bcache: explicitly destroy mutex while exiting (bsc#1076110).
- bcache: fix wrong cache_misses statistics (bsc#1076110).
- bcache: update bucket_in_use in real time (bsc#1076110).
- bcache: convert cached_dev.count from atomic_t to refcount_t
  (bsc#1076110).
- bcache: only permit to recovery read error when cache device
  is clean (bsc#1076110, bsc#1043652).
- bcache: writeback rate clamping: make 32 bit safe (bsc#1076110).
- bcache: safeguard a dangerous addressing in closure_queue
  (bsc#1076110).
- bcache: rearrange writeback main thread ratelimit (bsc#1076110).
- bcache: writeback rate shouldn't artifically clamp
  (bsc#1076110).
- bcache: smooth writeback rate control (bsc#1076110).
- bcache: implement PI controller for writeback rate
  (bsc#1076110).
- bcache: don't write back data if reading it failed (bsc#1076110,
  bsc#1043652).
- bcache: remove unused parameter (bsc#1076110).
- bcache: update bio->bi_opf bypass/writeback REQ_ flag hints
  (bsc#1076110).
- bcache: Remove redundant set_capacity (bsc#1076110).
- bcache: rewrite multiple partitions support (bsc#1076110,
  bsc#1038085).
- bcache: fix a comments typo in bch_alloc_sectors()
  (bsc#1076110).
- bcache: check ca->alloc_thread initialized before wake up it
  (bsc#1076110).
- bcache: Avoid nested function definition (bsc#1076110).
- bcache: use llist_for_each_entry_safe() in __closure_wake_up()
  (bsc#1076110).
- bcache: initialize dirty stripes in flash_dev_run()
  (bsc#1076110).
- bcache: fix bch_hprint crash and improve output (bsc#1076110).
- bcache: Update continue_at() documentation (bsc#1076110).
- bcache: silence static checker warning (bsc#1076110).
- bcache: fix for gc and write-back race (bsc#1076110).
- bcache: increase the number of open buckets (bsc#1076110).
- bcache: Correct return value for sysfs attach errors
  (bsc#1076110).
- bcache: correct cache_dirty_target in __update_writeback_rate()
  (bsc#1076110).
- bcache: gc does not work when triggering by manual command
  (bsc#1076110, bsc#1038078).
- bcache: Don't reinvent the wheel but use existing llist API
  (bsc#1076110).
- bcache: do not subtract sectors_to_gc for bypassed IO
  (bsc#1076110).
- bcache: fix sequential large write IO bypass (bsc#1076110).
- commit 54ef3ac
* Tue Jan 16 2018 colyli@suse.de
- bcache: Fix leak of bdev reference (bsc#1076110).
- commit fbfa4d4
* Tue Jan 16 2018 mkubecek@suse.cz
- Update
  patches.drivers/bpf-don-t-prune-branches-when-a-scalar-is-replaced-w.patch
  references (add CVE-2017-17855 bsc#1073928).
- Update
  patches.drivers/bpf-fix-incorrect-sign-extension-in-check_alu_op.patch
  references (add CVE-2017-16995 bsc#1073928).
- Update
  patches.drivers/bpf-fix-missing-error-return-in-check_stack_boundary.patch
  references (add CVE-2017-17857 bsc#1073928).
- Update
  patches.drivers/bpf-force-strict-alignment-checks-for-stack-pointers.patch
  references (add CVE-2017-17856 bsc#1073928).
- Update
  patches.drivers/bpf-verifier-fix-bounds-calculation-on-BPF_RSH.patch
  references (add CVE-2017-17853 bsc#1073928).
- commit e19e1fe
* Mon Jan 15 2018 bp@suse.de
- x86/mm, KVM: Fix warning when !CONFIG_PREEMPT_COUNT (bsc#1068032
  CVE-2017-5754).
- KVM: nVMX: fix HOST_CR3/HOST_CR4 cache (bsc#1068032
  CVE-2017-5754).
- Refresh
  patches.arch/19-x86-mm-implement-pcid-based-optimization-try-to-preserve-old-tlb-entries-using-pcid.patch.
- Refresh
  patches.arch/23-x86-mm-factor-out-cr3-building-code.patch.
- commit 237ac1a
* Mon Jan 15 2018 bp@suse.de
- x86/mm/64: Fix reboot interaction with CR4.PCIDE (bsc#1068032
  CVE-2017-5754).
- blacklist.conf:
- x86/mm/64: Initialize CR4.PCIDE early (bsc#1068032
  CVE-2017-5754).
- x86/hibernate/64: Mask off CR3's PCID bits in the saved CR3
  (bsc#1068032 CVE-2017-5754).
- x86/mm: Add the 'nopcid' boot option to turn off PCID
  (bsc#1068032 CVE-2017-5754).
- x86/mm: Enable CR4.PCIDE on supported systems (bsc#1068032
  CVE-2017-5754).
- Revert "x86/mm: Stop calling leave_mm() in idle code"
  (bsc#1068032 CVE-2017-5754).
- x86/mm: Remove debug/x86/tlb_defer_switch_to_init_mm
  (bsc#1068032 CVE-2017-5754).
- x86/mm: Tidy up "x86/mm: Flush more aggressively in lazy TLB
  mode" (bsc#1068032 CVE-2017-5754).
- x86/mm/64: Remove the last VM_BUG_ON() from the TLB code
  (bsc#1068032 CVE-2017-5754).
- x86/mm: Flush more aggressively in lazy TLB mode (bsc#1068032
  CVE-2017-5754).
- x86/mm: Factor out CR3-building code (bsc#1068032
  CVE-2017-5754).
- x86/mm: Get rid of VM_BUG_ON in switch_tlb_irqs_off()
  (bsc#1068032 CVE-2017-5754).
- x86/mm/64: Fix an incorrect warning with CONFIG_DEBUG_VM=y,
  !PCID (bsc#1068032 CVE-2017-5754).
- x86/mm: Reinitialize TLB state on hotplug and resume
  (bsc#1068032 CVE-2017-5754).
- x86/mm: Implement PCID based optimization: try to preserve
  old TLB entries using PCID (bsc#1068032 CVE-2017-5754).
- x86/mm, KVM: Teach KVM's VMX code that CR3 isn't a constant
  (bsc#1068032 CVE-2017-5754).
- x86/mm: Stop calling leave_mm() in idle code (bsc#1068032
  CVE-2017-5754).
- x86/mm: Rework lazy TLB mode and TLB freshness tracking
  (bsc#1068032 CVE-2017-5754).
- x86/mm: Remove reset_lazy_tlbstate() (bsc#1068032
  CVE-2017-5754).
- x86/mm: Track the TLB's tlb_gen and update the flushing
  algorithm (bsc#1068032 CVE-2017-5754).
- x86/mm: Give each mm TLB flush generation a unique ID
  (bsc#1068032 CVE-2017-5754).
- x86/ldt: Simplify the LDT switching logic (bsc#1068032
  CVE-2017-5754).
- x86/mm: Be more consistent wrt PAGE_SHIFT vs PAGE_SIZE in tlb
  flush code (bsc#1068032 CVE-2017-5754).
- x86/mm: Don't reenter flush_tlb_func_common() (bsc#1068032
  CVE-2017-5754).
- x86/mm: Rework lazy TLB to track the actual loaded mm
  (bsc#1068032 CVE-2017-5754).
- x86/mm: Remove the UP asm/tlbflush.h code, always use the
  (formerly) SMP code (bsc#1068032 CVE-2017-5754).
- x86/mm: Use new merged flush logic in arch_tlbbatch_flush()
  (bsc#1068032 CVE-2017-5754).
- x86/mm: Refactor flush_tlb_mm_range() to merge local and remote
  cases (bsc#1068032 CVE-2017-5754).
- x86/mm: Change the leave_mm() condition for local TLB flushes
  (bsc#1068032 CVE-2017-5754).
- x86/mm: Pass flush_tlb_info to flush_tlb_others() etc
  (bsc#1068032 CVE-2017-5754).
- mm, x86/mm: Make the batched unmap TLB flush API more generic
  (bsc#1068032 CVE-2017-5754).
- x86/mm: Reduce indentation in flush_tlb_func() (bsc#1068032
  CVE-2017-5754).
- x86/mm: Reimplement flush_tlb_page() using flush_tlb_mm_range()
  (bsc#1068032 CVE-2017-5754).
- commit 10bb3d6
* Mon Jan 15 2018 mkubecek@suse.cz
- bpf: simplify narrower ctx access (bsc#1073928).
- commit e69d191
* Mon Jan 15 2018 tbogendoerfer@suse.de
- nfp: always unmask aux interrupts at init (bsc#1055968).
- cxgb4: Fix FW flash errors (bsc#1064802 bsc#1066129).
- net/sched: Fix update of lastuse in act modules implementing
  stats_update (bsc#1056787).
- IB/srpt: Fix ACL lookup during login (bsc#1046306 FATE#322942).
- RDMA/netlink: Fix locking around __ib_get_device_by_index
  (bsc#1046306 FATE#322942).
- IB/ipoib: Fix race condition in neigh creation (bsc#1046307
  FATE#322941).
- IB/mlx4: Fix mlx4_ib_alloc_mr error flow (bsc#1046302
  FATE#322945).
- RDMA/cxgb3: remove redundant first assignement of sqp
  (bsc#1046306 FATE#322942).
- commit 861131d
* Mon Jan 15 2018 mkubecek@suse.cz
- bpf: fix integer overflows (CVE-2017-17854 bsc#1073928).
- commit 30aa5d1
* Mon Jan 15 2018 mkubecek@suse.cz
- bpf: fix 32-bit ALU op verification (CVE-2017-17852
  bsc#1073928).
- commit 9e3ea9b
* Mon Jan 15 2018 mkubecek@suse.cz
- bpf: fix incorrect tracking of register size truncation
  (CVE-2017-16996 bsc#1073928).
- commit fcb9274
* Mon Jan 15 2018 mkubecek@suse.cz
- bpf: fix branch pruning logic (CVE-2017-17862 CVE-2017-17864
  bsc#1073928).
- commit 72c5166
* Mon Jan 15 2018 mkubecek@suse.cz
- bpf: move global verifier log into verifier environment
  (bsc#1073928).
- Refresh
  patches.drivers/bpf-fix-missing-error-return-in-check_stack_boundary.patch.
- Refresh
  patches.drivers/bpf-verifier-fix-bounds-calculation-on-BPF_RSH.patch.
- Refresh
  patches.suse/bpf-prevent-out-of-bounds-speculation.patch.
- commit be080dc
* Mon Jan 15 2018 mkubecek@suse.cz
- bpf: encapsulate verifier log state into a structure
  (bsc#1073928).
- bpf/verifier: improve disassembly of BPF_NEG instructions
  (bsc#1073928).
- bpf/verifier: improve disassembly of BPF_END instructions
  (bsc#1073928).
- commit 1108f7e
* Mon Jan 15 2018 mkubecek@suse.cz
- Move Spectre BPF fixes into sorted section
- Refresh patches.drivers/bpf-Introduce-bpf_map-ID.patch.
- Refresh
  patches.drivers/bpf-free-up-BPF_JMP-BPF_CALL-BPF_X-opcode.patch.
- Refresh
  patches.suse/bpf-array-fix-overflow-in-max_entries-and-undefined-.patch.
- Refresh
  patches.suse/bpf-prevent-out-of-bounds-speculation.patch.
  (Strictly speaking, not exactly a refresh as the resulting expanded tree
  differs but I preferred to order the members of struct bpf_map as they are
  in mainline.)
- commit 7834099
* Sat Jan 13 2018 jkosina@suse.cz
- Update config files: run oldconfig on vanilla (HMM merge fallout)
- commit ffda3e4
* Fri Jan 12 2018 bp@suse.de
- x86/dumpstack: Fix partial register dumps (bsc#1068032
  CVE-2017-5754).
- x86/process: Define cpu_tss_rw in same section as declaration
  (bsc#1068032 CVE-2017-5754).
- x86/xen/64: Fix the reported SS and CS in SYSCALL (bsc#1068032
  CVE-2017-5754).
- x86/entry/64: Fix entry_SYSCALL_64_after_hwframe() IRQ tracing
  (bsc#1068032 CVE-2017-5754).
- Refresh
  patches.arch/10-x86-dumpstack-handle-stack-overflow-on-all-stacks.patch.
- Refresh
  patches.arch/22-x86-entry-64-make-cpu_entry_area-tss-read-only.patch.
- commit ea8be21
* Fri Jan 12 2018 bp@suse.de
- x86/cpufeatures: Make CPU bugs sticky (bsc#1068032
  CVE-2017-5754).
- x86/paravirt: Provide a way to check for hypervisors
  (bsc#1068032 CVE-2017-5754).
- x86/virt: Add enum for hypervisors to replace x86_hyper
  (bsc#1068032 CVE-2017-5754).
- x86/virt, x86/platform: Merge 'struct x86_hyper' into 'struct
  x86_platform' and 'struct x86_init' (bsc#1068032 CVE-2017-5754).
- x86/paravirt: Dont patch flush_tlb_single (bsc#1068032
  CVE-2017-5754).
- x86/entry/64: Make cpu_entry_area.tss read-only (bsc#1068032
  CVE-2017-5754).
- x86/entry: Clean up the SYSENTER_stack code (bsc#1068032
  CVE-2017-5754).
- x86/entry/64: Remove the SYSENTER stack canary (bsc#1068032
  CVE-2017-5754).
- x86/entry/64: Move the IST stacks into struct cpu_entry_area
  (bsc#1068032 CVE-2017-5754).
- x86/entry/64: Create a per-CPU SYSCALL entry trampoline
  (bsc#1068032 CVE-2017-5754).
- x86/xen/64: Rearrange the SYSCALL entries (bsc#1068032
  CVE-2017-5754).
- x86/entry/64: Return to userspace from the trampoline stack
  (bsc#1068032 CVE-2017-5754).
- x86/entry/64: Use a per-CPU trampoline stack for IDT entries
  (bsc#1068032 CVE-2017-5754).
- x86/espfix/64: Stop assuming that pt_regs is on the entry stack
  (bsc#1068032 CVE-2017-5754).
- x86/entry/64: Separate cpu_current_top_of_stack from TSS.sp0
  (bsc#1068032 CVE-2017-5754).
- x86/entry: Remap the TSS into the CPU entry area (bsc#1068032
  CVE-2017-5754).
- x86/entry: Move SYSENTER_stack to the beginning of struct
  tss_struct (bsc#1068032 CVE-2017-5754).
- x86/dumpstack: Handle stack overflow on all stacks (bsc#1068032
  CVE-2017-5754).
- x86/entry: Fix assumptions that the HW TSS is at the beginning
  of cpu_tss (bsc#1068032 CVE-2017-5754).
- x86/mm/fixmap: Generalize the GDT fixmap mechanism, introduce
  struct cpu_entry_area (bsc#1068032 CVE-2017-5754).
- x86/entry/gdt: Put per-CPU GDT remaps in ascending order
  (bsc#1068032 CVE-2017-5754).
- x86/dumpstack: Add get_stack_info() support for the SYSENTER
  stack (bsc#1068032 CVE-2017-5754).
- x86/entry/64: Allocate and enable the SYSENTER stack
  (bsc#1068032 CVE-2017-5754).
- x86/irq/64: Print the offending IP in the stack overflow warning
  (bsc#1068032 CVE-2017-5754).
- x86/unwinder: Handle stack overflows more gracefully
  (bsc#1068032 CVE-2017-5754).
- x86/unwinder/orc: Dont bail on stack overflow (bsc#1068032
  CVE-2017-5754).
- x86/entry/64/paravirt: Use paravirt-safe macro to access eflags
  (bsc#1068032 CVE-2017-5754).
- commit 4ffe4d7
* Fri Jan 12 2018 msuchanek@suse.de
- Refresh patches.arch/powerpc-rfi-flush-Move-the-logic-to-avoid-a-redo-int.patch.
  Add missing hunk
- commit 77b0afb
* Fri Jan 12 2018 jslaby@suse.cz
- bpf, array: fix overflow in max_entries and undefined behavior
  in index_mask (bsc#1068032 CVE-2017-5753).
- commit e1fc2a6
* Fri Jan 12 2018 jthumshirn@suse.de
- s390/disassembler: correct disassembly lines alignment
  (bnc#1072915, LTC#161577).
- commit 588da4b
* Fri Jan 12 2018 msuchanek@suse.de
- powerpc/pseries/rfi-flush: Call setup_rfi_flush() after LPM
  migration (bsc#1068032).
- powerpc/rfi-flush: Move the logic to avoid a redo into the
  sysfs code (bsc#1068032).
- commit 1eb315e
* Fri Jan 12 2018 jthumshirn@suse.de
- s390/pci: handle insufficient resources during dma tlb flush
  (bnc#1072915, LTC#163393).
- s390/disassembler: increase show_code buffer size (bnc#1072915,
  LTC#161577).
- s390/qeth: fix early exit from error path (bnc#1072915,
  LTC#162173).
- s390: fix transactional execution control register handling
  (bnc#1072915, LTC#162116).
- s390/disassembler: add missing end marker for e7 table
  (bnc#1072915, LTC#162117).
- commit aa6f28e
* Fri Jan 12 2018 jthumshirn@suse.de
- dm mpath: Use blk_path_error (FATE#323952, FATE#322506).
- nvme/multipath: Use blk_path_error (FATE#323952, FATE#322506).
- block: Provide blk_status_t decoding for path errors
  (FATE#323952, FATE#322506).
- nvme/multipath: Consult blk_status_t for failover (FATE#323952,
  FATE#322506).
- nvme: Add more command status translation (FATE#323952,
  FATE#322506).
- commit 0e5402c
* Fri Jan 12 2018 jthumshirn@suse.de
- scripts/git_sort/git_sort.py: add Jens Axboe's for-next branch
- commit 07603e6
* Fri Jan 12 2018 hare@suse.de
- nvme_fc: correct hang in nvme_ns_remove() (bsc#1075811).
- nvme_fc: fix rogue admin cmds stalling teardown (bsc#1075811).
- commit 529f10d
* Fri Jan 12 2018 jslaby@suse.cz
- Refresh
  patches.suse/bpf-prevent-out-of-bounds-speculation.patch.
- Delete
  patches.suse/0004-bpf-prevent-speculative-execution-in-eBPF-interprete.patch.
  Update the upstream status of the former.
  And removed the latter as it has been just replaced by the proper
  upstream solution.
- commit c092517
* Fri Jan 12 2018 jthumshirn@suse.de
- nvme: Fix NULL dereference on reservation request (FATE#323952,
  FATE#322506).
- commit 989d61e
* Fri Jan 12 2018 jthumshirn@suse.de
- Refresh
  patches.drivers/nvme-mpath-fix-last-path-removal-during-traffic.patch.
- commit b181043
* Fri Jan 12 2018 tbogendoerfer@suse.de
- iw_cxgb4: only clear the ARMED bit if a notification is needed
  (bsc#1074762).
- commit c4e49f6
* Fri Jan 12 2018 tiwai@suse.de
- drm/i915/cfl: Adding more Coffee Lake PCI IDs (FATE#322643
  bsc#1055900).
- x86/gpu: add CFL to early quirks (FATE#322643 bsc#1055900).
- drm/i915: Apply Display WA #1183 on skl, kbl, and cfl
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Map VBT DDC Pin to BSpec DDC Pin (FATE#322643
  bsc#1055900).
- drm/i915: Pass encoder type to cnl_ddi_vswing_sequence()
  explicitly (FATE#322643 bsc#1055900).
- drm/i915/kbl: Change a KBL pci id to GT2 from GT1.5 (FATE#322643
  bsc#1055900).
- drm/i915: rework IS_*_GT* macros (FATE#322643 bsc#1055900).
- drm/i915: mark all device info struct with __initconst
  (FATE#322643 bsc#1055900).
- drm/i915: add GT number to intel_device_info (FATE#322643
  bsc#1055900).
- drm/i915: Unify GT* and GT3 definitions (FATE#322643
  bsc#1055900).
- commit 1aca3f9
* Fri Jan 12 2018 msuchanek@suse.de
- ibmvnic: Don't handle RX interrupts when not up (bsc#1075066).
- powerpc/tm: Flush TM only if CPU has TM feature (bsc#1075746).
- commit 10ca720
* Fri Jan 12 2018 tiwai@suse.de
- Delete buggy i915 WA#1133
  Upstream reverted the commit via 7a8b70535037.
- commit f3d58a2
* Fri Jan 12 2018 tbogendoerfer@suse.de
- enic: Add support for 'ethtool -g/-G' (bsc#1037697).
- enic: reset fetch index (bsc#1037697).
- commit 1de5aa3
* Fri Jan 12 2018 jslaby@suse.cz
- bpf: prevent out-of-bounds speculation (bsc#1068032
  CVE-2017-5753).
- Refresh patches.drivers/bpf-Introduce-bpf_map-ID.patch.
- Refresh
  patches.drivers/bpf-free-up-BPF_JMP-BPF_CALL-BPF_X-opcode.patch.
- commit 5e34282
* Thu Jan 11 2018 tbogendoerfer@suse.de
- bnxt_en: Fix the 'Invalid VF' id check in bnxt_vf_ndo_prep
  routine (bsc#1050242 FATE#32291).
- bnxt_en: Fix population of flow_type in
  bnxt_hwrm_cfa_flow_alloc() (bsc#1050242 FATE#32291).
- commit a5c4842
* Thu Jan 11 2018 msuchanek@suse.de
- powerpc/powernv: Check device-tree for RFI flush settings
  (bsc#1068032).
- powerpc/pseries: Query hypervisor for RFI flush settings
  (bsc#1068032).
- powerpc/64s: Support disabling RFI flush with no_rfi_flush
  and nopti (bsc#1068032).
- powerpc/64s: Add support for RFI flush of L1-D cache
  (bsc#1068032).
- powerpc/64s: Convert slb_miss_common to use RFI_TO_USER/KERNEL
  (bsc#1068032).
- powerpc/64: Convert fast_exception_return to use
  RFI_TO_USER/KERNEL (bsc#1068032).
- powerpc/64: Convert the syscall exit path to use
  RFI_TO_USER/KERNEL (bsc#1068032).
- powerpc/64s: Simple RFI macro conversions (bsc#1068032).
- powerpc/64: Add macros for annotating the destination of
  rfid/hrfid (bsc#1068032).
- powerpc/pseries: Add H_GET_CPU_CHARACTERISTICS flags & wrapper
  (bsc#1068032).
- powerpc/64s: masked_interrupt() returns to kernel so avoid
  restoring r13 (bsc#1068032).
- powerpc/64s: Add EX_SIZE definition for paca exception save
  areas (bsc#1068032).
- commit 4d37f12
* Thu Jan 11 2018 msuchanek@suse.de
- ibmvnic: Fix pending MAC address changes (bsc#1075627).
- commit 6c5f5a0
* Thu Jan 11 2018 msuchanek@suse.de
- powerpc/pseries: Make RAS IRQ explicitly dependent on DLPAR WQ
  (FATE#323745, bsc#1067906).
- commit a40c0d4
* Thu Jan 11 2018 mgorman@suse.de
- Refresh
  patches.suse/cpufreq-intel_pstate-Temporarily-boost-P-state-when-exiting-from-idle.patch.
- commit 0b73b50
* Thu Jan 11 2018 tiwai@suse.de
- Refresh patches.drivers/mfd-Add-support-for-Cherry-Trail-Dollar-Cove-TI-PMIC (bsc#1068546)
  Fix the i2c probe due to missing empty table
- commit d3b0394
* Thu Jan 11 2018 lpechacek@suse.com
- rpm/kernel-binary.spec.in: more specific kGraft Provides: (fate#323682)
  Follow openSUSE packaging practices described at
  https://en.opensuse.org/openSUSE:Package_dependencies#Renaming_a_package.
- commit 050081b
* Thu Jan 11 2018 tiwai@suse.de
- ALSA: pcm: Allow aborting mutex lock at OSS read/write loops
  (bsc#1051510).
- ALSA: pcm: Abort properly at pending signal in OSS read/write
  loops (bsc#1051510).
- ALSA: aloop: Fix racy hw constraints adjustment (bsc#1051510).
- ALSA: aloop: Fix inconsistent format due to incomplete rule
  (bsc#1051510).
- ALSA: aloop: Release cable upon open error path (bsc#1051510).
- ALSA: pcm: Add missing error checks in OSS emulation plugin
  builder (bsc#1051510).
- ALSA: pcm: Remove incorrect snd_BUG_ON() usages (bsc#1051510).
- commit e8d347b
* Wed Jan 10 2018 bp@suse.de
- x86/entry/64: Shorten TEST instructions (bsc#1068032
  CVE-2017-5754).
- x86/traps: Use a new on_thread_stack() helper to clean up an
  assertion (bsc#1068032 CVE-2017-5754).
- x86/entry/64: Remove thread_struct::sp0 (bsc#1068032
  CVE-2017-5754).
- x86/entry/32: Fix cpu_current_top_of_stack initialization at
  boot (bsc#1068032 CVE-2017-5754).
- x86/entry/64: Remove all remaining direct thread_struct::sp0
  reads (bsc#1068032 CVE-2017-5754).
- x86/entry/64: Stop initializing TSS.sp0 at boot (bsc#1068032
  CVE-2017-5754).
- x86/xen/64, x86/entry/64: Clean up SP code in
  cpu_initialize_context() (bsc#1068032 CVE-2017-5754).
- x86/entry: Add task_top_of_stack() to find the top of a task's
  stack (bsc#1068032 CVE-2017-5754).
- x86/entry/64: Pass SP0 directly to load_sp0() (bsc#1068032
  CVE-2017-5754).
- x86/entry/32: Pull the MSR_IA32_SYSENTER_CS update code out
  of native_load_sp0() (bsc#1068032 CVE-2017-5754).
- x86/entry/64: De-Xen-ify our NMI code (bsc#1068032
  CVE-2017-5754).
- xen, x86/entry/64: Add xen NMI trap entry (bsc#1068032
  CVE-2017-5754).
- x86/xen: Get rid of paravirt op adjust_exception_frame
  (bsc#1068032 CVE-2017-5754).
- x86/entry/64: Remove the RESTORE_..._REGS infrastructure
  (bsc#1068032 CVE-2017-5754).
- x86/entry/64: Use POP instead of MOV to restore regs on NMI
  return (bsc#1068032 CVE-2017-5754).
- x86/entry/64: Merge the fast and slow SYSRET paths (bsc#1068032
  CVE-2017-5754).
- x86/entry/64: Use pop instead of movq in
  syscall_return_via_sysret (bsc#1068032 CVE-2017-5754).
- x86/entry/64: Shrink paranoid_exit_restore and make labels local
  (bsc#1068032 CVE-2017-5754).
- x86/entry/64: Simplify reg restore code in the standard IRET
  paths (bsc#1068032 CVE-2017-5754).
- x86/entry/64: Move SWAPGS into the common IRET-to-usermode path
  (bsc#1068032 CVE-2017-5754).
- x86/entry/64: Split the IRET-to-user and IRET-to-kernel paths
  (bsc#1068032 CVE-2017-5754).
- x86/entry/64: Remove the restore_c_regs_and_iret label
  (bsc#1068032 CVE-2017-5754).
- commit 0f7ab23
* Wed Jan 10 2018 tiwai@suse.de
- ACPI / watchdog: Make acpi_has_watchdog() false after failing
  the device creation (bsc#1073960).
- commit c0345e4
* Wed Jan 10 2018 mgorman@suse.de
- Refresh
  patches.suse/cpufreq-intel_pstate-Temporarily-boost-P-state-when-exiting-from-idle.patch.
- commit 7b370e7
* Wed Jan 10 2018 tiwai@suse.de
- Re-enable CONFIG_KEXEC_VERIFY_SIG=y for x86_64 (bsc#1075051)
  It was turned off due to the breakage of kdump in Leap 42.1, but now
  it's mandatory for kexec in secure boot mode.
- commit bb64d0d
* Wed Jan 10 2018 jthumshirn@suse.de
- nvme-mpath: fix last path removal during traffic (FATE#323952,
  FATE#322506).
- commit d221a0c
* Tue Jan  9 2018 lduncan@suse.com
- scsi: libiscsi: Allow sd_shutdown on bad transport
  (bsc#1075234).
- commit 31d7cc7
* Tue Jan  9 2018 tiwai@suse.de
- Update config files: fix arm64/vanilla config
- commit 33b1664
* Tue Jan  9 2018 tiwai@suse.de
- Move upstreamed input and misc driver patches into sorted section
- commit 5b07263
* Tue Jan  9 2018 tiwai@suse.de
- ASoC: atmel-classd: select correct Kconfig symbol (bsc#1051510).
- ASoC: rockchip: disable clock on error (bsc#1051510).
- ASoC: rsnd: ssiu: clear SSI_MODE for non TDM Extended modes
  (bsc#1051510).
- commit 3cec1bc
* Tue Jan  9 2018 tiwai@suse.de
- drm/i915: Protect DDI port to DPLL map from theoretical race
  (bsc#1051510).
- commit c8c45d6
* Tue Jan  9 2018 tbogendoerfer@suse.de
- Revert "mlx5: move affinity hints assignments to generic code"
  (bsc#1046303 FATE#322944 bsc#1075185).
- commit 9ba5d83
* Tue Jan  9 2018 tiwai@suse.de
- Move Wireless driver patches into the sorted section
  Update patch tags accordingly, too.
  Also, correct the bad backport in
  patches.drivers/0001-iwlwifi-mvm-send-all-non-bufferable-frames-on-the-pr
  Refreshed patches:
  patches.drivers/0123-iwlwifi-mvm-map-cab_queue-to-real-one-earlier.patch
  patches.drivers/iwlwifi-mvm-quietly-accept-non-sta-assoc-response-fr
  patches.drivers/iwlwifi-mvm-quietly-accept-non-sta-disassoc-frames
  patches.drivers/iwlwifi-pcie-fix-TVQM-queue-ID-range-check
  patches.drivers/iwlwifi-pcie-fix-command-completion-name-debug
  patches.drivers/0001-iwlwifi-mvm-send-all-non-bufferable-frames-on-the-pr.patch
  patches.drivers/0039-iwlwifi-pcie-don-t-init-a-Tx-queue-with-an-SSN-size-.patch
  patches.drivers/0048-iwlwifi-pcie-support-short-Tx-queues-for-A000-device.patch
  patches.drivers/0144-iwlwifi-mvm-send-delba-upon-rx-ba-session-timeout.patch
  patches.drivers/iwlwifi-mvm-fix-a-NULL-pointer-dereference-of-error-
- commit 7a1ea61
* Tue Jan  9 2018 yousaf.kaukab@suse.com
- config: arm64: enable UNMAP_KERNEL_AT_EL0
- commit 6afa3ca
* Tue Jan  9 2018 tiwai@suse.de
- Move DRM/video patches into the sorted section
  Update patch tags accordingly, too.
  Refreshed patches:
  patches.drivers/drm-i915-Always-use-9-bits-of-the-LPC-bridge-device-
  patches.drivers/drm-i915-Fix-PCH-names-for-KBP-and-CNP
  patches.drivers/drm-i915-cfl-Add-Coffee-Lake-PCI-IDs-for-H-Sku
  patches.drivers/drm-i915-cfl-Add-Coffee-Lake-PCI-IDs-for-S-Skus
  patches.drivers/drm-i915-cfl-Add-Coffee-Lake-PCI-IDs-for-U-Sku
  patches.drivers/drm-i915-cfl-Introduce-Coffee-Lake-workarounds
  patches.drivers/drm-i915-cnl-Add-Cannonlake-PCI-IDs-for-U-skus
  patches.drivers/drm-i915-cnl-Fix-the-CURSOR_COEFF_MASK-used-in-DDI-V
  patches.drivers/drm-i915-gen9-Reintroduce-WaEnableYV12BugFixInHalfSl
- commit 415c89f
* Tue Jan  9 2018 yousaf.kaukab@suse.com
- arm64: kaslr: Put kernel vectors address in separate data page
  (bsc#1068032).
- arm64: mm: Introduce TTBR_ASID_MASK for getting at the ASID
  in the TTBR (bsc#1068032).
- arm64: Kconfig: Add CONFIG_UNMAP_KERNEL_AT_EL0 (bsc#1068032).
- arm64: entry: Add fake CPU feature for unmapping the kernel
  at EL0 (bsc#1068032).
- arm64: tls: Avoid unconditional zeroing of tpidrro_el0 for
  native tasks (bsc#1068032).
- arm64: erratum: Work around Falkor erratum #E1003 in trampoline
  code (bsc#1068032).
- arm64: entry: Hook up entry trampoline to exception vectors
  (bsc#1068032).
- arm64: entry: Explicitly pass exception level to kernel_ventry
  macro (bsc#1068032).
- arm64: entry.S: move SError handling into a C function for
  future expansion (bsc#1068032).
- arm64: Mask all exceptions during kernel_exit (bsc#1068032).
- arm64: Move the async/fiq helpers to explicitly set process
  context flags (bsc#1068032).
- arm64: introduce an order for exceptions (bsc#1068032).
- arm64: explicitly mask all exceptions (bsc#1068032).
- arm64: add VMAP_STACK overflow detection (bsc#1068032).
- arm64: add on_accessible_stack() (bsc#1068032).
- arm64: add basic VMAP_STACK support (bsc#1068032).
- arm64: use an irq stack pointer (bsc#1068032).
- arm64: assembler: allow adr_this_cpu to use the stack pointer
  (bsc#1068032).
- arm64: factor out entry stack manipulation (bsc#1068032).
- efi/arm64: add EFI_KIMG_ALIGN (bsc#1068032).
- arm64: move SEGMENT_ALIGN to <asm/memory.h> (bsc#1068032).
- arm64: clean up irq stack definitions (bsc#1068032).
- arm64: clean up THREAD_* definitions (bsc#1068032).
- arm64: factor out PAGE_* and CONT_* definitions (bsc#1068032).
- arm64: kernel: remove {THREAD,IRQ_STACK}_START_SP (bsc#1068032).
- fork: allow arch-override of VMAP stack alignment (bsc#1068032).
- arm64: remove __die()'s stack dump (bsc#1068032).
- arm64: unwind: remove sp from struct stackframe (bsc#1068032).
- arm64: unwind: reference pt_regs via embedded stack frame
  (bsc#1068032).
- arm64: Add dump_backtrace() in show_regs (bsc#1068032).
- arm64: Call __show_regs directly (bsc#1068032).
- arm64: unwind: disregard frame.sp when validating frame pointer
  (bsc#1068032).
- arm64: unwind: avoid percpu indirection for irq stack
  (bsc#1068032).
- arm64: move non-entry code out of .entry.text (bsc#1068032).
- arm64: consistently use bl for C exception entry (bsc#1068032).
- arm64: Add ASM_BUG() (bsc#1068032).
- arm64: mm: Map entry trampoline into trampoline and kernel
  page tables (bsc#1068032).
- arm64: entry: Add exception trampoline page for exceptions
  from EL0 (bsc#1068032).
- arm64: mm: Invalidate both kernel and user ASIDs when performing
  TLBI (bsc#1068032).
- arm64: mm: Add arm64_kernel_unmapped_at_el0 helper
  (bsc#1068032).
- arm64: mm: Allocate ASIDs in pairs (bsc#1068032).
- arm64: mm: Fix and re-enable ARM64_SW_TTBR0_PAN (bsc#1068032).
- arm64: mm: Rename post_ttbr0_update_workaround (bsc#1068032).
- arm64: mm: Remove pre_ttbr0_update_workaround for Falkor
  erratum #E1003 (bsc#1068032).
- arm64: context: Fix comments and remove pointless smp_wmb()
  (bsc#1068032).
- arm64: mm: Move ASID from TTBR0 to TTBR1 (bsc#1068032).
- arm64: mm: Temporarily disable ARM64_SW_TTBR0_PAN (bsc#1068032).
- arm64: mm: Use non-global mappings for kernel space
  (bsc#1068032).
- arm64: Move PTE_RDONLY bit handling out of set_pte_at()
  (bsc#1068032).
- arm64: Convert pte handling from inline asm to using (cmp)xchg
  (bsc#1068032).
- arm64: Fix potential race with hardware DBM in
  ptep_set_access_flags() (bsc#1068032).
- commit 0b6ce86
* Tue Jan  9 2018 tbogendoerfer@suse.de
- net/mlx5: Fix misspelling in the error message and comment
  (bsc#1046303 FATE#322944).
- net/mlx4_core: Fix wrong calculation of free counters
  (bsc#1046300 FATE#322946).
- net/mlx4_en: Fix selftest for small MTUs (bsc#1046299
  FATE#322947 Mellanox).
- i40e: fix the calculation of VFs mac addresses (bsc#1056658
  FATE#322188 bsc#1056662 FATE#322186).
- i40e: only redistribute MSI-X vectors when needed (bsc#1056658
  FATE#322188 bsc#1056662 FATE#322186).
- net/mlx4_core: Fix cast warning in fw.c (bsc#1046300
  FATE#322946).
- net/mlx4: Fix endianness issue in qp context params (bsc#1046300
  FATE#322946).
- commit 15cabbf
* Tue Jan  9 2018 jslaby@suse.cz
- userns: prevent speculative execution (bsc#1068032
  CVE-2017-5753).
- udf: prevent speculative execution (bsc#1068032 CVE-2017-5753).
- net: mpls: prevent speculative execution (bsc#1068032
  CVE-2017-5753).
- fs: prevent speculative execution (bsc#1068032 CVE-2017-5753).
- ipv6: prevent speculative execution (bsc#1068032 CVE-2017-5753).
- ipv4: prevent speculative execution (bsc#1068032 CVE-2017-5753).
- Thermal/int340x: prevent speculative execution (bsc#1068032
  CVE-2017-5753).
- cw1200: prevent speculative execution (bsc#1068032
  CVE-2017-5753).
- qla2xxx: prevent speculative execution (bsc#1068032
  CVE-2017-5753).
- p54: prevent speculative execution (bsc#1068032 CVE-2017-5753).
- carl9170: prevent speculative execution (bsc#1068032
  CVE-2017-5753).
- uvcvideo: prevent speculative execution (bsc#1068032
  CVE-2017-5753).
- x86, bpf, jit: prevent speculative execution when JIT is enabled
  (bsc#1068032 CVE-2017-5753).
- bpf: prevent speculative execution in eBPF interpreter
  (bsc#1068032 CVE-2017-5753).
- locking/barriers: introduce new observable speculation barrier
  (bsc#1068032 CVE-2017-5753).
- x86/cpu/AMD: Remove now unused definition of MFENCE_RDTSC
  feature (bsc#1068032 CVE-2017-5753).
- x86/cpu/AMD: Make the LFENCE instruction serialized (bsc#1068032
  CVE-2017-5753).
- commit ee60c7e
* Mon Jan  8 2018 tiwai@suse.de
- x86/mm: Unbreak modules that use the DMA API (bsc#1075052).
- commit 0f06940
* Mon Jan  8 2018 jack@suse.cz
- ext4: Fix ENOSPC handling in DAX page fault handler
  (bsc#1067281).
- dax: Pass detailed error code from dax_iomap_fault()
  (bsc#1067281).
- commit a1646e6
* Mon Jan  8 2018 jthumshirn@suse.de
- bsg-lib: fix use-after-free under memory-pressure (bsc#1074140).
- commit 67cee42
* Mon Jan  8 2018 tbogendoerfer@suse.de
- RDMA/vmw_pvrdma: Avoid use after free due to QP/CQ/SRQ destroy
  (bsc#1046306 FATE#322942).
- RDMA/vmw_pvrdma: Use refcount_dec_and_test to avoid warning
  (bsc#1046306 FATE#322942).
- s390/qeth: fix error handling in checksum cmd callback
  (bsc#1061024 FATE#323301).
- s390/qeth: update takeover IPs after configuration change
  (bsc#1061024 FATE#323301).
- s390/qeth: lock IP table while applying takeover changes
  (bsc#1061024 FATE#323301).
- s390/qeth: don't apply takeover changes to RXIP (bsc#1061024
  FATE#323301).
- s390/qeth: apply takeover changes when mode is toggled
  (bsc#1061024 FATE#323301).
- RDMA/vmw_pvrdma: Add shared receive queue support (bsc#1046306
  FATE#322942).
- IB/mlx4: Increase maximal message size under UD QP (bsc#1046302
  FATE#322945).
- IB/mlx5: Assign send CQ and recv CQ of UMR QP (bsc#1046305
  FATE#322943).
- commit 573bb09
* Mon Jan  8 2018 jthumshirn@suse.de
- bsg-lib: fix kernel panic resulting from missing allocation
  of reply-buffer (bsc#1074140).
- commit 707b96d
* Mon Jan  8 2018 jthumshirn@suse.de
- Refresh
  patches.drivers/nvmet-fc-cleanup-nvmet-add_port-remove_port.patch.
- Delete patches.drivers/nvmet_fc-correct-broken-add_port.patch.
- commit 38a8d6d
* Mon Jan  8 2018 tbogendoerfer@suse.de
- blacklist.conf: mark cd36c3a21a40 as duplicate of 33ba43ed0afc
- commit 08645b1
* Mon Jan  8 2018 tbogendoerfer@suse.de
- bpf: fix incorrect sign extension in check_alu_op()
  (bsc1056787).
- commit 977b7b1
* Mon Jan  8 2018 msuchanek@suse.de
- KVM: PPC: Book3S: fix XIVE migration of pending interrupts
  (bsc#1061840).
- KVM: PPC: Book3S HV: Fix pending_pri value in
  kvmppc_xive_get_icp() (bsc#1061840).
- commit d8d002b
* Mon Jan  8 2018 msuchanek@suse.de
- powerpc/perf/imc: Fix nest-imc cpuhotplug callback failure
  (bsc#1054914).
- powerpc/perf: Fix kfree memory allocated for nest pmus
  (bsc#1054914).
- cxl: Check if vphb exists before iterating over AFU devices
  (bsc#1055014).
- commit 61c1d48
* Mon Jan  8 2018 msuchanek@suse.de
- powerpc/perf: Dereference BHRB entries safely (bsc#1065729).
- commit 57f8b50
* Mon Jan  8 2018 tbogendoerfer@suse.de
- net/mlx5: Stay in polling mode when command EQ destroy fails
  (bsc#1046303 FATE#322944).
- net/mlx5: Cleanup IRQs in case of unload failure (bsc#1046303
  FATE#322944).
- net/mlx5e: Prevent possible races in VXLAN control flow
  (bsc#1046303 FATE#322944).
- net/mlx5e: Add refcount to VXLAN structure (bsc#1046303
  FATE#322944).
- net/mlx5e: Fix possible deadlock of VXLAN lock (bsc#1046303
  FATE#322944).
- socket, bpf: fix possible use after free (bsc1056787).
- commit e08b924
* Mon Jan  8 2018 tbogendoerfer@suse.de
- net_sched: fix a compile warning in act_ife (bsc1056787).
- commit bd78fe1
* Mon Jan  8 2018 tbogendoerfer@suse.de
- crypto: chelsio - select CRYPTO_GF128MUL (bsc#1046548).
- net: sched: fix static key imbalance in case of
  ingress/clsact_init error (bsc1056787).
- net_sched: red: Avoid illegal values (bsc1056787).
- net: sched: cbq: create block for q->link.block (bsc1056787).
- net: sched: fix crash when deleting secondary chains
  (bsc1056787).
- net sched actions: fix module auto-loading (bsc1056787).
- net sched actions: change IFE modules alias names (bsc1056787).
- net_sched: gen_estimator: fix scaling error in bytes/packets
  samples (bsc1056787).
- net sched actions: Use proper root attribute table for actions
  (bsc1056787).
- commit 2bbf18d
* Mon Jan  8 2018 ohering@suse.de
- scsi: storvsc: Fix scsi_cmd error assignments in
  storvsc_handle_error (fate#323887).
- vmbus: unregister device_obj->channels_kset (fate#323887).
- hv: kvp: Avoid reading past allocated blocks from KVP file
  (fate#323887).
- Drivers: hv: vmbus: Fix a rescind issue (fate#323887).
- commit 12ffd27
* Mon Jan  8 2018 msuchanek@suse.de
- kernel-obs-build.spec.in: add --no-hostonly-cmdline to dracut invocation (boo#1062303).
  call dracut with --no-hostonly-cmdline to avoid the random rootfs UUID
  being added into the initrd's /etc/cmdline.d/95root-dev.conf
- commit da5186f
* Mon Jan  8 2018 mgorman@suse.de
- cpufreq: intel_pstate: Temporarily boost P-state when exiting
  from idle (bnc#1068680 Update schedutil and intel_pstate to
  default to load-based policy).
- commit 3b0b990
* Mon Jan  8 2018 mgorman@suse.de
- Refresh
  patches.suse/mm-page_alloc.c-avoid-excessive-IRQ-disabled-times-in-free_unref_page_list.patch.
- commit fcb0706
* Sun Jan  7 2018 lduncan@suse.com
- X.509: fix buffer overflow detection in sprint_oid()
  (bsc#1074877).
- 509: fix printing uninitialized stack memory when OID is empty
  (bsc#1074879).
- KEYS: add missing permission check for request_key() destination
  (bsc#1074878).
- KEYS: trusted: fix writing past end of buffer in trusted_read()
  (bsc#1074880).
- KEYS: encrypted: fix dereference of NULL user_key_payload
  (bsc#1074876).
- commit 3160a2d
* Sat Jan  6 2018 jslaby@suse.cz
- rpm/constraints.in: lower kernel-syzkaller's mem requirements
  OBS now reports that it needs only around 2G, so lower the limit to
  8G, so that more compliant workers can be used.
- commit a73399a
* Sat Jan  6 2018 jbohac@suse.cz
- Remove patches.arch/x86_64-hpet-64bit-timer.patch.
  This is an ancient patch we should have never included in the first place. It
  adds a command-line  parameter "hpet64" which works around a hardware "bug" that
  is only visible if applications mmap HPET.
  The bug makes the HPET main counter wrap at the 32 bit boundary when Timer 0 is
  used in 32 bit mode.
  Thomas Gleixner refused the patch upstream, he claims this does not work on
  some HPETs: https://patchwork.kernel.org/patch/10103049/
  If someone insists on accessing the hardware directly, they should deal with
  hardware oddities.
- commit 20efbd0
* Fri Jan  5 2018 lhenriques@suse.com
- regulator: da9063: Return an error code on probe failure
  (bsc#1074847).
- commit ca048fa
* Fri Jan  5 2018 tbogendoerfer@suse.de
- IB/mlx5: Serialize access to the VMA list (bsc#1046305
  FATE#322943).
- RDMA/vmw_pvrdma: Call ib_umem_release on destroy QP path
  (bsc#1046306 FATE#322942).
- iw_cxgb4: when flushing, complete all wrs in a chain
  (bsc#1046543 FATE#322927).
- bpf: force strict alignment checks for stack pointers
  (bsc#1056787).
- net/mlx5: Fix error flow in CREATE_QP command (bsc#1046303
  FATE#322944).
- net/mlx5e: Fix defaulting RX ring size when not needed
  (bsc#1046303 FATE#322944).
- bpf, ppc64: do not reload skb pointers in non-skb context
  (bsc#1056787).
- bpf, s390x: do not reload skb pointers in non-skb context
  (bsc#1056787).
- net/mlx5e: Add support for ethtool msglvl support (bsc#1046303
  FATE#322944).
- commit d4fe50f
* Fri Jan  5 2018 tbogendoerfer@suse.de
- cxgb4: collect TX rate limit info in UP CIM logs (bsc#1073513).
- cxgb4: RSS table is 4k for T6 (bsc#1073513).
- cxgb4: collect PCIe configuration logs (bsc#1073513).
- cxgb4: collect egress and ingress SGE queue contexts
  (bsc#1073513).
- cxgb4: skip TX and RX payload regions in memory dumps
  (bsc#1073513).
- cxgb4: collect HMA memory dump (bsc#1073513).
- cxgb4: collect MC memory dump (bsc#1073513).
- cxgb4: collect on-chip memory information (bsc#1073513).
- commit 5208a72
* Fri Jan  5 2018 mgorman@suse.de
- cpufreq, intel_pstate: Update setpoint for unspecified ACPI
  profile (bnc#1068680 Update schedutil and intel_pstate to
  default to load-based policy).
- commit 61ed90d
* Fri Jan  5 2018 ghe@suse.com
- dlm: recheck kthread_should_stop() before schedule()
  (bsc#1071422).
- commit ecebdc2
* Fri Jan  5 2018 ghe@suse.com
- DLM: fix NULL pointer dereference in send_to_sock()
  (bsc#1074590).
- commit 33ddb10
* Fri Jan  5 2018 ghe@suse.com
- DLM: fix to reschedule rwork (bsc#1074590).
- commit e8637ae
* Fri Jan  5 2018 ghe@suse.com
- DLM: fix to use sk_callback_lock correctly (bsc#1074590).
- commit 710c4fa
* Fri Jan  5 2018 ghe@suse.com
- DLM: fix overflow dlm_cb_seq (bsc#1074590).
- commit 09372fc
* Fri Jan  5 2018 ghe@suse.com
- DLM: fix memory leak in tcp_accept_from_sock() (bsc#1074590).
- commit 5aedf91
* Fri Jan  5 2018 ghe@suse.com
- DLM: fix conversion deadlock when DLM_LKF_NODLCKWT flag is set
  (bsc#1074590).
- commit 69894be
* Fri Jan  5 2018 ghe@suse.com
- DLM: use CF_CLOSE flag to stop dlm_send correctly (bsc#1074590).
- commit e8a6712
* Fri Jan  5 2018 ghe@suse.com
- DLM: Reanimate CF_WRITE_PENDING flag (bsc#1074590).
- commit a4de653
* Fri Jan  5 2018 ghe@suse.com
- DLM: fix race condition between dlm_recoverd_stop and
  dlm_recoverd (bsc#1074590).
- commit 819a622
* Fri Jan  5 2018 ghe@suse.com
- DLM: close othercon at send/receive error (bsc#1074590).
- commit 0937fb9
* Fri Jan  5 2018 ghe@suse.com
- DLM: retry rcom when dlm_wait_function is timed out
  (bsc#1074590).
- commit c842f52
* Fri Jan  5 2018 ghe@suse.com
- DLM: fix to use sock_mutex correctly in xxx_accept_from_sock
  (bsc#1074590).
- commit 78dd4c6
* Fri Jan  5 2018 ghe@suse.com
- DLM: fix race condition between dlm_send and dlm_recv
  (bsc#1074590).
- commit 11bc1dd
* Fri Jan  5 2018 ghe@suse.com
- DLM: fix double list_del() (bsc#1074590).
- commit a0f2a2c
* Fri Jan  5 2018 ghe@suse.com
- DLM: fix remove save_cb argument from add_sock() (bsc#1074590).
- commit 4b9a8d1
* Fri Jan  5 2018 ghe@suse.com
- DLM: Fix saving of NULL callbacks (bsc#1074590).
- commit 59e7b7b
* Fri Jan  5 2018 ghe@suse.com
- DLM: Eliminate CF_WRITE_PENDING flag (bsc#1074590).
- commit 28eba49
* Fri Jan  5 2018 ghe@suse.com
- DLM: Eliminate CF_CONNECT_PENDING flag (bsc#1074590).
- commit 367693f
* Fri Jan  5 2018 ghe@suse.com
- dlm: remove this patch temporarily
  since I plan to back-port valuable patches of DLM dlm-4.15 to SLE15
  kernel source, but this patch will impact more older patches to
  apply SLE15 kernel. So, I will remove this patch temporarily,
  then get this patch back after this back-port is done.
- commit 70cb39a
* Fri Jan  5 2018 lduncan@suse.com
- scsi: libcxgbi: simplify task->hdr allocation for mgmt cmds
  (bsc#1073515).
- scsi: cxgb4i: fix Tx skb leak (bsc#1073515).
- commit c19f0ba
* Fri Jan  5 2018 lduncan@suse.com
- Fixed incorrect commit for nvmet-fc patch.
  The commits seems to be incorrect for
  patches.drivers/nvmet-fc-cleanup-nvmet-add_port-remove_port.patch,
  perhaps because of upstream merging? Set it to the
  correct commit.
- commit 3e2aa51
* Thu Jan  4 2018 tiwai@suse.de
- ALSA: seq: Avoid invalid lockdep class warning (bsc#1051510).
- commit 1d6dc29
* Thu Jan  4 2018 ghe@suse.com
- dlm: use sock_create_lite inside tcp_accept_from_sock
  (bsc#1069364).
- commit 8b8e456
* Thu Jan  4 2018 neilb@suse.com
- sunrpc: use supplimental groups in auth hash (bsc#1012917).
- commit 9a10aa8
* Thu Jan  4 2018 neilb@suse.com
- kernel: make groups_sort calling a responsibility group_info
  allocators (bsc#1070623).
- commit de0ae1a
* Thu Jan  4 2018 tiwai@suse.de
- ALSA: hda: Drop useless WARN_ON() (bsc#1051510).
- commit f2fb93c
* Thu Jan  4 2018 tiwai@suse.de
- ASoC: twl4030: fix child-node lookup (bsc#1051510).
- commit 69b6ece
* Thu Jan  4 2018 tiwai@suse.de
- ASoC: tlv320aic31xx: Fix GPIO1 register definition
  (bsc#1051510).
- commit 11c73a1
* Thu Jan  4 2018 tiwai@suse.de
- ASoC: codecs: msm8916-wcd: Fix supported formats (bsc#1051510).
- commit 374ba25
* Thu Jan  4 2018 tiwai@suse.de
- ASoC: fsl_ssi: AC'97 ops need regmap, clock and cleaning up
  on failure (bsc#1051510).
- commit dcacf0c
* Thu Jan  4 2018 tiwai@suse.de
- ASoC: da7218: fix fix child-node lookup (bsc#1051510).
- commit e945eac
* Thu Jan  4 2018 tiwai@suse.de
- ASoC: wm_adsp: Fix validation of firmware and coeff lengths
  (bsc#1051510).
- commit 51a0c9c
* Thu Jan  4 2018 tiwai@suse.de
- ALSA: usb-audio: Fix the missing ctl name suffix at parsing SU
  (bsc#1051510).
- commit 563b896
* Thu Jan  4 2018 tiwai@suse.de
- ALSA: rawmidi: Avoid racy info ioctl via ctl device
  (bsc#1051510).
- commit 9c189e8
* Thu Jan  4 2018 tiwai@suse.de
- ALSA: hda - Add vendor id for Cannonlake HDMI codec
  (bsc#1051510).
- commit e971433
* Thu Jan  4 2018 tiwai@suse.de
- ALSA: usb-audio: Add native DSD support for Esoteric D-05X
  (bsc#1051510).
- commit 4d85d23
* Thu Jan  4 2018 tiwai@suse.de
- ALSA: pcm: prevent UAF in snd_pcm_info (bsc#1051510).
- commit 25f7384
* Thu Jan  4 2018 tiwai@suse.de
- ALSA: usb-audio: Add check return value for usb_string()
  (bsc#1051510).
- commit 3171828
* Thu Jan  4 2018 tiwai@suse.de
- ALSA: usb-audio: Fix out-of-bound error (bsc#1051510).
- commit 6578e73
* Thu Jan  4 2018 tiwai@suse.de
- ALSA: seq: Remove spurious WARN_ON() at timer check
  (bsc#1051510).
- commit fc7e398
* Thu Jan  4 2018 tiwai@suse.de
- ALSA: hda - fix headset mic problem for Dell machines with
  alc274 (bsc#1051510).
- commit d23de14
* Thu Jan  4 2018 tiwai@suse.de
- ALSA: seq: Fix OSS sysex delivery in OSS emulation
  (bsc#1051510).
- commit 510ff99
* Thu Jan  4 2018 tiwai@suse.de
- ALSA: timer: Limit max instances per timer (bsc#1051510).
- commit 103491e
* Thu Jan  4 2018 tiwai@suse.de
- ASoC: adau17x1: Workaround for noise bug in ADC (bsc#1051510).
- commit 85fa8c4
* Thu Jan  4 2018 tiwai@suse.de
- ALSA: seq: Fix nested rwsem annotation for lockdep splat
  (bsc#1051510).
- commit fa3fd1f
* Thu Jan  4 2018 tiwai@suse.de
- ALSA: seq: Enable 'use' locking in all configurations
  (bsc#1051510).
- commit 655ae8d
* Thu Jan  4 2018 tiwai@suse.de
- ALSA: usb-audio: Add native DSD support for Pro-Ject Pre Box
  S2 Digital (bsc#1051510).
- commit 6cd87cf
* Thu Jan  4 2018 tiwai@suse.de
- ALSA: caiaq: Fix stray URB at probe error path (bsc#1051510).
- commit 43475d3
* Thu Jan  4 2018 tiwai@suse.de
- ALSA: seq: Fix copy_from_user() call inside lock (bsc#1051510).
- commit 2297056
* Thu Jan  4 2018 tiwai@suse.de
- ALSA: usx2y: Suppress kernel warning at page allocation failures
  (bsc#1051510).
- commit 13eccc1
* Thu Jan  4 2018 tiwai@suse.de
- ALSA: hda - Add MIC_NO_PRESENCE fixup for 2 HP machines
  (bsc#1051510).
- commit 81dfa71
* Thu Jan  4 2018 tiwai@suse.de
- ALSA: hda - Fix missing COEF init for ALC225/295/299
  (bsc#1051510).
- commit a3ae07c
* Thu Jan  4 2018 tiwai@suse.de
- ALSA: hda - change the location for one mic on a Lenovo machine
  (bsc#1051510).
- commit 53462d1
* Thu Jan  4 2018 tiwai@suse.de
- ALSA: hda - fix headset mic detection issue on a Dell machine
  (bsc#1051510).
- commit ec4781a
* Thu Jan  4 2018 tiwai@suse.de
- ALSA: hda/realtek - Fix Dell AIO LineOut issue (bsc#1051510).
- commit 4de0a3d
* Thu Jan  4 2018 tiwai@suse.de
- ALSA: hda/realtek - New codec support for ALC257 (bsc#1051510).
- commit c025c50
* Thu Jan  4 2018 tiwai@suse.de
- ALSA: hda/realtek - Add support for ALC1220 (bsc#1051510).
- commit cd79b10
* Thu Jan  4 2018 tiwai@suse.de
- Move upstreamed sound patches into sorted section
- commit 2f5f898
* Wed Jan  3 2018 mgorman@suse.de
- rcu: Remove debugfs tracing (bnc#1073315 remove defunct
  debugfs tracing).
- commit 761bb8f
* Wed Jan  3 2018 mbenes@suse.cz
- livepatch: Mark the kernel unsupported when disabling a live
  patch (fate#323487).
- commit 38cb6c2
* Wed Jan  3 2018 ghe@suse.com
- dlm: Make dismatch error message more clear (bsc#1074440).
- commit 47fea46
* Wed Jan  3 2018 mgalbraith@suse.de
- sched/rt: Do not pull from current CPU if only one CPU to pull
  (bnc#1022476).
- sched/rt: Simplify the IPI based RT balancing logic
  (bnc#1022476).
- commit 2c0bd50
* Tue Jan  2 2018 tbogendoerfer@suse.de
- IB/mlx5: Fix mlx5_ib_alloc_mr error flow (bsc#1046303
  FATE#322944).
- IB/core: Verify that QP is security enabled in create and
  destroy (bsc#1046306 FATE#322942).
- IB/uverbs: Fix command checking as part of
  ib_uverbs_ex_modify_qp() (bsc#1046306 FATE#322942).
- IB/hfi: Only read capability registers if the capability exists
  (bsc#1060463 FATE#323043).
- IB/mlx5: Fix congestion counters in LAG mode (bsc#1046303
  FATE#322944).
- iw_cxgb4: reflect the original WR opcode in drain cqes
  (bsc#1064802 bsc#1066129).
- bpf: don't prune branches when a scalar is replaced with a
  pointer (bsc#1056787).
- bpf: fix missing error return in check_stack_boundary()
  (bsc#1056787).
- bpf/verifier: fix bounds calculation on BPF_RSH (bsc#1056787).
- net/mlx5e: Fix features check of IPv6 traffic (bsc#1046305
  FATE#322943).
- net/mlx5: Fix rate limit packet pacing naming and struct
  (bsc#1046305 FATE#322943).
- net/mlx5: FPGA, return -EINVAL if size is zero (bsc#1046303
  FATE#322944).
- net/mlx4_en: Fill all counters under one call of stats lock
  (bsc#1046299 FATE#322947).
- commit 9946ea4
* Tue Jan  2 2018 ghe@suse.com
- ocfs2: fix a static checker warning (bsc#1074282).
- commit 691c72c
* Mon Jan  1 2018 bpoirier@suse.com
- git-sort tests wip
- commit fac0c20
* Thu Dec 28 2017 acho@suse.com
- Bluetooth: Prevent stack info leak from the EFS element
  (bsc#1070535 CVE-2017-1000410).
- commit 0214ec3
* Wed Dec 27 2017 bpoirier@suse.com
- git_sort: Use pygit2 to read git config.
  Fixes an error when operating on a repository with no configured remotes.
- commit f28d0a2
* Tue Dec 26 2017 bpoirier@suse.com
- scripts/git_sort/README.md: Add information about quilt package.
- commit 41d89b6
* Tue Dec 26 2017 bpoirier@suse.com
- scripts/git-pre-commit: Specify paths to check to git diff.
  Also, specifically check for changes between the index and HEAD (--cached).
- commit 2450ed3
* Tue Dec 26 2017 dbueso@suse.de
- Delete patches.fixes/0001-autofs-fix-AT_NO_AUTOMOUNT-not-being-honored.patch.
  Per upstream commit:
    5d38f049cee (autofs: revert "autofs: fix AT_NO_AUTOMOUNT not being honored")
- commit ed5935d
* Tue Dec 26 2017 dbueso@suse.de
- blacklist.conf: we don't build null_blk module
- commit bb0a8a8
* Tue Dec 26 2017 dbueso@suse.de
- block: unalign call_single_data in struct request (bsc#1050549).
- commit 5e7d58d
* Tue Dec 26 2017 bpoirier@suse.com
- git_sort: Support configurable cache path.
  Also, create the cache directory if it does not exist.
- commit db0e54d
* Mon Dec 25 2017 bpoirier@suse.com
- series_sort: Catch pygit2 import failure.
  Provide some instructions about how to install the module in the README.
  Note that this only catches the exception from series_sort.py. There are
  other executable python scripts which import pygit2 and those will still
  raise an ImportError if the pygit2 module is not available. However,
  series_sort.py is the most common entry point for new users.
- commit 3c7e689
* Fri Dec 22 2017 jthumshirn@suse.de
- nvmet_fc: correct broken add_port (bsc#1072553).
- commit cc3e8db
* Fri Dec 22 2017 bpoirier@suse.com
- e1000e: Fix e1000_check_for_copper_link_ich8lan return value
  (bsc#1073809).
- e1000e: Avoid receiver overrun interrupt bursts (bsc#1073809).
- e1000e: Separate signaling for link check/link up (bsc#1073809).
- e1000e: Fix return value test (bsc#1073809).
- e1000e: Fix wrong comment related to link detection
  (bsc#1073809).
- e1000e: Fix error path in link detection (bsc#1073809).
- commit 6843b8f
* Fri Dec 22 2017 bpoirier@suse.com
- Refresh patch order in sorted section
- commit 45e9108
* Fri Dec 22 2017 msuchanek@suse.de
- ibmvnic: Include header descriptor support for ARP packets
  (bsc#1073912).
- ibmvnic: Increase maximum number of RX/TX queues (bsc#1073912).
- ibmvnic: Rename IBMVNIC_MAX_TX_QUEUES to IBMVNIC_MAX_QUEUES
  (bsc#1073912).
- commit e6d9f08
* Fri Dec 22 2017 msuchanek@suse.de
- Refresh sorted section.
- commit 08f400d
* Thu Dec 21 2017 mbenes@suse.cz
- Delete
  patches.suse/0002-module-move-add_taint_module-to-a-header-file.patch.
  kGraft-specific patch not needed with upstream livepatch. We have
  add_taint_module() call in kernel/module.c (upstream commit 2992ef29ae01
  ("livepatch/module: make TAINT_LIVEPATCH module-specific")).
- commit cfddc2c
* Thu Dec 21 2017 tbogendoerfer@suse.de
- bnxt_en: Uninitialized variable in bnxt_tc_parse_actions()
  (bsc#1050242 FATE#322914).
- bnxt_en: Add ETH_RESET_AP support (bsc#1050242 FATE#322914).
- commit a2af10c
* Thu Dec 21 2017 tbogendoerfer@suse.de
- drivers: net: bnxt: use setup_timer() helper (bsc#1050242
  FATE#322914).
- Refresh
  patches.drivers/bnxt_en-Reorganize-the-coalescing-parameters.patch.
- commit a924173
* Thu Dec 21 2017 tiwai@suse.de
- crypto: hmac - require that the underlying hash algorithm is
  unkeyed (CVE-2017-17806,bsc#1073874).
- commit ab2ecae
* Thu Dec 21 2017 tiwai@suse.de
- crypto: salsa20 - fix blkcipher_walk API usage
  (CVE-2017-17805,bsc#1073792).
- commit 81ba0ab
* Thu Dec 21 2017 tbogendoerfer@suse.de
- bnxt_en: Use NETIF_F_GRO_HW (bsc#1050242 FATE#322914).
- net: Disable GRO_HW when generic XDP is installed on a device
  (bsc#1050242 FATE#322914).
- net: Introduce NETIF_F_GRO_HW (bsc#1050242 FATE#322914).
- net: ethtool: add support for reset of AP inside NIC interface
  (bsc#1050242 FATE#322914).
- bnxt_en: Fix sources of spurious netpoll warnings (bsc#1050242
  FATE#322914).
- bnxt_en: fix dst/src fid for vxlan encap/decap actions
  (bsc#1050242 FATE#322914).
- bnxt_en: wildcard smac while creating tunnel decap filter
  (bsc#1050242 FATE#322914).
- bnxt_en: Fix an error handling path in
  'bnxt_get_module_eeprom()' (bsc#1050242 FATE#322914).
- bnxt_re: Make room for mapping beyond 32 entries (bsc#1050242
  FATE#322914).
- bnxt: fix bnxt_hwrm_fw_set_time for y2038 (bsc#1050242
  FATE#322914).
- bnxt_en: Fix IRQ coalescing regression (bsc#1050242
  FATE#322914).
- bnxt_en: fix typo in bnxt_set_coalesce (bsc#1050242
  FATE#322914).
- bnxt_en: Fix randconfig build errors (bsc#1050242 FATE#322914).
- bnxt_en: alloc tc_info{} struct only when tc flower is enabled
  (bsc#1050242 FATE#322914).
- bnxt_en: query cfa flow stats periodically to compute 'lastused'
  attribute (bsc#1050242 FATE#322914).
- bnxt_en: add hwrm FW cmds for cfa_encap_record and decap_filter
  (bsc#1050242 FATE#322914).
- bnxt_en: add support for Flower based vxlan encap/decap offload
  (bsc#1050242 FATE#322914).
- bnxt_en: Refactor and simplify coalescing code (bsc#1050242
  FATE#322914).
- bnxt_en: Reorganize the coalescing parameters (bsc#1050242
  FATE#322914).
- bnxt_en: Add ethtool reset method (bsc#1050242 FATE#322914).
- bnxt_en: Check maximum supported MTU from firmware (bsc#1050242
  FATE#322914).
- bnxt_en: Optimize .ndo_set_mac_address() for VFs (bsc#1050242
  FATE#322914).
- bnxt_en: Get firmware package version one time (bsc#1050242
  FATE#322914).
- bnxt_en: Check for zero length value in bnxt_get_nvram_item()
  (bsc#1050242 FATE#322914).
- bnxt_en: adding PCI ID for SMARTNIC VF support (bsc#1050242
  FATE#322914).
- bnxt_en: Add PCIe device ID for bcm58804 (bsc#1050242
  FATE#322914).
- bnxt_en: Update firmware interface to 1.8.3.1 (bsc#1050242
  FATE#322914).
- bnxt: Move generic devlink code to new file (bsc#1050242
  FATE#322914).
- bnxt_en: don't consider building bnxt_tc.o if option not enabled
  (bsc#1050242 FATE#322914).
- bnxt_en: Remove redundant unlikely() (bsc#1050242 FATE#322914).
- net: add new netdevice feature for offload of RX port for UDP
  tunnels (bsc#1056787).
- commit 8a8e435
* Thu Dec 21 2017 msuchanek@suse.de
- kernel-obs-build: use pae and lpae kernels where available
  (bsc#1073579).
- commit 1ac1946
* Thu Dec 21 2017 tiwai@suse.de
- Disable CONFIG_SPI_INTEL_SPI_PLATFORM for BIOS breakge on Lenovo laptops
  (bsc#1073836)
- commit 47130d8
* Wed Dec 20 2017 dbueso@suse.de
- epoll: remove ep_call_nested() from ep_eventpoll_poll()
  (bsc#1056427).
- epoll: avoid calling ep_call_nested() from ep_poll_safewake()
  (bsc#1056427).
- locking/qrwlock: Prevent slowpath writers getting held up by
  fastpath (bsc#1050549).
- locking/qrwlock: Use atomic_cond_read_acquire() when spinning
  in qrwlock (bsc#1050549).
- locking/qrwlock: Use 'struct qrwlock' instead of 'struct
  __qrwlock' (bsc#1050549).
- locking/atomic: Add atomic_cond_read_acquire() (bsc#1050549).
- commit f353922
* Wed Dec 20 2017 msuchanek@suse.de
- Refresh patches.arch/powerpc-64s-Implement-system-reset-idle-wakeup-reason.patch.
- commit 2e65242
* Wed Dec 20 2017 msuchanek@suse.de
- powerpc/64s: Fix Power9 DD2.1 logic in DT CPU features
  (bsc#1055121).
- powerpc/64s: Fix Power9 DD2.0 workarounds by adding DD2.1
  feature (bsc#1055121).
- powerpc/64s/idle: avoid POWER9 DD1 and DD2.0 PMU workaround
  on DD2.1 (bsc#1055121).
- powerpc/powernv: Save/Restore additional SPRs for stop4 cpuidle
  (bsc#1055121).
- powerpc/64s/idle: avoid POWER9 DD1 and DD2.0 ERAT workaround
  on DD2.1 (bsc#1055121).
- powerpc/64s: idle POWER9 can execute stop in virtual mode
  (bsc#1055121).
- powerpc/64s: Drop no longer used IDLE_STATE_ENTER_SEQ
  (bsc#1055121).
- powerpc/64s: POWER9 can execute stop without a sync sequence
  (bsc#1055121).
- powerpc/64s: Move IDLE_STATE_ENTER_SEQ[_NORET] into
  idle_book3s.S (bsc#1055121).
- powerpc/powernv/idle: Clear r12 on wakeup from stop lite
  (bsc#1055121).
- powerpc/64s/idle: Avoid SRR usage in idle sleep/wake paths
  (bsc#1055121).
- powerpc: add POWER9_DD20 feature (bsc#1055121).
- powerpc/64: Free up CPU_FTR_ICSWX (bsc#1055121).
- commit 9dfdd40
* Wed Dec 20 2017 tiwai@suse.de
- Update config files: Fix ppc64le vanilla config
- commit 410ed34
* Wed Dec 20 2017 msuchanek@suse.de
- powerpc: conditionally compile platform-specific serial drivers
  (bsc#1065729).
- tpm: ibmvtpm: simplify crq initialization and document crq
  format (bsc#1065729).
- commit d8d888e
* Wed Dec 20 2017 msuchanek@suse.de
- supported.conf: add missing modules.
  Changed:
  crypto/aes_generic -> crypto/aes_ti
  drivers/scsi/ibmvscsi/ibmvstgt -> drivers/scsi/ibmvscsi_tgt/ibmvscsis
  New modules:
  arch/powerpc/crypto/crc32c-vpmsum
  drivers/tty/serial/8250/8250_of
  - drivers/char/powernv-op-panel
  Add core/lib:
  drivers/char/tpm/tpm_tis_core
  drivers/pci/hotplug/pnv-php
  lib/parman
- commit d4b29da
* Wed Dec 20 2017 msuchanek@suse.de
- supported.conf: remove garbage.
- commit 1ce25e4
* Wed Dec 20 2017 sparschauer@suse.de
- scsi_scan: Exit loop if TUR to LUN0 fails with 0x05/0x25 (bsc#1063043).
  This is specific to FUJITSU ETERNUS_DX* targets. They can return
  "Illegal Request - Logical unit not supported" and processing should
  leave the timeout loop in this case.
- commit c16da9f
* Wed Dec 20 2017 jkosina@suse.cz
- README.BRANCH: Add Takashi as a temporary co-maintainer. Thanks Takashi!
- commit 076bb17
* Wed Dec 20 2017 neilb@suse.com
- NFS: Fix uninitialized rpc_wait_queue (git-fixes).
- xprtrdma: Throw away reply when version is unrecognized
  (git-fixes).
- svcrdma: Preserve CB send buffer across retransmits (git-fixes).
- commit 3eac6c0
* Tue Dec 19 2017 neilb@suse.com
- blacklist.conf: mark 11e3e8d6d927 not-applicable
- commit 250f889
* Tue Dec 19 2017 neilb@suse.com
- autofs: fix careless error in recent commit (bnc#1012382
  bsc#1065180).
- NFS: revalidate "." etc correctly on "open" (git-fixes).
- commit 4c82a6d
* Tue Dec 19 2017 msuchanek@suse.de
- powerpc/64s: Fix hypercall entry clobbering r12 input
  (bsc#1055117).
- powerpc/64s: Optimize hypercall/syscall entry (bsc#1055117).
- commit 0ca40fc
* Tue Dec 19 2017 jkosina@suse.cz
- README.BRANCH: add Takashi as comaintainer
- commit d7552c3
* Tue Dec 19 2017 msuchanek@suse.de
- KVM: PPC: Book3S HV: Fix migration and HPT resizing of HPT
  guests on radix hosts (bsc#1061840).
- KVM: PPC: Book3S HV: Add infrastructure for running HPT guests
  on radix host (bsc#1061840).
- KVM: PPC: Book3S HV: Unify dirty page map between HPT and radix
  (bsc#1061840).
- commit 51c7c60
* Tue Dec 19 2017 msuchanek@suse.de
- KVM: PPC: Book3S HV: Rename hpte_setup_done to mmu_ready (bsc#1061840).
- Refresh patches.arch/KVM-PPC-Book3S-HV-Fix-exclusion-between-HPT-resizing.patch.
- commit 052b912
* Tue Dec 19 2017 msuchanek@suse.de
- KVM: PPC: Tie KVM_CAP_PPC_HTM to the user-visible TM feature (bsc#1061840).
- Refresh patches.arch/KVM-PPC-Fix-oops-when-checking-KVM_CAP_PPC_HTM.patch.
- commit 9c0b1aa
* Tue Dec 19 2017 msuchanek@suse.de
- KVM: PPC: Book3S HV: Don't rely on host's page size information
  (bsc#1061840).
- KVM: PPC: Book3S HV: Explicitly disable HPT operations on
  radix guests (bsc#1061840).
- KVM: PPC: Book3S HV: Fix memory leak in kvm_vm_ioctl_get_htab_fd
  (bsc#1061840).
- KVM: PPC: Book3S HV: Report storage key support to userspace
  (bsc#1061840).
- commit 1a88a98
* Tue Dec 19 2017 bp@suse.de
- x86/ACPI/cstate: Allow ACPI C1 FFH MWAIT use on AMD systems
  (bsc#1069881).
- commit 8e6ab6a
* Tue Dec 19 2017 lhenriques@suse.com
- ceph: drop negative child dentries before try pruning inode's
  alias (bsc#1073525).
- commit aeb9e15
* Mon Dec 18 2017 jlee@suse.com
- Update config files.
  Enabling hibernation verification.
- commit 490e23f
* Mon Dec 18 2017 jack@suse.cz
- fanotify: fix fsnotify_prepare_user_wait() failure
  (bsc#1052766).
- commit 080b493
* Mon Dec 18 2017 jack@suse.cz
- mm/frame_vector.c: release a semaphore in 'get_vaddr_frames()'
  (bsc#1052766).
- commit e8d4b10
* Mon Dec 18 2017 jlee@suse.com
- PM / hibernate: require hibernate snapshot image to be validly
  signed when kernel is locked down (fate#316350).
- PM / hibernate: a option to request that snapshot image must
  be validly signed (fate#316350).
- PM / hibernate: prevent EFI secret key to be regenerated
  (fate#316350).
- PM / hibernate: Generate and verify signature for snapshot image
  (fate#316350).
- PM / hibernate: encrypt hidden area (fate#316350).
- efi: allow user to regenerate secret key (fate#316350).
- efi: generate secret key in EFI boot environment (fate#316350).
- x86/KASLR: public the function for getting random long number
  (fate#316350).
- hibernate: avoid the data in hidden area to be snapshotted
  (fate#316350).
- security: create hidden area to keep sensitive data
  (fate#316350).
- commit 8c35bf3
* Mon Dec 18 2017 mhocko@suse.com
- userfaultfd: hugetlbfs: remove superfluous page unlock in
  VM_SHARED case (bnc#1073113, CVE-2017-15127).
- commit 0332d2e
* Mon Dec 18 2017 mhocko@suse.com
- userfaultfd: hugetlbfs: prevent UFFDIO_COPY to fill beyond
  the end of i_size (bnc#1073112, CVE-2017-15128).
- commit 31f7526
* Mon Dec 18 2017 mhocko@suse.com
- mm, oom_reaper: gather each vma to prevent leaking TLB entry
  (bnc#1073258).
- commit b55bb20
* Mon Dec 18 2017 tbogendoerfer@suse.de
- IB/ipoib: Restore MM behavior in case of tx_ring allocation
  failure (bsc#1046307 FATE#322941).
- iw_cxgb4: only insert drain cqes if wq is flushed (bsc#1046543
  FATE#32292).
- RDMA/netlink: Fix general protection fault (bsc#1046306
  FATE#322942).
- IB/mlx4: Fix RSS hash fields restrictions (bsc#1046302
  FATE#322945).
- IB/core: Don't enforce PKey security on SMI MADs (bsc#1046306
  FATE#322942).
- IB/core: Bound check alternate path port number (bsc#1046306
  FATE#322942).
- sfc: pass valid pointers from efx_enqueue_unwind (bsc#1058169
  FATE#322922).
- commit 6688227
* Mon Dec 18 2017 tbogendoerfer@suse.de
- Re-sorted sorted section
- commit 108f419
* Mon Dec 18 2017 jlee@suse.com
- Delete
  patches.suse/0001-PM-hibernate-Fix-2G-size-issue-of-snapshot-image-ver.patch.
- Delete
  patches.suse/0001-PM-hibernate-Fix-warning-about-non-void-function-not.patch.
- Delete
  patches.suse/0001-PM-hibernate-Force-verify-hibernation-signature-in-s.patch.
- Delete
  patches.suse/0001-PM-hibernate-define-HMAC-algorithm-and-digest-size-o.patch.
- Delete
  patches.suse/0001-x86-Removed-the-free-memblock-of-hibernat-keys-to-av.patch.
- Delete
  patches.suse/0001-x86-efi-Fix-invalid-parameter-error-when-getting-hib.patch.
- Delete
  patches.suse/0002-x86-efi-Add-get-and-set-variable-to-EFI-services-poi.patch.
- Delete
  patches.suse/0003-x86-boot-Public-getting-random-boot-function.patch.
- Delete
  patches.suse/0004-x86-efi-Generating-random-number-in-EFI-stub.patch.
- Delete
  patches.suse/0005-x86-efi-Get-entropy-through-EFI-random-number-genera.patch.
- Delete
  patches.suse/0006-x86-efi-Generating-random-HMAC-key-for-siging-hibern.patch.
- Delete
  patches.suse/0007-efi-Make-efi_status_to_err-public.patch.
- Delete
  patches.suse/0008-x86-efi-Carrying-hibernation-key-by-setup-data.patch.
- Delete
  patches.suse/0009-PM-hibernate-Reserve-hibernation-key-and-erase-footp.patch.
- Delete
  patches.suse/0010-PM-hibernate-Generate-and-verify-signature-of-hibern.patch.
- Delete
  patches.suse/0011-PM-hibernate-Avoid-including-hibernation-key-to-hibe.patch.
- Delete
  patches.suse/0012-PM-hibernate-Forward-signature-verifying-result-and-.patch.
- Delete
  patches.suse/0013-PM-hibernate-Add-configuration-to-enforce-signature-.patch.
- Delete
  patches.suse/0014-PM-hibernate-Allow-user-trigger-hibernation-key-re-g.patch.
- Delete
  patches.suse/0015-PM-hibernate-Bypass-verification-logic-on-legacy-BIO.patch.
- Delete
  patches.suse/0016-PM-hibernate-Document-signature-verification-of-hibe.patch.
  The hibernation verification will be refactored against v4.12.
  Removed old version.
- commit 80cd2cb
* Mon Dec 18 2017 jlee@suse.com
- Delete
  patches.suse/0049-uswsusp-Disable-when-the-kernel-is-locked-down.patch.
  Because the code is duplicate with
  0048-hibernate-Disable-when-the-kernel-is-locked-down.patch
- commit 713a68b
* Fri Dec 15 2017 msuchanek@suse.de
- Refresh patches.drivers/nvme-fc-remove-double-put-reference-if-admin-connect.patch.
  Fix commit hash.
- commit 61669a7
* Fri Dec 15 2017 msuchanek@suse.de
- Refresh sorted section.
- commit 8c10740
* Fri Dec 15 2017 msuchanek@suse.de
- git_sort.py: add rdma/rdma remote.
- commit ec2ea23
* Fri Dec 15 2017 mgorman@suse.de
- sched: Only immediately migrate tasks due to interrupts if prev
  and target CPUs share cache (bnc#1066110 Scheduler utilisation
  tracking).
- commit 8747826
* Fri Dec 15 2017 mgorman@suse.de
- mm/page_alloc.c: avoid excessive IRQ disabled times in
  free_unref_page_list() (bnc#971975 VM -- git fixes).
- commit e2361a2
* Fri Dec 15 2017 msuchanek@suse.de
- genwqe: Take R/W permissions into account when dealing with
  memory pages (bsc#1073090).
- commit 0f3a06a
* Fri Dec 15 2017 mhocko@suse.com
- mm, oom_reaper: fix memory corruption (bnc#1073039).
- commit c664e6e
* Fri Dec 15 2017 jslaby@suse.cz
- x86/stacktrace: make clear the success paths (bnc#1058115).
- Refresh
  patches.suse/0003-x86-stacktrace-remove-STACKTRACE_DUMP_ONCE-from-__sa.patch.
- Refresh
  patches.suse/0004-x86-stacktrace-do-not-fail-for-ORC-with-regs-on-stac.patch.
- Delete
  patches.suse/0002-x86-stacktrace-remove-unwind_state-error.patch.
  Fix livepatch to succeed also for kthreads and idle tasks.
- commit 228dd50
* Fri Dec 15 2017 tiwai@suse.de
- APEI / ERST: Fix missing error handling in erst_reader()
  (bsc#1072556).
- commit 1d69ef4
* Fri Dec 15 2017 tonyj@suse.de
- perf/x86/intel/uncore: Fix memory leaks on allocation failures
  (git-fixes).
- blacklist.conf:  Update perf git-fixes
- commit 25d3ce5
* Thu Dec 14 2017 oneukum@suse.com
- media: dvb-usb-v2: lmedm04: Improve logic checking of warm start
  (bsc#1066569 CVE-2017-16538).
- commit 4f7cbf8
* Thu Dec 14 2017 tiwai@suse.de
- Enable build of CX2072X codec for Intel Atom SST (bsc#1068546)
- commit dde0783
* Thu Dec 14 2017 tiwai@suse.de
- Enable Intel CHTDC-TI powerbutton driver (bsc#1068546)
- commit 5a6685e
* Thu Dec 14 2017 tiwai@suse.de
- platform/x86: Add support for Dollar Cove TI power button
  (bsc#1068546).
- commit e0bff99
* Thu Dec 14 2017 jthumshirn@suse.de
- nvmet-fc: cleanup nvmet add_port/remove_port (bsc#1072553).
- nvme-fc: remove double put reference if admin connect fails
  (bsc#1072553).
- nvme-fc: don't use bit masks for set/test_bit() numbers
  (bsc#1072553).
- nvmet-fc: correct ref counting error when deferred rcv used
  (bsc#1072553).
- nvme-loop: check if queue is ready in queue_rq (bsc#1072553).
- nvme-fc: check if queue is ready in queue_rq (bsc#1072553).
- nvme-fabrics: introduce init command check for a queue that
  is not alive (bsc#1072553).
- commit c9fa2b2
* Thu Dec 14 2017 tbogendoerfer@suse.de
- IB/hfi1: Use 4096 for default active MTU in query_qp
  (bsc#1070622).
- IB/CM: Change sgid to IB GID when handling CM request
  (bsc#1070622).
- IB/hfi1: Mask the path bits with the LMC for 16B RC Acks
  (bsc#1070622).
- bnxt_en: Don't print "Link speed -1 no longer supported"
  messages (bsc#1070116).
- commit 48fe400
* Thu Dec 14 2017 jthumshirn@suse.de
- lpfc: remove use of FC-specific error codes (bsc#1072553).
- nvme-fc: remove use of FC-specific error codes (bsc#1072553).
- nvme.h: remove FC transport-specific error values (bsc#1072553).
- nvmet-fc: remove use of FC-specific error codes (bsc#1072553).
- qla2xxx: remove use of FC-specific error codes (bsc#1072553).
- Refresh
  patches.drivers/nvme-fc-correct-io-termination-handling.patch.
- commit c63aa5a
* Thu Dec 14 2017 jthumshirn@suse.de
- scripts/git_sort/git_sort.py: Add nvme-4.16 to indexed heads
- commit f08f096
* Thu Dec 14 2017 fdmanana@suse.com
- Btrfs: fix reported number of inode blocks after buffered
  append writes (bsc#1061589).
- Btrfs: move definition of the function
  btrfs_find_new_delalloc_bytes (bsc#1061589).
- commit 3954048
* Thu Dec 14 2017 oneukum@suse.com
- USB: core: prevent malicious bNumInterfaces overflow
  (bsc#1072561 CVE-2017-17558).
- commit cdc5902
* Thu Dec 14 2017 jthumshirn@suse.de
- block: fix a crash caused by wrong API (bsc#1072355).
- commit 6bffd0a
* Thu Dec 14 2017 yousaf.kaukab@suse.com
- config: arm64: enable rk3399 missing drivers
- commit 611930b
* Thu Dec 14 2017 tiwai@suse.de
- qxl: alloc & use shadow for dumb buffers (bsc#1072190).
- drm/qxl: replace QXL_INFO with DRM_DEBUG_DRIVER (bsc#1072190).
- commit 6fed647
* Wed Dec 13 2017 jeffm@suse.com
- Btrfs: change how we iterate bios in endio (bsc#1071219).
- commit 248d2a7
* Wed Dec 13 2017 jeffm@suse.com
- housekeeping: update btrfs patch tags
- commit 5824e3f
* Wed Dec 13 2017 fdmanana@suse.com
- Refresh
  patches.suse/btrfs-add-support-for-fallocate-s-zero-range-operati.patch.
- commit c5e275b
* Wed Dec 13 2017 msuchanek@suse.de
- powerpc/powernv/npu: Move tlb flush before launching ATSD
  (bsc#1055120).
- commit 2674fa8
* Wed Dec 13 2017 mgorman@suse.de
- sched/fair: Update and fix the runnable propagation rule
  (bnc#1066110 Scheduler utilisation tracking).
- commit 426857f
* Wed Dec 13 2017 neilb@suse.com
- NFSv4: always set NFS_LOCK_LOST when a lock is lost
  (bsc#1068951).
- commit 8816f29
* Tue Dec 12 2017 bp@suse.de
- x86/microcode/AMD: Add support for fam17h microcode loading
  (bsc#1068032).
- commit 13cc8c9
* Tue Dec 12 2017 jthumshirn@suse.de
- acpi, nfit: validate commands against the device type
  (FATE#324505).
- commit 606c2ff
* Tue Dec 12 2017 jthumshirn@suse.de
- acpi: always include uuid.h (FATE#324505).
- commit 6bbdd80
* Tue Dec 12 2017 mkubecek@suse.cz
- netfilter: xt_osf: Add missing permission checks (CVE-2017-17450
  bsc#1071695).
- commit 3196363
* Tue Dec 12 2017 mkubecek@suse.cz
- netlink: Add netns check on taps (CVE-2017-17449 bsc#1071694).
- commit e92da0c
* Tue Dec 12 2017 mkubecek@suse.cz
- netfilter: nfnetlink_cthelper: Add missing permission checks
  (CVE-2017-17448 bsc#1071693).
- commit b16758e
* Tue Dec 12 2017 jthumshirn@suse.de
- scsi: bfa: fix type conversion warning (bsc#1065101).
- scsi: bfa: fix access to bfad_im_port_s (bsc#1065101).
- commit f3a3c83
* Tue Dec 12 2017 jthumshirn@suse.de
- git_sort.py: Add Martin Petersen's 4.15/scsi-fixes branch
- commit 20244cd
* Tue Dec 12 2017 jthumshirn@suse.de
- acpi, nfit: add 'Enable Latch System Shutdown Status' command
  support (FATE#324505).
- acpi, nfit: add support for NVDIMM_FAMILY_INTEL v1.6 DSMs
  (FATE#324505).
- commit 00a6cf4
* Tue Dec 12 2017 jthumshirn@suse.de
- acpi, nfit: add support for the _LSI, _LSR, and _LSW label
  methods (FATE#324505).
- Refresh
  patches.drivers/acpi-nfit-hide-unknown-commands-from-nmemX-commands.patch.
- commit 33bc52f
* Tue Dec 12 2017 mkubecek@suse.cz
- sctp: do not peel off an assoc from one netns to another one
  (CVE-2017-15115 bsc#1068671).
- commit 500f976
* Tue Dec 12 2017 tbogendoerfer@suse.de
- net_sched: red: Avoid devision by zero (bsc#1056787).
- i40iw: Notify user of established connection after QP in RTS
  (bsc#1058659 FATE#322535).
- i40iw: Move MPA request event for loopback after connect
  (bsc#1058659 FATE#322535).
- i40iw: Correct ARP index mask (bsc#1058659 FATE#322535).
- i40iw: Do not free sqbuf when event is I40IW_TIMER_TYPE_CLOSE
  (bsc#1058659 FATE#322535).
- i40iw: Allocate a sdbuf per CQP WQE (bsc#1058659 FATE#322535).
- s390/qeth: build max size GSO skbs on L2 devices (bsc#1061024
  FATE#323301).
- s390/qeth: fix GSO throughput regression (bsc#1061024
  FATE#323301).
- s390/qeth: fix thinko in IPv4 multicast address tracking
  (bsc#1061024 FATE#323301).
- IB/mlx5: Fix RoCE Address Path fields (bsc#1046305 FATE#322943).
- IB/srpt: Do not accept invalid initiator port names (bsc#1046306
  FATE#322942).
- commit 647cda2
* Tue Dec 12 2017 jthumshirn@suse.de
- acpi, nfit: hide unknown commands from nmemX/commands
  (FATE#324505).
- commit 26aa55c
* Tue Dec 12 2017 jthumshirn@suse.de
- acpi nfit: nfit_test supports translate SPA (FATE#324505).
- acpi nfit: Enable to show what feature is supported via
  ND_CMD_CALL for nfit_test (FATE#324505).
- acpi, nfit: Show bus_dsm_mask in sysfs (FATE#324505).
- libnvdimm, acpi, nfit: Add bus level dsm mask for pass thru
  (FATE#324505).
- acpi, nfit: Enable DSM pass thru for root functions
  (FATE#324505).
- commit 09b07e6
* Tue Dec 12 2017 mkubecek@suse.cz
- dccp: CVE-2017-8824: use-after-free in DCCP code (CVE-2017-8824
  bsc#1070771).
- commit ed1dc5d
* Tue Dec 12 2017 jthumshirn@suse.de
- thermal: int340x_thermal: fix compile after the UUID API switch
  (FATE#324505).
- thermal: int340x_thermal: Switch to use new generic UUID API
  (FATE#324505).
- commit 0f58456
* Tue Dec 12 2017 mkubecek@suse.cz
- Update
  patches.kernel.org/4.12.11-023-xfrm-policy-check-policy-direction-value.patch
  references (add CVE-2017-11600 bsc#1050231).
- commit c24a6f8
* Tue Dec 12 2017 jthumshirn@suse.de
- ACPI: Switch to use generic guid_t in acpi_evaluate_dsm()
  (FATE#324505).
- Refresh
  patches.drivers/0017-usb-typec-ucsi-Add-ACPI-driver.patch.
- Refresh
  patches.drivers/net-hns-add-acpi-function-of-xge-led-control.patch
- commit b154a19
* Mon Dec 11 2017 mbrugger@suse.com
- drm: hibmc: Initialize the hibmc_bo_driver.io_mem_pfn
  (bnc#1067977).
- drm: hibmc: Use set_busid function from drm core (bsc#1067977).
- vgaarb: Factor out EFI and fallback default device selection
  (bsc#1067977).
- vgaarb: Select a default VGA device even if there's no legacy
  VGA (bsc#1067977).
- commit 56166ea
* Mon Dec 11 2017 jthumshirn@suse.de
- ACPI / bus: Switch to use new generic UUID API (FATE#324505).
- commit eeb5838
* Mon Dec 11 2017 tiwai@suse.de
- blacklist.conf: Add drm inapplicable commits (bsc#1051510)
- commit ba5ee60
* Mon Dec 11 2017 tiwai@suse.de
- drm/i915/cnl: Mask previous DDI - PLL mapping (bsc#1051510).
- commit e06d654
* Mon Dec 11 2017 jthumshirn@suse.de
- ACPI / extlog: Switch to use new generic UUID API (FATE#324505).
- commit 9e27ec4
* Mon Dec 11 2017 msuchanek@suse.de
- powerpc: Force reload for recheckpoint during tm {fp, vec,
  vsx} unavailable exception (bsc#1065729).
- powerpc: Don't enable FP/Altivec if not checkpointed
  (bsc#1065729).
- powerpc: Fix missing newline before { (bsc#1065729).
- cxl: Rename register PSL9_FIR2 to PSL9_FIR_MASK (bsc#1055014).
- cxl: Enable global TLBIs for cxl contexts (bsc#1055014).
- powerpc/mm: Export flush_all_mm() (bsc#1055014).
- powerpc/mm: Make switch_mm_irqs_off() out of line (bsc#1055014).
- powerpc: Remove old unused icswx based coprocessor support
  (bsc#1055014).
- powerpc/mm: Optimize detection of thread local mm's
  (bsc#1055014).
- powerpc/mm: Move pgdir setting into a helper (bsc#1055014).
- commit 5bc2261
* Mon Dec 11 2017 msuchanek@suse.de
- Reorder powerpc patches.
- commit ddca890
* Mon Dec 11 2017 tbogendoerfer@suse.de
- Refresh
  patches.drivers/cxgb4-add-tc-flower-support-for-ETH-DMAC-rewrite.patch.
- commit 449190e
* Mon Dec 11 2017 mgorman@suse.de
- locking/x86: Use LOCK ADD for smp_mb() instead of MFENCE
  (bnc#1072172 x86 performance -- barriers).
- commit a4b5e51
* Mon Dec 11 2017 tiwai@suse.de
- supported.conf: Add missing supported modules (bsc#1072163)
- commit fb1f805
* Mon Dec 11 2017 jthumshirn@suse.de
- acpi, nfit: Switch to use new generic UUID API (FATE#324505).
- commit a3ed858
* Mon Dec 11 2017 tbogendoerfer@suse.de
- net: thunderx: Fix TCP/UDP checksum offload for IPv4 pkts
  (bsc#1069583).
- nfp: fix port stats for mac representors (bsc#1055968).
- IB/core: Only enforce security for InfiniBand (bsc#1070482).
- IB: INFINIBAND should depend on HAS_DMA (bsc#1046306
  FATE#322942).
- IB/hfi1: Initialize bth1 in 16B rc ack builder (bsc#1060463
  FATE#323043).
- bnxt_en: Fix a variable scoping in bnxt_hwrm_do_send_msg()
  (bsc#1050242 FATE#322914).
- bnxt_en: Need to unconditionally shut down RoCE in bnxt_shutdown
  (bsc#1050242 FATE#322914).
- IB/core: Avoid unnecessary return value check (bsc#1070482).
- commit 232528a
* Mon Dec 11 2017 jthumshirn@suse.de
- scsi: lpfc: Fix a precedence bug in lpfc_nvme_io_cmd_wqe_cmpl()
  (bsc#1050239,FATE#322918).
- commit 2fe735c
* Mon Dec 11 2017 jthumshirn@suse.de
- scsi: qla2xxx: Suppress a kernel complaint in
  qla_init_base_qpair() (FATE#322910).
- commit 9d4fd8e
* Mon Dec 11 2017 jgross@suse.com
- xen: fix hvm guest with kaslr enabled (bnc#1071891).
- xen: split up xen_hvm_init_shared_info() (bnc#1071891).
- x86: provide an init_mem_mapping hypervisor hook (bnc#1071891).
- commit 2820573
* Mon Dec 11 2017 mbenes@suse.cz
- livepatch: __klp_disable_patch() should never be called for
  disabled patches (bsc#1071995 fate#323487).
  Callbacks support. Coming from upstream klp tree, branch
  for-4.15/callbacks.
- livepatch: Correctly call klp_post_unpatch_callback() in error
  paths (bsc#1071995 fate#323487).
  Callbacks support. Coming from upstream klp tree, branch
  for-4.15/callbacks.
- livepatch: add transition notices (bsc#1071995 fate#323487).
  Callbacks support. Coming from upstream klp tree, branch
  for-4.15/callbacks.
- livepatch: move transition "complete" notice into
  klp_complete_transition() (bsc#1071995 fate#323487).
  Callbacks support. Coming from upstream klp tree, branch
  for-4.15/callbacks.
- livepatch: add (un)patch callbacks (bsc#1071995 fate#323487).
  Callbacks support. Coming from upstream klp tree, branch
  for-4.15/callbacks.
- commit bfcc8d1
* Mon Dec 11 2017 tiwai@suse.de
- Remove buggy IPMI patch (bsc#1071877)
  The broken fix was identified and removed/blacklisted now.
  Also re-enable the rest IPMI fixes that have been disabled.
- commit 0128c61
* Mon Dec 11 2017 mgorman@suse.de
- Update patches.suse/cpufreq-intel_pstate-use-setpoint-of-10-on-servers.patch
  (bnc#945201,bnc#1064414).
- commit f696fcb
* Mon Dec 11 2017 mbenes@suse.cz
- livepatch: Small shadow variable documentation fixes
  (bsc#1071995 fate#323487).
  Shadow variables support. Coming from upstream klp tree, branch
  for-4.15/shadow-variables.
- livepatch: __klp_shadow_get_or_alloc() is local to shadow.c
  (bsc#1071995 fate#323487).
  Shadow variables support. Coming from upstream klp tree, branch
  for-4.15/shadow-variables.
- livepatch: introduce shadow variable API (bsc#1071995
  fate#323487).
  Shadow variables support. Coming from upstream klp tree, branch
  for-4.15/shadow-variables.
- commit 576f832
* Mon Dec 11 2017 mbenes@suse.cz
- livepatch: unpatch all klp_objects if klp_module_coming fails
  (bsc#1071995 fate#323487).
  Fix coming from upstream klp tree, branch for-4.14/upstream-fixes
- commit 198dbfe
* Sat Dec  9 2017 tiwai@suse.de
- Disable IPMI fix patches due to regression (bsc#1071877)
- commit 8d8a8ff
* Fri Dec  8 2017 mkubecek@suse.cz
- net: openvswitch: datapath: fix data type in queue_gso_packets
  (bsc#1066757).
- net: accept UFO datagrams from tuntap and packet (bsc#1066757).
- net: Remove unused skb_shared_info member (bsc#1066757).
- commit 6e1c320
* Fri Dec  8 2017 mkubecek@suse.cz
- netfilter: ebtables: fix race condition in
  frame_filter_net_init() (bsc#1071929).
- commit 615d8a0
* Fri Dec  8 2017 mkubecek@suse.cz
- series.conf: refresh
  (just ran series_sort.py)
- commit 50b424d
* Fri Dec  8 2017 msuchanek@suse.de
- supported.conf add crypto_simd (bsc#1071991).
- commit 94d5bb1
* Fri Dec  8 2017 mcgrof@suse.com
- xfs: extend unsupported annotations: reflink or reverse mapping btree (FATE#324503).
- commit 53eb059
* Fri Dec  8 2017 vbabka@suse.cz
- hmm: heterogeneous memory management documentation (VM
  Functionality, FATE#323338, bsc#1047814).
- mm/device-public-memory: device memory cache coherent with CPU
  (VM Functionality, FATE#323338, bsc#1047814).
- mm/device-public-memory: fix edge case in _vm_normal_page()
  (VM Functionality, FATE#323338, bsc#1047814).
- mm/hmm: add new helper to hotplug CDM memory region (VM
  Functionality, FATE#323338, bsc#1047814).
- mm/hmm: avoid bloating arch that do not make use of HMM (VM
  Functionality, FATE#323338, bsc#1047814).
- mm/hmm/devmem: device memory hotplug using ZONE_DEVICE (VM
  Functionality, FATE#323338, bsc#1047814).
- mm/hmm/devmem: dummy HMM device for ZONE_DEVICE memory (VM
  Functionality, FATE#323338, bsc#1047814).
- mm/hmm: fix build when HMM is disabled (VM Functionality,
  FATE#323338, bsc#1047814).
- mm/hmm: heterogeneous memory management (HMM for short)
  (VM Functionality, FATE#323338, bsc#1047814).
- mm/hmm/mirror: device page fault handler (VM Functionality,
  FATE#323338, bsc#1047814).
- mm/hmm/mirror: helper to snapshot CPU page table (VM
  Functionality, FATE#323338, bsc#1047814).
- mm/hmm/mirror: mirror process address space on device with
  HMM helpers (VM Functionality, FATE#323338, bsc#1047814).
- mm/memcontrol: allow to uncharge page without using page->lru
  field (VM Functionality, FATE#323338, bsc#1047814).
- mm/memcontrol: support MEMORY_DEVICE_PRIVATE (VM Functionality,
  FATE#323338, bsc#1047814).
- mm/memory_hotplug: introduce add_pages (VM Functionality,
  FATE#323338, bsc#1047814).
- mm/migrate: allow migrate_vma() to alloc new page on empty entry
  (VM Functionality, FATE#323338, bsc#1047814).
- mm/migrate: fix indexing bug (off by one) and avoid out of
  bound access (VM Functionality, FATE#323338, bsc#1047814).
- mm/migrate: migrate_vma() unmap page from vma while collecting
  pages (VM Functionality, FATE#323338, bsc#1047814).
- mm/migrate: new memory migration helper for use with device
  memory (VM Functionality, FATE#323338, bsc#1047814).
- mm/migrate: new migrate mode MIGRATE_SYNC_NO_COPY (VM
  Functionality, FATE#323338, bsc#1047814).
- mm/migrate: support un-addressable ZONE_DEVICE page in migration
  (VM Functionality, FATE#323338, bsc#1047814).
- mm/ZONE_DEVICE: new type of ZONE_DEVICE for unaddressable memory
  (VM Functionality, FATE#323338, bsc#1047814).
- mm/ZONE_DEVICE: special case put_page() for device private pages
  (VM Functionality, FATE#323338, bsc#1047814).
- Update config files.
- commit 5579b56
* Fri Dec  8 2017 mwilck@suse.com
- Fix git-repo: header in scsi_devinfo patches
- Refresh
  patches.fixes/scsi-scsi_devinfo-cleanly-zero-pad-devinfo-strings.patch.
- Refresh
  patches.fixes/scsi-scsi_devinfo-handle-non-terminated-strings.patch.
- commit 53814b0
* Fri Dec  8 2017 tiwai@suse.de
- iwlwifi: mvm: mark MIC stripped MPDUs (bsc#1071648).
- iwlwifi: mvm: enable RX offloading with TKIP and WEP
  (bsc#1071648).
- iwlwifi: mvm: flush queue before deleting ROC (bsc#1071648).
- iwlwifi: add new cards for 9260 and 22000 series (bsc#1071648).
- iwlwifi: mvm: fix packet injection (bsc#1071648).
- iwlwifi: mvm: don't use transmit queue hang detection when it
  is not possible (bsc#1071648).
- iwlwifi: fix firmware names for 9000 and A000 series hw
  (bsc#1071648).
- iwlwifi: mvm: use IWL_HCMD_NOCOPY for MCAST_FILTER_CMD
  (bsc#1071648).
- iwlwifi: fix PCI IDs and configuration mapping for 9000 series
  (bsc#1071648).
- iwlwifi: add new cards for a000 series (bsc#1071648).
- iwlwifi: add new cards for 8265 series (bsc#1071648).
- iwlwifi: add new cards for 8260 series (bsc#1071648).
- iwlwifi: pcie: sort IDs for the 9000 series for easier
  comparisons (bsc#1071648).
- commit d40b4c9
* Fri Dec  8 2017 msuchanek@suse.de
- Add undefine _unique_build_ids (bsc#964063)
- commit 47e91a1
* Fri Dec  8 2017 yousaf.kaukab@suse.com
- scsi: libsas: align sata_device's rps_resp on a cacheline
  (bsc#1071401).
- scsi: hisi_sas: add v3 hw port AXI error handling (bsc#1071401).
- scsi: hisi_sas: add v3 hw support for AXI fatal error
  (bsc#1071401).
- scsi: hisi_sas: complete all tasklets prior to host reset
  (bsc#1071401).
- scsi: hisi_sas: fix a bug when free device for v3 hw
  (bsc#1071401).
- scsi: hisi_sas: add hisi_hba.rst_work init for v3 hw
  (bsc#1071401).
- scsi: hisi_sas: add v3 hw DFX feature (bsc#1071401).
- scsi: hisi_sas: init connect cfg register for v3 hw
  (bsc#1071401).
- scsi: hisi_sas: check PHY state in get_wideport_bitmap_v3_hw()
  (bsc#1071401).
- scsi: hisi_sas: use array for v2 hw AXI errors (bsc#1071401).
- scsi: hisi_sas: fix the risk of freeing slot twice
  (bsc#1071401).
- scsi: hisi_sas: fix NULL check in SMP abort task path
  (bsc#1071401).
- scsi: hisi_sas: us start_phy in PHY_FUNC_LINK_RESET
  (bsc#1071401).
- scsi: hisi_sas: fix SATA breakpoint memory size (bsc#1071401).
- scsi: hisi_sas: grab hisi_hba.lock when processing slots
  (bsc#1071401).
- scsi: hisi_sas: use spin_lock_irqsave() for hisi_hba.lock
  (bsc#1071401).
- scsi: hisi_sas: delete get_ncq_tag_v3_hw() (bsc#1071401).
- scsi: libsas: remove unused variable sas_ha (bsc#1071401).
- scsi: libsas: add event to defer list tail instead of head
  when draining (bsc#1071401).
- scsi: libsas: rename notify_port_event() for consistency
  (bsc#1071401).
- scsi: libsas: remove unused port_gone_completion and
  DISCE_PORT_GONE (bsc#1071401).
- scsi: libsas: remove the numbering for each event enum
  (bsc#1071401).
- scsi: libsas: kill useless ha_event and do some cleanup
  (bsc#1071401).
- scsi: libsas: Annotate fall-through in a switch statement
  (bsc#1071401).
- scsi: libsas: Remove a set-but-not-used variable (bsc#1071401).
- scsi: hisi_sas: replace kfree with scsi_host_put (bsc#1071401).
- scsi: hisi_sas: remove phy_down_v3_hw() res variable
  (bsc#1071401).
- scsi: hisi_sas: add phy_set_linkrate_v3_hw() (bsc#1071401).
- scsi: hisi_sas: update some v3 register init settings
  (bsc#1071401).
- scsi: hisi_sas: add reset handler for v3 hw (bsc#1071401).
- scsi: hisi_sas: kill tasklet when destroying irq in v3 hw
  (bsc#1071401).
- scsi: hisi_sas: fix v3 hw channel interrupt processing
  (bsc#1071401).
- scsi: hisi_sas: Modify v3 hw STP_LINK_TIMER setting
  (bsc#1071401).
- commit 9c6ddbc
* Fri Dec  8 2017 mgorman@suse.de
- cpufreq, intel_pstate: Ramp up frequency faster when utilisation
  reaches setpoint (bnc#1068680 Update schedutil and intel_pstate
  to default to load-based policy).
- cpufreq: intel_pstate: Improve IO performance with per-core
  P-states (bnc#1068680 Update schedutil and intel_pstate to
  default to load-based policy).
- cpufreq: intel_pstate: Use load-based policy by default
  but allow PID to be used (bnc#1068680 Update schedutil and
  intel_pstate to default to load-based policy).
- sched/fair: Update calc_group_*() comments (bnc#1066110
  Scheduler utilisation tracking).
- sched/fair: Calculate runnable_weight slightly differently
  (bnc#1066110 Scheduler utilisation tracking).
- sched/fair: Implement more accurate async detach (bnc#1066110
  Scheduler utilisation tracking).
- sched/fair: Align PELT windows between cfs_rq and its se
  (bnc#1066110 Scheduler utilisation tracking).
- sched/fair: Implement synchonous PELT detach on load-balance
  migrate (bnc#1066110 Scheduler utilisation tracking).
- sched/fair: Propagate an effective runnable_load_avg
  (bnc#1066110 Scheduler utilisation tracking).
- sched/pelt: Fix false running accounting (bnc#1066110 Scheduler
  utilisation tracking).
- sched/fair: Rewrite PELT migration propagation (bnc#1066110
  Scheduler utilisation tracking).
- sched/fair: Rewrite cfs_rq->removed_*avg (bnc#1066110 Scheduler
  utilisation tracking).
- sched/fair: Use reweight_entity() for set_user_nice()
  (bnc#1066110 Scheduler utilisation tracking).
- sched/fair: More accurate reweight_entity() (bnc#1066110
  Scheduler utilisation tracking).
- sched/fair: Introduce {en,de}queue_load_avg() (bnc#1066110
  Scheduler utilisation tracking).
- sched/fair: Rename {en,de}queue_entity_load_avg() (bnc#1066110
  Scheduler utilisation tracking).
- sched/fair: Move enqueue migrate handling (bnc#1066110 Scheduler
  utilisation tracking).
- sched/fair: Change update_load_avg() arguments (bnc#1066110
  Scheduler utilisation tracking).
- sched/fair: Remove se->load.weight from se->avg.load_sum
  (bnc#1066110 Scheduler utilisation tracking).
- sched/fair: Cure calc_cfs_shares() vs. reweight_entity()
  (bnc#1066110 Scheduler utilisation tracking).
- sched/fair: Add comment to calc_cfs_shares() (bnc#1066110
  Scheduler utilisation tracking).
- sched/fair: Clean up calc_cfs_shares() (bnc#1066110 Scheduler
  utilisation tracking).
- sched/fair: Drop always true parameter of
  update_cfs_rq_load_avg() (bnc#1066110 Scheduler utilisation
  tracking).
- sched/fair: Avoid checking cfs_rq->nr_running twice (bnc#1066110
  Scheduler utilisation tracking).
- sched/fair: Pass 'rq' to weighted_cpuload() (bnc#1066110
  Scheduler utilisation tracking).
- sched/core: Reuse put_prev_task() (bnc#1066110 Scheduler
  utilisation tracking).
- sched/fair: Use task_groups instead of leaf_cfs_rq_list to
  walk all cfs_rqs (bnc#1066110 Scheduler utilisation tracking).
- sched/fair: Fix O(nr_cgroups) in load balance path (bnc#1066110
  Scheduler utilisation tracking).
- sched/fair: Call cpufreq update util handlers less frequently
  on UP (bnc#1066110 Scheduler utilisation tracking).
- commit 9ea022c
* Thu Dec  7 2017 dbueso@suse.de
- fs/proc: Report eip/esp in /prod/PID/stat for coredumping
  (bsc#1050549).
- locking/x86: Use LOCK ADD for smp_mb() instead of MFENCE
  (bsc#1050549).
- commit 1941e2e
* Wed Dec  6 2017 tiwai@suse.de
- iwlwifi: mvm: support version 7 of the SCAN_REQ_UMAC FW command
  (bsc#1068838,bsc#1071652).
- commit d602917
* Wed Dec  6 2017 oneukum@suse.com
- USB: uas: fix bug in handling of alternate settings
  (bsc#1071074).
- commit e1e1aea
* Wed Dec  6 2017 tbogendoerfer@suse.de
- IB/mlx4: Add contig support for control objects (bsc#1071218).
- IB/mlx4: Use optimal numbers of MTT entries (bsc#1071218).
- IB/mlx4: Add report for RSS capabilities by vendor channel
  (bsc#1071218).
- commit 8514de9
* Wed Dec  6 2017 yousaf.kaukab@suse.com
- regulator: fan53555: fix I2C device ids (bsc#1071296).
- Update config files.
- supported.conf:
- regulator: fan53555: Use of_device_get_match_data() to simplify
  probe (bsc#1071296).
- commit aab6c79
* Wed Dec  6 2017 oneukum@suse.com
- blacklist.conf: usbtest is not compiled
  document that patch for security issue is not needed
- commit 33a85d1
* Wed Dec  6 2017 oneukum@suse.com
- blacklist.conf: the driver is not compiled. Ignore fixes.
- commit eab7a74
* Wed Dec  6 2017 mgorman@suse.de
- sched/wait: fix add_wait_queue() behavior change (bnc#971975
  VM performance -- page waitqueue).
- commit b67e247
* Wed Dec  6 2017 mwilck@suse.com
- scsi: scsi_devinfo: cleanly zero-pad devinfo strings
  (bsc#1062941, bsc#1037404, bsc#1012523, bsc#1038299).
- scsi: scsi_devinfo: handle non-terminated strings (bsc#1062941,
  bsc#1037404, bsc#1012523, bsc#1038299).
- commit fcb27f8
* Wed Dec  6 2017 tiwai@suse.de
- isa: Prevent NULL dereference in isa_bus driver callbacks
  (bsc#1051510).
- commit 32eeca3
* Wed Dec  6 2017 gqjiang@suse.com
- md: always set THREAD_WAKEUP and wake up wqueue if thread
  existed (bsc#1071403).
- dlm: recheck kthread_should_stop() before schedule()
  (bsc#1071422).
- commit a2cb166
* Wed Dec  6 2017 mwilck@suse.com
- scsi_devinfo fixes from 4.15 (bsc#1062941, bsc#1037404)
- scsi: scsi_devinfo: Add 'AIX VDASD' to blacklist (bsc#1012523
  bsc#1037404 bsc#1038299 bsc#1062941).
- scsi: scsi_devinfo: Add TRY_VPD_PAGES to HITACHI OPEN-V
  blacklist entry (bsc#1012523 bsc#1037404 bsc#1038299
  bsc#1062941).
- scsi: scsi_devinfo: fixup string compare (bsc#1012523
  bsc#1037404 bsc#1038299 bsc#1062941).
- scsi: scsi_devinfo: Whitespace fixes (bsc#1012523 bsc#1037404
  bsc#1038299 bsc#1062941).
- commit 0b796f6
* Wed Dec  6 2017 mwilck@suse.com
- Move iTCO_wdt patch to sorted section
- commit c15439f
* Tue Dec  5 2017 jeffm@suse.com
- btrfs: fix NULL pointer dereference from free_reloc_roots()
  (bsc#1071099).
- commit f5d556f
* Tue Dec  5 2017 jack@suse.cz
- dax: fix general protection fault in dax_alloc_inode
  (bsc#1052766).
- commit cc66850
* Tue Dec  5 2017 jack@suse.cz
- f2fs: fix to show ino management cache size correctly
  (bsc#1052766).
- commit 3007e0f
* Tue Dec  5 2017 jack@suse.cz
- Revert "f2fs: handle dirty segments inside refresh_sit_entry"
  (bsc#1052766).
- commit dcc8098
* Tue Dec  5 2017 jack@suse.cz
- f2fs: fix to clear FI_NO_PREALLOC (bsc#1052766).
- commit 8a0aa54
* Tue Dec  5 2017 jack@suse.cz
- ocfs2: ip_alloc_sem should be taken in ocfs2_get_block()
  (bsc#1052766).
- commit 8d3384d
* Tue Dec  5 2017 jack@suse.cz
- dnotify: Handle errors from fsnotify_add_mark_locked() in
  fcntl_dirnotify() (bsc#1052766).
- commit 16097ad
* Tue Dec  5 2017 jack@suse.cz
- fsnotify: pin both inode and vfsmount mark (bsc#1052766).
- commit 1702fdd
* Tue Dec  5 2017 jack@suse.cz
- fsnotify: clean up fsnotify_prepare/finish_user_wait()
  (bsc#1052766).
- commit cb63dd7
* Tue Dec  5 2017 mbrugger@suse.com
- supported.conf: update arm64 relevant drivers
- commit 4d1cbfb
* Tue Dec  5 2017 tbogendoerfer@suse.de
- IB/rdmavt: Don't wait for resources in QP reset (bsc#1070622).
- IB/hfi1: Allow meta version 4 for platform configuration
  (bsc#1070622).
- IB/hfi1: Add parsing for platform configuration format version 4
  (bsc#1070622).
- commit 63d7eea
* Tue Dec  5 2017 jack@suse.cz
- mm/memory.c: mark create_huge_pmd() inline to prevent build
  failure (fate#323590).
- commit 8e193c8
* Tue Dec  5 2017 oneukum@suse.com
- crypto: cavium - clean up clang warning on unread variable
  offset (FATE#323051).
- commit f445359
* Tue Dec  5 2017 mbrugger@suse.com
- scsi: hisi_sas: fix internal abort slot timeout bug
  (bsc#1068693).
- commit 645ee34
* Tue Dec  5 2017 jslaby@suse.cz
- x86/stacktrace: do now unwind after user regs (bnc#1058115).
- x86/stacktrace: remove unwind_state->error (bnc#1058115).
- x86/stacktrace: remove STACKTRACE_DUMP_ONCE from
  __save_stack_trace_reliable (bnc#1058115).
- x86/stacktrace: do not fail for ORC with regs on stack
  (bnc#1058115).
  More make-ORC-reliable patches.
- commit 91578f6
* Mon Dec  4 2017 bp@suse.de
- perf/x86/intel/bts: Fix exclusive event reference leak
  (git-fixes d2878d642a4ed).
- commit 798cbcd
* Mon Dec  4 2017 tiwai@suse.de
- blacklist.conf: Add inapplicable / non-issues commits for WiFi and DRM
- commit 999cd73
* Mon Dec  4 2017 tiwai@suse.de
- mmc: core: prepend 0x to OCR entry in sysfs (bsc#1051510).
- mmc: core: prepend 0x to pre_eol_info entry in sysfs
  (bsc#1051510).
- mac80211_hwsim: Fix memory leak in hwsim_new_radio_nl()
  (bsc#1051510).
- rtlwifi: rtl8821ae: Fix connection lost problem (bsc#1051510).
- brcmfmac: fix double free upon register_netdevice() failure
  (bsc#1051510).
- ath10k: fix reported HT MCS rates with NSS > 1 (bsc#1051510).
- drm/i915: Prevent zero length "index" write (bsc#1051510).
- drm/i915: Don't try indexed reads to alternate slave addresses
  (bsc#1051510).
- commit 4923254
* Mon Dec  4 2017 oneukum@suse.com
- thunderbolt: tb: fix use after free in tb_activate_pcie_devices
  (FATE#323948).
- commit d3f0bb9
* Mon Dec  4 2017 tiwai@suse.de
- Refresh
  patches.drivers/drm-i915-Suppress-switch_mm-emission-between-the-sam.
  Add the cherry-picked upstream commit id, too
- commit f2ecc61
* Mon Dec  4 2017 tiwai@suse.de
- blacklist.conf: Add inapplicable DRM and IIO commits (bsc#1051510)
- commit b18d7d1
* Mon Dec  4 2017 tiwai@suse.de
- ipmi_ssif: unlock on allocation failure (bsc#1051510).
- iio: trigger: stm32-timer: fix a corner case to write preset
  (bsc#1051510).
- iio: inkern: fix a static checker error (bsc#1051510).
- mfd: omap-usb-tll: Fix register offsets (bsc#1051510).
- drm/omap: displays: panel-dpi: add backlight dependency
  (bsc#1051510).
- drm/omap: Fix error handling path in 'omap_dmm_probe()'
  (bsc#1051510).
- drm/i915: fix intel_backlight_device_register declaration
  (bsc#1051510).
- commit d3a4e07
* Mon Dec  4 2017 rgoldwyn@suse.com
- apparmor: fix off-by-one comparison on MAXMAPPED_SIG
  (bsc#1071070).
- apparmor: fix locking when creating a new complain profile
  (bsc#1071061).
- apparmor: fix leak of null profile name if profile allocation
  fails (bsc#1071057).
- apparmor: fix profile attachment for special unconfined profiles
  (bsc#1071035).
- commit 196f7ba
* Mon Dec  4 2017 jack@suse.cz
- mm: always enable thp for dax mappings (fate#323590).
  Refresh patches.fixes/dax-use-common-4k-zero-page-for-dax-mmap-reads.patch
- commit a9ff0a7
* Mon Dec  4 2017 oneukum@suse.com
- iwlwifi: mvm: support version 7 of the SCAN_REQ_UMAC FW command (FATE#322675).
- commit be16b41
* Mon Dec  4 2017 jack@suse.cz
- mm: improve readability of transparent_hugepage_enabled()
  (fate#323590).
- commit 52d3d3e
* Mon Dec  4 2017 msuchanek@suse.de
- blacklist 65c5ec11c25e powerpc/boot: Fix 64-bit boot wrapper build with
  non-biarch compiler
  - correct backlisted commit id
- commit 2fd25e6
* Mon Dec  4 2017 oneukum@suse.com
- iwlwifi: fix wrong struct for a000 device (FATE#322675).
- commit 6762404
* Mon Dec  4 2017 jack@suse.cz
- IB/core: disable memory registration of filesystem-dax vmas
  (bsc#1070967).
- commit 68da5e4
* Mon Dec  4 2017 jack@suse.cz
- v4l2: disable filesystem-dax mapping support (bsc#1070967).
- commit add8a46
* Mon Dec  4 2017 jack@suse.cz
- mm: fail get_vaddr_frames() for filesystem-dax mappings
  (bsc#1070967).
- commit 9705a09
* Mon Dec  4 2017 jack@suse.cz
- mm: introduce get_user_pages_longterm (bsc#1070967).
- commit 3240a1e
* Mon Dec  4 2017 jack@suse.cz
- ecryptfs: fix dereference of NULL user_key_payload
  (bsc#1052766).
- commit b2e39ae
* Mon Dec  4 2017 jack@suse.cz
- dax: fix PMD faults on zero-length files (bsc#1052766).
- commit 640b01c
* Mon Dec  4 2017 jack@suse.cz
- quota: Check for register_shrinker() failure (bsc#1052766).
- commit 7ea927a
* Mon Dec  4 2017 jack@suse.cz
- xfs: evict all inodes involved with log redo item (bsc#1052766).
- commit 1e78f32
* Mon Dec  4 2017 jack@suse.cz
- xfs: clear MS_ACTIVE after finishing log recovery (bsc#1052766).
- commit cd4c172
* Mon Dec  4 2017 jack@suse.cz
- mm, hugetlbfs: introduce ->split() to vm_operations_struct
  (bsc#1070968).
- commit b96e8a1
* Mon Dec  4 2017 jack@suse.cz
- device-dax: implement ->split() to catch invalid munmap attempts
  (bsc#1070968).
- commit 542be39
* Mon Dec  4 2017 jack@suse.cz
- 9p: set page uptodate when required in write_end()
  (bsc#1052766).
- commit de002ea
* Mon Dec  4 2017 tbogendoerfer@suse.de
- net: thunderx: Fix TCP/UDP checksum offload for IPv6 pkts
  (bsc#1069583).
- bpf: fix lockdep splat (bsc#1056787).
- net/mlx5e: Add rollback on add VLAN failure (bsc#1046303
  FATE#322944).
- rtnetlink: bring NETDEV_CHANGEMTU event process back in
  rtnetlink_event (bsc#1056787).
- net: sched: fix use-after-free in tcf_action_destroy and
  tcf_del_walker (bsc#1056787).
- commit 7674fd9
* Mon Dec  4 2017 tbogendoerfer@suse.de
- Re-sorted series.conf
- commit da1763f
* Mon Dec  4 2017 mhocko@suse.com
- mm/hugetlb: fix NULL-pointer dereference on 5-level paging
  machine (bnc#1070965).
- commit 008deb0
* Mon Dec  4 2017 mhocko@suse.com
- mm/madvise.c: fix madvise() infinite loop under special
  circumstances (bnc#1070964).
- commit 6645258
* Mon Dec  4 2017 mhocko@suse.com
- mm/cma: fix alloc_contig_range ret code/potential leak
  (bnc#1070962).
- commit 0363569
* Mon Dec  4 2017 mhocko@suse.com
- blacklist.conf: blacklist 3f3295709edea6268ff1609855f498035286af73 as a
  minor optimization
- commit 689fb18
* Fri Dec  1 2017 mcgrof@suse.com
- xfs: Properly retry failed inode items in case of error during buffer writeback (bsc#1070682).
- xfs: Add infrastructure needed for error propagation during buffer IO failure (bsc#1070682).
- commit b6a619b
* Fri Dec  1 2017 jthumshirn@suse.de
- dm, dax: Make sure dm_dax_flush() is called if device supports
  it (FATE#323717).
- Refresh
  patches.drivers/dax-remove-the-pmem_dax_ops-flush-abstraction.patch.
- commit 5a023df
* Fri Dec  1 2017 hare@suse.de
- Btrfs: work around maybe-uninitialized warning (FATE#323952,
  FATE#322506).
- commit c56eb06
* Fri Dec  1 2017 rgoldwyn@suse.com
- apparmor: fix oops in audit_signal_cb hook (bsc#1070227).
- commit da7b6ca
* Fri Dec  1 2017 jthumshirn@suse.de
- dax: convert to bitmask for flags (FATE#323717).
- dax, pmem: introduce an optional 'flush' dax_operation
  (FATE#323717).
- dax: remove the pmem_dax_ops->flush abstraction (FATE#323717).
- dm: add ->copy_from_iter() dax operation support (FATE#323717).
- dm: add ->flush() dax operation support (FATE#323717).
- filesystem-dax: convert to dax_copy_from_iter() (FATE#323717).
- filesystem-dax: convert to dax_flush() (FATE#323717).
- libnvdimm, nd_blk: remove mmio_flush_range() (FATE#323717).
- libnvdimm, pmem, dax: export a cache control attribute
  (FATE#323717).
- libnvdimm, pmem: disable dax flushing when pmem is fronting
  a volatile region (FATE#323717).
- x86, dax, libnvdimm: remove wb_cache_pmem() indirection
  (FATE#323717).
- x86, dax: replace clear_pmem() with open coded memset +
  dax_ops->flush (FATE#323717).
- x86, libnvdimm, pmem: move arch_invalidate_pmem() to libnvdimm
  (FATE#323717).
- Refresh
  patches.fixes/dax-explain-how-read-2-write-2-addresses-are-validat.patch.
- commit 2bc41df
* Fri Dec  1 2017 ohering@suse.de
- hv_netvsc: preserve hw_features on mtu/channels/ringparam
  changes (fate#323887).
- hv_netvsc: hide warnings about uninitialized/missing rndis
  device (fate#323887).
- hv_netvsc: netvsc_teardown_gpadl() split (fate#323887).
- scsi: storvsc: Avoid excessive host scan on controller change
  (fate#323887).
- hyper-v: trace channel events (fate#323887).
- hyper-v: trace vmbus_send_tl_connect_request() (fate#323887).
- hyper-v: trace vmbus_release_relid() (fate#323887).
- hyper-v: trace vmbus_negotiate_version() (fate#323887).
- hyper-v: trace vmbus_teardown_gpadl() (fate#323887).
- hyper-v: trace vmbus_establish_gpadl() (fate#323887).
- hyper-v: trace vmbus_close_internal() (fate#323887).
- hyper-v: trace vmbus_open() (fate#323887).
- hyper-v: trace vmbus_request_offers() (fate#323887).
- hyper-v: trace vmbus_onversion_response() (fate#323887).
- hyper-v: trace vmbus_ongpadl_torndown() (fate#323887).
- hyper-v: trace vmbus_ongpadl_created() (fate#323887).
- hyper-v: trace vmbus_onopen_result() (fate#323887).
- hyper-v: trace vmbus_onoffer_rescind() (fate#323887).
- hyper-v: trace vmbus_onoffer() (fate#323887).
- hyper-v: trace vmbus_on_message() (fate#323887).
- hyper-v: trace vmbus_on_msg_dpc() (fate#323887).
- scsi: storvsc: Allow only one remove lun work item to be issued
  per lun (fate#323887).
- Drivers: hv: vmbus: Make panic reporting to be more useful
  (fate#323887).
- Drivers: hv: vmbus: Expose per-channel interrupts and events
  counters (fate#323887).
- hv_netvsc: Set tx_table to equal weight after subchannels open
  (fate#323887).
- vmbus: initialize reserved fields in messages (fate#323887).
- hv_netvsc: Add initialization of tx_table in netvsc_device_add()
  (fate#323887).
- hv_netvsc: Rename tx_send_table to tx_table (fate#323887).
- hv_netvsc: Rename ind_table to rx_table (fate#323887).
- hv_netvsc: Add ethtool handler to set and get TCP hash levels
  (fate#323887).
- hv_netvsc: Change the hash level variable to bit flags
  (fate#323887).
- HID: hyperv: pr_err() strings should end with newlines
  (fate#323887).
- vmbus: add per-channel sysfs info (fate#323887).
- hv_netvsc: report stop_queue and wake_queue (fate#323887).
- hv_netvsc: Fix the real number of queues of non-vRSS cases
  (fate#323887).
- hv_netvsc: make const array ver_list static, reduces object
  code size (fate#323887).
- commit 76f63c8
* Fri Dec  1 2017 hare@suse.de
- scsi: mpt3sas: remove a stray KERN_INFO (bsc#1067965).
- scsi: mpt3sas: cleanup _scsih_pcie_enumeration_event()
  (bsc#1067965).
- scsi: mpt3sas: fix dma_addr_t casts (bsc#1067965).
- scsi: mpt3sas: Update mpt3sas driver version (bsc#1067965).
- scsi: mpt3sas: Fix sparse warnings (bsc#1067965).
- scsi: mpt3sas: Fix nvme drives checking for tlr (bsc#1067965).
- scsi: mpt3sas: NVMe drive support for BTDHMAPPING ioctl command
  and log info (bsc#1067965).
- scsi: mpt3sas: Add-Task-management-debug-info-for-NVMe-drives
  (bsc#1067965).
- scsi: mpt3sas: scan and add nvme device after controller reset
  (bsc#1067965).
- scsi: mpt3sas: Set NVMe device queue depth as 128 (bsc#1067965).
- scsi: mpt3sas: Handle NVMe PCIe device related events generated
  from firmware (bsc#1067965).
- scsi: mpt3sas: API's to remove nvme drive from sml
  (bsc#1067965).
- scsi: mpt3sas: API 's to support NVMe drive addition to SML
  (bsc#1067965).
- scsi: mpt3sas: Added support for nvme encapsulated request
  message (bsc#1067965).
- scsi: mpt3sas: SGL to PRP Translation for I/Os to NVMe devices
  (bsc#1067965).
- scsi: mpt3sas: Add nvme device support in slave alloc, target
  alloc and probe (bsc#1067965).
- commit 5d6012f
* Fri Dec  1 2017 hare@suse.de
- Rediff patches after sorting series.conf
- patches.arch/s390-sles15-00-10-01-kernel-sthyi-reorganize-sthyi-implementation.patch:
  (FATE#324258, LTC#160415, bsc#1068273).
- Refresh patches.drivers/s390-cpu-alternatives.patch.
- commit 92c2ed1
* Fri Dec  1 2017 ohering@suse.de
- rename a bunch hyperv patches to reflect new upstream ordering
- commit ab8bb68
* Fri Dec  1 2017 hare@suse.de
- patches.arch/s390-sles15-00-10-03-kernel-sthyi-add-s390_sthyi-system-call.patch:
  (FATE#324258, LTC#160415, bsc#1068273).
- patches.arch/s390-sles15-00-10-02-kernel-sthyi-add-cache-to-store-hypervisor-info.patch:
  (FATE#324258, LTC#160415, bsc#1068273).
- patches.arch/s390-sles15-00-10-01-kernel-sthyi-reorganize-sthyi-implementation.patch:
  (FATE#324258, LTC#160415, bsc#1068273).
- commit bbfb48f
* Fri Dec  1 2017 hare@suse.de
- KVM: s390: Support Configuration z/Architecture Mode
  (FATE#324111, LTC#158961,bsc#1066434).
- commit 39c4947
* Fri Dec  1 2017 tbogendoerfer@suse.de
- iw_cxgb4: atomically flush the qp (bsc#1064802 bsc#1066129).
- iw_cxgb4: only call the cq comp_handler when the cq is armed
  (bsc#1064802 bsc#1066129).
- iw_cxgb4: Fix possible circular dependency locking warning
  (bsc#1064802 bsc#1066129).
- iw_cxgb4: remove BUG_ON() usage (bsc#1064802 bsc#1066129).
- RDMA/cxgb4: Protect from possible dereference (bsc#1064802
  bsc#1066129).
- RDMA/cxgb4: Annotate r2 and stag as __be32 (bsc#1064802
  bsc#1066129).
- RDMA/cxgb4: Declare stag as __be32 (bsc#1064802 bsc#1066129).
- RDMA/cxgb4: Remove a set-but-not-used variable (bsc#1064802
  bsc#1066129).
- RDMA/cxgb4: Suppress gcc 7 fall-through complaints (bsc#1064802
  bsc#1066129).
- RDMA/cxgb4: Remove the obsolete kernel module option
  'c4iw_debug' (bsc#1064802 bsc#1066129).
- RDMA/cxgb4: Fix indentation (bsc#1064802 bsc#1066129).
- iw_cxgb4: add referencing to wait objects (bsc#1064802
  bsc#1066129).
- iw_cxgb4: allocate wait object for each ep object (bsc#1064802
  bsc#1066129).
- iw_cxgb4: allocate wait object for each qp object (bsc#1064802
  bsc#1066129).
- iw_cxgb4: allocate wait object for each cq object (bsc#1064802
  bsc#1066129).
- iw_cxgb4: allocate wait object for each memory object
  (bsc#1064802 bsc#1066129).
- iw_cxgb4: change pr_debug to appropriate log level (bsc#1064802
  bsc#1066129).
- iw_cxgb4: Remove __func__ parameter from pr_debug() (bsc#1064802
  bsc#1066129).
- IB/{cxgb3,cxgb4}: Remove unneeded config dependencies
  (bsc#1064802 bsc#1066129).
- cxgb4: collect SGE queue context dump (bsc#1064802 bsc#1066129).
- cxgb4: collect LE-TCAM dump (bsc#1064802 bsc#1066129).
- cxgb4: collect vpd info directly from hardware (bsc#1064802
  bsc#1066129).
- cxgb4vf: define get_fecparam ethtool callback (bsc#1064802
  bsc#1066129).
- cxgb4: fix error return code in cxgb4_set_hash_filter()
  (bsc#1064802 bsc#1066129).
- cxgb4: add support to create hash-filters via tc-flower offload
  (bsc#1064802 bsc#1066129).
- cxgb4: add support to retrieve stats for hash filters
  (bsc#1064802 bsc#1066129).
- cxgb4: add support to delete hash filter (bsc#1064802
  bsc#1066129).
- cxgb4: add support to create hash filters (bsc#1064802
  bsc#1066129).
- cxgb4: initialize hash-filter configuration (bsc#1064802
  bsc#1066129).
- cxgb4: save additional filter tuple field shifts in tp_params
  (bsc#1064802 bsc#1066129).
- cxgb3: Check and handle the dma mapping errors (bsc#1064802
  bsc#1066129).
- cxgb4: collect hardware misc dumps (bsc#1064802 bsc#1066129).
- cxgb4: collect hardware scheduler dumps (bsc#1064802
  bsc#1066129).
- cxgb4: collect PBT tables dump (bsc#1064802 bsc#1066129).
- cxgb4: collect MPS-TCAM dump (bsc#1064802 bsc#1066129).
- cxgb4: collect TID info dump (bsc#1064802 bsc#1066129).
- cxgb4: collect RSS dumps (bsc#1064802 bsc#1066129).
- cxgb4: collect CIM queue configuration dump (bsc#1064802
  bsc#1066129).
- cxgb4: collect hardware LA dumps (bsc#1064802 bsc#1066129).
- cxgb4: fix overflow in collecting IBQ and OBQ dump (bsc#1064802
  bsc#1066129).
- cxgb4: add tc flower support for L3/L4 rewrite (bsc#1064802
  bsc#1066129).
- cxgb4: introduce fw_filter2_wr to prepare for L3/L4 rewrite
  support (bsc#1064802 bsc#1066129).
- cxgb4: add tc flower support for ETH-SMAC rewrite (bsc#1064802
  bsc#1066129).
- cxgb4: introduce SMT ops to prepare for SMAC rewrite support
  (bsc#1064802 bsc#1066129).
- cxgb4: add tc flower support for ETH-DMAC rewrite (bsc#1064802
  bsc#1066129).
- cxgb4: add tc flower support for action PASS (bsc#1064802
  bsc#1066129).
- cxgb4: add tc flower match support for vlan (bsc#1064802
  bsc#1066129).
- cxgb4: add tc flower match support for TOS (bsc#1064802
  bsc#1066129).
- cxgb4: fix missing break in switch and indent return statements
  (bsc#1064802 bsc#1066129).
- cxgb4: collect IBQ and OBQ dumps (bsc#1064802 bsc#1066129).
- cxgb4: collect hardware module dumps (bsc#1064802 bsc#1066129).
- cxgb4: collect TP dump (bsc#1064802 bsc#1066129).
- cxgb4: update API for TP indirect register access (bsc#1064802
  bsc#1066129).
- cxgb4: collect firmware mbox and device log dump (bsc#1064802
  bsc#1066129).
- cxgb4: collect on-chip memory dump (bsc#1064802 bsc#1066129).
- cxgb4: collect register dump (bsc#1064802 bsc#1066129).
- cxgb4: implement ethtool dump data operations (bsc#1064802
  bsc#1066129).
- cxgb4: Add support for new flash parts (bsc#1064802
  bsc#1066129).
- cxgb4vf: make a couple of functions static (bsc#1064802
  bsc#1066129).
- cxgb4: Update comment for min_mtu (bsc#1064802 bsc#1066129).
- cxgb4: make function ch_flower_stats_cb, fixes warning
  (bsc#1064802 bsc#1066129).
- net: sched: introduce helper to identify gact pass action
  (bsc#1064802 bsc#1066129).
- cxgb4: do DCB state reset in couple of places (bsc#1064802
  bsc#1066129).
- cxgb4: fetch stats for offloaded tc flower flows (bsc#1064802
  bsc#1066129).
- cxgb4: add support to offload action vlan (bsc#1064802
  bsc#1066129).
- cxgb4: add basic tc flower offload support (bsc#1064802
  bsc#1066129).
- cxgb4: add tc flower offload skeleton (bsc#1064802 bsc#1066129).
- cxgb4: avoid stall while shutting down the adapter (bsc#1064802
  bsc#1066129).
- net: sched: add couple of goto_chain helpers (bsc#1064802
  bsc#1066129).
- net: sched: introduce helper to identify gact trap action
  (bsc#1064802 bsc#1066129).
- commit 20cef46
* Fri Dec  1 2017 tbogendoerfer@suse.de
- Re-sorted series.conf
- commit 7b3ce49
* Fri Dec  1 2017 ghe@suse.com
- ocfs2: fstrim: Fix start offset of first cluster group during
  fstrim (bsc#1063586).
- commit 0ab4132
* Fri Dec  1 2017 lduncan@suse.com
- target: Move a declaration of a global variable into a header
  file (bsc#1070678).
- commit 4efa2af
* Wed Nov 29 2017 msuchanek@suse.de
- rpm/kernel-binary.spec.in: fix incorrectly moved comment
  While moving # END COMMON DEPS moved following comment with it.
- commit 858b7e7
* Wed Nov 29 2017 jlee@suse.com
- MODSIGN: checking the blacklisted hash before loading a kernel
  module (fate#316531, bnc#854875).
- Delete
  patches.suse/0001-MODSIGN-Print-appropriate-status-message-when-access.patch.
- Delete
  patches.suse/MODSIGN-loading-keys-from-db-when-SecureBoot-disabled.patch.
- commit edc0be3
* Wed Nov 29 2017 jack@suse.cz
- eCryptfs: use after free in ecryptfs_release_messaging()
  (bsc#1052766).
- commit f859ac2
* Wed Nov 29 2017 jlee@suse.com
- MODSIGN: load blacklist from MOKx (fate#316531, bnc#854875).
- Delete
  patches.suse/0001-MODSIGN-check-hash-of-PKCS-7-signed-kernel-module-in.patch.
- commit 803e6b3
* Wed Nov 29 2017 jack@suse.cz
- xfs: skip bmbt block ino validation during owner change
  (bsc#1052766).
- commit 6bfd0e1
* Wed Nov 29 2017 jlee@suse.com
- MODSIGN: print appropriate status message when getting UEFI
  certificates list (fate#316531, bnc#854875).
- Delete
  patches.suse/0002-MODSIGN-load-hash-blacklist-of-modules-from-MOKx.patch.
- commit 7bcb5b3
* Wed Nov 29 2017 jack@suse.cz
- fs/9p: Compare qid.path in v9fs_test_inode (bsc#1052766).
- commit dbfff87
* Wed Nov 29 2017 jack@suse.cz
- mm/page-writeback.c: remove unused parameter from
  balance_dirty_pages() (bsc#1052766).
- blacklist.conf: Blacklist 0fafdc9f888b
- commit 1229ece
* Wed Nov 29 2017 jlee@suse.com
- MODSIGN: do not load mok when secure boot disabled (fate#316531,
  bnc#854875).
- Delete
  patches.suse/0001-MODSIGN-check-hash-of-kernel-module-in-blacklist.patch.
- commit 8579580
* Wed Nov 29 2017 lhenriques@suse.com
- blaclist.conf: ignore a non-critical clk compile-testing fix
- commit e7dbc17
* Wed Nov 29 2017 msuchanek@suse.de
- powerpc/signal: Properly handle return value from
  uprobe_deny_signal() (bsc#1066223, bsc#1065729).
- powerpc/powernv: Make opal_event_shutdown() callable from IRQ
  context (bsc#1066223, bsc#1065729).
- powerpc/opal: Fix EBUSY bug in acquiring tokens (bsc#1066223,
  bsc#1065729).
- commit 8e87d41
* Wed Nov 29 2017 tbogendoerfer@suse.de
- IB/hfi1: Add MODULE_FIRMWARE statements (bsc#1060463 FATE#323043
  bsc#1036800).
- commit 4895106
* Wed Nov 29 2017 mkubecek@suse.cz
- ipsec: Fix aborted xfrm policy dump crash (CVE-2017-16939
  bsc#1069702).
- commit 1423016
* Wed Nov 29 2017 mkubecek@suse.cz
- series.conf: refresh
  (just ran scripts/series_sort.py)
- commit ae21bc7
* Wed Nov 29 2017 tbogendoerfer@suse.de
- RDMA/core: avoid uninitialized variable warning in create_udata
  (bsc#1046306 FATE#322942).
- commit f931b31
* Wed Nov 29 2017 msuchanek@suse.de
- powerpc/perf: Fix core-imc hotplug callback failure during
  imc initialization (FATE#322448, bsc#1054914).
- commit 38573c2
* Wed Nov 29 2017 tbogendoerfer@suse.de
- blacklist.conf: mark duplicate commit
- commit e6f182d
* Wed Nov 29 2017 tbogendoerfer@suse.de
- IB/hfi1: Allow MgmtAllowed on B2B setups (bsc#1060463
  FATE#323043).
- IB/hfi1: Fix incorrect available receive user context count
  (bsc#1060463 FATE#323043).
- commit 040fd09
* Wed Nov 29 2017 jthumshirn@suse.de
- Delete
  patches.fixes/nvme-check-for-disk-before-submitting-cmd.patch.
  Not needed anymore and in fact causing regressions (bsc#1070098).
- commit 1c081cf
* Wed Nov 29 2017 tbogendoerfer@suse.de
- IB/hfi1: Extend input hdr tracing for packet type (bsc#1060463
  FATE#323043).
- Refresh
  patches.drivers/IB-hfi1-Fix-output-trace-issues-from-16B-change.patch.
- commit 5d3e02e
* Wed Nov 29 2017 tbogendoerfer@suse.de
- IB/cm: Fix memory corruption in handling CM request (bsc#1046306
  FATE#322942).
- i40iw: Move cqp_cmd_head init to CQP initialization (bsc#1058659
  FATE#322535).
- i40iw: Remove UDA QP from QoS list if creation fails
  (bsc#1058659 FATE#322535).
- i40iw: Clear CQP Head/Tail during initialization (bsc#1058659
  FATE#322535).
- i40iw: Account for IPv6 header when setting MSS (bsc#1058659
  FATE#322535).
- i40iw: Move exception_lan_queue to VSI structure (bsc#1058659
  FATE#322535).
- i40iw: Ignore AE source field in AEQE for some AEs (bsc#1058659
  FATE#322535).
- i40iw: Cleanup AE processing (bsc#1058659 FATE#322535).
- IB/srp: Avoid that a cable pull can trigger a kernel crash
  (bsc#1046306 FATE#322942).
- i40iw: Do not allow posting WR after QP is flushed (bsc#1058659
  FATE#322535).
- i40iw: Do not generate CQE for RTR on QP flush (bsc#1058659
  FATE#322535).
- i40iw: Do not retransmit MPA request after it is ACKed
  (bsc#1058659 FATE#322535).
- IB/uverbs: clean up INIT_UDATA_BUF_OR_NULL usage (bsc#1046306
  FATE#322942).
- IB/core: Fix calculation of maximum RoCE MTU (bsc#1046306
  FATE#322942).
- net/smc: dev_put for netdev after usage of ib_query_gid()
  (bsc#1046306 FATE#322942).
- net/mlx4_en: Use __force to fix a sparse warning in TX datapath
  (bsc#1046299 FATE#322947).
- net/mlx5: Avoid NULL pointer dereference on steering cleanup
  (bsc#1046303 FATE#322944).
- commit edced08
* Wed Nov 29 2017 mhocko@suse.com
- Update
  patches.kernel.org/4.12.10-050-fork-fix-incorrect-fput-of-exe_file-causing-u.patch
  (bnc#1060662, bnc#1070266, CVE-2017-17052).
- commit e963703
* Wed Nov 29 2017 msuchanek@suse.de
- ibmvnic: fix dma_mapping_error call (bsc#1069942).
  - refresh sorted section
- ibmvnic: Feature implementation of Vital Product Data (VPD)
  for the ibmvnic driver (bsc#1069942).
- commit 4421afe
* Wed Nov 29 2017 msuchanek@suse.de
- ibmvnic: Add vnic client data to login buffer (bsc#1069942).
- commit d008cdc
* Wed Nov 29 2017 tiwai@suse.de
- blacklist.conf: Add an inapplicable DRM blacklist commit
- commit ac5e9b7
* Wed Nov 29 2017 tiwai@suse.de
- video: udlfb: Fix read EDID timeout (bsc#1051510).
- drm/vc4: Account for interrupts in flight (bsc#1051510).
- drm/kirin: Checking for IS_ERR() instead of NULL (bsc#1051510).
- drm/i915: Clear breadcrumb node when cancelling signaling
  (bsc#1051510).
- drm/edid: Don't send non-zero YQ in AVI infoframe for HDMI
  1.x sinks (bsc#1051510).
- drm: handle HDMI 2.0 VICs in AVI info-frames (bsc#1051510).
- drm/tegra: Set MODULE_FIRMWARE for the VIC (bsc#1051510).
- drm/fsl-dcu: avoid disabling pixel clock twice on suspend
  (bsc#1051510).
- drm/atomic-helper: Realign function parameters (bsc#1051510).
- drm/amdgpu: Throttle visible VRAM moves separately
  (bsc#1051510).
- commit a1d9e66
* Wed Nov 29 2017 tiwai@suse.de
- ipmi_si: fix memory leak on new_smi (bsc#1070006).
- ipmi: Prefer ACPI system interfaces over SMBIOS ones
  (bsc#1070006).
- drm/i915: Fix init_clock_gating for resume (bsc#1051510).
- commit e55a660
* Wed Nov 29 2017 lduncan@suse.com
- KEYS: return full count in keyring_read() if buffer is too small
  (bsc#1066478).
- commit db9dfe7
* Tue Nov 28 2017 msuchanek@suse.de
- powerpc/mm/radix: Fix crashes on Power9 DD1 with radix MMU and
  STRICT_RWX (bsc#1055186, fate#323286, git-fixes 7614ff3272a1).
- commit a720d8d
* Tue Nov 28 2017 msuchanek@suse.de
- blacklist: fc2a5a6161a2 powerpc/64s: ppc_save_regs is now needed for
  all 64s builds
- commit 23ca0a5
* Tue Nov 28 2017 msuchanek@suse.de
- powerpc/64s/slice: Use addr limit when computing slice mask
  (bsc#1070169).
- powerpc/64s: mm_context.addr_limit is only used on hash
  (bsc#1070169).
- powerpc/64s/hash: Allow MAP_FIXED allocations to cross 128TB
  boundary (bsc#1070169).
- powerpc/64s/hash: Fix 128TB-512TB virtual address boundary
  case allocation (bsc#1070169).
- powerpc/64s/hash: Fix fork() with 512TB process address space
  (bsc#1070169).
- powerpc/64s/radix: Fix 128TB-512TB virtual address boundary
  case allocation (bsc#1070169).
- powerpc/64s/hash: Fix 512T hint detection to use >= 128T
  (bsc#1070169).
- commit 9e4b8a7
* Tue Nov 28 2017 tbogendoerfer@suse.de
- RDMA/bnxt_re: synchronize poll_cq and req_notify_cq verbs
  (bsc#1050244 FATE#322915).
- RDMA/bnxt_re: Flush CQ notification Work Queue before destroying
  QP (bsc#1050244 FATE#322915).
- RDMA/bnxt_re: Set QP state in case of response completion errors
  (bsc#1050244 FATE#322915).
- RDMA/bnxt_re: Add memory barriers when processing CQ/EQ entries
  (bsc#1050244 FATE#322915).
- bnxt_re: changing the ip address shouldn't affect new
  connections (bsc#1050244 FATE#322915).
- bnxt_re: fix a crash in qp error event processing (bsc#1050244
  FATE#322915).
- bnxt_re: Implement the shutdown hook of the L2-RoCE driver
  interface (bsc#1050244 FATE#322915).
- bnxt_re: Fix incorrect usage of test_bit() (bsc#1050244
  FATE#322915).
- cxgb4: add new T6 pci device id's (bsc#1062057).
- cxgb4: add new T5 pci device id's (bsc#1062057).
- cxgb4: add new T6 pci device id's (bsc#1062057).
- cxgb4: add new T5 pci device id's (bsc#1062057).
- commit c0d6d87
* Tue Nov 28 2017 msuchanek@suse.de
- powerpc/kexec: Fix kexec/kdump in P9 guest kernels
  (bsc#1070053).
- powerpc/powernv: Fix kexec crashes caused by tlbie tracing
  (bsc#1055117, fate#323286, git-fixes 0428491cba92).
- commit 1619f34
* Tue Nov 28 2017 msuchanek@suse.de
- powerpc/perf/imc: Use cpu_to_node() not
  topology_physical_package_id() (FATE#322448, bsc#1054914).
- powerpc/perf: Fix IMC_MAX_PMU macro (FATE#322448, bsc#1054914).
- commit aff096d
* Tue Nov 28 2017 msuchanek@suse.de
- powerpc/book3s: EXPORT_SYMBOL_GPL machine_check_print_event_info
  (bsc#1061840).
- commit bf1a2aa
* Tue Nov 28 2017 msuchanek@suse.de
- KVM: PPC: Book3S HV: Don't call real-mode XICS hypercall
  handlers if not enabled (bsc#1061840).
- KVM: PPC: Book3S HV: Fix exclusion between HPT resizing and
  other HPT updates (bsc#1061840).
- KVM: PPC: Book3S HV: Add more barriers in XIVE load/unload code
  (bsc#1061840).
- KVM: PPC: Book3S HV: Close race with testing for signals on
  guest entry (bsc#1061840).
- KVM: PPC: Book3S HV: Simplify dynamic micro-threading code
  (bsc#1061840).
- KVM: PPC: Book3S HV: Exit guest upon MCE when FWNMI capability
  is enabled (bsc#1061840).
- KVM: PPC: Book3S HV: Add new capability to control MCE behaviour
  (bsc#1061840).
  Refresh patches.drivers/KVM-s390-02-CMMA-tracking-ESSA-emulation-migration-mode.patch.
- commit 1cc7495
* Tue Nov 28 2017 msuchanek@suse.de
- Reorder KVM patches.
- commit 78a9369
* Tue Nov 28 2017 ddiss@suse.de
- target: fix ALUA state file path truncation (bsc#1064606).
- target: fix PR state file path truncation (bsc#1064606).
  Also update patches.drivers/0058-fs-fix-kernel_write-prototype context.
- rbd: set discard_alignment to zero (bsc#1064320).
- commit 684d96b
* Tue Nov 28 2017 mhocko@suse.com
- mm/pagewalk.c: report holes in hugetlb ranges (bnc#1069996,
  CVE-2017-16994).
- commit 346de02
* Mon Nov 27 2017 msuchanek@suse.de
- Do not enforce patch directories yet.
- commit f0d8a60
* Mon Nov 27 2017 dbueso@suse.de
- lib/int_sqrt: adjust comments (bsc#1069436).
- lib/int_sqrt: optimize initial value compute (bsc#1069436).
- lib/int_sqrt: optimize small argument (bsc#1069436).
- kernel/kcmp.c: drop branch leftover typo (bsc#1052639).
- autofs: fix AT_NO_AUTOMOUNT not being honored (bsc#1069987).
- commit 8651b98
* Mon Nov 27 2017 tbogendoerfer@suse.de
- supported.conf: added liquidio, liquidio_vf and opa_vnic
- commit 6dd2c4f
* Mon Nov 27 2017 tbogendoerfer@suse.de
- Update config files.
- commit d61614e
* Mon Nov 27 2017 tbogendoerfer@suse.de
- liquidio: fix timespec64_to_ns typo (bsc#1067126).
- liquidio: fix crash in presence of zeroed-out base address regs
  (bsc#1067126).
- liquidio: show NIC's U-Boot version in a dev_info() message
  (bsc#1067126).
- liquidio: change manner of detecting whether or not NIC firmware
  is loaded (bsc#1067126).
- liquidio: make VF driver notify NIC firmware of MTU change
  (bsc#1067126).
- liquidio: move macro definition to a proper place (bsc#1067126).
- liquidio: fix use of pf in pass-through mode in a virtual
  machine (bsc#1067126).
- liquidio: remove support for deprecated f/w cmd
  OCTNET_CMD_RESET_PF (bsc#1067126).
- liquidio: fix Smatch error (bsc#1067126).
- liquidio: with embedded f/w, issue droq credits before
  enablement (bsc#1067126).
- liquidio: with embedded f/w, don't reload f/w, issue pf flr
  at exit (bsc#1067126).
- liquidio: fix spelling mistake: "interuupt" -> "interrupt"
  (bsc#1067126).
- liquidio: update VF's netdev->max_mtu if there's a change in
  PF's MTU (bsc#1067126).
- liquidio: added support for ethtool --set-channels feature
  (bsc#1067126).
- liquidio: moved octeon_setup_interrupt to lio_core.c
  (bsc#1067126).
- liquidio: moved liquidio_legacy_intr_handler to lio_core.c
  (bsc#1067126).
- liquidio: moved liquidio_msix_intr_handler to lio_core.c
  (bsc#1067126).
- liquidio: fix issues with fw_type module parameter
  (bsc#1067126).
- liquidio: added support for ethtool --set-ring feature
  (bsc#1067126).
- liquidio: moved liquidio_setup_io_queues to lio_core.c
  (bsc#1067126).
- liquidio: moved liquidio_napi_poll to lio_core.c (bsc#1067126).
- liquidio: moved liquidio_napi_drv_callback to lio_core.c
  (bsc#1067126).
- liquidio: moved liquidio_push_packet to lio_core.c
  (bsc#1067126).
- liquidio: moved octeon_setup_droq to lio_core.c (bsc#1067126).
- liquidio: moved update_txq_status to lio_core.c (bsc#1067126).
- liquidio: moved wait_for_pending_requests to octeon_network.h
  (bsc#1067126).
- liquidio: fix duplicated code for different branches
  (bsc#1067126).
- liquidio: update debug console logging mechanism (bsc#1067126).
- liquidio: moved ptp_enable to octeon_device structure
  (bsc#1067126).
- liquidio: removed check for queue size alignment (bsc#1067126).
- liquidio: rx/tx queue cleanup (bsc#1067126).
- liquidio: napi cleanup (bsc#1067126).
- liquidio: fix misspelled firmware image filenames (bsc#1067126).
- liquidio: fix wrong info about vf rx/tx ring parameters reported
  to ethtool (bsc#1067126).
- liquidio: moved console_bitmask module param to lio_main.c
  (bsc#1067126).
- liquidio: add missing strings in oct_dev_state_str array
  (bsc#1067126).
- liquidio: set sriov_totalvfs correctly (bsc#1067126).
- liquidio: bump up driver version to match newer NIC firmware
  (bsc#1067126).
- liquidio: cleanup: removed cryptic and misleading macro
  (bsc#1067126).
- liquidio: standardization: use min_t instead of custom macro
  (bsc#1067126).
- liquidio: fix implicit irq include causing build failures
  (bsc#1067126).
- liquidio: lio_main: remove unnecessary static in
  setup_io_queues() (bsc#1067126).
- liquidio: lio_vf_main: remove unnecessary static in
  setup_io_queues() (bsc#1067126).
- liquidio: lowmem: init allocated memory to 0 (bsc#1067126).
- liquidio: lowmem: do not dereference null ptr (bsc#1067126).
- liquidio: lowmem: init allocated memory to 0 (bsc#1067126).
- liquidio: support new firmware statistic fw_err_pki
  (bsc#1067126).
- liquidio: fix possible eeprom format string overflow
  (bsc#1067126).
- liquidio: stop using huge static buffer, save 4096k in .data
  (bsc#1067126).
- liquidio: replace info-pointer mode with buffer-pointer-only
  mode (bsc#1067126).
- liquidio: implement vlan filter enable and disable
  (bsc#1067126).
- liquidio: fix VF driver off-by-one bug when setting ethtool
  - C ethX rx-frames (bsc#1067126).
- liquidio: disallow enabling firmware debug from a VF
  (bsc#1067126).
- liquidio: Fix checkpatch errors with references crossing single
  line (bsc#1067126).
- liquidio: VF interrupt initialization cleanup (bsc#1067126).
- liquidio: fix inaccurate count of napi-processed rx packets
  reported to Octeon (bsc#1067126).
- liquidio: fix rare pci_driver.probe failure of VF driver
  (bsc#1067126).
- liquidio: make the spinlock octeon_devices_lock static
  (bsc#1067126).
- liquidio: fix PF falsely indicating success at setting MAC
  address of a nonexistent VF (bsc#1067126).
- liquidio: fix insmod failure when multiple NICs are plugged in
  (bsc#1067126).
- liquidio: use pcie_flr instead of duplicating it (bsc#1067126).
- commit 4fe19f6
* Mon Nov 27 2017 tbogendoerfer@suse.de
- IB/rxe: put the pool on allocation failure (bsc#1050662
  FATE#323951).
- commit 927c30e
* Mon Nov 27 2017 pmladek@suse.com
- printk: Make sure to wake up printk kthread from irq work for
  pending output (bnc#744692, bnc#789311).
- Refresh patches.suse/printk-make-synchronous-param-rw.patch.
- commit 2e337de
* Mon Nov 27 2017 tbogendoerfer@suse.de
- IB/rxe: don't crash, if allocation of crc algorithm failed
  (bsc#1051635).
- IB/rxe: check for allocation failure on elem (bsc#1050662
  FATE#323951).
- i40e: Avoid some useless variables and initializers in NVM
  functions (bsc#1056658 FATE#322188).
- i40e: Add programming descriptors to cleaned_count (bsc#1056658
  FATE#322188).
- i40e: Fix incorrect use of tx_itr_setting when checking for
  Rx ITR setup (bsc#1056658 FATE#322188).
- ixgbe: Fix Tx map failure path (bsc#1056657 FATE#322189
  bsc#1056653 FATE#322190).
- igb: Fix TX map failure path (bsc#1056651 FATE#322191
  bsc#1056643 FATE#322192).
- e1000: avoid null pointer dereference on invalid stat type
  (bsc#1056665 FATE#322184).
- e1000: fix race condition between e1000_down() and
  e1000_watchdog (bsc#1056665 FATE#322184).
- i40e: Fix memory leak related filter programming status
  (bsc#1056658 FATE#322188).
- i40e: Fix comment about locking for __i40e_read_nvm_word()
  (bsc#1056658 FATE#322188).
- ixgbe: incorrect XDP ring accounting in ethtool tx_frame param
  (bsc#1056657 FATE#322189 bsc#1056653 FATE#322190).
- ixgbe: fix masking of bits read from IXGBE_VXLANCTRL register
  (bsc#1056657 FATE#322189 bsc#1056653 FATE#322190).
- ixgbe: Return error when getting PHY address if PHY access is
  not supported (bsc#1056657 FATE#322189 bsc#1056653 FATE#322190).
- commit 71a839f
* Mon Nov 27 2017 pmladek@suse.com
- Port async printk for SLE15 (bsc#744692, bsc#789311, bsc#995541, bsc#1034995, bsc#1043347)
- Refresh
  patches.suse/printk-Switch-to-the-sync-mode-when-an-emergency-mes.patch.
- Refresh patches.suse/printk-fix-suspend-hang.patch.
- Refresh patches.suse/printk-make-async.patch.
- Refresh
  patches.suse/printk-xen-Force-printk-sync-mode-when-migrating-Xen.patch.
- commit b97b16d
* Mon Nov 27 2017 jthumshirn@suse.de
- Update config files, activate NVMe multipathing on the default kernel.
- commit 02da60f
* Mon Nov 27 2017 jthumshirn@suse.de
- nvmet_fc: fix better length checking (FATE#323952, FATE#322506).
- nvme: expose subsys attribute to sysfs (FATE#323952,
  FATE#322506).
- nvme: create 'slaves' and 'holders' entries for hidden
  controllers (FATE#323952, FATE#322506).
- block: create 'slaves' and 'holders' entries for hidden gendisks
  (FATE#323952, FATE#322506).
- nvme: also expose the namespace identification sysfs files
  for mpath nodes (FATE#323952, FATE#322506).
- nvme: implement multipath access to nvme subsystems
  (FATE#323952, FATE#322506).
- nvme: track shared namespaces (FATE#323952, FATE#322506).
- nvme: introduce a nvme_ns_ids structure (FATE#323952,
  FATE#322506).
- nvme: track subsystems (FATE#323952, FATE#322506).
- commit 6e1681a
* Mon Nov 27 2017 tbogendoerfer@suse.de
- Update config files.
- commit 81510df
* Mon Nov 27 2017 vbabka@suse.cz
- x86/mm: fix use-after-free of vma during userfaultfd fault
  (Git-fixes, bsc#1069916).
- x86/mm: Fix fault error path using unsafe vma pointer
  (Git-fixes, bsc#1069916).
- commit 26d860b
* Mon Nov 27 2017 jthumshirn@suse.de
- nvmet: kill nvmet_inline_bio_init (FATE#323952, FATE#322506).
- nvmet: better data length validation (FATE#323952, FATE#322506).
- nvme-pci: avoid dereference of symbol from unloaded module
  (FATE#323952, FATE#322506).
- nvme: send uevent for some asynchronous events (FATE#323952,
  FATE#322506).
- nvme: unexport starting async event work (FATE#323952,
  FATE#322506).
- nvme: remove handling of multiple AEN requests (FATE#323952,
  FATE#322506).
- nvme-fc: remove unused "queue_size" field (FATE#323952,
  FATE#322506).
- nvme: centralize AEN defines (FATE#323952, FATE#322506).
- nvmet: remove redundant local variable (FATE#323952,
  FATE#322506).
- nvmet: remove redundant memset if failed to get_smart_log failed
  (FATE#323952, FATE#322506).
- blk-mq: Avoid that request queue removal can trigger list
  corruption (FATE#323952, FATE#322506).
- commit de963be
* Mon Nov 27 2017 tbogendoerfer@suse.de
- qed: Fix iWARP out of order flow (bsc#1050536 FATE#322898
  bsc#1050545 FATE#322893).
- Refresh
  patches.drivers/IB-Move-PCI-dependency-from-root-KConfig-to-HW-s-KCo.patch.
- commit 8815545
* Mon Nov 27 2017 jthumshirn@suse.de
- nvme: fix eui_show() print format (FATE#323952, FATE#322506).
- nvme: compare NQN string with right size (FATE#323952,
  FATE#322506).
- nvmet: fix comment typos in admin-cmd.c (FATE#323952,
  FATE#322506).
- nvme-rdma: fix nvme_rdma_create_queue_ib error flow
  (FATE#323952, FATE#322506).
- nvmet-rdma: update queue list during ib_device removal
  (FATE#323952, FATE#322506).
- nvme-fc: decouple ns references from lldd references
  (FATE#323952, FATE#322506).
- nvme-fc: fix localport resume using stale values (FATE#323952,
  FATE#322506).
- nvme: check admin passthru command effects (FATE#323952,
  FATE#322506).
- nvme: factor get log into a helper (FATE#323952, FATE#322506).
- nvme: fix and clarify the check for missing metadata
  (FATE#323952, FATE#322506).
- nvme: split __nvme_revalidate_disk (FATE#323952, FATE#322506).
- nvme: set the chunk size before freezing the queue (FATE#323952,
  FATE#322506).
- nvme: don't pass struct nvme_ns to nvme_config_discard
  (FATE#323952, FATE#322506).
- nvme: don't pass struct nvme_ns to nvme_init_integrity
  (FATE#323952, FATE#322506).
- nvme: always unregister the integrity profile in
  __nvme_revalidate_disk (FATE#323952, FATE#322506).
- nvme: move the dying queue check from cancel to completion
  (FATE#323952, FATE#322506).
- commit de01ab6
* Mon Nov 27 2017 jthumshirn@suse.de
- Re-sort series.conf
- commit 3402cbf
* Mon Nov 27 2017 tbogendoerfer@suse.de
- nfp: inherit the max_mtu from the PF netdev (bsc#1055968).
- nfp: fix vlan receive MAC statistics typo (bsc#1055968).
- nfp: fix flower offload metadata flag usage (bsc#1055968).
- IB/core: Only maintain real QPs in the security lists
  (bsc#1046306 FATE#322942).
- IB/hfi1: Mask upper 16Bits of Extended LID prior to rvt_cq_entry
  (bsc#1046306 FATE#322942).
- IB/core: Convert OPA AH to IB for Extended LIDs only
  (bsc#1046306 FATE#322942).
- IB/core: Avoid crash on pkey enforcement failed in received MADs
  (bsc#1046306 FATE#322942).
- IB/mlx4: Fix RSS's QPC attributes assignments (bsc#1046302
  FATE#322945).
- IB/hfi1: Set hdr_type when tx req is allocated (bsc#1060463
  FATE#323043).
- IB/hfi1: Eliminate allocation while atomic (bsc#1060463
  FATE#323043).
- IB/hfi1: Mask out A bit from psn trace (bsc#1060463
  FATE#323043).
- IB/core: Fix endianness annotation in rdma_is_multicast_addr()
  (bsc#1046306 FATE#322942).
- infiniband: add MMU dependency for user_mem (bsc#1046306
  FATE#322942).
- IB/hfi1: Do not warn on lid conversions for OPA (bsc#1046306
  FATE#322942).
- IB/core: Do not warn on lid conversions for OPA (bsc#1046306
  FATE#322942).
- IB/core: Use __be32 for LIDs in opa_is_extended_lid (bsc#1046306
  FATE#322942).
- IB/hfi1: Prevent LNI out of sync by resetting host interface
  version (bsc#1060463 FATE#323043).
- IB/hfi1: Fix output trace issues from 16B change (bsc#1060463
  FATE#323043).
- IB/core: Fix use workqueue without WQ_MEM_RECLAIM (bsc#1046306
  FATE#322942).
- qed: Add iWARP support for fpdu spanned over more than two
  tcp packets (bsc#1050536 FATE#322898 bsc#1050545 FATE#322893).
- qed: Add support for MPA header being split over two tcp packets
  (bsc#1050536 FATE#322898 bsc#1050545 FATE#322893).
- qed: Add support for freeing two ll2 buffers for corner cases
  (bsc#1050536 FATE#322898 bsc#1050545 FATE#322893).
- qed: Add unaligned and packed packet processing (bsc#1050536
  FATE#322898 bsc#1050545 FATE#322893).
- qed: Add mpa buffer descriptors for storing and processing
  mpa fpdus (bsc#1050536 FATE#322898 bsc#1050545 FATE#322893).
- qed: Add ll2 connection for processing unaligned MPA packets
  (bsc#1050536 FATE#322898 bsc#1050545 FATE#322893).
- qed: Add LL2 slowpath handling (bsc#1050536 FATE#322898
  bsc#1050545 FATE#322893).
- qed: Add the source of a packet sent on an iWARP ll2 connection
  (bsc#1050536 FATE#322898 bsc#1050545 FATE#322893).
- qed: Fix initialization of ll2 offload feature (bsc#1050536
  FATE#322898 bsc#1050545 FATE#322893).
- qed: Add ll2 option for dropping a tx packet (bsc#1050536
  FATE#322898 bsc#1050545 FATE#322893).
- qed: Add ll2 ability of opening a secondary queue (bsc#1050536
  FATE#322898 bsc#1050545 FATE#322893).
- qed: Add ll2 option to limit the number of bds per packet
  (bsc#1050536 FATE#322898 bsc#1050545 FATE#322893).
- qed: Delete redundant check on dcb_app priority (bsc#1050536
  FATE#322898 bsc#1050545 FATE#322893).
- qed: iWARP - Add check for errors on a SYN packet (bsc#1050536
  FATE#322898 bsc#1050545 FATE#322893).
- qed: Fix maximum number of CQs for iWARP (bsc#1050536
  FATE#322898 bsc#1050545 FATE#322893).
- qed: Add iWARP out of order support (bsc#1050536 FATE#322898
  bsc#1050545 FATE#322893).
- qed: Add iWARP enablement support (bsc#1050536 FATE#322898
  bsc#1050545 FATE#322893).
- commit f5625a0
* Mon Nov 27 2017 tbogendoerfer@suse.de
- Re-sorted patches
- commit b5ad2da
* Mon Nov 27 2017 tiwai@suse.de
- Revert a broken USB-audio patch (bsc#1051510)
  Delete
  patches.drivers/ALSA-usb-audio-Fix-potential-zero-division-at-parsin.
  Also blacklist it.
- commit 6ef0b1b
* Mon Nov 27 2017 hare@suse.de
- block: avoid null pointer dereference on null disk (FATE#323952,
  FATE#322506).
- commit 81a37d2
* Mon Nov 27 2017 hare@suse.de
- bio: ensure __bio_clone_fast copies bi_partno (FATE#323952,
  FATE#322506).
- fs: guard_bio_eod() needs to consider partitions (FATE#323952,
  FATE#322506).
- block: add a poll_fn callback to struct request_queue
  (FATE#323952, FATE#322506).
- block: introduce GENHD_FL_HIDDEN (FATE#323952, FATE#322506).
- block: don't look at the struct device dev_t in disk_devt
  (FATE#323952, FATE#322506).
- block: add a blk_steal_bios helper (FATE#323952, FATE#322506).
- block: provide a direct_make_request helper (FATE#323952,
  FATE#322506).
- block: add REQ_DRV bit (FATE#323952, FATE#322506).
- block: move REQ_NOWAIT (FATE#323952, FATE#322506).
- btrfs: Fix bug for misused dev_t when lookup in dev state hash
  table (FATE#323952, FATE#322506).
- block: tolerate tracing of NULL bio (FATE#323952, FATE#322506).
- commit ad4c58e
* Mon Nov 27 2017 hare@suse.de
- block: replace bi_bdev with a gendisk pointer and partitions
  index (FATE#323952, FATE#322506).
- Refresh
  patches.drivers/0004-md-Runtime-support-for-multiple-ppls.patch.
- Refresh
  patches.drivers/nvme-factor-metadata-handling-out-of-__nvme_submit_u.patch.
- Refresh
  patches.fixes/nvme-check-for-disk-before-submitting-cmd.patch.
- commit 2c78f3d
* Fri Nov 24 2017 lhenriques@suse.com
- iommu/vt-d: Don't register bus-notifier under dmar_global_lock
  (bsc#1069793).
- commit 0f58c9b
* Fri Nov 24 2017 tiwai@suse.de
- rpm/kernel-binary.spec.in: Correct supplements for recent SLE products (bsc#1067494)
- commit 8f05b9f
* Fri Nov 24 2017 yousaf.kaukab@suse.com
- hwmon: (xgene) Fix up error handling path mixup in
  'xgene_hwmon_probe()' (bsc#1069757).
- mmc: dw_mmc: Fix the DTO timeout calculation (bsc#1069721).
- mmc: core: add driver strength selection when selecting hs400es
  (bsc#1069721).
- commit 75c3fc9
* Fri Nov 24 2017 jkosina@suse.cz
- HID: elo: clear BTN_LEFT mapping (bsc#1065866).
- commit 9f9219a
* Fri Nov 24 2017 mbrugger@suse.com
- net: hns: set correct return value (bsc#1068693).
- scsi: libsas: move bus_reset_handler() to target_reset_handler()
  (bsc#1068693).
- scsi: hisi_sas: remove driver versioning (bsc#1068693).
- scsi: hisi_sas: add status and command buffer for internal abort
  (bsc#1068693).
- scsi: hisi_sas: support zone management commands (bsc#1068693).
- scsi: hisi_sas: service interrupt ITCT_CLR interrupt in v2 hw
  (bsc#1068693).
- scsi: hisi_sas: add irq and tasklet cleanup in v2 hw
  (bsc#1068693).
- scsi: hisi_sas: remove repeated device config in v2 hw
  (bsc#1068693).
- scsi: hisi_sas: use array for v2 hw ECC errors (bsc#1068693).
- scsi: hisi_sas: add v2 hw DFX feature (bsc#1068693).
- scsi: hisi_sas: fix v2 hw underflow residual value
  (bsc#1068693).
- scsi: hisi_sas: avoid potential v2 hw interrupt issue
  (bsc#1068693).
- scsi: hisi_sas: fix reset and port ID refresh issues
  (bsc#1068693).
- net: hns: Fix for __udivdi3 compiler error (bsc#1068693).
- net: hns: Add self-adaptive interrupt coalesce support in hns
  driver (bsc#1068693).
- hns: remove useless void cast (bsc#1068693).
- clocksource/drivers/arm_arch_timer: Avoid infinite recursion
  when ftrace is enabled (bsc#1068693).
- net: hns: add acpi function of xge led control (bsc#1068693).
- scsi: hisi_sas: make several const arrays static (bsc#1068693).
- net: hns: Bugfix for Tx timeout handling in hns driver
  (bsc#1068693).
- net: hns: Fix a skb used after free bug (bsc#1068693).
- net: hns: Fix a wrong op phy C45 code (bsc#1068693).
- scsi: hisi_sas: optimise DMA slot memory (bsc#1068693).
- scsi: hisi_sas: redefine hisi_sas_phy.phy_type as u32
  (bsc#1068693).
- scsi: hisi_sas: modify internal abort dev flow for v3 hw
  (bsc#1068693).
- scsi: hisi_sas: add v3 code to fill some more hw function
  pointers (bsc#1068693).
- scsi: hisi_sas: add get_wideport_bitmap_v3_hw() (bsc#1068693).
- scsi: hisi_sas: add v3 code to send internal abort command
  (bsc#1068693).
- scsi: hisi_sas: add v3 code for itct setup and free
  (bsc#1068693).
- scsi: hisi_sas: add v3 code to send ATA frame (bsc#1068693).
- scsi: hisi_sas: add v3 code to send SMP frame (bsc#1068693).
- scsi: hisi_sas: add v3 code to send SSP frame (bsc#1068693).
- scsi: hisi_sas: add v3 cq interrupt handler (bsc#1068693).
- scsi: hisi_sas: add phy up/down/bcast and channel ISR
  (bsc#1068693).
- scsi: hisi_sas: add v3 hw PHY init (bsc#1068693).
- scsi: hisi_sas: add v3 hw init (bsc#1068693).
- scsi: hisi_sas: add initialisation for v3 pci-based controller
  (bsc#1068693).
- scsi: hisi_sas: add skeleton v3 hw driver (bsc#1068693).
- scsi: hisi_sas: create hisi_sas_get_fw_info() (bsc#1068693).
- scsi: hisi_sas: add pci_dev in hisi_hba struct (bsc#1068693).
- scsi: hisi_sas: relocate get_ncq_tag_v2_hw() (bsc#1068693).
- scsi: hisi_sas: relocate sata_done_v2_hw() (bsc#1068693).
- scsi: hisi_sas: relocate get_ata_protocol() (bsc#1068693).
- scsi: hisi_sas: optimise the usage of hisi_hba.lock
  (bsc#1068693).
- scsi: hisi_sas: define hisi_sas_device.device_id as int
  (bsc#1068693).
- scsi: hisi_sas: fix timeout check in
  hisi_sas_internal_task_abort() (bsc#1068693).
- scsi: hisi_sas: add null check before indirect pointer
  dereference (bsc#1068693).
- net: hns: Use phy_driver to setup Phy loopback (bsc#1068693).
- net: phy: Add phy loopback support in net phy framework
  (bsc#1068693).
- commit b48234d
* Fri Nov 24 2017 vbabka@suse.cz
- mm, page_alloc: fix potential false positive in
  __zone_watermark_ok (Git-fixes, bsc#1068978).
- commit 79749ae
* Fri Nov 24 2017 tiwai@suse.de
- ALSA: timer: Remove kernel warning at compat ioctl error paths
  (bsc#1051510).
- ALSA: pcm: update tstamp only if audio_tstamp changed
  (bsc#1051510).
- ALSA: usb-audio: Add sanity checks in v2 clock parsers
  (bsc#1051510).
- ALSA: usb-audio: Fix potential zero-division at parsing FU
  (bsc#1051510).
- ALSA: usb-audio: Fix potential out-of-bound access at parsing SU
  (bsc#1051510).
- ALSA: usb-audio: Add sanity checks to FE parser (bsc#1051510).
- ALSA: usb-audio: uac1: Invalidate ctl on interrupt
  (bsc#1051510).
- ALSA: hda: Add Raven PCI ID (bsc#1051510).
- ALSA: hda/realtek - Fix ALC700 family no sound issue
  (bsc#1051510).
- ALSA: hda/realtek: Add headset mic support for Intel NUC Skull
  Canyon (bsc#1051510).
- ALSA: hda: Fix too short HDMI/DP chmap reporting (bsc#1051510).
- ALSA: hda/realtek - Fix ALC275 no sound issue (bsc#1051510).
- commit 2816ae2
* Fri Nov 24 2017 jack@suse.cz
- ext4: fix null pointer dereference on sbi (fate#322879).
- commit f2b1207
* Fri Nov 24 2017 jack@suse.cz
- dax: fix FS_DAX=n BLOCK=y compilation (fate#322879).
- commit e1180b5
* Thu Nov 23 2017 yousaf.kaukab@suse.com
- i2c: xlp9xx: Handle I2C_M_RECV_LEN in msg->flags (bsc#1067225).
- i2c: xlp9xx: Get clock frequency with clk API (bsc#1067225).
- i2c: xlp9xx: Enable HWMON class probing for xlp9xx (bsc#1067225).
- PCI: Mark Cavium CN8xxx to avoid bus reset (bsc#1069250).
- PCI: Apply Cavium ThunderX ACS quirk to more Root Ports (bsc#1069250).
- PCI: Set Cavium ACS capability quirk flags to assert RR/CR/SV/UF (bsc#1069250).
- ACPI / APD: Add clock frequency for ThunderX2 I2C controller (bsc#1067225).
- commit de9db6c
* Thu Nov 23 2017 tiwai@suse.de
- blacklist.conf: Add an iwlwifi blacklist commit
- commit c177979
* Thu Nov 23 2017 tiwai@suse.de
- iwlwifi: fix multi queue notification for a000 devices
  (bsc#1051510).
- iwlwifi: mvm: reset seq num after restart (bsc#1051510).
- iwlwifi: mvm: add missing lq_color (bsc#1051510).
- mac80211: validate user rate mask before configuring driver
  (bsc#1051510).
- iwlwifi: mvm: fix reorder buffer for 9000 devices (bsc#1051510).
- nl80211: fix null-ptr dereference on invalid mesh configuration
  (bsc#1051510).
- nl80211: look for HT/VHT capabilities in beacon's tail
  (bsc#1051510).
- mac80211: agg-tx: call drv_wake_tx_queue in proper context
  (bsc#1051510).
- mwifiex: replace netif_carrier_on/off by
  netif_device_attach/dettach (bsc#1051510).
- commit f574816
* Thu Nov 23 2017 tiwai@suse.de
- blacklist.conf: Blacklist an already-applied drm commit
- commit 3376c3c
* Thu Nov 23 2017 tiwai@suse.de
- drm/sun4i: tcon: Unconditionally reset the TCON (bsc#1051510).
- drm/sun4i: backend: Offset layer buffer address by DRAM starting
  address (bsc#1051510).
- drm/radeon: disable hard reset in hibernate for APUs
  (bsc#1051510).
- drm/nouveau/kms/nv50: perform null check on msto[i] rathern
  than msto (bsc#1051510).
- drm/i915/perf: fix perf enable/disable ioctls with 32bits
  userspace (bsc#1051510).
- drm/i915: Use crtc_state_is_legacy_gamma in intel_color_check
  (bsc#1051510).
- drm/bridge/sii8620: Fix memory corruption (bsc#1051510).
- commit ff1cf1f
* Thu Nov 23 2017 jthumshirn@suse.de
- Refresh
  patches.drivers/block-Fix-a-race-between-blk_cleanup_queue-and-timeo.patch.
- Refresh
  patches.drivers/block-introduce-blk_mq_tagset_iter.patch.
- Refresh patches.drivers/block-remove-blk_mq_reinit_tagset.patch.
- Refresh patches.drivers/nvme-Remove-unused-headers.patch.
- Refresh patches.drivers/nvme-add-duplicate_connect-option.patch.
- Refresh
  patches.drivers/nvme-add-helper-to-compare-options-to-controller.patch.
- Refresh
  patches.drivers/nvme-allow-controller-RESETTING-to-RECONNECTING-tran.patch.
- Refresh
  patches.drivers/nvme-check-for-a-live-controller-in-nvme_dev_open.patch.
- Refresh
  patches.drivers/nvme-comment-typo-fixed-in-clearing-AER.patch.
- Refresh
  patches.drivers/nvme-consolidate-common-code-from-reset_work.patch.
- Refresh
  patches.drivers/nvme-fc-add-a-dev_loss_tmo-field-to-the-remoteport.patch.
- Refresh
  patches.drivers/nvme-fc-add-dev_loss_tmo-timeout-and-remoteport-resu.patch.
- Refresh
  patches.drivers/nvme-fc-add-support-for-duplicate_connect-option.patch.
- Refresh
  patches.drivers/nvme-fc-add-uevent-for-auto-connect.patch.
- Refresh
  patches.drivers/nvme-fc-avoid-workqueue-flush-stalls.patch.
- Refresh
  patches.drivers/nvme-fc-change-ctlr-state-assignments-during-reset-r.patch.
- Refresh
  patches.drivers/nvme-fc-check-connectivity-before-initiating-reconne.patch.
- Refresh
  patches.drivers/nvme-fc-merge-__nvme_fc_schedule_delete_work-into-__.patch.
- Refresh
  patches.drivers/nvme-fc-remove-NVME_FC_MAX_SEGMENTS.patch.
- Refresh
  patches.drivers/nvme-flush-reset_work-before-safely-continuing-with-.patch.
- Refresh patches.drivers/nvme-get-rid-of-nvme_ctrl_list.patch.
- Refresh patches.drivers/nvme-introduce-nvme_reinit_tagset.patch.
- Refresh
  patches.drivers/nvme-move-controller-deletion-to-common-code.patch.
- Refresh
  patches.drivers/nvme-rdma-Add-debug-message-when-reaches-timeout.patch.
- Refresh
  patches.drivers/nvme-rdma-add-support-for-duplicate_connect-option.patch.
- Refresh
  patches.drivers/nvme-rdma-align-nvme_rdma_device-structure.patch.
- Refresh
  patches.drivers/nvme-rdma-remove-nvme_rdma_remove_ctrl.patch.
- Refresh
  patches.drivers/nvme-rdma-reuse-nvme_delete_ctrl-when-reconnect-atte.patch.
- Refresh patches.drivers/nvme-simplify-nvme_open.patch.
- Refresh
  patches.drivers/nvme-switch-controller-refcounting-to-use-struct-dev.patch.
- Refresh
  patches.drivers/nvme-use-kref_get_unless_zero-in-nvme_find_get_ns.patch.
- Refresh patches.drivers/nvmet-fix-fatal_err_work-deadlock.patch.
  Update Patch-mainline tag.
- commit b021439
* Thu Nov 23 2017 hare@suse.de
- block: cache the partition index in struct block_device
  (FATE#323952, FATE#322506).
- block: add a __disk_get_part helper (FATE#323952, FATE#322506).
- block: reject attempts to allocate more than DISK_MAX_PARTS
  partitions (FATE#323952, FATE#322506).
- raid5: remove a call to get_start_sect (FATE#323952,
  FATE#322506).
- btrfs: index check-integrity state hash by a dev_t (FATE#323952,
  FATE#322506).
- commit f184e50
* Thu Nov 23 2017 tiwai@suse.de
- blacklist.conf: Add an amdgpu blacklist commit (bsc#1051510)
- commit 08272a2
* Thu Nov 23 2017 tiwai@suse.de
- drm/amd/powerplay: initialize a variable before using it
  (bsc#1051510).
- commit c3e3026
* Thu Nov 23 2017 tiwai@suse.de
- Refresh patches.fixes/drm-amdgpu-revert-update-tile-table-for-oland-hainan.patch
  Add the upstream commit information.
- commit 24df947
* Thu Nov 23 2017 tiwai@suse.de
- mmc: sdhci-pci: remove outdated declaration (bsc#1051510).
- mmc: sdhci-pci: Fix default d3_retune for Intel host controllers
  (bsc#1051510).
- staging: rtl8723bs: avoid null pointer dereference on pmlmepriv
  (bsc#1051510).
- rtlwifi: rtl8821ae: Fix HW_VAR_NAV_UPPER operation
  (bsc#1051510).
- PM / devfreq: Fix memory leak when fail to register device
  (bsc#1051510).
- commit 6bc162b
* Thu Nov 23 2017 tiwai@suse.de
- mfd: intel_soc_pmic: Export separate mfd-cell configs for BYT
  and CHT (bsc#1051510).
- Refresh
  patches.drivers/mfd-intel_soc_pmic-Differentiate-between-Bay-and-Che.
- commit 07bf2c4
* Thu Nov 23 2017 tiwai@suse.de
- ASoC: sun8i-codec: Fix left and right channels inversion
  (bsc#1051510).
- ASoC: cs42l56: Fix reset GPIO name in example DT binding
  (bsc#1051510).
- ALSA: usb-audio: support new Amanero Combo384 firmware version
  (bsc#1051510).
- ALSA: timer: Add missing mutex lock for compat ioctls
  (bsc#1051510).
- ALSA: compress: Remove unused variable (bsc#1051510).
- commit 42e54fa
* Thu Nov 23 2017 hare@suse.de
- Move MD RAID patches to ordered section
- Refresh
  patches.drivers/0001-raid5-ppl-check-recovery_offset-when-performing-ppl-.patch.
- Refresh
  patches.drivers/0002-raid5-ppl-don-t-resync-after-rebuild.patch.
- commit eb74fe0
* Thu Nov 23 2017 hare@suse.de
- blk-mq: enable checking two part inflight counts at the same
  time (FATE#323952, FATE#322506).
- blk-mq: provide internal in-flight variant (FATE#323952,
  FATE#322506).
- block: make part_in_flight() take an array of two ints
  (FATE#323952, FATE#322506).
- block: pass in queue to inflight accounting (FATE#323952,
  FATE#322506).
- blk-mq-tag: check for NULL rq when iterating tags (FATE#323952,
  FATE#322506).
- commit 1b31ec9
* Thu Nov 23 2017 jthumshirn@suse.de
- nvme: comment typo fixed in clearing AER (FATE#323952,
  FATE#322506).
- nvme: Remove unused headers (FATE#323952, FATE#322506).
- nvmet: fix fatal_err_work deadlock (FATE#323952, FATE#322506).
- nvme-fc: add dev_loss_tmo timeout and remoteport resume support
  (FATE#323952, FATE#322506).
- nvme: allow controller RESETTING to RECONNECTING transition
  (FATE#323952, FATE#322506).
- nvme-fc: check connectivity before initiating reconnects
  (FATE#323952, FATE#322506).
- nvme-fc: add a dev_loss_tmo field to the remoteport
  (FATE#323952, FATE#322506).
- nvme-fc: change ctlr state assignments during reset/reconnect
  (FATE#323952, FATE#322506).
- nvme: flush reset_work before safely continuing with delete
  operation (FATE#323952, FATE#322506).
- nvme-rdma: reuse nvme_delete_ctrl when reconnect attempts expire
  (FATE#323952, FATE#322506).
- nvme: consolidate common code from ->reset_work (FATE#323952,
  FATE#322506).
- nvme-rdma: remove nvme_rdma_remove_ctrl (FATE#323952,
  FATE#322506).
- nvme: move controller deletion to common code (FATE#323952,
  FATE#322506).
- nvme-fc: merge __nvme_fc_schedule_delete_work into
  __nvme_fc_del_ctrl (FATE#323952, FATE#322506).
- nvme-fc: avoid workqueue flush stalls (FATE#323952,
  FATE#322506).
- nvme-fc: remove NVME_FC_MAX_SEGMENTS (FATE#323952, FATE#322506).
- nvme-fc: add support for duplicate_connect option (FATE#323952,
  FATE#322506).
- nvme-rdma: add support for duplicate_connect option
  (FATE#323952, FATE#322506).
- nvme: add helper to compare options to controller (FATE#323952,
  FATE#322506).
- nvme: add duplicate_connect option (FATE#323952, FATE#322506).
- commit 9578246
* Thu Nov 23 2017 hare@suse.de
- Btrfs: use bio_clone_bioset_partial to simplify DIO submit
  (FATE#323952, FATE#322506).
- Btrfs: new helper btrfs_bio_clone_partial (FATE#323952,
  FATE#322506).
- Btrfs: use bio_clone_fast to clone our bio (FATE#323952,
  FATE#322506).
- commit aef50da
* Thu Nov 23 2017 jthumshirn@suse.de
- nvme: check for a live controller in nvme_dev_open (FATE#323952,
  FATE#322506).
- nvme: get rid of nvme_ctrl_list (FATE#323952, FATE#322506).
- nvme: switch controller refcounting to use struct device
  (FATE#323952, FATE#322506).
- nvme: simplify nvme_open (FATE#323952, FATE#322506).
- nvme: use kref_get_unless_zero in nvme_find_get_ns (FATE#323952,
  FATE#322506).
- nvme-rdma: Add debug message when reaches timeout (FATE#323952,
  FATE#322506).
- nvme-rdma: align nvme_rdma_device structure (FATE#323952,
  FATE#322506).
- commit 8f38e6b
* Thu Nov 23 2017 jthumshirn@suse.de
- block: Fix a race between blk_cleanup_queue() and timeout
  handling (FATE#323952, FATE#322506).
- block: introduce blk_mq_tagset_iter (FATE#323952, FATE#322506).
- block: remove blk_mq_reinit_tagset (FATE#323952, FATE#322506).
- nvme-fc: add uevent for auto-connect (FATE#323952, FATE#322506).
- nvme: introduce nvme_reinit_tagset (FATE#323952, FATE#322506).
- Refresh
  patches.drivers/nvme-fc-move-remote-port-get-put-free-location.patch.
- Refresh patches.suse/blk-timeout-no-round.
- commit 990148a
* Thu Nov 23 2017 jthumshirn@suse.de
- nvme: Fix setting logical block format when revalidating
  (FATE#323952, FATE#322506).
- nvme-fc: fix iowait hang (FATE#323952, FATE#322506).
- nvme-fc: retry initial controller connections 3 times
  (FATE#323952, FATE#322506).
- nvme-pci: Use PCI bus address for data/queues in CMB
  (FATE#323952, FATE#322506).
- nvme-rdma: Fix error status return in tagset allocation failure
  (FATE#323952, FATE#322506).
- nvme-rdma: Fix possible double free in reconnect flow
  (FATE#323952, FATE#322506).
- nvme-rdma: fix possible hang when issuing commands during ctrl
  removal (FATE#323952, FATE#322506).
- nvmet: synchronize sqhd update (FATE#323952, FATE#322506).
- Refresh
  patches.drivers/nvme-rdma-change-queue-flag-semantics-DELETING-ALLOC.patch.
- commit 4b99674
* Thu Nov 23 2017 mgorman@suse.de
- Update
  patches.suse/cpufreq-intel_pstate-use-setpoint-of-40-on-servers.patch
  (bnc#945201,bnc#1064414).
  Update
  patches.suse/cpufreq-ondemand-set-default-up_threshold-to-40-on-multi-core-systems.patch
  (bnc#945201,bnc#1064414).
- commit 4ef8315
* Wed Nov 22 2017 jack@suse.cz
- fs, dax: unify IOMAP_F_DIRTY read vs write handling policy in
  the dax core (fate#322879).
- xfs: support for synchronous DAX faults (fate#322879).
- xfs: Implement xfs_filemap_pfn_mkwrite() using
  __xfs_filemap_fault() (fate#322879).
- ext4: Support for synchronous DAX faults (fate#322879).
- ext4: Simplify error handling in ext4_dax_huge_fault()
  (fate#322879).
- dax: Implement dax_finish_sync_fault() (fate#322879).
- dax, iomap: Add support for synchronous faults (fate#322879).
- mm: Define MAP_SYNC and VM_SYNC flags (fate#322879).
- dax: Allow tuning whether dax_insert_mapping_entry() dirties
  entry (fate#322879).
- dax: Allow dax_iomap_fault() to return pfn (fate#322879).
- dax: Fix comment describing dax_iomap_fault() (fate#322879).
- dax: Inline dax_pmd_insert_mapping() into the callsite
  (fate#322879).
- dax: Inline dax_insert_mapping() into the callsite
  (fate#322879).
- dax: Create local variable for vmf->flags & FAULT_FLAG_WRITE
  test (fate#322879).
- dax: Create local variable for VMA in dax_iomap_pte_fault()
  (fate#322879).
- dax: Factor out getting of pfn out of iomap (fate#322879).
- dax: Simplify arguments of dax_insert_mapping() (fate#322879).
- mm: Remove VM_FAULT_HWPOISON_LARGE_MASK (fate#322879).
- mm: introduce MAP_SHARED_VALIDATE, a mechanism to safely define
  new mmap flags (fate#322879).
- mm: Handle 0 flags in _calc_vm_trans() macro (fate#322879).
- ext4: perform dax_device lookup at mount (fate#322879).
- ext2: perform dax_device lookup at mount (fate#322879).
- xfs: perform dax_device lookup at mount (fate#322879).
- dax: introduce a fs_dax_get_by_bdev() helper (fate#322879).
- ext4: fix fault handling when mounted with -o dax,ro
  (fate#322879).
- xfs: consolidate the various page fault handlers (fate#322879).
- iomap: return VM_FAULT_* codes from iomap_page_mkwrite
  (fate#322879).
- commit 4b7d25c
* Wed Nov 22 2017 jkosina@suse.cz
- Update config files: enable KASLR for x86_64 (FATE#323473)
- commit a75287b
* Wed Nov 22 2017 hare@suse.de
- scsi: megaraid_sas: driver version upgrade
  (bsc#1066909,FATE#322937).
- scsi: megaraid_sas: Add support for 64bit consistent DMA
  (bsc#1066909,FATE#322937).
- scsi: megaraid_sas: Do not limit queue_depth to 1k in non-RDPQ
  mode (bsc#1066909,FATE#322937).
- scsi: megaraid_sas: Retry with reduced queue depth when alloc
  fails for higher QD (bsc#1066909,FATE#322937).
- scsi: megaraid_sas: Incorrect processing of IOCTL frames for
  SMP/STP commands (bsc#1066909,FATE#322937).
- scsi: megaraid_sas: Resize MFA frame used for IOC INIT to 4k
  (bsc#1066909,FATE#322937).
- scsi: megaraid_sas: Update current host time to FW during IOC
  Init (bsc#1066909,FATE#322937).
- scsi: megaraid_sas: Move controller memory allocations
  and DMA mask settings from probe to megasas_init_fw
  (bsc#1066909,FATE#322937).
- scsi: megaraid_sas: Move initialization of instance parameters
  inside newly created function megasas_init_ctrl_params
  (bsc#1066909,FATE#322937).
- scsi: megaraid_sas: remove instance->ctrl_info
  (bsc#1066909,FATE#322937).
- scsi: megaraid_sas: Pre-allocate frequently used DMA buffers
  (bsc#1066909,FATE#322937).
- scsi: megaraid_sas: Create separate functions for allocating
  and freeing controller DMA buffers (bsc#1066909,FATE#322937).
- scsi: megaraid_sas: Create separate functions to allocate ctrl
  memory (bsc#1066909,FATE#322937).
- scsi: megaraid_sas: reduce size of fusion_context and use
  kmalloc for allocation (bsc#1066909,FATE#322937).
- scsi: megaraid_sas: replace is_ventura with adapter_type checks
  (bsc#1066909,FATE#322937).
- scsi: megaraid_sas: Remove redundant checks for ctrl_context
  (bsc#1066909,FATE#322937).
- scsi: megaraid_sas: replace instance->ctrl_context checks with
  instance->adapter_type (bsc#1066909,FATE#322937).
- scsi: megaraid_sas: Add support for Crusader controllers
  (bsc#1066909,FATE#322937).
- scsi: megaraid_sas: use adapter_type for all gen controllers
  (bsc#1066909,FATE#322937).
- commit 2b04e3e
* Wed Nov 22 2017 tbogendoerfer@suse.de
- net/mlx5e: Increase Striding RQ minimum size limit to 4
  multi-packet WQEs (bsc#1046303 FATE#322944).
- net/mlx5e: Set page to null in case dma mapping fails
  (bsc#1046303 FATE#322944).
- net/mlx5e: Fix napi poll with zero budget (bsc#1046305
  FATE#322943).
- net/mlx5: Cancel health poll before sending panic teardown
  command (bsc#1046303 FATE#322944).
- net/mlx5: Loop over temp list to release delay events
  (bsc#1046303 FATE#322944).
- net/mlx5e/core/en_fs: fix pointer dereference after free in
  mlx5e_execute_l2_action (bsc#1046305 FATE#322943).
- commit 919ca4c
* Wed Nov 22 2017 hare@suse.de
- s390x/default: Enable CONFIG_TUNE_Z13 (bsc#1067886)
  Update s390x config files.
- commit e68d618
* Wed Nov 22 2017 hare@suse.de
- Fixup s390x zfcpdump build failure (bsc#1066354)
  Refresh patches.drivers/s390-cpu-alternatives.patch.
- commit 2b990ee
* Wed Nov 22 2017 oneukum@suse.com
- net: cdc_ether: fix divide by 0 on bad descriptors (bsc#1067085
  CVE-2017-16649).
- commit 73a409e
* Wed Nov 22 2017 jkosina@suse.cz
- Update config files: INTEL_SOC_PMIC=n for arm/vanilla
- commit c812597
* Wed Nov 22 2017 tiwai@suse.de
- Enable ACP, SI, CIK and USERPTR for amdgpu (bsc#1069343)
- commit 37a7bbc
* Tue Nov 21 2017 jslaby@suse.cz
- objtool: Print top level commands on incorrect usage
  (bnc#1058115).
- x86/unwind: Disable KASAN checking in the ORC unwinder
  (bnc#1058115).
- x86/module: Detect and skip invalid relocations (bnc#1058115).
- objtool: Prevent GCC from merging annotate_unreachable(),
  take 2 (bnc#1058115).
- commit 24f3048
* Tue Nov 21 2017 tiwai@suse.de
- drm/i915/skl+: unify cpp value in WM calculation (FATE#322643
  bsc#1055900).
- drm/i915/skl+: WM calculation don't require height (FATE#322643
  bsc#1055900).
- drm/i915/skl+: Scaling not supported in IF-ID Interlace mode
  (FATE#322643 bsc#1055900).
- drm/i915/skl+: Check for supported plane configuration in
  Interlace mode (FATE#322643 bsc#1055900).
- drm/i915/cnl: Enable wrpll computation for CNL (FATE#322643
  bsc#1055900).
- commit 10cf16b
* Tue Nov 21 2017 tiwai@suse.de
- platform/x86: sony-laptop: Fix error handling in
  sony_nc_setup_rfkill() (bsc#1051510).
- platform/x86: hp-wmi: Fix tablet mode detection for convertibles
  (bsc#1051510).
- platform/x86: fujitsu-laptop: Fix radio LED detection
  (bsc#1051510).
- serial: 8250_fintek: Fix rs485 disablement on invalid ioctl()
  (bsc#1051510).
- mfd: rn5t618: Unregister restart handler on remove
  (bsc#1051510).
- mfd: lpc_ich: Do not touch SPI-NOR write protection bit on
  Haswell/Broadwell (bsc#1051510).
- mfd: intel_soc_pmic: Differentiate between Bay and Cherry
  Trail CRC variants (bsc#1051510).
- mfd: intel_soc_pmic: Select designware i2c-bus driver
  (bsc#1051510).
- media: usbtv: fix brightness and contrast controls
  (bsc#1051510).
- media: omap_vout: Fix a possible null pointer dereference in
  omap_vout_open() (bsc#1051510).
- commit 25e6140
* Tue Nov 21 2017 tiwai@suse.de
- Update blacklist and no-fix tags
  Refreshed:
  patches.drivers/drm-i915-Always-wake-the-device-to-flush-the-GTT
  patches.drivers/drm-i915-bxt-set-min-brightness-from-VBT
- commit e7acd40
* Tue Nov 21 2017 tiwai@suse.de
- drm/tilcdc: Precalculate total frametime in
  tilcdc_crtc_set_mode() (bsc#1051510).
- drm/panel: simple: Fix width and height for Olimex
  LCD-OLinuXino-4.3TS (bsc#1051510).
- drm/panel: simple: Add missing panel_simple_unprepare() calls
  (bsc#1051510).
- drm/i915: Prune the reservation shared fence array
  (bsc#1051510).
- drm/i915: Move init_clock_gating() back to where it was
  (bsc#1051510).
- drm: gma500: fix logic error (bsc#1051510).
- drm: Drop drm_get_link_status_name() (bsc#1051510).
- commit f67acae
* Tue Nov 21 2017 jslaby@suse.cz
- x86/unwind: Make CONFIG_UNWINDER_ORC=y the default in kconfig
  for 64-bit (bnc#1058115).
- Update config files.
- x86/unwind: Rename unwinder config options to
  'CONFIG_UNWINDER_*' (bnc#1058115).
- Refresh patches.suse/0001-orc-mark-it-as-reliable.patch.
- Update config files.
- x86/unwinder: Make CONFIG_UNWINDER_ORC=y the default in the
  64-bit defconfig (bnc#1058115).
- commit b87f785
* Tue Nov 21 2017 jslaby@suse.cz
- x86/stacktrace: Avoid recording save_stack_trace() wrappers
  (bnc#1058115).
- commit d5fd971
* Tue Nov 21 2017 tiwai@suse.de
- ASoC: topology: Fix a potential memory leak in
  'soc_tplg_dapm_widget_denum_create()' (bsc#1051510).
- ASoC: topology: Fix a potential NULL pointer dereference in
  'soc_tplg_dapm_widget_denum_create()' (bsc#1051510).
- ASoC: sun8i-codec: Set the BCLK divider (bsc#1051510).
- ASoC: sun8i-codec: Invert Master / Slave condition
  (bsc#1051510).
- ASoC: samsung: Fix possible double iounmap on s3c24xx driver
  probe failure (bsc#1051510).
- ASoC: samsung: Fix invalid argument when devm_gpiod_get is
  called (bsc#1051510).
- ASoC: rt5665: fix gcc-7 warning (bsc#1051510).
- ASoC: rt5665: Fix uninitialized warning in
  rt5665_i2s_pin_event() (bsc#1051510).
- ASoC: rt5514: fix gcc-7 warning (bsc#1051510).
- ASoC: rsnd: avoid duplicate free_irq() (bsc#1051510).
- ASoC: rockchip: Correct 'dmic-delay' property name
  (bsc#1051510).
- ASoC: mediatek: Fix an error checking code (bsc#1051510).
- ASoC: intel: include linux/module.h as needed (bsc#1051510).
- ASoC: davinci-mcasp: Fix an error handling path in
  'davinci_mcasp_probe()' (bsc#1051510).
- ASoC: codecs: msm8916: fix invalid cast to bool type
  (bsc#1051510).
- commit 4a79751
* Tue Nov 21 2017 jslaby@suse.cz
- Refresh
  patches.suse/0001-objtool-Don-t-report-end-of-section-error-after-an-e.patch.
- Refresh
  patches.suse/0002-x86-head-Remove-confusing-comment.patch.
- Refresh
  patches.suse/0003-x86-head-Remove-unused-bad_address-code.patch.
- Refresh
  patches.suse/0004-x86-head-Fix-head-ELF-function-annotations.patch.
- Refresh
  patches.suse/0005-x86-boot-Annotate-verify_cpu-as-a-callable-function.patch.
- Refresh
  patches.suse/0006-x86-xen-Fix-xen-head-ELF-annotations.patch.
- Refresh
  patches.suse/0007-x86-xen-Add-unwind-hint-annotations.patch.
- Refresh
  patches.suse/0008-x86-head-Add-unwind-hint-annotations.patch.
  Update upstream status.
- commit e207155
* Tue Nov 21 2017 bp@suse.de
- blacklist.conf: no need for 9275b933d409
- commit 18d829a
* Tue Nov 21 2017 jslaby@suse.cz
- Refresh
  patches.suse/0001-futex-futex_wake_op-do-not-fail-on-invalid-op.patch.
  Update upstream status
- commit 915f469
* Tue Nov 21 2017 jslaby@suse.cz
- crypto: x86/chacha20 - satisfy stack validation 2.0
  (bnc#1058115).
- commit e52c6fc
* Tue Nov 21 2017 bp@suse.de
- X86/KVM: Clear encryption attribute when SEV is active
  (bsc#1063068).
- X86/KVM: Decrypt shared per-cpu variables when SEV is active
  (bsc#1063068).
- percpu: Introduce DEFINE_PER_CPU_DECRYPTED (bsc#1063068).
- x86: Add support for changing memory encryption attribute in
  early boot (bsc#1063068).
- x86/io: Unroll string I/O when SEV is active (bsc#1063068).
- x86/boot: Add early boot support when running with SEV active
  (bsc#1063068).
- x86/mm: Add DMA support for SEV memory encryption (bsc#1063068).
- x86/mm, resource: Use PAGE_KERNEL protection for ioremap of
  memory pages (bsc#1063068).
- resource: Provide resource struct in resource walk callback
  (bsc#1063068).
- resource: Consolidate resource walking code (bsc#1063068).
- x86/efi: Access EFI data as encrypted when SEV is active
  (bsc#1063068).
- x86/mm: Include SEV for encryption memory attribute changes
  (bsc#1063068).
- x86/mm: Use encrypted access of boot related data with SEV
  (bsc#1063068).
- x86/realmode: Don't decrypt trampoline area under SEV
  (bsc#1063068).
- x86/mm: Don't attempt to encrypt initrd under SEV (bsc#1063068).
- x86/mm: Add Secure Encrypted Virtualization (SEV) support
  (bsc#1063068).
- Documentation/x86: Add AMD Secure Encrypted Virtualization
  (SEV) description (bsc#1063068).
- commit 4c52764
* Tue Nov 21 2017 jthumshirn@suse.de
- nvme: check for disk before submitting cmd (bsc#1067848).
- commit 3af97e1
* Mon Nov 20 2017 mgorman@suse.de
- cpufreq: intel_pstate: Drop ->get from intel_pstate structure
  (bnc#1068680 Update schedutil and intel_pstate to default to
  load-based policy).
- commit d7b80bc
* Mon Nov 20 2017 mgorman@suse.de
- cpufreq: intel_pstate: report correct CPU frequencies during
  trace (bnc#1068680 Update schedutil and intel_pstate to default
  to load-based policy).
- cpufreq: schedutil: Fix sugov_start() versus
  sugov_update_shared() race (bnc#1068680 Update schedutil and
  intel_pstate to default to load-based policy).
- cpuidle: menu: allow state 0 to be disabled (bnc#1068680 Update
  schedutil and intel_pstate to default to load-based policy).
- cpufreq: intel_pstate: Fix ratio setting for min_perf_pct
  (bnc#1068680 Update schedutil and intel_pstate to default to
  load-based policy).
- cpufreq: intel_pstate: constify attribute_group structures
  (bnc#1068680 Update schedutil and intel_pstate to default to
  load-based policy).
- cpufreq: intel_pstate: Clean up after performance governor
  changes (bnc#1068680 Update schedutil and intel_pstate to
  default to load-based policy).
- intel_pstate: skip scheduler hook when in "performance" mode
  (bnc#1068680 Update schedutil and intel_pstate to default to
  load-based policy).
- intel_pstate: delete scheduler hook in HWP mode (bnc#1068680
  Update schedutil and intel_pstate to default to load-based
  policy).
- cpufreq: intel_pstate: Remove max/min fractions to limit
  performance (bnc#1068680 Update schedutil and intel_pstate to
  default to load-based policy).
- intel_pstate: use updated msr-index.h HWP.EPP values
  (bnc#1068680 Update schedutil and intel_pstate to default to
  load-based policy).
- commit 5cdc1ae
* Mon Nov 20 2017 mhocko@suse.com
- mm/page_ext.c: check if page_ext is not prepared (bnc#1068982).
- commit ee8873e
* Mon Nov 20 2017 mgorman@suse.de
- x86: msr-index.h: fix shifts to ULL results in HWP macros
  (bnc#1068680 Update schedutil and intel_pstate to default to
  load-based policy).
- x86: msr-index.h: define HWP.EPP values (bnc#1068680 Update
  schedutil and intel_pstate to default to load-based policy).
- x86: msr-index.h: define EPB mid-points (bnc#1068680 Update
  schedutil and intel_pstate to default to load-based policy).
- commit d4d2ce6
* Mon Nov 20 2017 jeffm@suse.com
- ext4: in ext4_seek_{hole,data}, return -ENXIO for negative
  offsets (bsc#1068897).
- commit b65087c
* Mon Nov 20 2017 mhocko@suse.com
- mm/page_alloc.c: broken deferred calculation (bnc#1068980).
- commit eef6b44
* Mon Nov 20 2017 jthumshirn@suse.de
- PCI: vmd: Free up IRQs on suspend path (bsc#1067483).
- commit 8be6133
* Mon Nov 20 2017 hare@suse.de
- KVM: s390: Fix KVM_S390_GET_CMMA_BITS ioctl definition
  (LTC#160419,bsc#1066194).
- commit a777801
* Mon Nov 20 2017 hare@suse.de
- Update s390x config files.
- commit ba626f1
* Mon Nov 20 2017 mhocko@suse.com
- mm, sparse: do not swamp log with huge vmemmap allocation
  failures (bnc#1040797).
- commit d6d0c93
* Mon Nov 20 2017 mhocko@suse.com
- mm, memory_hotplug: remove timeout from __offline_memory
  (bnc#1051406).
- mm, memory_hotplug: do not fail offlining too early
  (bnc#1051406).
- mm, page_alloc: fail has_unmovable_pages when seeing reserved
  pages (bnc#1051406).
- mm: distinguish CMA and MOVABLE isolation in
  has_unmovable_pages() (bnc#1051406).
- commit e2cd981
* Mon Nov 20 2017 yousaf.kaukab@suse.com
- drm: bridge: synopsys/dw-hdmi: Provide default configuration
  function for HDMI 2.0 PHY (fate#323912).
- commit 97f9ebc
* Mon Nov 20 2017 bp@suse.de
- x86/MCE/AMD: Always give panic severity for UC errors in kernel
  context (git-fixes bf80bbd7dcf5).
- commit af09f69
* Mon Nov 20 2017 bp@suse.de
- x86/intel_rdt: Initialize bitmask of shareable resource if CDP enabled (git-fixes 0dd2d7494cd8).
- blacklist.conf: 3916a4135c696fa226a1abe6d6a0ff7f5edd9a7c and
  ac5292e9a294618cecb31109d1ba265e3d027ba2
- commit 7d8d364
* Mon Nov 20 2017 hare@suse.de
- s390/noexec: execute kexec datamover without DAT (bnc#1066799, LTC#161403).
- commit 7dec3bf
* Mon Nov 20 2017 hare@suse.de
- scsi: zfcp: fix erp_action use-before-initialize in REC action
  trace (bnc#1066983, LTC#160081).
- s390/cputime: fix guest/irq/softirq times after CPU hotplug
  (bnc#1066983, LTC#161328).
- commit f168a73
* Mon Nov 20 2017 hare@suse.de
- s390/topology: enable / disable topology dynamically
  (bnc#1066983, LTC#159177).
- s390/topology: alternative topology for topology-less machines
  (bnc#1066983, LTC#159177).
- s390/mm: fix write access check in gup_huge_pmd() (bnc#1066983,
  LTC#160551).
- scsi: zfcp: trace high part of "new" 64 bit SCSI LUN
  (bnc#1066983, LTC#158495).
- scsi: zfcp: trace HBA FSF response by default on dismiss or
  timedout late response (bnc#1066983, LTC#158494).
- scsi: zfcp: fix payload with full FCP_RSP IU in SCSI trace
  records (bnc#1066983, LTC#158494).
- scsi: zfcp: fix missing trace records for early returns in
  TMF eh handlers (bnc#1066983, LTC#158494).
- scsi: zfcp: fix passing fsf_req to SCSI trace on TMF to
  correlate with HBA (bnc#1066983, LTC#158494).
- scsi: zfcp: fix capping of unsuccessful GPN_FT SAN response
  trace records (bnc#1066983, LTC#158494).
- scsi: zfcp: fix queuecommand for scsi_eh commands when DIX
  enabled (bnc#1066983, LTC#158493).
- s390/vmcp: make use of contiguous memory allocator (bnc#1066983,
  LTC#159171).
- s390/cpcmd,vmcp: avoid GFP_DMA allocations (bnc#1066983,
  LTC#159112).
- s390/mm: prevent memory offline for memory blocks with cma areas
  (bnc#1066983, LTC#159171).
- s390/mm: add missing virt_to_pfn() etc. helper functions
  (bnc#1066983, LTC#159171).
- s390/pci: recognize name clashes with uids (bnc#1066983,
  LTC#157731).
- s390/pci: provide more debug information (bnc#1066983,
  LTC#157731).
- s390/pci: fix handling of PEC 306 (bnc#1066983, LTC#157731).
- s390/pci: improve pci hotplug (bnc#1066983, LTC#157731).
- s390/pci: introduce clp_get_state (bnc#1066983, LTC#157731).
- s390/pci: improve error handling during fmb (de)registration
  (bnc#1066983, LTC#157731).
- s390/pci: improve unreg_ioat error handling (bnc#1066983,
  LTC#157731).
- s390/pci: improve error handling during interrupt deregistration
  (bnc#1066983, LTC#157731).
- s390/pci: don't cleanup in arch_setup_msi_irqs (bnc#1066983,
  LTC#157731).
- commit 187b6e4
* Mon Nov 20 2017 hare@suse.de
- s390/spinlock: use cpu alternatives to enable niai instruction
  (FATE#322614,LTC#160173,bsc#1066354).
- commit 2099d05
* Mon Nov 20 2017 hare@suse.de
- s390: introduce CPU alternatives
  (FATE#322614,LTC#160173,bsc#1066354).
- commit c544efd
* Mon Nov 20 2017 hare@suse.de
- s390/spinlock: add niai spinlock hints
  (FATE#322614,LTC#160173,bsc#1066354).
- commit 670388a
* Mon Nov 20 2017 hare@suse.de
- Refresh patch header to reflect mainline status
- Refresh
  patches.drivers/0001-scsi-be2iscsi-fix-boot-flags-in-sysfs.
- Refresh
  patches.drivers/0002-scsi-be2iscsi-fix-return-value-in-mgmt_open_connection.
- Refresh
  patches.drivers/0003-scsi-be2iscsi-free-msi_name-and-disable-hw-intr.
- Refresh
  patches.drivers/0004-scsi-be2iscsi-fix-modify_eq_delay-buffer-overflow.
- Refresh
  patches.drivers/0005-scsi-be2iscsi-fix-get_initname-buffer-overflow.
- Refresh
  patches.drivers/0006-scsi-be2iscsi-modify-ioctl-to-fetch-user-configured-iqn.
- Refresh
  patches.drivers/0007-scsi-be2iscsi-add-cmd-to-set-host-data.
- Refresh
  patches.drivers/0008-scsi-be2iscsi-fix-misc-static-analysis-errors.
- Refresh
  patches.drivers/0009-scsi-be2iscsi-remove-a-circumflex-character-in-copyright-marking.
- Refresh
  patches.drivers/0010-scsi-be2iscsi-update-driver-version.
- Refresh
  patches.drivers/IB-Move-PCI-dependency-from-root-KConfig-to-HW-s-KCo.patch.
- Refresh
  patches.drivers/RDMA-qedr-Add-iWARP-connection-management-functions.patch.
- Refresh
  patches.drivers/RDMA-qedr-Add-iWARP-connection-management-qp-related.patch.
- Refresh
  patches.drivers/RDMA-qedr-Add-iWARP-support-in-existing-verbs.patch.
- Refresh
  patches.drivers/RDMA-qedr-Add-support-for-iWARP-in-user-space.patch.
- Refresh
  patches.drivers/RDMA-qedr-Add-support-for-read-with-invalidate-suppo.patch.
- Refresh
  patches.drivers/RDMA-qedr-Add-support-for-registering-an-iWARP-devic.patch.
- Refresh
  patches.drivers/RDMA-qedr-Fix-rdma_type-initialization.patch.
- Refresh
  patches.drivers/RDMA-qedr-Missing-error-code-in-qedr_init_user_queue.patch.
- Refresh
  patches.drivers/RDMA-qedr-Rename-the-qedr_cm-file-as-a-preparation-f.patch.
- Refresh
  patches.drivers/RDMA-qedr-fix-build-error-without-ipv6.patch.
- Refresh
  patches.drivers/i40e-add-private-flag-to-control-source-pruning.patch.
- Refresh patches.drivers/ibmvnic-113-Set-state-UP.patch.
- Refresh
  patches.drivers/ibmvnic-115-Enable-scatter-gather-support.patch.
- Refresh patches.drivers/ibmvnic-116-Enable-TSO-support.patch.
- Refresh
  patches.drivers/ibmvnic-117-Let-users-change-net-device-features.patch.
- Refresh
  patches.drivers/ibmvnic-118-Update-reset-infrastructure-to-support-tunab.patch.
- Refresh
  patches.drivers/ibmvnic-119-Fix-failover-error-path-for-non-fatal-resets.patch.
- Refresh
  patches.drivers/nvme-fabrics-request-transport-module.patch.
- Refresh
  patches.drivers/nvme-fc-Add-BLK_MQ_F_NO_SCHED-flag-to-admin-tag-set.patch.
- Refresh
  patches.drivers/nvme-fc-correct-io-termination-handling.patch.
- Refresh
  patches.drivers/nvme-fc-correct-io-timeout-behavior.patch.
- Refresh
  patches.drivers/nvme-fc-create-fc-class-and-transport-device.patch.
- Refresh
  patches.drivers/nvme-fc-move-remote-port-get-put-free-location.patch.
- Refresh
  patches.drivers/nvme-loop-Add-BLK_MQ_F_NO_SCHED-flag-to-admin-tag-se.patch.
- Refresh patches.drivers/nvme-pci-add-SGL-support.patch.
- Refresh patches.drivers/nvme-pci-fix-typos-in-comments.patch.
- Refresh
  patches.drivers/nvme-rdma-Add-BLK_MQ_F_NO_SCHED-flag-to-admin-tag-se.patch.
- Refresh
  patches.drivers/nvme-rdma-Check-that-reinit_request-got-a-proper-mr.patch.
- Refresh
  patches.drivers/nvme-rdma-Don-t-local-invalidate-if-the-queue-is-not.patch.
- Refresh
  patches.drivers/nvme-rdma-change-queue-flag-semantics-DELETING-ALLOC.patch.
- Refresh
  patches.drivers/nvme-rdma-fix-wrong-logging-message.patch.
- Refresh
  patches.drivers/nvme-rdma-move-assignment-to-declaration.patch.
- Refresh
  patches.drivers/nvme-rdma-pass-tagset-to-directly-nvme_rdma_free_tag.patch.
- Refresh
  patches.drivers/nvme-rdma-stop-controller-reset-if-the-controller-is.patch.
- Refresh
  patches.drivers/nvme-rdma-teardown-admin-io-queues-once-on-error-rec.patch.
- Refresh
  patches.drivers/nvme-simplify-compat_ioctl-handling.patch.
- Refresh
  patches.drivers/nvme-update-timeout-module-parameter-type.patch.
- Refresh
  patches.drivers/nvme-use-ida_simple_-get-remove-for-the-controller-i.patch.
- Refresh patches.drivers/nvme-use-menu-Kconfig-interface.patch.
- Refresh
  patches.drivers/nvmet-Change-max_nsid-in-subsystem-due-to-ns_disable.patch.
- Refresh patches.drivers/nvmet-bump-NVMET_NR_QUEUES-to-128.patch.
- Refresh
  patches.drivers/s390-qeth-add-VNICC-enable-disable-support.patch.
- Refresh
  patches.drivers/s390-qeth-add-VNICC-get-set-timeout-support.patch.
- Refresh patches.drivers/s390-qeth-add-basic-VNICC-support.patch.
- Refresh
  patches.drivers/scsi-lpfc-Cocci-spatch-pool_zalloc-simple.patch.
- Refresh
  patches.drivers/scsi-lpfc-Disable-NPIV-support-if-NVME-is-enabled.patch.
- Refresh
  patches.drivers/scsi-lpfc-Ensure-io-aborts-interlocked-with-the-targ.patch.
- Refresh patches.drivers/scsi-lpfc-Extend-RDP-support.patch.
- Refresh
  patches.drivers/scsi-lpfc-Fix-FCP-hba_wqidx-assignment.patch.
- Refresh
  patches.drivers/scsi-lpfc-Fix-crash-in-lpfc_nvme_fcp_io_submit-durin.patch.
- Refresh
  patches.drivers/scsi-lpfc-Fix-crash-receiving-ELS-while-detaching-dr.patch.
- Refresh
  patches.drivers/scsi-lpfc-Fix-lpfc-nvme-host-rejecting-IO-with-Not-R.patch.
- Refresh
  patches.drivers/scsi-lpfc-Fix-oops-if-nvmet_fc_register_targetport-f.patch.
- Refresh
  patches.drivers/scsi-lpfc-Fix-oops-of-nvme-host-during-driver-unload.patch.
- Refresh
  patches.drivers/scsi-lpfc-Fix-secure-firmware-updates.patch.
- Refresh
  patches.drivers/scsi-lpfc-Fix-warning-messages-when-NVME_TARGET_FC-n.patch.
- Refresh
  patches.drivers/scsi-lpfc-Make-ktime-sampling-more-accurate.patch.
- Refresh
  patches.drivers/scsi-lpfc-Move-CQ-processing-to-a-soft-IRQ.patch.
- Refresh
  patches.drivers/scsi-lpfc-PLOGI-failures-during-NPIV-testing.patch.
- Refresh
  patches.drivers/scsi-lpfc-Reduce-log-spew-on-controller-reconnects.patch.
- Refresh
  patches.drivers/scsi-lpfc-Revise-NVME-module-parameter-descriptions-.patch.
- Refresh
  patches.drivers/scsi-lpfc-Set-missing-abort-context.patch.
- Refresh
  patches.drivers/scsi-lpfc-change-version-to-11.4.0.4.patch.
- Refresh
  patches.drivers/scsi-lpfc-correct-nvme-sg-segment-count-check.patch.
- Refresh
  patches.drivers/scsi-lpfc-fix-pci-hot-plug-crash-in-list_add-call.patch.
- Refresh
  patches.drivers/scsi-lpfc-fix-pci-hot-plug-crash-in-timer-management.patch.
- Refresh
  patches.drivers/scsi-lpfc-remove-redundant-null-check-on-eqe.patch.
- Refresh
  patches.drivers/scsi-mpt3sas-Adding-support-for-SAS3616-HBA-device.patch.
- Refresh
  patches.drivers/scsi-mpt3sas-Bump-mpt3sas-driver-version-to-v16.100..patch.
- Refresh
  patches.drivers/scsi-mpt3sas-Display-chassis-slot-information-of-the.patch.
- Refresh
  patches.drivers/scsi-mpt3sas-Fix-IO-error-occurs-on-pulling-out-a-dr.patch.
- Refresh
  patches.drivers/scsi-mpt3sas-Fix-possibility-of-using-invalid-Enclos.patch.
- Refresh
  patches.drivers/scsi-mpt3sas-Fix-removal-and-addition-of-vSES-device.patch.
- Refresh
  patches.drivers/scsi-mpt3sas-Fixed-memory-leaks-in-driver.patch.
- Refresh
  patches.drivers/scsi-mpt3sas-Processing-of-Cable-Exception-events.patch.
- Refresh
  patches.drivers/scsi-mpt3sas-Reduce-memory-footprint-in-kdump-kernel.patch.
- Refresh
  patches.drivers/scsi-mpt3sas-Updated-MPI-headers-to-v2.00.48.patch.
- Refresh
  patches.drivers/scsi-mpt3sas-remove-redundant-copy_from_user-in-_ctl.patch.
- Refresh
  patches.drivers/scsi-pm80xx-Different-SAS-addresses-for-phys.patch.
- Refresh
  patches.drivers/scsi-pm80xx-ILA-and-inactive-firmware-version-throug.patch.
- Refresh
  patches.drivers/scsi-pm80xx-cleanup-in-pm8001_abort_task-function.patch.
- Refresh
  patches.drivers/scsi-pm80xx-corrected-SATA-abort-handling-sequence.patch.
- Refresh
  patches.drivers/scsi-pm80xx-corrected-linkrate-value.patch.
- Refresh
  patches.drivers/scsi-pm80xx-modified-port-reset-timer-value-for-PM80.patch.
- Refresh
  patches.drivers/scsi-pm80xx-panic-on-ncq-error-cleaning-up-the-read-.patch.
- Refresh
  patches.drivers/scsi-pm80xx-redefine-sas_identify_frame-structure.patch.
- Refresh
  patches.drivers/scsi-pm80xx-tag-allocation-for-phy-control-request.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Add-ATIO-Q-processing-for-INTx-mode.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Allow-MBC_GET_PORT_DATABASE-to-query-an.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Changes-to-support-N2N-logins.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Cocci-spatch-pool_zalloc-simple.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Query-FC4-type-during-RSCN-processing.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Reinstate-module-parameter-ql2xenablems.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Update-driver-version-to-10.00.00.02-k.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Use-ql2xnvmeenable-to-enable-Q-Pair-for.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-don-t-break-the-bsg-lib-abstractions.patch.
- Refresh
  patches.drivers/scsi-smartpqi-cleanup-raid-map-warning-message.patch.
- Refresh
  patches.drivers/scsi-smartpqi-update-controller-ids.patch.
- Refresh
  patches.drivers/scsi-smartpqi-update-driver-version-to-1.1.2-126.patch.
- commit f976d20
* Mon Nov 20 2017 neilb@suse.com
- autofs: don't fail mount for transient error (bsc#1065180).
- commit f023e91
* Fri Nov 17 2017 tiwai@suse.de
- ASoC: intel: Add headset jack support to cht-cx2072x
  (bsc#1068546).
- ASoC: Intel: add support for CX2072x machine driver
  (bsc#1068546).
- ASoC: Intel: Add machine driver for Cherrytrail-CX2072X
  (bsc#1068546).
- ASoC: add support for Conexant CX2072X CODEC (bsc#1068546).
- ASoC: cx2072x: Add DT bingings documentation for CX2072X CODEC
  (bsc#1068546).
- commit e2196fe
* Fri Nov 17 2017 tiwai@suse.de
- supported.conf: Updated for missing entries (bsc#1066369)
  Also mark old x86-platform ones unsupported
- commit 2e66eed
* Fri Nov 17 2017 tiwai@suse.de
- supported.conf: List up CHT DC TI PMIC and INT0002 VGPIO (bsc#1068546)
- commit 5f4a9b1
* Fri Nov 17 2017 tiwai@suse.de
- blacklist.conf: Add BT commits to be ignored (bsc#1068546)
- commit 2b7fddf
* Fri Nov 17 2017 tiwai@suse.de
- Update config files: Enable Cherrytrail kconfigs (bsc#1068546)
- commit 470e1f9
* Fri Nov 17 2017 tiwai@suse.de
- platform/x86: Add driver for ACPI INT0002 Virtual GPIO device
  (bsc#1068546).
- ASoC: rt5645: Add jack detection workaround for GPD Win
  (bsc#1068546).
- ASoC: rt5645: add inv_jd1_1 flag (bsc#1068546).
- ASoC: rt5645: rename jd_invert flag in platform data
  (bsc#1068546).
- ASoC: rt5645: read jd1_1 status for jd detection (bsc#1068546).
- ACPI / PMIC: Add opregion driver for Intel Dollar Cove TI PMIC
  (bsc#1068546).
- mfd: Add support for Cherry Trail Dollar Cove TI PMIC
  (bsc#1068546).
- brcmfmac: Use separate firmware for revision 0 of the brcm43430
  chip (bsc#1068546).
- Bluetooth: hci_bcm: Add support for BCM2E7E (bsc#1068546).
- mmc: sdhci-acpi: Workaround conflict with PCI wifi on GPD Win
  handheld (bsc#1068546).
- video/console: Update BIOS dates list for GPD win console
  rotation DMI quirk (bsc#1068546).
- video/console: Add new BIOS date for GPD pocket to dmi quirk
  table (bsc#1068546).
- video/console: Add dmi quirk table for x86 systems which need
  fbcon rotation (bsc#1068546).
- ACPI / x86: Extend KIOX000A quirk to cover all affected BIOS
  versions (bsc#1068546).
- ACPI / x86: Add KIOX000A accelerometer on GPD win to
  always_present_ids array (bsc#1068546).
- ACPI / x86: Allow matching always_present_id array entries by
  DMI (bsc#1068546).
- commit 20e1325
* Fri Nov 17 2017 mbrugger@suse.com
- arm64: Update config files and support.conf
  Compile SCSI_HISI_SAS_PCI as a module.
  Mark the driver as not supported.
- commit f6b8981
* Fri Nov 17 2017 mgorman@suse.de
- pcc-cpufreq: Re-introduce deadband effect to reduce number of
  frequency changes (bsc#981838).
- commit 7533cac
* Thu Nov 16 2017 mgorman@suse.de
- Refresh
  patches.suse/mm-only-drain-per-cpu-pagevecs-once-per-pagevec-usage.patch.
- Refresh
  patches.suse/mm-page_alloc-enable-disable-IRQs-once-when-freeing-a-list-of-pages.patch.
- Refresh
  patches.suse/mm-page_alloc-simplify-list-handling-in-rmqueue_bulk.patch.
- Refresh
  patches.suse/mm-pagevec-remove-cold-parameter-for-pagevecs.patch.
- Refresh
  patches.suse/mm-pagevec-rename-pagevec-drained-field.patch.
- Refresh patches.suse/mm-remove-__GFP_COLD.patch.
- Refresh
  patches.suse/mm-remove-cold-parameter-for-release_pages.patch.
- Refresh
  patches.suse/mm-remove-cold-parameter-from-free_hot_cold_page.patch.
- Refresh
  patches.suse/mm-truncate-do-not-check-mapping-for-every-page-being-truncated.patch.
- Refresh
  patches.suse/mm-truncate-remove-all-exceptional-entries-from-pagevec-under-one-lock.patch.
- Delete
  patches.suse/mm-truncate-remove-all-exceptional-entries-from-pagevec-under-one-lock-fix.patch.
- commit b425423
* Wed Nov 15 2017 yousaf.kaukab@suse.com
- PCI: rockchip: Add per-lane PHY support (fate#323912).
- PCI: rockchip: Factor out rockchip_pcie_get_phys()
  (fate#323912).
- commit 42c5487
* Wed Nov 15 2017 mgorman@suse.de
- rcu: Use lockdep to assert IRQs are disabled/enabled
  (bnc#1068202 Avoid irqs_disabled debugging checks in fast
  paths).
- netpoll: Use lockdep to assert IRQs are disabled/enabled
  (bnc#1068202 Avoid irqs_disabled debugging checks in fast
  paths).
- timers/posix-cpu-timers: Use lockdep to assert IRQs are
  disabled/enabled (bnc#1068202 Avoid irqs_disabled debugging
  checks in fast paths).
- sched/clock, sched/cputime: Use lockdep to assert IRQs are
  disabled/enabled (bnc#1068202 Avoid irqs_disabled debugging
  checks in fast paths).
- irq_work: Use lockdep to assert IRQs are disabled/enabled
  (bnc#1068202 Avoid irqs_disabled debugging checks in fast
  paths).
- perf/core: Use lockdep to assert IRQs are disabled/enabled
  (bnc#1068202 Avoid irqs_disabled debugging checks in fast
  paths).
- x86: Use lockdep to assert IRQs are disabled/enabled
  (bnc#1068202 Avoid irqs_disabled debugging checks in fast
  paths).
- smp/core: Use lockdep to assert IRQs are disabled/enabled
  (bnc#1068202 Avoid irqs_disabled debugging checks in fast
  paths).
- timers/hrtimer: Use lockdep to assert IRQs are disabled/enabled
  (bnc#1068202 Avoid irqs_disabled debugging checks in fast
  paths).
- timers/nohz: Use lockdep to assert IRQs are disabled/enabled
  (bnc#1068202 Avoid irqs_disabled debugging checks in fast
  paths).
- workqueue: Use lockdep to assert IRQs are disabled/enabled
  (bnc#1068202 Avoid irqs_disabled debugging checks in fast
  paths).
- irq/softirqs: Use lockdep to assert IRQs are disabled/enabled
  (bnc#1068202 Avoid irqs_disabled debugging checks in fast
  paths).
- locking/lockdep: Add IRQs disabled/enabled assertion APIs:
  lockdep_assert_irqs_enabled()/disabled() (bnc#1068202 Avoid
  irqs_disabled debugging checks in fast paths).
- sched/idle: Micro-optimize the idle loop (bnc#978907 Scheduler
  performance -- idle).
- commit dc86215
* Wed Nov 15 2017 jkosina@suse.cz
- s390x: Update config files.
- commit fcf3905
* Wed Nov 15 2017 yousaf.kaukab@suse.com
- Update config files.
- supported.conf:
  Enable Rockchip rk3399 drivers
  supported.conf checker reported following missing modules:
  drivers/phy/allwinner/phy-sun4i-usb.ko
  drivers/phy/allwinner/phy-sun9i-usb.ko
  drivers/phy/amlogic/phy-meson8b-usb2.ko
  drivers/phy/broadcom/phy-bcm-ns-usb2.ko
  drivers/phy/broadcom/phy-bcm-ns-usb3.ko
  drivers/phy/broadcom/phy-bcm-ns2-pcie.ko
  drivers/phy/broadcom/phy-brcm-sata.ko
  drivers/phy/hisilicon/phy-hi6220-usb.ko
  drivers/phy/qualcomm/phy-qcom-qmp.ko
  drivers/phy/qualcomm/phy-qcom-qusb2.ko
  drivers/phy/qualcomm/phy-qcom-usb-hs.ko
  drivers/phy/qualcomm/phy-qcom-usb-hsic.ko
  Since this patch has not enabled any of them, adding all of them in
  supported.conf with '-' as they were never marked as supported.
- commit 3664826
* Wed Nov 15 2017 yousaf.kaukab@suse.com
- lib/mpi: call cond_resched() from mpi_powm() loop (bsc#1066688).
- commit 35d6a4a
* Wed Nov 15 2017 yousaf.kaukab@suse.com
- iommu/rockchip: ignore isp mmu reset operation (fate#323912).
- commit 59a5545
* Wed Nov 15 2017 yousaf.kaukab@suse.com
- iommu/rockchip: add multi irqs support (fate#323912).
- iommu/rockchip: Enable Rockchip IOMMU on ARM64 (fate#323912).
- drm/rockchip: add CONFIG_OF dependency for lvds (fate#323912).
- drm/rockchip: add PINCTRL dependency for LVDS (fate#323912).
- drm/rockchip: Rely on the default best_encoder() behavior
  (fate#323912).
- drm/rockchip: Cocci spatch "vma_pages" (fate#323912).
- drm/rockchip: Fix uninitialized use of ret (fate#323912).
- drm/rockchip: Replace dev_* with DRM_DEV_* (fate#323912).
- drm/rockchip: Add support for Rockchip Soc LVDS (fate#323912).
- drm/rockchip: switch to drm_*_get(), drm_*_put() helpers
  (fate#323912).
- drm/rockchip: Fix suspend crash when drm is not bound
  (fate#323912).
- drm/rockchip: make drm_connector_funcs structures const
  (fate#323912).
- drm/rockchip: fix race with kms hotplug and fbdev (fate#323912).
- drm/rockchip: vop: no need wait vblank on crtc enable
  (fate#323912).
- drm/rockchip: vop: report error when check resource error
  (fate#323912).
- drm/rockchip: vop: round_up pitches to word align (fate#323912).
- drm/rockchip: vop: fix NV12 video display error (fate#323912).
- drm/rockchip: vop: fix iommu page fault when resume
  (fate#323912).
- drm/rockchip: vop: rk3328: fix overlay abnormal (fate#323912).
- drm/rockchip: vop: add a series of vop support (fate#323912).
- drm/rockchip: vop: group vop registers (fate#323912).
- drm/rockchip: vop: move line_flag_num to interrupt registers
  (fate#323912).
- drm/rockchip: vop: move write_relaxed flags to vop register
  (fate#323912).
- drm/rockchip: vop: initialize registers directly (fate#323912).
- drm/rockchip: Use .dumb_map_offset and .dumb_destroy defaults
  (fate#323912).
- drm/rockchip: Use for_each_oldnew_plane_in_state in
  vop_crtc_atomic_flush (fate#323912).
- drm/rockchip: fix NULL check on devm_kzalloc() return value
  (fate#323912).
- drm/rockchip: Drop drm_vblank_cleanup (fate#323912).
- drm/rockchip: dw_hdmi: introduce the pclk for grf (fate#323912).
- drm/rockchip: dw_hdmi: introduce the VPLL clock setting
  (fate#323912).
- drm/rockchip: dw_hdmi: add RK3399 HDMI support (fate#323912).
- drm/rockchip: Remove unnecessary NULL check (fate#323912).
- drm/rockchip: gem: add the lacks lock and trivial changes
  (fate#323912).
- drm/rockchip: use drm_for_each_connector_iter() (fate#323912).
- drm/rockchip: analogix_dp: Remove unused check and variables
  (fate#323912).
- drm/rockchip: Set line flag config register in vop_crtc_enable
  (fate#323912).
- mfd: rk808: Fix up the chip id get failed (fate#323912).
- pwm: rockchip: Use same PWM ops for each IP (fate#323912).
- pwm: rockchip: Move the configuration of polarity (fate#323912).
- pwm: rockchip: Use pwm_apply() instead of pwm_enable()
  (fate#323912).
- pwm: rockchip: Remove the judge from return value of
  pwm_config() (fate#323912).
- pwm: rockchip: Add APB and function both clocks support
  (fate#323912).
- phy: rockchip-typec: Do the calibration more correctly
  (fate#323912).
- phy: rockchip-typec: Avoid magic numbers + add delays in aux
  calib (fate#323912).
- phy: rockchip-typec: Check for errors from tcphy_phy_init()
  (fate#323912).
- phy: rockchip-typec: Don't set the aux voltage swing to 400 mV
  (fate#323912).
- phy: rockchip-typec: Set the AUX channel flip state earlier
  (fate#323912).
- phy: rockchip-pcie: Reconstruct driver to support per-lane PHYs
  (fate#323912).
- phy: rockchip-typec: remove unused dfp variable (fate#323912).
- phy: rockchip-inno-usb2: add support of usb2-phy for rv1108 SoCs
  (fate#323912).
- phy: rockchip-inno-usb2: add support for otg-mux interrupt
  (fate#323912).
- phy: rockchip-inno-usb2: add support for rockchip,usbgrf
  property (fate#323912).
- phy: rockchip-inno-usb2: Replace the extcon API (fate#323912).
- phy: rockchip-inno-usb2: add support of usb2-phy for rk3228 SoCs
  (fate#323912).
- phy: rockchip-inno-usb2: add one phy comprises with two
  host-ports support (fate#323912).
- phy: rockchip-inno-usb2: increase otg sm work first schedule
  time (fate#323912).
- phy: rockchip-inno-usb2: add a delay after phy resume
  (fate#323912).
- phy: Group vendor specific phy drivers (fate#323912).
- phy: Move ULPI phy header out of drivers to include path
  (fate#323912).
- phy: qcom-usb: Remove unused ulpi phy header (fate#323912).
- clk: rockchip: Remove superfluous error message in
  rockchip_clk_register_cpuclk() (fate#323912).
- clk: rockchip: Mark rockchip_fractional_approximation static
  (fate#323912).
- clk: rockchip: add special approximation to fix up fractional
  clk's jitter (fate#323912).
- clk: fractional-divider: allow overriding of approximation
  (fate#323912).
- clk: rockchip: add ids for rk3399 testclks used for camera
  handling (fate#323912).
- clk: rockchip: add dt-binding header for rk3128 (fate#323912).
- clk: rockchip: add ids for camera on rk3399 (fate#323912).
- spi: rockchip: configure CTRLR1 according to size and data frame
  (fate#323912).
- spi: rockchip: Fix clock handling in suspend/resume
  (fate#323912).
- spi: rockchip: Fix clock handling in remove (fate#323912).
- spi: rockchip: Slightly rework return value handling
  (fate#323912).
- spi: rockchip: Disable Runtime PM when chip select is asserted
  (fate#323912).
- spi: rockchip: Set GPIO_SS flag to enable Slave Select with
  GPIO CS (fate#323912).
- spi: rockchip: fix error handling when probe (fate#323912).
- pinctrl: rockchip: Fix the rk3399 gpio0 and gpio1 banks'
  drv_offset at pmu grf (fate#323912).
- pinctrl: rockchip: Use common interface for recalced iomux
  (fate#323912).
- pinctrl: rockchip: Add iomux-route switching support for rk3399
  (fate#323912).
- pinctrl: rockchip: Add iomux-route switching support for rk3328
  (fate#323912).
- pinctrl: rockchip: Add iomux-route switching support for rk3228
  (fate#323912).
- pinctrl: rockchip: Add iomux-route switching support
  (fate#323912).
- pinctrl: rockchip: remove unneeded (void *) casts in
  of_match_table (fate#323912).
- clocksource/drivers/rockchip: pr_err() strings should end with
  newlines (fate#323912).
- iio: adc: rockchip_saradc: explicitly request exclusive reset
  control (fate#323912).
- iio: adc: rockchip_saradc: add NULL check on of_match_device()
  return value (fate#323912).
- PM / devfreq: rk3399_dmc: fix error return code in
  rk3399_dmcfreq_probe() (fate#323912).
- commit e27a9b1
* Tue Nov 14 2017 tiwai@suse.de
- drm/i915/glk: Add cold boot sequence for GLK DSI (bsc#1067957).
- drm/i915/glk: Split GLK DSI device ready functionality
  (bsc#1067957).
- drm/i915/huc: Update GLK HuC version (bsc#1067957).
- drm/i915/gen9: Reintroduce WaEnableYV12BugFixInHalfSliceChicken7
  (bsc#1067957).
- drm/i915/glk: Calculate high/low switch count for GLK
  (bsc#1067957).
- drm/i915/glk: Don't allow 12 bpc when htotal is too big
  (bsc#1067957).
- drm/i915/GLK/HuC: Load HuC on GLK (bsc#1067957).
- drm/i915/GuC/GLK: Load GuC on GLK (bsc#1067957).
- drm/i915/glk: limit pixel clock to 99%% of cdclk workaround
  (bsc#1067957).
- commit f5509cc
* Tue Nov 14 2017 tiwai@suse.de
- drm/i915/glk: Remove the alpha_support flag (bsc#1067957).
- commit 4bae915
* Tue Nov 14 2017 lpechacek@suse.com
- btrfs: use GFP_KERNEL in mount and remount (bsc#1062897).
- commit e1d90be
* Tue Nov 14 2017 jkosina@suse.cz
- Refresh patches.fixes/ext4-add-ext4_should_use_dax.patch: update upstream
  commit reference SHA
- commit f3bb07f
* Tue Nov 14 2017 jkosina@suse.cz
- Refresh
  patches.fixes/ext4-add-sanity-check-for-encryption-DAX.patch: update
  upstream commit reference SHA
- commit db0eb3c
* Tue Nov 14 2017 jkosina@suse.cz
- Refresh
  patches.fixes/ext4-prevent-data-corruption-with-journaling-DAX.patch: update
  upstream commit SHA
- commit 73f86f5
* Tue Nov 14 2017 tiwai@suse.de
- Correct to the updated upstream fix patch (CVE-2017-16647, bsc#1067102)
  Refreshed
  patches.drivers/net-usb-asix-fill-null-ptr-deref-in-asix_suspend.patch
- commit decd96f
* Tue Nov 14 2017 msuchanek@suse.de
- powerpc/pseries/vio: Dispose of virq mapping on vdevice
  unregister (bsc#1067888).
- commit 927b61a
* Mon Nov 13 2017 msuchanek@suse.de
- powerpc/vphn: Fix numa update end-loop bug (FATE#323745,
  bsc#1067906).
- powerpc/hotplug: Improve responsiveness of hotplug change
  (FATE#323745, bsc#1067906).
- powerpc/vphn: Improve recognition of PRRN/VPHN (FATE#323745,
  bsc#1067906).
- powerpc/vphn: Update CPU topology when VPHN enabled
  (FATE#323745, bsc#1067906).
- commit 2e4ca0c
* Mon Nov 13 2017 tiwai@suse.de
- media: rainshadow-cec: avoid -Wmaybe-uninitialized warning again
  (bsc#1051510).
- commit a30769c
* Mon Nov 13 2017 tiwai@suse.de
- blacklist.conf: add media and other commits (bsc#1051510)
- commit e57653b
* Mon Nov 13 2017 tiwai@suse.de
- serial: pch_uart: Make port type explicit (bsc#1051510).
- Refresh
  patches.drivers/serial-fix-port-type-numbering-for-ti-da8xx.
- commit 71e99cb
* Mon Nov 13 2017 tiwai@suse.de
- iio: dummy: events: Add missing break (bsc#1051510).
- Input: ucb1400_ts - fix suspend and resume handling
  (bsc#1051510).
- Input: ti_am335x_tsc - fix incorrect step config for 5 wire
  touchscreen (bsc#1051510).
- i2c: cadance: fix ctrl/addr reg write order (bsc#1051510).
- rtc: sa1100: fix unbalanced
  clk_prepare_enable/clk_disable_unprepare (bsc#1051510).
- cfg80211: honor NL80211_RRF_NO_HT40{MINUS,PLUS} (bsc#1051510).
- serial: 8250_uniphier: fix serial port index in private data
  (bsc#1051510).
- Revert "net: bcmgenet: Remove init parameter from
  bcmgenet_mii_config" (bsc#1051510).
- rtc: rtc-nuc900: fix loop timeout test (bsc#1051510).
- libertas: Fix lbs_prb_rsp_limit_set() (bsc#1051510).
- mmc: mediatek: Fixed size in dma_free_coherent (bsc#1051510).
- Fix serial console on SNI RM400 machines (bsc#1051510).
- media: v4l2-compat-ioctl32: Fix timespec conversion
  (bsc#1051510).
- [media] rainshadow-cec: use strlcat instead of strncat
  (bsc#1051510).
- [media] rainshadow-cec: avoid -Wmaybe-uninitialized warning
  (bsc#1051510).
- [media] mceusb: fix memory leaks in error path (bsc#1051510).
- media: em28xx: calculate left volume level correctly
  (bsc#1051510).
- media: devnode: Rename mdev argument as devnode (bsc#1051510).
- media: au0828: fix RC_CORE dependency (bsc#1051510).
- media: Revert "[media] et8ek8: Export OF device ID as module
  aliases" (bsc#1051510).
- gpu: ipu-v3: add DRM dependency (bsc#1051510).
- gpu: host1x: Free the IOMMU domain when there is no device to
  attach (bsc#1051510).
- gpu: host1x: Don't fail on NULL bo physical address
  (bsc#1051510).
- drm: rcar-du: Use the VBK interrupt for vblank events
  (bsc#1051510).
- commit 26cdc26
* Mon Nov 13 2017 tiwai@suse.de
- Refresh patch-mainline tag:
  patches.drivers/net-usb-asix-fill-null-ptr-deref-in-asix_suspend.patch.
- commit c4c86fe
* Mon Nov 13 2017 tiwai@suse.de
- ALSA: line6: Fix missing initialization before error path
  (bsc#1052235).
- ALSA: line6: Fix leftover URB at error-path during probe
  (bsc#1052235).
- ALSA: line6: Fix NULL dereference at podhd_disconnect()
  (bsc#1052235).
- commit b480beb
* Mon Nov 13 2017 tiwai@suse.de
- Fix the logic error in mgag200 patch (bsc#1066589)
  Refreshed
  patches.drivers/drm-mgag200-Add-mode-validation-debugging-code.patch.
- commit 507c2b5
* Mon Nov 13 2017 mhocko@suse.com
- blacklist.conf: blacklist a872eb2131e9 (bnc#1066602)
- commit c02d5e2
* Mon Nov 13 2017 oneukum@suse.com
- net: qmi_wwan: fix divide by 0 on bad descriptors (bsc#1067086
  CVE-2017-16650).
- commit 2135e29
* Mon Nov 13 2017 bp@suse.de
- x86/smpboot: Make optimization of delay calibration work
  correctly (git-fixes).
- commit cb9a8c3
* Fri Nov 10 2017 dbueso@suse.de
- locking/pvqspinlock: Implement hybrid PV queued/unfair locks
  (bsc#1050549).
- futex: Fix more put_pi_state() vs. exit_pi_state_list() races
  (bsc#1067665).
- futex: Fix pi_state->owner serialization (bsc#1067665).
- commit df2923d
* Thu Nov  9 2017 tiwai@suse.de
- blacklist.conf: Add drm/vgmem blacklist patch (bsc#1051510)
- commit a526463
* Thu Nov  9 2017 tiwai@suse.de
- drm/crc: Only open CRC on atomic drivers when the CRTC is active
  (bsc#1051510).
- drm/vc4: Don't disable DSI clocks on component unload
  (bsc#1051510).
- drm/vc4: Fix leak of HDMI EDID (bsc#1051510).
- drm/i915: Hold rcu_read_lock when iterating over the radixtree
  (objects) (bsc#1051510).
- commit 34fddd9
* Thu Nov  9 2017 bpoirier@suse.com
- Update some Git-repo tags according to most recent upstream status.
- Refresh
  patches.arch/KVM-PPC-Book3S-0005-Fix-server-always-zero-from-kvmppc_xi.patch.
- Refresh patches.arch/cxl-Fix-memory-page-not-handled.patch.
- Refresh
  patches.arch/perf-pmu-events-support-additional-power8-pvr-in-mapfile.patch.
- Refresh
  patches.arch/perf-vendor-events-add-power9-pmu-events.patch.
- Refresh
  patches.arch/perf-vendor-events-add-power9-pvrs-to-mapfile.patch.
- Refresh
  patches.arch/perf-vendor-events-powerpc-remove-suffix-in-mapfile.patch.
- Refresh
  patches.arch/perf-vendor-events-powerpc-update-power9-events.patch.
- Refresh
  patches.arch/powerpc-Fix-action-argument-for-cpufeatures-based-TLB-flush.patch.
- Refresh
  patches.arch/powerpc-Fix-workaround-for-spurious-MCE-on-POWER9.patch.
- Refresh
  patches.arch/powerpc-Handle-MCE-on-POWER9-with-only-DSISR-bit-30-set.patch.
- Refresh
  patches.arch/powerpc-mm-radix-Avoid-flushing-the-PWC-on-every-flush_tlb_range.patch.
- Refresh
  patches.arch/powerpc-mm-radix-Improve-TLB-PWC-flushes.patch.
- Refresh
  patches.arch/powerpc-mm-radix-Improve-_tlbiel_pid-to-be-usable-for-PWC-flushes.patch.
- Refresh
  patches.arch/powerpc-perf-Cleanup-of-PM_BR_CMPL-vs.-PM_BRU_CMPL-in-Power9-event-list.patch.
- Refresh
  patches.arch/powerpc-perf-Update-default-sdar_mode-value-for-power9.patch.
- Refresh
  patches.arch/powerpc-perf-add-core-imc-pmu-support.patch.
- Refresh
  patches.arch/powerpc-perf-add-nest-imc-pmu-support.patch.
- Refresh
  patches.arch/powerpc-perf-add-thread-imc-pmu-support.patch.
- Refresh
  patches.arch/powerpc-perf-fix-double-unlock-in-imc_common_cpuhp_mem_free.patch.
- Refresh
  patches.arch/powerpc-perf-fix-usage-of-nest_imc_refc.patch.
- Refresh
  patches.arch/powerpc-perf-imc-fix-nest-events-on-muti-socket-system.patch.
- Refresh
  patches.arch/powerpc-xive-04-Ensure-active-irqd-when-setting-affinit.patch.
- Refresh
  patches.arch/powerpc-xive-05-Fix-section-mismatch-warnings.patch.
- Refresh
  patches.arch/powerpc-xive-06-Fix-the-size-of-the-cpumask-used-in-xive_find_target_in_mask.patch.
- Refresh
  patches.arch/powerpc-xive-07-powerpc-xmon-Exclude-all-of-xmon-from-ftrace.patch.
- Refresh
  patches.arch/powerpc-xive-08-introduce-a-common-routine-xive_queue_p.patch.
- Refresh
  patches.arch/powerpc-xive-09-guest-exploitation-of-the-XIVE-interrup.patch.
- Refresh
  patches.arch/powerpc-xive-10-rename-xive_poke_esb-in-xive_esb_read.patch.
- Refresh
  patches.arch/powerpc-xive-11-introduce-xive_esb_write.patch.
- Refresh
  patches.arch/powerpc-xive-12-add-the-HW-IRQ-number-under-xive_irq_da.patch.
- Refresh
  patches.arch/powerpc-xive-13-introduce-H_INT_ESB-hcall.patch.
- Refresh
  patches.arch/powerpc-xive-14-add-XIVE-Exploitation-Mode-to-CAS.patch.
- Refresh
  patches.arch/powerpc-xive-15-improve-debugging-macros.patch.
- Refresh
  patches.arch/powerpc-xive-16-Fix-section-__init-warning.patch.
- Refresh patches.arch/powerpc-xive-18-Fix-IPI-reset.patch.
- Refresh
  patches.arch/powerpc-xive-19-Clear-XIVE-internal-structures-when-a-C.patch.
- Refresh
  patches.drivers/0001-acpica-iort-Update-SMMU-models-for-IORT-rev.-C.patch.
- Refresh
  patches.drivers/0001-ata-ceva-Move-sata-port-phy-oob-settings-to-device-t.patch.
- Refresh
  patches.drivers/0002-ata-ceva-Add-gen-3-mode-support-in-driver.patch.
- Refresh
  patches.drivers/0002-tty-xilinx_uartps-move-to-arch_initcall-for-earlier-.patch.
- Refresh
  patches.drivers/0003-ata-ceva-Disable-Device-Sleep-capability.patch.
- Refresh
  patches.drivers/0004-ata-ceva-Make-RxWaterMark-value-as-module-parameter.patch.
- Refresh
  patches.drivers/0005-ata-ceva-Add-CCI-support-for-SATA-if-CCI-is-enabled.patch.
- Refresh
  patches.drivers/0006-ata-ceva-Correct-the-AXI-bus-configuration-for-SATA-.patch.
- Refresh
  patches.drivers/0007-ata-ceva-Correct-the-suspend-and-resume-logic-for-SA.patch.
- Refresh
  patches.drivers/0008-ata-ceva-Add-SMMU-support-for-SATA-IP.patch.
- Refresh
  patches.drivers/0031-ACPI-APEI-Enable-APEI-multiple-GHES-source-to-share-.patch.
- Refresh
  patches.drivers/05-edac-pnd2-build-in-a-minimal-sideband-driver-for-apollo-lake.patch.
- Refresh
  patches.drivers/06-edac-pnd2-mask-off-the-lower-four-bits-of-a-bar.patch.
- Refresh
  patches.drivers/07-edac-pnd2-conditionally-unhide-hide-the-p2sb-pci-device-to-read-bar.patch.
- Refresh
  patches.drivers/08-edac-pnd2-properly-toggle-hidden-state-for-p2sb-pci-device.patch.
- Refresh
  patches.drivers/ALSA-hda-Abort-capability-probe-at-invalid-register-.
- Refresh
  patches.drivers/ALSA-hda-Implement-mic-mute-LED-mode-enum.
- Refresh
  patches.drivers/ALSA-ice1712-Add-support-for-STAudio-ADCIII.
- Refresh
  patches.drivers/drm-i915-Align-vswing-sequences-with-old-ddi-buffer-.
- Refresh
  patches.drivers/drm-i915-Display-WA-1133-WaFbcSkipSegments-cnl-glk.
- Refresh
  patches.drivers/drm-i915-Enable-voltage-swing-before-enabling-DDI_BU.
- Refresh patches.drivers/drm-i915-Introduce-intel_ddi_dp_level.
- Refresh patches.drivers/drm-i915-Shrink-cnl_ddi_buf_trans.
- Refresh
  patches.drivers/drm-i915-Stop-using-long-platform-names-on-clock-gat.
- Refresh
  patches.drivers/drm-i915-avoid-division-by-zero-on-cnl_calc_wrpll_li.
- Refresh
  patches.drivers/drm-i915-avoid-potential-uninitialized-variable-use.
- Refresh
  patches.drivers/drm-i915-cfl-Coffee-Lake-works-on-Kaby-Lake-PCH.
- Refresh
  patches.drivers/drm-i915-cfl-Remove-alpha-support-protection.
- Refresh patches.drivers/drm-i915-cnl-Add-Gen10-LRC-size.
- Refresh
  patches.drivers/drm-i915-cnl-Add-WaDisableReplayBufferBankArbitratio.
- Refresh
  patches.drivers/drm-i915-cnl-Add-support-slice-subslice-eu-configs.
- Refresh
  patches.drivers/drm-i915-cnl-Allow-the-reg_read-ioctl-to-read-the-RC.
- Refresh
  patches.drivers/drm-i915-cnl-Apply-large-line-width-optimization.
- Refresh
  patches.drivers/drm-i915-cnl-Avoid-ioremap_wc-on-Cannonlake-as-well.
- Refresh
  patches.drivers/drm-i915-cnl-Change-the-macro-name-to-DPLL_CFGCR0_DC.
- Refresh
  patches.drivers/drm-i915-cnl-Do-not-add-an-extra-page-for-precaution.
- Refresh
  patches.drivers/drm-i915-cnl-Extend-WM-workaround-with-IPC-for-CNL.
- Refresh
  patches.drivers/drm-i915-cnl-Fix-DDI-hdmi-level-selection.
- Refresh patches.drivers/drm-i915-cnl-Fix-DP-max-voltage.
- Refresh
  patches.drivers/drm-i915-cnl-Introduce-initial-Cannonlake-Workaround.
- Refresh
  patches.drivers/drm-i915-cnl-Move-ddi-buf-trans-related-functions-up.
- Refresh
  patches.drivers/drm-i915-cnl-Move-voltage-check-into-ddi-buf-trans-f.
- Refresh
  patches.drivers/drm-i915-cnl-Reprogram-DMC-firmware-after-S3-S4-resu.
- Refresh
  patches.drivers/drm-i915-cnl-WA-FtrEnableFastAnisoL1BankingFix.
- Refresh
  patches.drivers/drm-i915-cnl-WaDisableEnhancedSBEVertexCaching.
- Refresh patches.drivers/drm-i915-cnl-WaDisableI2mCycleOnWRPort.
- Refresh
  patches.drivers/drm-i915-cnl-WaForceContextSaveRestoreNonCoherent.patch.
- Refresh
  patches.drivers/drm-i915-cnl-WaPushConstantDereferenceHoldDisable.
- Refresh
  patches.drivers/drm-i915-cnl-WaThrottleEUPerfToAvoidTDBackPressure-c.
- Refresh
  patches.drivers/drm-i915-cnl-don-t-hardcode-DPCLKA_CFGCR0_DDI_CLK_SE.
- Refresh
  patches.drivers/drm-i915-cnl-extract-cnl_set_procmon_ref_values.
- Refresh
  patches.drivers/drm-i915-cnl-simplify-cnl_procmon_values-handling.
- Refresh
  patches.drivers/drm-i915-cnp-Display-Wa-1179-WaHardHangonHotPlug.
- Refresh
  patches.drivers/drm-i915-cnp-Don-t-touch-other-PCH-clock-gating-bits.
- Refresh
  patches.drivers/drm-i915-cnp-Wa-1181-Fix-Backlight-issue.
- Refresh
  patches.drivers/drm-i915-decouple-gen9-and-gen10-dp-signal-levels.
- Refresh
  patches.drivers/drm-i915-glk-cnl-Implement-WaDisableScalarClockGatin.
- Refresh
  patches.drivers/media-cx231xx-cards-fix-NULL-deref-on-missing-associ.
- Refresh
  patches.drivers/media-dib0700-fix-invalid-dvb_detach-argument.
- Refresh
  patches.drivers/media-imon-Fix-null-ptr-deref-in-imon_probe.
- Refresh patches.drivers/powerpc-powernv-Add-IMC-OPAL-APIs.patch.
- Refresh
  patches.drivers/powerpc-powernv-Add-support-for-powercap-framework.patch.
- Refresh
  patches.drivers/powerpc-powernv-Add-support-to-clear-sensor-groups-data.patch.
- Refresh
  patches.drivers/powerpc-powernv-Add-support-to-set-power-shifting-ratio.patch.
- Refresh
  patches.drivers/powerpc-powernv-Detect-and-create-IMC-device.patch.
- Refresh
  patches.drivers/powerpc-powernv-Enable-PCI-peer-to-peer.patch.
- Refresh
  patches.fixes/ALSA-seq-Fix-use-after-free-at-creating-a-port.
- Refresh patches.fixes/loop-Remove-unused-bdev-argument.patch.
- Refresh patches.fixes/loop-fix-error-handling.patch.
- Refresh patches.fixes/loop-support-4k-blocksize.patch.
- Refresh
  patches.fixes/mac80211-accept-key-reinstall-without-changing-anyth.patch.
- Refresh
  patches.fixes/nl80211-check-for-the-required-netlink-attributes-pr.patch.
- Refresh
  patches.fixes/powerpc-mm-book3s64-Make-KERN_IO_START-a-variable.patch.
- Refresh
  patches.fixes/powerpc-mm-hash64-Make-vmalloc-56T-on-hash.patch.
- Refresh
  patches.fixes/powerpc-mm-slb-Move-comment-next-to-the-code-it-s-referring-to.patch.
- Refresh
  patches.fixes/sched-core-Address-more-wake_affine-regressions.patch.
- Refresh
  patches.fixes/sched-core-Fix-wake_affine-performance-regression.patch.
- Refresh
  patches.suse/0001-locking-osq_lock-Fix-osq_lock-queue-corruption.patch.
- Refresh
  patches.suse/0001-objtool-Don-t-report-end-of-section-error-after-an-e.patch.
- Refresh
  patches.suse/0001-sched-wait-Remove-the-lockless-swait_active-check-in.patch.
- Refresh
  patches.suse/0002-x86-head-Remove-confusing-comment.patch.
- Refresh
  patches.suse/0003-x86-head-Remove-unused-bad_address-code.patch.
- Refresh
  patches.suse/0004-x86-head-Fix-head-ELF-function-annotations.patch.
- Refresh
  patches.suse/0005-x86-boot-Annotate-verify_cpu-as-a-callable-function.patch.
- Refresh
  patches.suse/0006-x86-xen-Fix-xen-head-ELF-annotations.patch.
- Refresh
  patches.suse/0007-x86-xen-Add-unwind-hint-annotations.patch.
- Refresh
  patches.suse/0008-x86-head-Add-unwind-hint-annotations.patch.
- commit b965d15
* Thu Nov  9 2017 tiwai@suse.de
- Revert "ALSA: echoaudio: purge contradictions between dimension
  matrix members and total number of members" (bsc#1051510).
- commit 46377e9
* Thu Nov  9 2017 tiwai@suse.de
- blacklist.conf: Add i915 blacklist (bsc#1051510)
- commit a51cd00
* Thu Nov  9 2017 tiwai@suse.de
- drm/i915: Use bdw_ddi_translations_fdi for Broadwell
  (bsc#1051510).
- drm/i915: Report -EFAULT before pwrite fast path into shmemfs
  (bsc#1051510).
- drm/i915: Order two completing nop_submit_request (bsc#1051510).
- drm/i915: Read timings from the correct transcoder in
  intel_crtc_mode_get() (bsc#1051510).
- drm/i915: remove redundant variable hw_check (bsc#1051510).
- drm/i915: Fix DDI PHY init if it was already on (bsc#1051510).
- drm/i915/glk: Fix DMC/DC state idleness calculation
  (bsc#1051510).
- drm/i915: Re-enable GTT following a device reset (bsc#1051510).
- drm/i915: Clear lost context-switch interrupts across reset
  (bsc#1051510).
- drm/i915: Avoid the gpu reset vs. modeset deadlock
  (bsc#1051510).
- commit c463053
* Thu Nov  9 2017 lpechacek@suse.com
- rpm/kernel-binary.spec.in: rename kGraft to KLP (fate#323682)
- commit 0ed191d
* Thu Nov  9 2017 msuchanek@suse.de
- Support paes_s390 and pkey modules (bsc#1066939)
- commit 5932b2c
* Thu Nov  9 2017 msuchanek@suse.de
- s390/crypto: fix aes/paes Kconfig dependeny (bsc#1066939).
- Update config files.
- commit 85fd2af
* Thu Nov  9 2017 jkosina@suse.cz
- x86/mm: Unbreak modules that rely on external PAGE_KERNEL
  availability (FATE#322123).
- commit 2ce8e65
* Wed Nov  8 2017 jack@suse.cz
- mm, truncate: remove all exceptional entries from pagevec
  under one lock -fix (bsc#1065138).
- commit e824298
* Wed Nov  8 2017 pmladek@suse.com
- lib/ratelimit.c: use deferred printk() version (bsc#979928).
- commit 2c73591
* Wed Nov  8 2017 oneukum@suse.com
- Input: gtco - fix potential out-of-bound access (bsc#1067085
  CVE-2017-16649).
- commit 60895ec
* Wed Nov  8 2017 tiwai@suse.de
- media: dib0700: fix invalid dvb_detach argument (CVE-2017-16646
  bsc#1067105).
- commit 66fca6a
* Wed Nov  8 2017 tiwai@suse.de
- net: usb: asix: fill null-ptr-deref in asix_suspend
  (CVE-2017-16647 bsc#1067102).
- commit f86cac1
* Wed Nov  8 2017 tiwai@suse.de
- Input: ims-psu - check if CDC union descriptor is sane
  (CVE-2017-16645 bsc#1067132).
- commit fba5e7b
* Wed Nov  8 2017 oneukum@suse.com
- USB: core: harden cdc_parse_cdc_header (bsc#1066693
  CVE-2017-16534).
- commit a719332
* Wed Nov  8 2017 gqjiang@suse.com
- Refresh
  patches.drivers/0003-md-cluster-Suspend-writes-in-RAID10-if-within-range.patch.
- Delete
  patches.drivers/0002-md-raid10-add-honouring-of-suspend_-lo-hi.patch.
- commit 6922f7b
* Tue Nov  7 2017 oneukum@suse.com
- USB: core: fix out-of-bounds access bug in
  usb_get_bos_descriptor() (bsc#1066700 CVE-2017-16535).
- commit c7ecdbf
* Tue Nov  7 2017 rgoldwyn@suse.com
- apparmor: Revert network mediation to old patches.
  References: bsc#1065536
  Backport of upstream patch 651e28c5537a ("apparmor: add base
  infastructure for socket mediation") allowed us delete old apparmor
  networking patches which we have been carrying for quite some time.
  However, through 80c094a47dd4 ("Revert "apparmor: add base
  infastructure for socket mediation""), this patch was reverted.
  In order to support our networking infrastructure for apparmor,
  we have to retain our old patches.
- apparmor: update apparmor-basic-networking-rules for 4.11-rc1
  (FATE#300516).
- AppArmor: basic networking rules (FATE#300516).
- apparmor: Fix quieting of audit messages for network mediation
  (FATE#300516).
- Delete
  patches.apparmor/0011-apparmor-add-base-infastructure-for-socket-mediation.patch.
- commit 68ae091
* Tue Nov  7 2017 oneukum@suse.com
- USB: fix out-of-bounds in usb_set_configuration (bsc#1066671
  CVE-2017-16531).
- commit 503cdcb
* Tue Nov  7 2017 nborisov@suse.com
- btrfs: change how we decide to commit transactions during
  flushing (bsc#1060197).
  Also enable Liu Bo's patch now that the maths behind transaction commit is
  fixed.
- commit 090a8a5
* Mon Nov  6 2017 yousaf.kaukab@suse.com
- arm64: Ensure the instruction emulation is ready for userspace
  (bsc#1066688).
- commit d42b0c9
* Mon Nov  6 2017 tiwai@suse.de
- assoc_array: Fix a buggy node-splitting case (CVE-2017-12193
  bsc#1066192).
- commit 2a60539
* Mon Nov  6 2017 tbogendoerfer@suse.de
- net: ethtool: remove error check for legacy setting transceiver
  type (bsc#1056787).
- commit 7d9e6b5
* Mon Nov  6 2017 agraf@suse.de
- Update config files to enable spidev on arm64. (bsc#1066696)
- supported.conf: Support spidev (bsc#1066696)
- commit 181d4fc
* Mon Nov  6 2017 bpoirier@suse.com
- Refresh patch order in sorted section
- commit 8c0cbfa
* Mon Nov  6 2017 tbogendoerfer@suse.de
- net_sched: avoid matching qdisc with zero handle (bsc#1056787).
- soreuseport: fix initialization race (bsc#1056787).
- netlink: fix netlink_ack() extack race (bsc#1056787).
- net: enable interface alias removal via rtnl (bsc#1056787).
- gso: fix payload length when gso_size is zero (bsc#1056787).
- net: rtnetlink: fix info leak in RTM_GETSTATS call
  (bsc#1056787).
- inet: fix improper empty comparison (bsc#1056787).
- net: ethtool: Add back transceiver type (bsc#1056787).
- net_sched: always reset qdisc backlog in qdisc_reset()
  (bsc#1056787).
- net: change skb->mac_header when Generic XDP calls adjust_head
  (bsc#1056787).
- net/sched: cls_matchall: fix crash when used with classful qdisc
  (bsc#1056787).
- net/sock: allow the user to set negative peek offset
  (bsc#1056787).
- sch_tbf: fix two null pointer dereferences on init failure
  (bsc#1056787).
- sch_netem: avoid null pointer deref on init failure
  (bsc#1056787).
- sch_fq_codel: avoid double free on init failure (bsc#1056787).
- sch_cbq: fix null pointer dereferences on init failure
  (bsc#1056787).
- sch_hhf: fix null pointer dereference on init failure
  (bsc#1056787).
- sch_htb: fix crash on init failure (bsc#1056787).
- gue: fix remcsum when GRO on and CHECKSUM_PARTIAL boundary is
  outer UDP (bsc#1056787).
- vxlan: fix remcsum when GRO on and CHECKSUM_PARTIAL boundary
  is outer UDP (bsc#1056787).
- net: bridge: fix dest lookup when vlan proto doesn't match
  (bsc#1056787).
- commit 112af25
* Mon Nov  6 2017 oneukum@suse.com
- USB: serial: console: fix use-after-free on disconnect
  (bsc#1066618 CVE-2017-16525).
- USB: serial: console: fix use-after-free after failed setup
  (bsc#1066618 CVE-2017-16525).
- commit f99e4d9
* Mon Nov  6 2017 tiwai@suse.de
- ALSA: usb-audio: Check out-of-bounds access by corrupted buffer
  descriptor (CVE-2017-16529 bsc#1066650).
- commit d27bf12
* Mon Nov  6 2017 hare@suse.de
- s390/kvm: fix detection of guest machine checks
  (FATE#324256,LTC#160417,bsc#1066327).
- KVM: s390: Inject machine check into the nested guest
  (FATE#324256,LTC#160417,bsc#1066327).
- KVM: s390: Inject machine check into the guest
  (FATE#324256,LTC#160417,bsc#1066327).
- KVM: s390: Backup the guest's machine check info
  (FATE#324256,LTC#160417,bsc#1066327).
- s390/nmi: s390: New low level handling for machine check
  happening in guest (FATE#324256,LTC#160417,bsc#1066327).
- commit 03cf0ff
* Mon Nov  6 2017 hare@suse.de
- KVM: s390: expose no-DAT to guest and migration support
  (LTC#160419,bsc#1066194).
- KVM: s390: ioctls to get and set guest storage attributes
  (LTC#160419,bsc#1066194).
- KVM: s390: CMMA tracking, ESSA emulation, migration mode
  (LTC#160419,bsc#1066194).
- commit c96fac7
* Mon Nov  6 2017 hare@suse.de
- KVM: make pid available for uevents without debugfs
  (FATE#323770,bsc#1061982).
- KVM: trigger uevents when creating or destroying a VM
  (FATE#323770,bsc#1061982).
- commit 4b7e072
* Mon Nov  6 2017 tiwai@suse.de
- media: imon: Fix null-ptr-deref in imon_probe (CVE-2017-16537
  bsc#1066573).
- [media] cx231xx-cards: fix NULL-deref on missing association
  descriptor (CVE-2017-16536 bsc#1066606).
- commit b162a90
* Mon Nov  6 2017 tbogendoerfer@suse.de
- RDMA/nldev: Enforce device index check for port callback
  (bsc#1046306 FATE#322942).
- net/mlx5e: DCBNL, Implement tc with ets type and zero bandwidth
  (bsc#1046303 FATE#322944).
- net/mlx5e: Properly deal with encap flows add/del under neigh
  update (bsc#1046303 FATE#322944).
- net/mlx5: Delay events till mlx5 interface's add complete for
  pci resume (bsc#1046303 FATE#322944).
- net/mlx5: Fix health work queue spin lock to IRQ safe
  (bsc#1046303 FATE#322944).
- nfp: refuse offloading filters that redirects to upper devices
  (bsc#1055968).
- RDMA/netlink: OOPs in rdma_nl_rcv_msg() from misinterpreted flag
  (bsc#1046306 FATE#322942).
- commit c03a7d9
* Mon Nov  6 2017 tbogendoerfer@suse.de
- Re-sorted sorted section
- commit b3742e5
* Mon Nov  6 2017 msuchanek@suse.de
- powerpc/64s/radix: Fix preempt imbalance in TLB flush
  (bsc#1055186).
- commit 4c97add
* Mon Nov  6 2017 vbabka@suse.cz
- Update
  patches.fixes/mm-memcontrol-fix-null-pointer-crash-in-test_clear_page_writeback.patch
  (VM Functionality, bsc#1061849, bsc#1065971). Fix bsc#1065971 by editing the
  patch in-place.
- commit 44552ab
* Mon Nov  6 2017 tiwai@suse.de
- Set CONFIG_MQ_IOSCHED_DEADLINE=y on config/arm64/default (bsc#1066369)
- commit 9841c29
* Mon Nov  6 2017 tiwai@suse.de
- ALSA: usb-audio: Kill stray URB at exiting (CVE-2017-16527
  bsc#1066625).
- ALSA: seq: Cancel pending autoload work at unbinding device
  (CVE-2017-16528 bsc#1066629).
- commit e9dde55
* Mon Nov  6 2017 jkosina@suse.cz
- rpm/kernel-binary.spec.in: add explicit dependency of kernel-*-devel on
  libelf-devel. Otherwise warning that got turned into error by e683952999
  ("objtool: Upgrade libelf-devel warning to error...") would trigger and
  cause any packages being built against kernel-*-devel (such as KMPs,
  crash) not to have the libelf dependency included, and fail to build.
- commit cad1ef9
* Mon Nov  6 2017 bp@suse.de
- x86/alternatives: Fix alt_max_short macro to really be a max()
  (git-fixes).
- commit 440e729
* Mon Nov  6 2017 jkosina@suse.cz
- Revert "scripts/git-pre-commit: Check the content of the series.conf sorted section."
  This reverts commit 869e9a97f5038eb456502f1b0ee7cd06f3b8e5c3; we have to first
  announce this globally with a fixed transition date and give committers time
  to readjust their infrastructure (namely have pygit2 put in place properly).
- commit 28dd483
* Mon Nov  6 2017 mkubecek@suse.cz
- supported.conf: mark vsockmon as supported (bsc#1066369)
  This module creates a device receiving copies of vsock traffic so that it
  packets can be monitored e.g. by tcpdump/wireshark (the same way nlmon
  works for netlink). (vsock is a framework for specific guest-host
  communication channels, used by VMware, virtio and recently also Hyper-V)
- commit 683ca74
* Mon Nov  6 2017 gqjiang@suse.com
- md-cluster/raid10: set "do_balance = 0" if area is resyncing
  (fate#323171).
- md/raid10: add honouring of suspend_{lo,hi} (fate#323171).
- md-cluster: Suspend writes in RAID10 if within range
  (fate#323171).
- md-cluster: Use a small window for raid10 resync (fate#323171).
- md-cluster: update document for raid10 (fate#323171).
- Delete
  patches.suse/0036-md-cluster-remove-EXPERIMENTAL-info.patch.
- commit 0803ffd
* Fri Nov  3 2017 mcgrof@suse.com
- mac80211: don't compare TKIP TX MIC key in reinstall prevention
  (bsc#1066472).
- commit 3545ef0
* Fri Nov  3 2017 mcgrof@suse.com
- mac80211: use constant time comparison with keys (bsc#1066471).
- commit 0ae0929
* Fri Nov  3 2017 mcgrof@suse.com
- kernel/sysctl.c: remove duplicate UINT_MAX check on do_proc_douintvec_conv() (bsc#1066470).
- commit b275255
* Fri Nov  3 2017 tiwai@suse.de
- Update no-fix patch tags for recent i915 patches
  This removes the false-positive checks by git-fixes.
- commit 9fccb15
* Fri Nov  3 2017 tiwai@suse.de
- ALSA: hda - fix headset mic problem for Dell machines with
  alc236 (bsc#1052235).
- ALSA: hda/realtek - Add support for ALC236/ALC3204
  (bsc#1052235).
- ALSA: hda: Remove superfluous '-' added by printk conversion
  (bsc#1052235).
- ALSA: hda - program ICT bits to support HBR audio (bsc#1052235).
- ALSA: hda: Fix forget to free resource in error handling code
  path in hda_codec_driver_probe (bsc#1052235).
- ALSA: hda/realtek - Fix pincfg for Dell XPS 13 9370
  (bsc#1052235).
- ALSA: hda: Add Cannonlake PCI ID (bsc#1052235).
- ALSA: hda - Add hdmi id for a Geminilake variant (bsc#1052235).
- ALSA: hda - Add AZX_DRIVER_SKL for simplification (bsc#1052235).
- commit f2aaa75
* Fri Nov  3 2017 mfleming@suse.de
- sched/fair: Enable SIS_AVG_CPU by default (bsc#1061593).
- commit fc3055c
* Fri Nov  3 2017 msuchanek@suse.de
- ibmvnic: Fix failover error path for non-fatal resets
  (bsc#1066382).
- commit 786fbe8
* Fri Nov  3 2017 msuchanek@suse.de
- ibmvnic: Update reset infrastructure to support tunable
  parameters (bsc#1066382).
- commit 4058b41
* Fri Nov  3 2017 msuchanek@suse.de
- ibmvnic: Let users change net device features (bsc#1066382).
- commit c706428
* Fri Nov  3 2017 msuchanek@suse.de
- ibmvnic: Enable TSO support (bsc#1066382).
- commit 251d320
* Fri Nov  3 2017 msuchanek@suse.de
- ibmvnic: Enable scatter-gather support (bsc#1066382).
- commit 36f16a2
* Fri Nov  3 2017 msuchanek@suse.de
- ibmvnic: Fix calculation of number of TX header descriptors
  (bsc#1066382).
- commit 5ec05af
* Fri Nov  3 2017 bp@suse.de
- x86/fpu: Don't let userspace set bogus xcomp_bv (bsc#1063984,
  CVE-2017-15537).
- commit 17bafc1
* Fri Nov  3 2017 yousaf.kaukab@suse.com
- ata: ceva: Add SMMU support for SATA IP (bsc#1066345).
- ata: ceva: Correct the suspend and resume logic for SATA
  (bsc#1066345).
- ata: ceva: Correct the AXI bus configuration for SATA ports
  (bsc#1066345).
- ata: ceva: Add CCI support for SATA if CCI is enabled
  (bsc#1066345).
- ata: ceva: Make RxWaterMark value as module parameter
  (bsc#1066345).
- ata: ceva: Disable Device Sleep capability (bsc#1066345).
- ata: ceva: Add gen 3 mode support in driver (bsc#1066345).
- ata: ceva: Move sata port phy oob settings to device-tree
  (bsc#1066345).
- commit 4b09db7
* Fri Nov  3 2017 tiwai@suse.de
- supported.conf: Add wdat_wdt as supported (bsc#1066296)
- commit 45de744
* Fri Nov  3 2017 bpoirier@suse.com
- Refresh patch order in sorted section
- commit 071abc3
* Thu Nov  2 2017 msuchanek@suse.de
- powerpc/xmon: Fix display of SPRs (bsc#1065729).
- commit e8eae4d
* Thu Nov  2 2017 msuchanek@suse.de
- powerpc/powernv: Increase memory block size to 1GB on radix
  (bsc#1065729).
- commit c2f4068
* Thu Nov  2 2017 msuchanek@suse.de
- powerpc/pseries: Don't attempt to acquire drc during memory
  hot add for assigned lmbs (FATE#322022, bsc#1065729).
- powerpc/pseries: Check memory device state before
  onlining/offlining (FATE#322022, bsc#1065729).
- commit 7e9a794
* Thu Nov  2 2017 msuchanek@suse.de
- scsi: ipr: Set no_report_opcodes for RAID arrays (bsc#1066213).
- commit 620e3a3
* Thu Nov  2 2017 msuchanek@suse.de
- scsi: ipr: Fix scsi-mq lockdep issue (bsc#1066213).
- commit a69de39
* Thu Nov  2 2017 bpoirier@suse.com
- Refresh patch order in sorted section
- commit 96020ad
* Thu Nov  2 2017 hare@suse.de
- dax: initialize variable pfn before using it (FATE#323721).
- dax: use PG_PMD_COLOUR instead of open coding (FATE#323721).
- dax: explain how read(2)/write(2) addresses are validated
  (FATE#323721).
- dax: remove DAX code from page_cache_tree_insert()
  (FATE#323721).
- dax: use common 4k zero page for dax mmap reads (FATE#323721).
- dax: relocate some dax functions (FATE#323721).
- mm: add vm_insert_mixed_mkwrite() (FATE#323721).
- commit ade91b6
* Thu Nov  2 2017 msuchanek@suse.de
- powerpc/sysrq: Fix oops whem ppmu is not registered
  (bsc#1065729).
- commit f08eb15
* Thu Nov  2 2017 tiwai@suse.de
- drm/i915: avoid division by zero on cnl_calc_wrpll_link
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Do not add an extra page for precaution in the
  Gen10 LRC size (FATE#322643 bsc#1055900).
- drm/i915: avoid potential uninitialized variable use
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Reprogram DMC firmware after S3/S4 resume
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Add Gen10 LRC size (FATE#322643 bsc#1055900).
- drm/i915/cnl: Extend WM workaround with IPC for CNL (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Change the macro name to
  DPLL_CFGCR0_DCO_FRACTION_SHIFT (FATE#322643 bsc#1055900).
- drm/i915: Shrink cnl_ddi_buf_trans (FATE#322643 bsc#1055900).
- drm/i915/glk, cnl: Implement WaDisableScalarClockGating
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Add support slice/subslice/eu configs (FATE#322643
  bsc#1055900).
- drm/i915/cnl:
  WaThrottleEUPerfToAvoidTDBackPressure:cnl(pre-prod) (FATE#322643
  bsc#1055900).
- drm/i915: Display WA #1133 WaFbcSkipSegments:cnl, glk
  (FATE#322643 bsc#1055900).
- drm/i915/cnp: Display Wa #1179: WaHardHangonHotPlug (FATE#322643
  bsc#1055900).
- drm/i915/cnp: set min brightness from VBT (FATE#322643
  bsc#1055900).
- drm/i915/cnp: Don't touch other PCH clock gating bits
  (FATE#322643 bsc#1055900).
- drm/i915/cnp: Wa 1181: Fix Backlight issue (FATE#322643
  bsc#1055900).
- drm/i915: Stop using long platform names on clock gating
  functions (FATE#322643 bsc#1055900).
- drm/i915/cnl: Allow the reg_read ioctl to read the RCS TIMESTAMP
  register (FATE#322643 bsc#1055900).
- drm/i915/cnl: Avoid ioremap_wc on Cannonlake as well
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Fix DP max voltage (FATE#322643 bsc#1055900).
- drm/i915/cnl: Fix DDI hdmi level selection (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Move ddi buf trans related functions up
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Move voltage check into ddi buf trans functions
  (FATE#322643 bsc#1055900).
- drm/i915: Enable voltage swing before enabling DDI_BUF_CTL
  (FATE#322643 bsc#1055900).
- drm/i915: Align vswing sequences with old ddi buffer registers
  (FATE#322643 bsc#1055900).
- drm/i915: decouple gen9 and gen10 dp signal levels (FATE#322643
  bsc#1055900).
- drm/i915: Introduce intel_ddi_dp_level (FATE#322643
  bsc#1055900).
- drm/i915/cnl: WaDisableI2mCycleOnWRPort (FATE#322643
  bsc#1055900).
- drm/i915/cnl: WA FtrEnableFastAnisoL1BankingFix (FATE#322643
  bsc#1055900).
- drm/i915/cnl: don't hardcode DPCLKA_CFGCR0_DDI_CLK_SEL_SHIFT
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: WaForceContextSaveRestoreNonCoherent (FATE#322643
  bsc#1055900).
- drm/i915/cnl: WaPushConstantDereferenceHoldDisable (FATE#322643
  bsc#1055900).
- drm/i915/cnl: extract cnl_set_procmon_ref_values (FATE#322643
  bsc#1055900).
- drm/i915/cnl: simplify cnl_procmon_values handling (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Apply large line width optimization (FATE#322643
  bsc#1055900).
- drm/i915/cnl: WaDisableEnhancedSBEVertexCaching (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Add
  WaDisableReplayBufferBankArbitrationOptimization (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Introduce initial Cannonlake Workarounds
  (FATE#322643 bsc#1055900).
- drm/i915/cfl: Remove alpha support protection (FATE#322643
  bsc#1055900).
- drm/i915/cfl: Coffee Lake works on Kaby Lake PCH (FATE#322643
  bsc#1055900).
- commit 2e11a0a
* Thu Nov  2 2017 tiwai@suse.de
- drm/i915/cnl: Fix PLL initialization for HDMI (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Fix PLL mapping (FATE#322643 bsc#1055900).
- drm/i915: Fix the missing PPAT cache attributes on CNL
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Fix LSPCON support (FATE#322643 bsc#1055900).
- drm/i915/cnl: Reuse skl_wm_get_hw_state on Cannonlake
  (FATE#322643 bsc#1055900).
- drm/i915/gen10: implement gen 10 watermarks calculations
  (FATE#322643 bsc#1055900).
- drm/i915: Addition wrapper for fixed16.16 operation (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Setup PAT Index (FATE#322643 bsc#1055900).
- drm/i915/gen10: fix WM latency printing (FATE#322643
  bsc#1055900).
- drm/i915/gen10: fix the gen 10 SAGV block time (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Enable SAGV for Cannonlake (FATE#322643
  bsc#1055900).
- drm/i915/gen10+: use the SKL code for reading WM latencies
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Dump the right pll registers when dumping pipe
  config (FATE#322643 bsc#1055900).
- drm/i915/cnl: Add allowed DP rates for Cannonlake (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Add max allowed Cannonlake DC (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Add slice and subslice information to debugfs
  (FATE#322643 bsc#1055900).
- drm/i915: Return correct EDP voltage swing table for 0.85V
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Removing missing DDI_E bits from CNL (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Fix loadgen select programming on ddi vswing
  sequence (FATE#322643 bsc#1055900).
- drm/i915/cnl: Add missing type case (FATE#322643 bsc#1055900).
- drm/i915/cnl: Don't trust VBT's alternate pin for port D for
  now (FATE#322643 bsc#1055900).
- drm/i915/cnl: Get DDI clock based on PLLs (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Inherit RPS stuff from previous platforms
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Cannonlake color init (FATE#322643 bsc#1055900).
- x86/gpu: CNL uses the same GMS values as SKL (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Add force wake for gen10+ (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Fix the CURSOR_COEFF_MASK used in DDI Vswing
  Programming (FATE#322643 bsc#1055900).
- drm/i915/cnl: Fix RMW on ddi vswing sequence (FATE#322643
  bsc#1055900).
- drm/i915/cnl: LSPCON support is gen9+ (FATE#322643 bsc#1055900).
- drm/i915/cnl: Enable fifo underrun for Cannonlake (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Fix Cannonlake scaler mode programing (FATE#322643
  bsc#1055900).
- drm/i915: Use HAS_CSR instead of gen number on DMC load
  (FATE#322643 bsc#1055900).
- drm/i915/DMC/CNL: Load DMC on CNL (FATE#322643 bsc#1055900).
- drm/i915/cnl: Enable loadgen_select bit for vswing sequence
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Implement voltage swing sequence (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Add DDI Buffer translation tables for Cannonlake
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Add registers related to voltage swing sequences
  (FATE#322643 bsc#1055900).
- drm/i915: Add MMIO helper for 6 ports with different offsets
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Initialize PLLs (FATE#322643 bsc#1055900).
- drm/i915: Configure DPLL's for Cannonlake (FATE#322643
  bsc#1055900).
- drm/i915/cnl: DDI - PLL mapping (FATE#322643 bsc#1055900).
- drm/i915/cnl: Allow dynamic cdclk changes on CNL (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Implement CNL display init/unit sequence
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Implement .set_cdclk() for CNL (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Implement .get_display_clock_speed() for CNL
  (FATE#322643 bsc#1055900).
- drm/i915: Remove unnecessary PORT3 definition (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Also need power well sanitize (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Add power wells for CNL (FATE#322643 bsc#1055900).
- drm/i915/gen10: Set value of Indirect Context Offset for gen10
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Cannonlake has same MOCS table than Skylake
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Configure EU slice power gating (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Cannonlake has 4 planes (3 sprites) per pipe
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: add IS_CNL_REVID macro (FATE#322643 bsc#1055900).
- drm/i915/cnl: Add Cannonlake PCI IDs for Y-skus (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Add Cannonlake PCI IDs for U-skus (FATE#322643
  bsc#1055900).
- drm/i915: Always use 9 bits of the LPC bridge device ID for
  PCH detection (FATE#322643 bsc#1055900).
- drm/i915: Fix PCH names for KBP and CNP (FATE#322643
  bsc#1055900).
- commit 99ef3b0
* Thu Nov  2 2017 jkosina@suse.cz
- scripts/git_sort/git_sort.py: add ext4 git repository
- commit 7d0f4fb
* Thu Nov  2 2017 hare@suse.de
- Update s390x config files (FATE#323442)
- commit 139ffd3
* Thu Nov  2 2017 hare@suse.de
- s390/dasd: Add discard support for FBA devices (FATE#322263,
  bsc#1061020).
- commit fcd8c50
* Thu Nov  2 2017 hare@suse.de
- s390/mm,kvm: use nodat PGSTE tag to optimize TLB flushing
  (FATE#321512, bsc#1061009).
- s390/mm: add guest ASCE TLB flush optimization (FATE#321512,
  bsc#1061009).
- s390/mm: add no-dat TLB flush optimization (FATE#321512,
  bsc#1061009).
- s390/mm: tag normal pages vs pages used in page tables
  (FATE#321512, bsc#1061009).
- s390/sclp: single increment assignment control (FATE#323299,
  bsc#1061050).
- scsi: Do not retry invalid function error (bnc#809122).
- Delete
  patches.suse/scsi-do-not-retry-invalid-function-error.patch.
- commit cbe6ec6
* Wed Nov  1 2017 lduncan@suse.com
- KEYS: prevent KEYCTL_READ on negative key (bsc#1066043).
- KEYS: fix writing past end of user-supplied buffer in
  keyring_read() (bsc#1066046).
- serial: Fix port type numbering for TI DA8xx (bsc#1066048).
- serial: Remove unused port type (bsc#1066045).
- commit e8b8788
* Wed Nov  1 2017 msuchanek@suse.de
- Delete patches.rpmify/firmware-path
  Firmware path is irrelevant since the firmware is not used anyway
  (bsc#1054239).
- commit 6a4e78f
* Wed Nov  1 2017 bp@suse.de
- iommu/amd: Do not disable SWIOTLB if SME is active
  (fate#322123).
- commit bf4176e
* Wed Nov  1 2017 jack@suse.cz
- ext4: add ext4_should_use_dax() (bsc#1064591).
- commit a01f212
* Wed Nov  1 2017 jack@suse.cz
- ext4: add sanity check for encryption + DAX (bsc#1064591).
- commit 19ca8bf
* Wed Nov  1 2017 jack@suse.cz
- ext4: prevent data corruption with journaling + DAX
  (bsc#1064591).
- commit 0aec3e0
* Wed Nov  1 2017 jack@suse.cz
- ext4: prevent data corruption with inline data + DAX
  (bsc#1064591).
- commit 7dfd254
* Wed Nov  1 2017 vbabka@suse.cz
- mm,compaction: serialize waitqueue_active() checks (for real)
  (Git-fixes, VM Performance).
- commit 483dd23
* Wed Nov  1 2017 jgross@suse.com
- Kbuild: use -fshort-wchar globally (bnc#1065600).
- commit 3a70c58
* Wed Nov  1 2017 jgross@suse.com
- xen: x86: mark xen_find_pt_base as __init (bnc#1065600).
- commit 1037440
* Wed Nov  1 2017 jgross@suse.com
- xen/events: events_fifo: Don't use {get,put}_cpu() in
  xen_evtchn_fifo_init() (bnc#1065600).
- commit 61488f9
* Tue Oct 31 2017 msuchanek@suse.de
- KVM: PPC: Book3S: Protect kvmppc_gpa_to_ua() with SRCU
  (bsc#1061840).
- commit ad12195
* Tue Oct 31 2017 msuchanek@suse.de
- KVM: PPC: Book3S HV: POWER9 more doorbell fixes (bsc#1061840).
- commit db3a4d5
* Tue Oct 31 2017 msuchanek@suse.de
- KVM: PPC: Fix oops when checking KVM_CAP_PPC_HTM (bsc#1061840).
- commit 7d9f250
* Tue Oct 31 2017 msuchanek@suse.de
- KVM: PPC: Book3S HV: Use msgsync with hypervisor doorbells on
  POWER9 (bsc#1061840).
- commit 7e124d4
* Tue Oct 31 2017 msuchanek@suse.de
- KVM: PPC: Book3S HV: Hold kvm->lock around call to
  kvmppc_update_lpcr (bsc#1061840).
- commit e13b8b9
* Tue Oct 31 2017 msuchanek@suse.de
- KVM: PPC: Book3S HV: Fix case where HDEC is treated as 32-bit
  on POWER9 (bsc#1061840).
- commit 9b7c48e
* Tue Oct 31 2017 bpoirier@suse.com
- Refresh
  patches.drivers/0008-Revert-commit-1a8b6d76dc5b-net-add-one-common-config.patch.
- Refresh
  patches.drivers/0009-ixgbe-Use-new-PCI_DEV_FLAGS_NO_RELAXED_ORDERING-flag.patch.
- Refresh
  patches.drivers/0047-scsi-qla2xxx-Cleanup-FC-NVMe-code.patch.
- Refresh
  patches.drivers/0048-scsi-qla2xxx-Move-function-prototype-to-correct-head.patch.
- Refresh
  patches.drivers/0049-scsi-qla2xxx-Added-change-to-enable-ZIO-for-FC-NVMe-.patch.
- Refresh
  patches.drivers/0050-scsi-qla2xxx-Simpify-unregistration-of-FC-NVMe-local.patch.
- Refresh
  patches.drivers/0051-scsi-qla2xxx-Fix-remoteport-disconnect-for-FC-NVMe.patch.
- Refresh
  patches.drivers/0052-scsi-qla2xxx-use-dma_mapping_error-to-check-map-erro.patch.
- Refresh
  patches.drivers/0053-scsi-qla2xxx-fix-spelling-mistake-of-variable-sfp_ad.patch.
- Refresh
  patches.drivers/0054-scsi-qla2xxx-Correction-to-vha-vref_count-timeout.patch.
- Refresh
  patches.drivers/0055-scsi-qla2xxx-Fix-target-multiqueue-configuration.patch.
- Refresh
  patches.drivers/0056-scsi-qla2xxx-Update-fw_started-flags-at-qpair-creati.patch.
- Refresh
  patches.drivers/0057-scsi-qla2xxx-Add-command-completion-for-error-path.patch.
- Refresh
  patches.drivers/0058-scsi-qla2xxx-Fix-WWPN-WWNN-in-debug-message.patch.
- Refresh
  patches.drivers/0059-scsi-qla2xxx-Fix-system-panic-due-to-pointer-access-.patch.
- Refresh
  patches.drivers/0060-scsi-qla2xxx-Use-BIT_6-to-acquire-FAWWPN-from-switch.patch.
- Refresh
  patches.drivers/0061-scsi-qla2xxx-Fix-NPIV-host-enable-after-chip-reset.patch.
- Refresh
  patches.drivers/0062-scsi-qla2xxx-Remove-extra-register-read.patch.
- Refresh
  patches.drivers/0063-scsi-qla2xxx-Change-ha-wq-max_active-value-to-defaul.patch.
- Refresh
  patches.drivers/0064-scsi-qla2xxx-Use-fabric-name-for-Get-Port-Speed-comm.patch.
- Refresh
  patches.drivers/0065-scsi-qla2xxx-Add-ability-to-autodetect-SFP-type.patch.
- Refresh
  patches.drivers/0066-scsi-qla2xxx-Prevent-sp-free-null-uninitialized-poin.patch.
- Refresh
  patches.drivers/0067-scsi-qla2xxx-Use-sp-free-instead-of-hard-coded-call.patch.
- Refresh
  patches.drivers/0068-scsi-qla2xxx-Move-logging-default-mask-to-execute-on.patch.
- Refresh
  patches.drivers/0069-scsi-qla2xxx-Add-timeout-ability-to-wait_for_sess_de.patch.
- Refresh
  patches.drivers/0070-scsi-qla2xxx-Allow-SNS-fabric-login-to-be-retried.patch.
- Refresh
  patches.drivers/0071-scsi-qla2xxx-Fix-task-mgmt-handling-for-NPIV.patch.
- Refresh
  patches.drivers/0072-scsi-qla2xxx-Print-correct-mailbox-registers-in-fail.patch.
- Refresh
  patches.drivers/0073-scsi-qla2xxx-Remove-potential-macro-parameter-side-e.patch.
- Refresh
  patches.drivers/0074-scsi-qla2xxx-Add-support-for-minimum-link-speed.patch.
- Refresh
  patches.drivers/0075-scsi-qla2xxx-Add-LR-distance-support-from-nvram-bit.patch.
- Refresh
  patches.drivers/0076-scsi-qla2xxx-Cleanup-NPIV-host-in-target-mode-during.patch.
- Refresh
  patches.drivers/0077-scsi-qla2xxx-Enable-Async-TMF-processing.patch.
- Refresh
  patches.drivers/0078-scsi-qla2xxx-Increase-ql2xmaxqdepth-to-64.patch.
- Refresh
  patches.drivers/0079-scsi-qla2xxx-Recheck-session-state-after-RSCN.patch.
- Refresh
  patches.drivers/0080-scsi-qla2xxx-Skip-zero-queue-count-entry-during-FW-d.patch.
- Refresh
  patches.drivers/0081-scsi-qla2xxx-Ability-to-process-multiple-SGEs-in-Com.patch.
- Refresh
  patches.drivers/0082-scsi-qla2xxx-Do-not-call-abort-handler-function-duri.patch.
- Refresh
  patches.drivers/0083-scsi-qla2xxx-Update-driver-version-to-10.00.00.01-k.patch.
- Refresh
  patches.drivers/0084-scsi-qla2xxx-Fix-an-integer-overflow-in-sysfs-code.patch.
- Refresh
  patches.drivers/IB-rxe-Another-fix-for-broken-receive-queue-draining.patch.
- Refresh
  patches.drivers/IB-rxe-Move-refcounting-earlier-in-rxe_send.patch.
- Refresh
  patches.drivers/e1000e-Don-t-return-uninitialized-stats.patch.
- Refresh
  patches.drivers/ibmvnic-103-Initialize-SCRQ-s-during-login-renegotiation.patch.
- Refresh
  patches.drivers/ibmvnic-104-Check-for-transport-event-on-driver-resume.patch.
- Refresh
  patches.drivers/ibmvnic-105-Report-rx-buffer-return-codes-as-netdev_dbg.patch.
- Refresh
  patches.drivers/ibmvnic-106-Implement-per-queue-statistics-reporting.patch.
- Refresh
  patches.drivers/ibmvnic-107-Convert-vnic-server-reported-statistics-to-cpu-endian.patch.
- Refresh
  patches.drivers/ibmvnic-108-Implement-.get_ringparam.patch.
- Refresh
  patches.drivers/ibmvnic-109-Implement-.get_channels.patch.
- Refresh
  patches.drivers/ibmvnic-110-Clean-up-resources-on-probe-failure.patch.
- Refresh
  patches.drivers/ibmvnic-111-Add-netdev_dbg-output-for-debugging.patch.
- Refresh
  patches.drivers/ibmvnic-112-constify-vio_device_id.patch.
- Refresh
  patches.drivers/net-check-type-when-freeing-metadata-dst.patch.
- Refresh
  patches.drivers/net-mlx5e-IPoIB-Fix-driver-name-retrieved-by-ethtool.patch.
- Refresh
  patches.drivers/net-sched-fix-memleak-for-chain-zero.patch.
- Refresh
  patches.drivers/scsi-cxlflash-22-Fix-an-error-handling-path-in-cxlflash.patch.
- Refresh
  patches.drivers/scsi-cxlflash-23-Remove-unnecessary-existence-check.patch.
- Refresh
  patches.drivers/scsi-cxlflash-24-Avoid-double-mutex-unlock.patch.
- Refresh
  patches.drivers/scsi-cxlflash-25-Fix-vlun-resize-failure-in-the-shrink-.patch.
- Refresh
  patches.drivers/scsi-libfc-fix-a-deadlock-in-fc_rport_work.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Add-ATIO-Q-processing-for-INTx-mode.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Allow-MBC_GET_PORT_DATABASE-to-query-an.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Changes-to-support-N2N-logins.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Query-FC4-type-during-RSCN-processing.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Reinstate-module-parameter-ql2xenablems.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Update-driver-version-to-10.00.00.02-k.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Use-ql2xnvmeenable-to-enable-Q-Pair-for.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-don-t-break-the-bsg-lib-abstractions.patch.
- Refresh
  patches.drivers/scsi-scsi_transport_iscsi-fix-the-issue-that.patch.
- Refresh
  patches.drivers/scsi_transport_fc-return-EBUSY-for-deleted-vport.patch.
- Refresh
  patches.fixes/0001-loop-Add-PF_LESS_THROTTLE-to-block-loop-device-threa.patch.
- Refresh
  patches.fixes/0001-md-raid5-fix-a-race-condition-in-stripe-batch.patch.
  Update Git-repo tags according to current content in each repository.
- commit e2d8d15
* Mon Oct 30 2017 msuchanek@suse.de
- cxl: Fix driver use count (bsc#1055014).
- commit 004458e
* Mon Oct 30 2017 msuchanek@suse.de
- powerpc/tm: Fix illegal TM state in signal handler
  (bsc#1065729).
- powerpc/pseries: Fix parent_dn reference leak in add_dt_node()
  (bsc#1065729).
- powerpc/mm/hash: Free the subpage_prot_table correctly
  (bsc#1065729).
- powerpc/mm: Fix check of multiple 16G pages from device tree
  (bsc#1065729).
- powerpc: Correct instruction code for xxlor instruction
  (bsc#1065729).
- commit 701cd66
* Mon Oct 30 2017 ddiss@suse.de
- SMB3: Validate negotiate request must always be signed
  (bsc#1064597).
- SMB: fix validate negotiate info uninitialised memory use
  (bsc#1064597).
- SMB: fix leak of validate negotiate info response buffer
  (bsc#1064597).
- commit f686414
* Mon Oct 30 2017 yousaf.kaukab@suse.com
- cavium: cn99xx: enable out of tree ahci errata
  Refresh
  patches.drivers/0001-PCI-Vulcan-AHCI-PCI-bar-fix-for-Broadcom-Vulcan-earl.patch.
- commit 5b59192
* Mon Oct 30 2017 vbabka@suse.cz
- drivers: dma-mapping: Do not leave an invalid area->pages
  pointer in dma_common_contiguous_remap() (Git-fixes,
  bsc#1065692).
- commit 0f78052
* Mon Oct 30 2017 jgross@suse.com
- xen: fix booting ballooned down hvm guest (bnc#1065600).
- commit 177d959
* Mon Oct 30 2017 jslaby@suse.cz
- objtool: Fix memory leak in decode_instructions() (bnc#1058115).
- x86/unwind: Disable unwinder warnings on 32-bit (bnc#1058115).
- x86/unwind: Align stack pointer in unwinder dump (bnc#1058115).
- x86/unwind: Use MSB for frame pointer encoding on 32-bit
  (bnc#1058115).
- x86/unwind: Fix dereference of untrusted pointer (bnc#1058115).
- x86/kvm: Move kvm_fastop_exception to .fixup section
  (bnc#1058115).
- objtool: Upgrade libelf-devel warning to error for
  CONFIG_ORC_UNWINDER (bnc#1058115).
- kprobes/x86: Set up frame pointer in kprobe trampoline
  (bnc#1058115).
- objtool: Support unoptimized frame pointer setup (bnc#1058115).
- objtool: Skip unreachable warnings for GCC 4.4 and older
  (bnc#1058115).
- commit 0942514
* Mon Oct 30 2017 yousaf.kaukab@suse.com
- tty: xilinx_uartps: move to arch_initcall for earlier console
  (fate#323912).
- serial: xuartps: Remove __init marking from early write
  (fate#323912).
- commit bb8f007
* Sun Oct 29 2017 jslaby@suse.cz
- x86/unwind: Show function name+offset in ORC error messages
  (bnc#1058115).
- x86/entry: Fix idtentry unwind hint (bnc#1058115).
  x86/entry: Fix idtentry unwind hint (bnc#1058115).
- commit a59af47
* Fri Oct 27 2017 fdmanana@suse.com
- Btrfs: add support for fallocate's zero range operation
  (fate#323233).
- commit 5c14b28
* Fri Oct 27 2017 yousaf.kaukab@suse.com
- random: do not ignore early device randomness (bsc#1064475).
- commit 272473f
* Fri Oct 27 2017 msuchanek@suse.de
- powerpc/perf: Fix for core/nest imc call trace on cpuhotplug
  (FATE#322448, bsc#1054914).
- commit c0cc9d1
* Fri Oct 27 2017 msuchanek@suse.de
- powerpc/perf: Fix IMC initialization crash (FATE#322448,
  bsc#1054914).
- powerpc/perf: Add ___GFP_NOWARN flag to alloc_pages_node()
  (FATE#322448, bsc#1054914).
- commit 64c2f61
* Fri Oct 27 2017 jslaby@suse.cz
- futex: futex_wake_op, fix sign_extend32 sign bits (bnc#1064590).
- futex: futex_wake_op, do not fail on invalid op (bnc#1064590).
- commit dff8df7
* Thu Oct 26 2017 neilb@suse.com
- VFS: expedite unmount (bsc#1024412).
- commit 7f33b23
* Wed Oct 25 2017 tbogendoerfer@suse.de
- blacklist.conf: patched file is not backported
- commit 7103104
* Wed Oct 25 2017 tbogendoerfer@suse.de
- bpf: fix byte order test in test_verifier (bsc#1056787).
- commit 0318ced
* Wed Oct 25 2017 tbogendoerfer@suse.de
- nfp: handle page allocation failures (bsc#1055968).
- nfp: fix ethtool stats gather retry (bsc#1055968).
- nfp: wait for the NSP resource to appear on boot (bsc#1055968).
- nfp: wait for board state before talking to the NSP
  (bsc#1055968).
- nfp: flower: restore RTNL locking around representor updates
  (bsc#1055968).
- nfp: build the flower offload by default (bsc#1055968).
- nfp: be drop monitor friendly (bsc#1055968).
- nfp: move the start/stop app callbacks back (bsc#1055968).
- nfp: flower: base lifetime of representors on existence of
  lower vNIC (bsc#1055968).
- nfp: separate app vNIC init/clean from alloc/free (bsc#1055968).
- nfp: add basic SR-IOV ndo functions to representors
  (bsc#1055968).
- nfp: add basic SR-IOV ndo functions (bsc#1055968).
- nfp: don't reuse pointers in ring dumping (bsc#1055968).
- nfp: fix copy paste in names and messages regarding vNICs
  (bsc#1055968).
- nfp: add ethtool statistics for representors (bsc#1055968).
- nfp: add pointer to vNIC config memory to nfp_port structure
  (bsc#1055968).
- nfp: report MAC statistics in ethtool (bsc#1055968).
- nfp: store pointer to MAC statistics in nfp_port (bsc#1055968).
- nfp: split software and hardware vNIC statistics (bsc#1055968).
- nfp: add helper for printing ethtool strings (bsc#1055968).
- nfp: don't report standard netdev statistics in ethtool
  (bsc#1055968).
- nfp: allow retreiving management FW logs on representors
  (bsc#1055968).
- nfp: provide ethtool_drvinfo on representors (bsc#1055968).
- nfp: link basic ethtool ops to representors (bsc#1055968).
- nfp: process MTU updates from firmware flower app (bsc#1055968).
- nfp: process control messages in workqueue in flower app
  (bsc#1055968).
- nfp: send control message when MAC representors are created
  (bsc#1055968).
- bpf, nfp: implement jiting of BPF_J{LT,LE} (bsc#1055968).
- nfp: TX time stamp packets before HW doorbell is rung
  (bsc#1055968).
- commit 773d1a0
* Wed Oct 25 2017 tbogendoerfer@suse.de
- bpf: fix pattern matches for direct packet access (bsc#1056787).
- bpf: fix off by one for range markings with L{T, E} patterns
  (bsc#1056787).
- bpf: do not test for PCPU_MIN_UNIT_SIZE before percpu
  allocations (bsc#1056787).
- bpf: disallow arithmetic operations on context pointer
  (bsc#1056787).
- bpf: fix liveness marking (bsc#1056787).
- bpf: fix bpf_tail_call() x64 JIT (bsc#1056787).
- bpf: do not disable/enable BH in bpf_map_free_id()
  (bsc#1056787).
- bpf/verifier: reject BPF_ALU64|BPF_END (bsc#1056787).
- bpf: Only set node->ref = 1 if it has not been set
  (bsc#1056787).
- bpf: Inline LRU map lookup (bsc#1056787).
- bpf/verifier: document liveness analysis (bsc#1056787).
- bpf/verifier: remove varlen_map_value_access flag (bsc#1056787).
- bpf/verifier: when pruning a branch, ignore its write marks
  (bsc#1056787).
- bpf: inline map in map lookup functions for array and htab
  (bsc#1056787).
- bpf: make htab inlining more robust wrt assumptions
  (bsc#1056787).
- bpf: fix liveness propagation to parent in spilled stack slots
  (bsc#1056787).
- bpf: export bpf_prog_inc_not_zero (bsc#1056787).
- bpf/verifier: track liveness for pruning (bsc#1056787).
- bpf: enable BPF_J{LT, LE, SLT, SLE} opcodes in verifier
  (bsc#1056787).
- bpf: add BPF_J{LT,LE,SLT,SLE} instructions (bsc#1056787).
- bpf: Extend check_uarg_tail_zero() checks (bsc#1056787).
- bpf: Move check_uarg_tail_zero() upward (bsc#1056787).
- bpf/verifier: increase complexity limit to 128k (bsc#1056787).
- bpf/verifier: more concise register state logs for constant
  var_off (bsc#1056787).
- bpf/verifier: track signed and unsigned min/max values
  (bsc#1056787).
- bpf/verifier: rework value tracking (bsc#1056787).
- bpf: fix bpf_prog_get_info_by_fd to dump correct xlated_prog_len
  (bsc#1056787).
- bpf: don't indicate success when copy_from_user fails
  (bsc#1056787).
- selftests/bpf: subtraction bounds test (bsc#1056787).
- bpf: more tests for mixed signed and unsigned bounds checks
  (bsc#1056787).
- bpf: add test for mixed signed and unsigned bounds checks
  (bsc#1056787).
- bpf: fix up test cases with mixed signed/unsigned bounds
  (bsc#1056787).
- bpf: Implement show_options (bsc#1056787).
- bpf: don't open-code memdup_user() (bsc#1056787).
- bpf: export whether tail call has jited owner (bsc#1056787).
- bpf: Fix out-of-bound access on interpreters (bsc#1056787).
- bpf: Add syscall lookup support for fd array and htab
  (bsc#1056787).
- bpf: possibly avoid extra masking for narrower load in verifier
  (bsc#1056787).
- selftests/bpf: Add test cases to test narrower ctx field loads
  (bsc#1056787).
- bpf: reset id on spilled regs in clear_all_pkt_pointers
  (bsc#1056787).
- bpf: reset id on CONST_IMM transition (bsc#1056787).
- bpf: don't check spilled reg state for non-STACK_SPILLed type
  slots (bsc#1056787).
- bpf: cgroup skb progs cannot access ld_abs/ind (bsc#1056787).
- bpf: Add BPF_OBJ_GET_INFO_BY_FD (bsc#1056787).
- bpf: Add jited_len to struct bpf_prog (bsc#1056787).
- bpf: Add BPF_MAP_GET_FD_BY_ID (bsc#1056787).
- bpf: Add BPF_PROG_GET_FD_BY_ID (bsc#1056787).
- bpf: Add BPF_(PROG|MAP)_GET_NEXT_ID command (bsc#1056787).
- bpf: Introduce bpf_map ID (bsc#1056787).
- bpf: Remove the capability check for cgroup skb eBPF program
  (bsc#1056787).
- bpf: Allow CGROUP_SKB eBPF program to access sk_buff
  (bsc#1056787).
- bpf: use different interpreter depending on required stack size
  (bsc#1056787).
- bpf: reconcile bpf_tail_call and stack_depth (bsc#1056787).
- bpf: split bpf core interpreter (bsc#1056787).
- bpf: free up BPF_JMP | BPF_CALL | BPF_X opcode (bsc#1056787).
- commit afa6680
* Wed Oct 25 2017 jthumshirn@suse.de
- Update config files, add CONFIG_BLK_MQ_RDMA=y.
- commit 596d823
* Wed Oct 25 2017 jthumshirn@suse.de
- nvme-fc: correct io timeout behavior (FATE#323952, FATE#322506).
- nvme-fc: correct io termination handling (FATE#323952,
  FATE#322506).
- nvme-pci: add SGL support (FATE#323952, FATE#322506).
- nvme: use ida_simple_{get,remove} for the controller instance
  (FATE#323952, FATE#322506).
- nvmet: Change max_nsid in subsystem due to ns_disable if needed
  (FATE#323952, FATE#322506).
- nvme-loop: Add BLK_MQ_F_NO_SCHED flag to admin tag set
  (FATE#323952, FATE#322506).
- nvme-fc: Add BLK_MQ_F_NO_SCHED flag to admin tag set
  (FATE#323952, FATE#322506).
- nvme-rdma: Add BLK_MQ_F_NO_SCHED flag to admin tag set
  (FATE#323952, FATE#322506).
- nvme-pci: fix typos in comments (FATE#323952, FATE#322506).
- nvme-rdma: stop controller reset if the controller is deleting
  (FATE#323952, FATE#322506).
- nvme-rdma: change queue flag semantics DELETING -> ALLOCATED
  (FATE#323952, FATE#322506).
- nvme-rdma: Don't local invalidate if the queue is not live
  (FATE#323952, FATE#322506).
- nvme-rdma: teardown admin/io queues once on error recovery
  (FATE#323952, FATE#322506).
- nvme-rdma: Check that reinit_request got a proper mr
  (FATE#323952, FATE#322506).
- nvme-rdma: move assignment to declaration (FATE#323952,
  FATE#322506).
- nvme-rdma: fix wrong logging message (FATE#323952, FATE#322506).
- nvme-rdma: pass tagset to directly nvme_rdma_free_tagset
  (FATE#323952, FATE#322506).
- nvme: simplify compat_ioctl handling (FATE#323952, FATE#322506).
- nvme-fc: move remote port get/put/free location (FATE#323952,
  FATE#322506).
- nvme-fc: create fc class and transport device (FATE#323952,
  FATE#322506).
- nvme-fabrics: request transport module (FATE#323952,
  FATE#322506).
- nvmet: bump NVMET_NR_QUEUES to 128 (FATE#323952, FATE#322506).
- nvme: use menu Kconfig interface (FATE#323952, FATE#322506).
- nvme: update timeout module parameter type (FATE#323952,
  FATE#322506).
- nvme-fcloop: fix port deletes and callbacks (FATE#323952,
  FATE#322506).
- nvmet-fc: sync header templates with comments (FATE#323952,
  FATE#322506).
- nvmet-fc: ensure target queue id within range (FATE#323952,
  FATE#322506).
- nvmet-fc: on port remove call put outside lock (FATE#323952,
  FATE#322506).
- nvme-rdma: don't fully stop the controller in error recovery
  (FATE#323952, FATE#322506).
- nvme-rdma: give up reconnect if state change fails (FATE#323952,
  FATE#322506).
- nvme-core: Use nvme_wq to queue async events and fw activation
  (FATE#323952, FATE#322506).
- nvme: fix sqhd reference when admin queue connect fails
  (FATE#323952, FATE#322506).
- nvmet: implement valid sqhd values in completions (FATE#323952,
  FATE#322506).
- nvme-fabrics: Allow 0 as KATO value (FATE#323952, FATE#322506).
- nvme: allow timed-out ios to retry (FATE#323952, FATE#322506).
- nvme: stop aer posting if controller state not live
  (FATE#323952, FATE#322506).
- nvme-pci: Print invalid SGL only once (FATE#323952,
  FATE#322506).
- nvme-pci: initialize queue memory before interrupts
  (FATE#323952, FATE#322506).
- nvmet-fc: fix failing max io queue connections (FATE#323952,
  FATE#322506).
- nvme-fc: use transport-specific sgl format (FATE#323952,
  FATE#322506).
- nvme: add transport SGL definitions (FATE#323952, FATE#322506).
- commit 2ece78f
* Wed Oct 25 2017 jthumshirn@suse.de
- nvmet-fcloop: remove use of FC-specific error codes
  (FATE#323952, FATE#322506).
- nvme-pci: implement the HMB entry number and size limitations
  (FATE#323952, FATE#322506).
- nvme-pci: propagate (some) errors from host memory buffer setup
  (FATE#323952, FATE#322506).
- nvme-pci: use appropriate initial chunk size for HMB allocation
  (FATE#323952, FATE#322506).
- nvme-pci: fix host memory buffer allocation fallback
  (FATE#323952, FATE#322506).
- nvme: fix lightnvm check (FATE#323952, FATE#322506).
- nvmet: add support for reporting the host identifier
  (FATE#323952, FATE#322506).
- nvme: Use metadata for passthrough commands (FATE#323952,
  FATE#322506).
- nvme: Make nvme user functions static (FATE#323952,
  FATE#322506).
- nvme/pci: Use req_op to determine DIF remapping (FATE#323952,
  FATE#322506).
- nvme: factor metadata handling out of __nvme_submit_user_cmd
  (FATE#323952, FATE#322506).
- nvme-fabrics: Convert nvmf_transports_mutex to an rwsem
  (FATE#323952, FATE#322506).
- nvme: don't blindly overwrite identifiers on disk revalidate
  (FATE#323952, FATE#322506).
- nvme: remove nvme_revalidate_ns (FATE#323952, FATE#322506).
- nvme: remove unused struct nvme_ns fields (FATE#323952,
  FATE#322506).
- nvme: allow calling nvme_change_ctrl_state from irq context
  (FATE#323952, FATE#322506).
- nvme: report more detailed status codes to the block layer
  (FATE#323952, FATE#322506).
- nvme: honor RTD3 Entry Latency for shutdowns (FATE#323952,
  FATE#322506).
- nvme: fix uninitialized prp2 value on small transfers
  (FATE#323952, FATE#322506).
- nvme-rdma: Use unlikely macro in the fast path (FATE#323952,
  FATE#322506).
- nvmet-fc: simplify sg list handling (FATE#323952, FATE#322506).
- nvme-fc: Reattach to localports on re-registration (FATE#323952,
  FATE#322506).
- nvme: rename AMS symbolic constants to fit specification
  (FATE#323952, FATE#322506).
- nvme: add symbolic constants for CC identifiers (FATE#323952,
  FATE#322506).
- nvme: fix identify namespace logging (FATE#323952, FATE#322506).
- nvme-fabrics: log a warning if hostid is invalid (FATE#323952,
  FATE#322506).
- nvme-rdma: call ops->reg_read64 instead of nvmf_reg_read64
  (FATE#323952, FATE#322506).
- nvme-rdma: cleanup error path in controller reset (FATE#323952,
  FATE#322506).
- nvme-rdma: introduce nvme_rdma_start_queue (FATE#323952,
  FATE#322506).
- nvme-rdma: rename nvme_rdma_init_queue to nvme_rdma_alloc_queue
  (FATE#323952, FATE#322506).
- nvme-rdma: stop queues instead of simply flipping their state
  (FATE#323952, FATE#322506).
- nvme-rdma: introduce configure/destroy io queues (FATE#323952,
  FATE#322506).
- nvme-rdma: reuse configure/destroy_admin_queue (FATE#323952,
  FATE#322506).
- nvme-rdma: don't free tagset on resets (FATE#323952,
  FATE#322506).
- nvme-rdma: disable the controller on resets (FATE#323952,
  FATE#322506).
- nvme-rdma: move tagset allocation to a dedicated routine
  (FATE#323952, FATE#322506).
- nvme: Add admin_tagset pointer to nvme_ctrl (FATE#323952,
  FATE#322506).
- nvme-rdma: move nvme_rdma_configure_admin_queue code location
  (FATE#323952, FATE#322506).
- nvme-rdma: remove NVME_RDMA_MAX_SEGMENT_SIZE (FATE#323952,
  FATE#322506).
- nvmet-fcloop: remove ALL_OPTS define (FATE#323952, FATE#322506).
- nvmet: fix the return error code of target if host is not
  allowed (FATE#323952, FATE#322506).
- nvmet: use NVME_NSID_ALL (FATE#323952, FATE#322506).
- nvme: add support for NVMe 1.3 Timestamp Feature (FATE#323952,
  FATE#322506).
- nvme: define NVME_NSID_ALL (FATE#323952, FATE#322506).
- nvme: add support for FW activation without reset (FATE#323952,
  FATE#322506).
- blk-mq: Make blk_mq_reinit_tagset() calls easier to read
  (FATE#323952, FATE#322506).
- nvmem: include linux/err.h from header (FATE#323952,
  FATE#322506).
- nvmem: core: Add nvmem_cell_read_u32 (FATE#323952, FATE#322506).
- nvmet-rdma: remove redundant empty device add callout
  (FATE#323952, FATE#322506).
- nvme-rdma: remove redundant empty device add callout
  (FATE#323952, FATE#322506).
- nvme-rdma: use intelligent affinity based queue mappings
  (FATE#323952, FATE#322506).
- block: Add rdma affinity based queue mapping helper
  (FATE#323952, FATE#322506).
- commit 747cb11
* Wed Oct 25 2017 jthumshirn@suse.de
- scripts/git_sort/git_sort.py: Add upstream NVMe repository
- commit 7a0ab79
* Wed Oct 25 2017 tbogendoerfer@suse.de
- bnxt_en: Fix possible corruption in DCB parameters from firmware
  (bsc#1050242 FATE#322914).
- bnxt_en: Fix possible corrupted NVRAM parameters from firmware
  response (bsc#1050242 FATE#322914).
- bnxt_en: Fix VF resource checking (bsc#1050242 FATE#322914).
- bnxt_en: Fix VF PCIe link speed and width logic (bsc#1050242
  FATE#322914).
- bnxt_en: Don't use rtnl lock to protect link change logic in
  workqueue (bsc#1050242 FATE#322914).
- bnxt_en: Improve VF/PF link change logic (bsc#1050242
  FATE#322914).
- commit 99e5c52
* Tue Oct 24 2017 oneukum@suse.com
- power: supply: Fix power_supply_am_i_supplied to return -ENODEV
  when apropriate (bsc#1064870).
- commit 36c0450
* Tue Oct 24 2017 msuchanek@suse.de
- Blacklist build fixes for configurations we don't use
  7e7dc66adcf4 powerpc/mm: Build fix for non SPARSEMEM_VMEMAP config
- commit 65839a0
* Tue Oct 24 2017 oneukum@suse.com
- bcma: gpio: Correct number of GPIOs for BCM53573 (bsc#1048185).
- commit b622f9e
* Tue Oct 24 2017 msuchanek@suse.de
- Blacklist fixes for unsupported ppc platforms
  3c29b6038828 powerpc/8xx: fix mpc8xx_get_irq() return on no irq
  8d046759f6ad powerpc/44x: Fix mask and shift to zero bug
  c65540453e15 powerpc/83xx: Use sizeof correct type when ioremapping
- commit bc9210e
* Tue Oct 24 2017 oneukum@suse.com
- iwlwifi: nvm: set the correct offsets to 3168 series
  (FATE#322675).
- commit 012cc15
* Tue Oct 24 2017 oneukum@suse.com
- blacklist.conf: just removes an unused constant
- commit 41edaf8
* Tue Oct 24 2017 oneukum@suse.com
- blacklist.conf: We do not use m-bus
- commit 0028f53
* Tue Oct 24 2017 oneukum@suse.com
- pinctrl: check ops->pin_config_set in pinconf_set_config()
  (bsc#1064862).
- commit 7ffeae7
* Tue Oct 24 2017 oneukum@suse.com
- iwlwifi: mvm: return -ENODATA when reading the temperature
  with the FW down (FATE#322675).
- commit 82b7e03
* Tue Oct 24 2017 oneukum@suse.com
- blacklist.conf: Totally unused
- commit c8b4062
* Tue Oct 24 2017 mcgrof@suse.com
- supported.conf: add CONFIG_TEST_LKM=m on kselftests-kmp
- Update config files.
  The kselftests-kmp fails to build on vanilla as no modules
  are present. We add the test_module just so that kselftests-kmp
  is never empty on any flavor.
- commit 88d2cfb
* Mon Oct 23 2017 msuchanek@suse.de
- Remove remaining RPi3 patches.
  The post-4.12 patches modify only devicetree and we don't use the
  devicetree from kernel.
- commit c65306e
* Mon Oct 23 2017 dbueso@suse.de
- locking/rwsem-xadd: Fix missed wakeup due to reordering of load (bsc#1050549).
- commit 16013be
* Mon Oct 23 2017 msuchanek@suse.de
- Refresh metadata on rpi3 enablement patches.
- commit 39ba7ab
* Mon Oct 23 2017 dmulder@suse.com
- CIFS: fix circular locking dependency (bsc#1064701).
- commit 0d88f5f
* Mon Oct 23 2017 oneukum@suse.com
- blacklist.conf: We do not use the driver. It is not even compiled.
- commit 81c882d
* Mon Oct 23 2017 oneukum@suse.com
- blacklist.conf: We do not use the driver. It is not even compiled.
- commit 363694d
* Mon Oct 23 2017 oneukum@suse.com
- blacklist.conf: We do not use the driver. It is not even compiled.
- commit c1f6612
* Mon Oct 23 2017 oneukum@suse.com
- blacklist.conf: We do not use the driver. It is not even compiled.
- commit 48d23a2
* Mon Oct 23 2017 oneukum@suse.com
- blacklist.conf: We do not use the driver. It is not even compiled.
- commit 865ea84
* Mon Oct 23 2017 oneukum@suse.com
- blacklist.conf: We do not use the driver. It is not even compiled.
- commit 5da7287
* Mon Oct 23 2017 oneukum@suse.com
- blacklist.conf: We do not use the driver. It is not even compiled.
- commit 87aae5f
* Mon Oct 23 2017 oneukum@suse.com
- blacklist.conf: We do not use the driver. It is not even compiled.
- commit 5d96e28
* Mon Oct 23 2017 oneukum@suse.com
- blacklist.conf: We do not use the driver. It is not even compiled.
- commit 55132f5
* Mon Oct 23 2017 oneukum@suse.com
- blacklist.conf: We do not use the driver. It is not even compiled.
- commit 75c2056
* Mon Oct 23 2017 oneukum@suse.com
- blacklist.conf: We do not use the driver. It is not even compiled.
- commit 3eb65cd
* Mon Oct 23 2017 oneukum@suse.com
- blacklist.conf: We do noy use the driver. It is not even compiled.
- commit 973ce20
* Mon Oct 23 2017 oneukum@suse.com
- blacklist.conf: We do not use the driver. It is not even compiled.
- commit ae3cfa6
* Mon Oct 23 2017 oneukum@suse.com
- blacklist.conf: We do not use the driver. It is not even compiled.
- commit cb9514c
* Mon Oct 23 2017 oneukum@suse.com
- blacklist.conf: We do not use the driver. It is not even compiled.
- commit 93eb95b
* Mon Oct 23 2017 oneukum@suse.com
- blacklist.conf: We do not use thwe driver. It is not even compiled.
- commit 1fc6071
* Mon Oct 23 2017 oneukum@suse.com
- blacklist.conf: We do not use the driver. It is not even compiled.
- commit cc3ae21
* Mon Oct 23 2017 oneukum@suse.com
- blacklist.conf: We do not use the driver. It is not even compiled.
- commit 7deff52
* Mon Oct 23 2017 oneukum@suse.com
- blacklist.conf: We do not use the driver. It is not even compiled.
- commit 8db603c
* Mon Oct 23 2017 oneukum@suse.com
- blacklist.conf: We do not use the driver. It is not even compiled.
- commit 5e82dac
* Mon Oct 23 2017 oneukum@suse.com
- blacklist.conf: We do not use the driver. It is not even compiled.
- commit 17fddcc
* Mon Oct 23 2017 oneukum@suse.com
- blacklist.conf: We do not use the driver. It is not even compiled.
- commit 5ec0458
* Mon Oct 23 2017 oneukum@suse.com
- blacklist.conf: We do not use the driver. It is not even compiled.
- commit ded0aea
* Mon Oct 23 2017 oneukum@suse.com
- blacklist.conf: we do not use the driver. It is not even compiled.
- commit d4a32ec
* Mon Oct 23 2017 tbogendoerfer@suse.de
- net/sched: cls_flower: Set egress_dev mark when calling into
  the HW driver (bsc#1056787).
- commit 7276c25
* Mon Oct 23 2017 ohering@suse.de
- vmbus: hvsock: add proper sync for
  vmbus_hvsock_device_unregister() (fate#323887).
- commit b1aee9d
* Mon Oct 23 2017 bpoirier@suse.com
- Refresh patches.suse/0001-ipc-sem-drop-sem_checkid-helper.patch.
- Refresh
  patches.suse/0001-rbtree-cache-leftmost-node-internally.patch.
- Refresh
  patches.suse/0002-ipc-sem-play-nicer-with-large-nsops-allocations.patch.
- Refresh
  patches.suse/0002-rbtree-optimize-root-check-during-rebalancing-loop.patch.
- Refresh
  patches.suse/0003-rbtree-add-some-additional-comments-for-rebalancing-.patch.
- Refresh
  patches.suse/0008-sched-deadline-replace-earliest-dl-and-rq-leftmost-c.patch.
- Refresh
  patches.suse/0009-locking-rtmutex-replace-top-waiter-and-pi_waiters-le.patch.
- Refresh
  patches.suse/0010-block-cfq-replace-cfq_rb_root-leftmost-caching.patch.
- Refresh
  patches.suse/0012-lib-interval-tree-correct-comment-wrt-generic-flavor.patch.
- Refresh
  patches.suse/0013-procfs-use-faster-rb_first_cached.patch.
- Refresh
  patches.suse/0014-fs-epoll-use-faster-rb_first_cached.patch.
- Refresh patches.suse/0015-mem-memcg-cache-rightmost-node.patch.
- Refresh
  patches.suse/0016-block-cfq-cache-rightmost-rb_node.patch.
- Refresh patches.suse/0039-efi-Add-EFI_SECURE_BOOT-bit.patch.
- Refresh
  patches.suse/0040-Add-the-ability-to-lock-down-access-to-the-running-k.patch.
- Refresh
  patches.suse/0041-efi-Lock-down-the-kernel-if-booted-in-secure-boot-mo.patch.
- Refresh
  patches.suse/0042-Enforce-module-signatures-if-the-kernel-is-locked-do.patch.
- Refresh
  patches.suse/0043-Restrict-dev-mem-and-dev-kmem-when-the-kernel-is-loc.patch.
- Refresh
  patches.suse/0045-kexec-Disable-at-runtime-if-the-kernel-is-locked-dow.patch.
- Refresh
  patches.suse/0046-Copy-secure_boot-flag-in-boot-params-across-kexec-re.patch.
- Refresh
  patches.suse/0047-kexec_file-Disable-at-runtime-if-securelevel-has-bee.patch.
- Refresh
  patches.suse/0048-hibernate-Disable-when-the-kernel-is-locked-down.patch.
- Refresh
  patches.suse/0049-uswsusp-Disable-when-the-kernel-is-locked-down.patch.
- Refresh
  patches.suse/0050-PCI-Lock-down-BAR-access-when-the-kernel-is-locked-d.patch.
- Refresh
  patches.suse/0051-x86-Lock-down-IO-port-access-when-the-kernel-is-lock.patch.
- Refresh
  patches.suse/0052-x86-Restrict-MSR-access-when-the-kernel-is-locked-do.patch.
- Refresh
  patches.suse/0053-asus-wmi-Restrict-debugfs-interface-when-the-kernel-.patch.
- Refresh
  patches.suse/0054-ACPI-Limit-access-to-custom_method-when-the-kernel-i.patch.
- Refresh
  patches.suse/0055-acpi-Ignore-acpi_rsdp-kernel-param-when-the-kernel-h.patch.
- Refresh
  patches.suse/0056-acpi-Disable-ACPI-table-override-if-the-kernel-is-lo.patch.
- Refresh
  patches.suse/0057-acpi-Disable-APEI-error-injection-if-the-kernel-is-l.patch.
  These patches are tagged with Git-commit ids which are not actually found
  in the respective Git-repo. Udate the tags accordingly.
- commit bad2721
* Fri Oct 20 2017 mkubecek@suse.cz
- packet: in packet_do_bind, test fanout with bind_lock held
  (CVE-2017-15649 bsc#1064388).
- packet: hold bind lock when rebinding to fanout hook
  (CVE-2017-15649 bsc#1064388).
- commit d09ce18
* Fri Oct 20 2017 mkubecek@suse.cz
- series.conf: refresh
  (just ran scripts/series_sort.py)
- commit 1be1653
* Fri Oct 20 2017 tbogendoerfer@suse.de
- i40iw: Fix port number for query QP (bsc#1058659 FATE#322535).
- i40iw: Add missing memory barriers (bsc#1058659 FATE#322535).
- IB/hfi1: On error, fix use after free during user context setup
  (bsc#1060463 FATE#323043).
- Revert "IB/ipoib: Update broadcast object if PKey value was
  changed in index 0" (bsc#1046307 FATE#322941).
- IB/hfi1: Return correct value in general interrupt handler
  (bsc#1060463 FATE#323043).
- IB/hfi1: Only reset QSFP after link up and turn off AOC TX
  (bsc#1060463 FATE#323043).
- IB/hfi1: Turn off AOC TX after offline substates (bsc#1060463
  FATE#323043).
- IB/ipoib: Fix inconsistency with free_netdev and
  free_rdma_netdev (bsc#1046307 FATE#322941).
- IB: Correct MR length field to be 64-bit (bsc#1046306
  FATE#322942).
- commit e86f670
* Fri Oct 20 2017 tbogendoerfer@suse.de
- drivers: net: xgene: Remove return statement from void function
  (bsc#1064426).
- drivers: net: xgene: Configure tx/rx delay for ACPI
  (bsc#1064426).
- drivers: net: xgene: Read tx/rx delay for ACPI (bsc#1064426).
- drivers: net: xgene: Correct probe sequence handling
  (bsc#1064426).
- xgene: Always get clk source, but ignore if it's missing for
  SGMII ports (bsc#1048501).
- xgene: Don't fail probe, if there is no clk resource for SGMII
  interfaces (bsc#1048501).
- commit 5124b20
* Fri Oct 20 2017 msuchanek@suse.de
- Refresh metadata on ibmvnic patches.
- commit 2625b9d
* Fri Oct 20 2017 msuchanek@suse.de
- Blacklist unsupported architectures.
- commit e2b7413
* Fri Oct 20 2017 jkosina@suse.cz
- Update config files.
- commit 7e76d8c
* Fri Oct 20 2017 ohering@suse.de
- x86/hyperv: Fix hypercalls with extended CPU ranges for TLB
  flushing (fate#323887).
- x86/hyperv: Don't use percpu areas for pcpu_flush/pcpu_flush_ex
  structures (fate#323887).
- x86/hyperv: Clear vCPU banks between calls to avoid flushing
  unneeded vCPUs (fate#323887).
- Drivers: hv: vmbus: Fix bugs in rescind handling (fate#323887).
- Drivers: hv: fcopy: restore correct transfer length
  (fate#323887).
- vmbus: don't acquire the mutex in
  vmbus_hvsock_device_unregister() (fate#323887).
- hv_netvsc: fix send buffer failure on MTU change (fate#323887).
- netvsc: increase default receive buffer size (fate#323887).
- x86/hyper-v: Remove duplicated
  HV_X64_EX_PROCESSOR_MASKS_RECOMMENDED definition (fate#323887).
- hv_netvsc: avoid unnecessary wakeups on subchannel creation
  (fate#323887).
- hv_netvsc: fix deadlock on hotplug (fate#323887).
- hv_netvsc: Fix the channel limit in netvsc_set_rxfh()
  (fate#323887).
- hv_netvsc: Simplify the limit check in netvsc_set_channels()
  (fate#323887).
- hv_netvsc: Simplify num_chn checking in
  rndis_filter_device_add() (fate#323887).
- hv_netvsc: Clean up an unused parameter in
  rndis_filter_set_rss_param() (fate#323887).
- netvsc: allow driver to be removed even if VF is present
  (fate#323887).
- netvsc: cleanup datapath switch (fate#323887).
- tracing/hyper-v: Trace hyperv_mmu_flush_tlb_others()
  (fate#323887).
- x86/hyper-v: Support extended CPU ranges for TLB flush
  hypercalls (fate#323887).
- scsi: storvsc: fix memory leak on ring buffer busy
  (fate#323887).
- hv_netvsc: Fix rndis_filter_close error during netvsc_remove
  (fate#323887).
- hv_netvsc: Add ethtool handler to set and get UDP hash levels
  (fate#323887).
- hv_netvsc: Clean up unused parameter from
  netvsc_get_rss_hash_opts() (fate#323887).
- hv_netvsc: Clean up unused parameter from netvsc_get_hash()
  (fate#323887).
- vmbus: remove unused vmbus_sendpacket_ctl (fate#323887).
- vmbus: remove unused vmubs_sendpacket_pagebuffer_ctl
  (fate#323887).
- vmbus: remove unused vmbus_sendpacket_multipagebuffer
  (fate#323887).
- Drivers: hv: vmbus: Fix rescind handling issues (fate#323887).
- Tools: hv: update buffer handling in hv_fcopy_daemon
  (fate#323887).
- Tools: hv: fix snprintf warning in kvp_daemon (fate#323887).
- Drivers: hv: kvp: Use MAX_ADAPTER_ID_SIZE for translating
  adapter id (fate#323887).
- Drivers: hv: balloon: Initialize last_post_time on startup
  (fate#323887).
- Drivers: hv: balloon: Show the max dynamic memory assigned
  (fate#323887).
- Drivers: hv: balloon: Correctly update onlined page count
  (fate#323887).
- Tools: hv: vss: Skip freezing filesystems backed by loop
  (fate#323887).
- netvsc: keep track of some non-fatal overload conditions
  (fate#323887).
- netvsc: allow controlling send/recv buffer size (fate#323887).
- netvsc: remove unnecessary check for NULL hdr (fate#323887).
- netvsc: remove unnecessary cast of void pointer (fate#323887).
- netvsc: whitespace cleanup (fate#323887).
- netvsc: no need to allocate send/receive on numa node
  (fate#323887).
- netvsc: check error return when restoring channels and mtu
  (fate#323887).
- netvsc: propagate MAC address change to VF slave (fate#323887).
- netvsc: don't signal host twice if empty (fate#323887).
- netvsc: delay setup of VF device (fate#323887).
- x86/hyper-v: Use hypercall for remote TLB flush (fate#323887).
- hyper-v: Globalize vp_index (fate#323887).
- x86/hyper-v: Implement rep hypercalls (fate#323887).
- hyper-v: Use fast hypercall for HVCALL_SIGNAL_EVENT
  (fate#323887).
- x86/hyper-v: Introduce fast hypercall implementation
  (fate#323887).
- x86/hyper-v: Make hv_do_hypercall() inline (fate#323887).
- x86/hyper-v: Include hyperv/ only when CONFIG_HYPERV is set
  (fate#323887).
- netvsc: fix race on sub channel creation (fate#323887).
- PCI: hv: Do not sleep in compose_msi_msg() (fate#323887).
- netvsc: remove bonding setup script (fate#323887).
- netvsc: Initialize 64-bit stats seqcount (fate#323887).
- Revert "x86/hyper-v: include hyperv/ only when CONFIG_HYPERV
  is set" (fate#323887).
- x86/hyper-v: stash the max number of virtual/logical processor
  (fate#323887).
- x86/hyper-v: include hyperv/ only when CONFIG_HYPERV is set
  (fate#323887).
- vmbus: add prefetch to ring buffer iterator (fate#323887).
- vmbus: more host signalling avoidance (fate#323887).
- vmbus: eliminate duplicate cached index (fate#323887).
- vmbus: refactor hv_signal_on_read (fate#323887).
- vmbus: drop unused ring_buffer_info elements (fate#323887).
- vmbus: simplify hv_ringbuffer_read (fate#323887).
- tools: hv: ignore a NIC if it has been configured (fate#323887).
- commit 6f087bf
* Fri Oct 20 2017 jthumshirn@suse.de
- scsi: pm80xx: corrected linkrate value (FATE#322890,
  bsc#1049518).
- scsi: pm80xx: panic on ncq error cleaning up the read log
  (FATE#322890, bsc#1049518).
- scsi: pm80xx: corrected SATA abort handling sequence
  (FATE#322890, bsc#1049518).
- scsi: pm80xx: modified port reset timer value for PM8006 card
  (FATE#322890, bsc#1049518).
- scsi: pm80xx: cleanup in pm8001_abort_task function
  (FATE#322890, bsc#1049518).
- scsi: pm80xx: tag allocation for phy control request
  (FATE#322890, bsc#1049518).
- scsi: pm80xx: Different SAS addresses for phys (FATE#322890,
  bsc#1049518).
- scsi: pm80xx: ILA and inactive firmware version through sysfs
  (FATE#322890, bsc#1049518).
- scsi: pm80xx: redefine sas_identify_frame structure
  (FATE#322890, bsc#1049518).
- scsi: pm8001: fix double free in pm8001_pci_probe (FATE#322890,
  bsc#1049518).
- commit e741c37
* Fri Oct 20 2017 mgorman@suse.de
- mm, page_alloc: simplify list handling in rmqueue_bulk()
  (bsc#1060256).
- commit 14e8830
* Fri Oct 20 2017 mgorman@suse.de
- mm, pagevec: rename pagevec drained field (bsc#1060256).
- commit ec03f35
* Fri Oct 20 2017 jkosina@suse.cz
- series.conf: reorder to reflect upstream merges
- Refresh
  patches.drivers/scsi-qla2xxx-Allow-MBC_GET_PORT_DATABASE-to-query-an.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Changes-to-support-N2N-logins.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-don-t-break-the-bsg-lib-abstractions.patch.
- commit 7f799ea
* Fri Oct 20 2017 lduncan@suse.com
- scsi: be2iscsi: Fix boot flags in sysfs (bsc#1050253).
- scsi: be2iscsi: Fix return value in mgmt_open_connection
  (bsc#1050253).
- scsi: be2iscsi: Free msi_name and disable HW intr (bsc#1050253).
- scsi: be2iscsi: Fix _modify_eq_delay buffer overflow
  (bsc#1050253).
- scsi: be2iscsi: Fix _get_initname buffer overflow (bsc#1050253).
- scsi: be2iscsi: Modify IOCTL to fetch user configured IQN
  (bsc#1050253).
- scsi: be2iscsi: Add cmd to set host data (bsc#1050253).
- scsi: be2iscsi: Fix misc static analysis errors (bsc#1050253).
- scsi: be2iscsi: Remove A-circumflex character in copyright
  marking (bsc#1050253).
- scsi: be2iscsi: Update driver version (bsc#1050253).
- commit c2fd5a6
* Fri Oct 20 2017 mcgrof@suse.com
- blacklist.conf: add test_kmod blacklist
  CONFIG_TEST_KMOD=n is currently set. When and if we enable it
  then we will need it, otherwise we don't.
- commit 4ceac95
* Thu Oct 19 2017 mgorman@suse.de
- mm: remove __GFP_COLD (bsc#1060256).
- Refresh
  patches.drivers/net-ena-add-support-for-out-of-order-rx-buffers-refi.patch.
- Refresh
  patches.drivers/net-mlx4_en-Improve-receive-data-path.patch.
- mm: remove cold parameter from free_hot_cold_page*
  (bsc#1060256).
- mm: remove cold parameter for release_pages (bsc#1060256).
- mm, pagevec: remove cold parameter for pagevecs (bsc#1060256).
- mm: only drain per-cpu pagevecs once per pagevec usage
  (bsc#1060256).
- mm, truncate: remove all exceptional entries from pagevec
  under one lock (bsc#1060256).
- mm, truncate: do not check mapping for every page being
  truncated (bsc#1060256).
- mm, page_alloc: enable/disable IRQs once when freeing a list
  of pages (bsc#1060256).
- commit af4a6ea
* Thu Oct 19 2017 tiwai@suse.de
- Enable CONFIG_DRM_VC4 again for arm64 with dependencies (bsc#1060104)
- commit ca643c4
* Thu Oct 19 2017 tiwai@suse.de
- Bluetooth: Add support for Intel Bluetooth device 9460/9560
  [8087:0aaa] (bsc#1064235).
- commit a7785ae
* Thu Oct 19 2017 jack@suse.cz
- mm: Batch radix tree operations when truncating pages
  (bsc#1060256).
- mm: Factor out checks and accounting from
  __delete_from_page_cache() (bsc#1060256).
- mm: Move clearing of page->mapping to page_cache_tree_delete()
  (bsc#1060256).
- mm: Move accounting updates before page_cache_tree_delete()
  (bsc#1060256).
- mm: Factor out page cache page freeing into a separate function
  (bsc#1060256).
- mm: Refactor truncate_complete_page() (bsc#1060256).
- mm: Speedup cancel_dirty_page() for clean pages (bsc#1060256).
- mm: hugetlb: return immediately for hugetlb page in
  __delete_from_page_cache() (bsc#1060256).
- commit b25574b
* Thu Oct 19 2017 jlee@suse.com
- efi: Add an EFI signature blob parser (fate#314508).
- Update config files.
- Delete
  patches.suse/0002-Add-an-EFI-signature-blob-parser-and-key-loader.patch.
- commit 50111a7
* Thu Oct 19 2017 jlee@suse.com
- modsign: Use secondary trust keyring for module signing
  (fate#314508).
- commit f04a6b3
* Thu Oct 19 2017 jkosina@suse.cz
- scripts/git_sort/git_sort.py: add David Howell's linux-fs.git
- commit 0a669c1
* Thu Oct 19 2017 jlee@suse.com
- MODSIGN: Allow the "db" UEFI variable to be suppressed
  (fate#314508).
- Delete
  patches.suse/0005-MODSIGN-Support-not-importing-certs-from-db.patch.
- commit fefd1b5
* Thu Oct 19 2017 jlee@suse.com
- Update config files.
- Update
  patches.suse/0004-MODSIGN-Import-certificates-from-UEFI-Secure-Boot.patch
  (fate#314508).
- commit b7a5639
* Thu Oct 19 2017 jlee@suse.com
- efi: Add EFI signature data types (fate#314508).
- Delete patches.suse/0001-Add-EFI-signature-data-types.patch.
- commit a22dd23
* Thu Oct 19 2017 jlee@suse.com
- KEYS: Allow unrestricted boot-time addition of keys to secondary
  keyring (fate#314508).
- commit 01ed74a
* Thu Oct 19 2017 jlee@suse.com
- Delete
  patches.suse/0003-KEYS-Add-a-system-blacklist-keyring.patch.
  This patch already replaced by 734114f87 and 436529562 in v4.12
  kernel.
  734114f87	KEYS: Add a system blacklist keyring
  436529562	X.509: Allow X.509 certs to be blacklisted
- commit 9855c97
* Wed Oct 18 2017 jslaby@suse.cz
- x86/mm: Disable various instrumentations of mm/mem_encrypt.c
  and mm/tlb.c (fate#322123).
- commit bc2e6c5
* Wed Oct 18 2017 mcgrof@suse.com
- mac80211: accept key reinstall without changing anything (CVE-2017-13080 bsc#1063667).
- commit 33c9018
* Wed Oct 18 2017 vbabka@suse.cz
- mm, page_owner: skip unnecessary stack_trace entries (VM
  Functionality, bsc#1063512).
- commit 019f21f
* Wed Oct 18 2017 yousaf.kaukab@suse.com
- supported.conf: enable dw_mmc-rockchip driver
  References: bsc#1064064
- commit 33b440c
* Wed Oct 18 2017 tiwai@suse.de
- ALSA: hda - Add model string for Intel reference board quirk
  (bsc#1064043).
- ALSA: hda/realtek - Enable jack detection function for Intel
  ALC700 (bsc#1064043).
- commit 0c8702a
* Wed Oct 18 2017 tiwai@suse.de
- x86/mm: Use pr_cont() in dump_pagetable() (bsc#1064024).
- commit 379bbd8
* Wed Oct 18 2017 tiwai@suse.de
- ALSA: hda: Abort capability probe at invalid register read
  (bsc#1064017).
- commit d9d62b1
* Wed Oct 18 2017 jlee@suse.com
- Add the ability to lock down access to the running kernel image
  (fate#314486).
- Update config files.
- Delete
  patches.suse/0001-Add-BSD-style-securelevel-support.patch.
  Replaced by the patch in David Howells's linux-fs git repo.
- commit f7f8bf3
* Wed Oct 18 2017 mcgrof@suse.com
- xfs: handle error if xfs_btree_get_bufs fails (bsc#1059863).
- commit 2689e7f
* Tue Oct 17 2017 jkosina@suse.cz
- scripts/git_sort/git_sort.py: add Michal Petersen's SCSI tree
- commit 42c245c
* Tue Oct 17 2017 jthumshirn@suse.de
- scsi: qla2xxx: don't break the bsg-lib abstractions
  (FATE#322910).
- scsi: qla2xxx: Query FC4 type during RSCN processing
  (FATE#322910).
- scsi: qla2xxx: Use ql2xnvmeenable to enable Q-Pair for FC-NVMe
  (FATE#322910).
- scsi: qla2xxx: Update driver version to 10.00.00.02-k
  (FATE#322910).
- scsi: qla2xxx: Changes to support N2N logins (FATE#322910).
- scsi: qla2xxx: Allow MBC_GET_PORT_DATABASE to query and save
  the port states (FATE#322910).
- scsi: qla2xxx: Add ATIO-Q processing for INTx mode
  (FATE#322910).
- scsi: qla2xxx: Reinstate module parameter ql2xenablemsix
  (FATE#322910).
- scsi: qla2xxx: Cocci spatch "pool_zalloc-simple" (FATE#322910).
- scsi: qla2xxx: Reset the logo flag, after target re-login
  (FATE#322910).
- scsi: qla2xxx: Fix slow mem alloc behind lock (FATE#322910).
- scsi: qla2xxx: Clear fc4f_nvme flag (FATE#322910).
- scsi: qla2xxx: Handle PCIe error for driver (FATE#322910).
- commit 641d8fb
* Tue Oct 17 2017 mkubecek@suse.cz
- ipv4: Fix traffic triggered IPsec connections (bsc#1061739).
- ipv6: Fix traffic triggered IPsec connections (bsc#1061739).
- net: prevent dst uses after free (bsc#1061739).
- ipv4: Don't override return code from ip_route_input_noref()
  (bsc#1061739).
- net: xfrm: don't double-hold dst when sk_policy in use
  (bsc#1061739).
- ipv6: release rt6->rt6i_idev properly during ifdown
  (bsc#1061739).
- commit 173c05a
* Tue Oct 17 2017 mkubecek@suse.cz
- tcp: tcp_data_queue() cleanup (bsc#1061739).
- tcp: remove unused mib counters (bsc#1061739).
- tcp: remove low_latency sysctl (bsc#1061739).
- tcp: reindent two spots after prequeue removal (bsc#1061739).
- tcp: remove prequeue support (bsc#1061739).
- tcp: better validation of received ack sequences (bsc#1061739).
- commit 6c0fdbb
* Tue Oct 17 2017 mkubecek@suse.cz
- net: add debug atomic_inc_not_zero() in dst_hold()
  (bsc#1061739).
- net: reorder all the dst flags (bsc#1061739).
- net: remove DST_NOCACHE flag (bsc#1061739).
- net: remove DST_NOGC flag (bsc#1061739).
- net: remove dst gc related code (bsc#1061739).
- decnet: take dst->__refcnt when struct dn_route is created
  (bsc#1061739).
- xfrm: take refcnt of dst when creating struct xfrm_dst bundle
  (bsc#1061739).
- ipv6: get rid of icmp6 dst garbage collector (bsc#1061739).
- ipv6: mark DST_NOGC and remove the operation of dst_free()
  (bsc#1061739).
- ipv6: call dst_hold_safe() properly (bsc#1061739).
- ipv6: call dst_dev_put() properly (bsc#1061739).
- ipv6: take dst->__refcnt for insertion into fib6 tree
  (bsc#1061739).
- ipv4: mark DST_NOGC and remove the operation of dst_free()
  (bsc#1061739).
- ipv4: call dst_hold_safe() properly (bsc#1061739).
- ipv4: call dst_dev_put() properly (bsc#1061739).
- ipv4: take dst->__refcnt when caching dst in fib (bsc#1061739).
- net: introduce a new function dst_dev_put() (bsc#1061739).
- net: introduce DST_NOGC in dst_release() to destroy dst based
  on refcnt (bsc#1061739).
- net: use loopback dev when generating blackhole route
  (bsc#1061739).
- udp: call dst_hold_safe() in udp_sk_rx_set_dst() (bsc#1061739).
- ipv6: remove unnecessary dst_hold() in ip6_fragment()
  (bsc#1061739).
- commit f97eac8
* Tue Oct 17 2017 jthumshirn@suse.de
- scsi: libfc: fix a deadlock in fc_rport_work (bsc#1063695).
- fs/mpage.c: fix mpage_writepage() for pages with buffers
  (bsc#1050471).
- commit d0711a1
* Tue Oct 17 2017 jkosina@suse.cz
- scripts/git_sort/git_sort.py: add md.git tree
- commit d2c30da
* Tue Oct 17 2017 jlee@suse.com
- Delete
  patches.suse/0001-Remove-BSD-style-securelevel-sysfs-file.patch.
  David Howells's lock down patch set doesn't provide sysfs interface
  anymore.
- commit 7180bdf
* Tue Oct 17 2017 jlee@suse.com
- acpi: Disable APEI error injection if the kernel is locked down
  (fate#314486).
- Delete
  patches.suse/acpi_Disable_APEI_error_injection_if_securelevel_is_set.patch.
  Replaced by the patch in David Howells's linux-fs git repo.
- commit 69a1c63
* Tue Oct 17 2017 jlee@suse.com
- acpi: Disable ACPI table override if the kernel is locked down
  (fate#314486).
- Delete
  patches.suse/acpi-Disable_ACPI_table_override_when_UEFI_Secure_Boot_is.patch.
  Replaced by the patch in David Howells's linux-fs git repo.
- commit 6ef9921
* Tue Oct 17 2017 jlee@suse.com
- acpi: Ignore acpi_rsdp kernel param when the kernel has been
  locked down (fate#314486).
- Delete
  patches.suse/0007-acpi-Ignore-acpi_rsdp-kernel-parameter-when-securele.patch.
  Replaced by the patch in David Howells's linux-fs git repo.
- commit 10e6554
* Tue Oct 17 2017 jlee@suse.com
- ACPI: Limit access to custom_method when the kernel is locked
  down (fate#314486).
- Delete
  patches.suse/0006-acpi-Limit-access-to-custom_method-if-securelevel-is.patch.
  Replaced by the patch in David Howells's linux-fs git repo.
- commit 62d1f7d
* Tue Oct 17 2017 jlee@suse.com
- asus-wmi: Restrict debugfs interface when the kernel is locked
  down (fate#314486).
- Delete
  patches.suse/0011-asus-wmi-Restrict-debugfs-interface-when-securelevel.patch.
  Replaced by the patch in David Howells's linux-fs git repo.
- commit e2ab47b
* Tue Oct 17 2017 jlee@suse.com
- x86: Restrict MSR access when the kernel is locked down
  (fate#314486).
- Delete
  patches.suse/0010-x86-Restrict-MSR-access-when-securelevel-is-set.patch.
  Replaced by the patch in David Howells's linux-fs git repo.
- commit 3909643
* Tue Oct 17 2017 jlee@suse.com
- x86: Lock down IO port access when the kernel is locked down
  (fate#314486).
- Delete
  patches.suse/0004-x86-Lock-down-IO-port-access-when-securelevel-is-ena.patch.
  Replaced by the patch in David Howells's linux-fs git repo.
- commit 1762c3f
* Tue Oct 17 2017 jlee@suse.com
- PCI: Lock down BAR access when the kernel is locked down
  (fate#314486).
- Delete
  patches.suse/0003-PCI-Lock-down-BAR-access-when-securelevel-is-enabled.patch.
  Replaced by the patch in David Howells's linux-fs git repo.
- commit 9fdfbff
* Tue Oct 17 2017 jlee@suse.com
- uswsusp: Disable when the kernel is locked down (fate#314486).
- Delete
  patches.suse/0009-uswsusp-Disable-when-securelevel-is-set.patch.
  Replaced by the patch in David Howells's linux-fs git repo.
- commit a084ec6
* Tue Oct 17 2017 jlee@suse.com
- hibernate: Disable when the kernel is locked down (fate#314486).
- Delete
  patches.suse/0014-hibernate-Disable-when-securelevel-is-set.patch.
  Replaced by the patch in David Howells's linux-fs git repo.
- commit 33abf1b
* Tue Oct 17 2017 jlee@suse.com
- Copy secure_boot flag in boot params across kexec reboot
  (fate#314486).
- Delete
  patches.suse/0015-kexec-uefi-copy-secure_boot-flag-in-boot-params-acro.patch.
  Replaced by the patch in David Howells's linux-fs git repo.
- commit 8f6bfe2
* Tue Oct 17 2017 jlee@suse.com
- kexec: Disable at runtime if the kernel is locked down
  (fate#314486).
- kexec_file: Disable at runtime if securelevel has been set
  (fate#314486).
- Delete
  patches.suse/0008-kexec-Disable-at-runtime-if-securelevel-has-been-set.patch.
  Replaced by the patch in David Howells's linux-fs git repo.
- commit 3ec1db3
* Tue Oct 17 2017 jlee@suse.com
- Restrict /dev/mem and /dev/kmem when the kernel is locked down
  (fate#314486).
- Delete
  patches.suse/0005-Restrict-dev-mem-and-dev-kmem-when-securelevel-is-se.patch.
  Replaced by the patch in David Howells's linux-fs git repo.
- commit 9d8716c
* Tue Oct 17 2017 jlee@suse.com
- Enforce module signatures if the kernel is locked down
  (fate#314486).
- Delete
  patches.suse/0001-Enforce-module-signatures-when-securelevel-is-greate.patch.
  Replaced by the patch in David Howells's linux-fs git repo.
- commit 96ad4fa
* Tue Oct 17 2017 jlee@suse.com
- efi: Lock down the kernel if booted in secure boot mode
  (fate#314486).
- Update config files.
- Delete
  patches.suse/0012-Add-option-to-automatically-set-securelevel-when-in-.patch.
  Replaced by the patch in David Howells's linux-fs git repo.
- commit c339fd5
* Tue Oct 17 2017 jlee@suse.com
- efi: Add EFI_SECURE_BOOT bit (fate#314486).
- Delete patches.suse/0014-efi-Add-EFI_SECURE_BOOT-bit.patch.
  Replaced by the patch in David Howells's linux-fs git repo.
- commit aff4b1b
* Tue Oct 17 2017 bpoirier@suse.com
- Refresh patch order in sorted section
- commit a59e716
* Mon Oct 16 2017 bp@suse.de
- EDAC, pnd2: Return proper error value from apl_rd_reg()
  (bsc#1056989).
- EDAC, pnd2: Make function sbi_send() static (bsc#1056989).
- EDAC, pnd2: Fix Apollo Lake DIMM detection (bsc#1056989).
- i2c: i801: Restore the presence state of P2SB PCI device after
  reading BAR (bsc#1056989).
- EDAC, pnd2: Build in a minimal sideband driver for Apollo Lake
  (bsc#1056989).
- EDAC, pnd2: Mask off the lower four bits of a BAR (bsc#1056989).
- EDAC, pnd2: Conditionally unhide/hide the P2SB PCI device to
  read BAR (bsc#1056989).
- EDAC, pnd2: Properly toggle hidden state for P2SB PCI device
  (bsc#1056989).
- Refresh
  patches.drivers/07-edac-add-owner-check-to-the-x86-platform-drivers.patch.
- commit 9dd1f7f
* Mon Oct 16 2017 oneukum@suse.com
- iwlwifi: mvm: disable dbg data collect when fw isn't alive
  (FATE#322675).
- iwlwifi: mvm: flush per station for DQA mode (FATE#322675).
- iwlwifi: mvm: support getting nvm data from firmware
  (FATE#322675).
- iwlwifi: refactor out paging code (FATE#322675).
- iwlwifi: mvm: support old method of NVM parsing (FATE#322675).
- iwlwifi: refactor shared mem parsing (FATE#322675).
- iwlwifi: mvm: fix endianness in lq_cmd declaration
  (FATE#322675).
- iwlwifi: track current firmware image in common code
  (FATE#322675).
- iwlwifi: mvm: document which group enums are used with which
  group ID (FATE#322675).
- iwlwifi: refactor firmware debug code (FATE#322675).
- iwlwifi: mvm: use proper sta_addr in firmware API (FATE#322675).
- iwlwifi: reorganize firmware API (FATE#322675).
- iwlwifi: fw api: fix various kernel-doc warnings (FATE#322675).
- iwlwifi: mvm: fix MCC endianness bug (FATE#322675).
- iwlwifi: mvm: add and use iwl_mvm_has_unified_ucode()
  (FATE#322675).
- iwlwifi: mvm: use u8 for reserved fields (FATE#322675).
- iwlwifi: mvm: check family instead of new TX API for workarounds
  (FATE#322675).
- iwlwifi: mvm: disentangle paging command structs (FATE#322675).
- iwlwifi: mvm: add documentation to some WoWLAN commands
  (FATE#322675).
- iwlwifi: mvm: byte-swap constant instead of variable
  (FATE#322675).
- iwlwifi: dvm: remove unused defines (FATE#322675).
- iwlwifi: mvm: wait for the flushed queue only (FATE#322675).
- iwlwifi: mvm: fix some kernel-doc (FATE#322675).
- iwlwifi: mvm: refactor beacon template command code
  (FATE#322675).
- iwlwifi: mvm: add documentation links to various fields
  (FATE#322675).
- iwlwifi: mvm: fix the FIFO numbers in A000 devices
  (FATE#322675).
- iwlwifi: mvm: fix uninitialized var while waiting for queues
  to empty (FATE#322675).
- iwlwifi: update device ID for a000 family (FATE#322675).
- iwlwifi: mvm: disentangle binding command versions
  (FATE#322675).
- iwlwifi: pcie: fix A-MSDU on gen2 devices (FATE#322675).
- iwlwifi: mvm: create/name various enums (FATE#322675).
- iwlwifi: mvm: support fw reading empty OTP (FATE#322675).
- iwlwifi: implement fseq version mismatch warning (FATE#322675).
- iwlwifi: mvm: document structures used by commands
  (FATE#322675).
- iwlwifi: mvm: add compile-time option to disable EBS
  (FATE#322675).
- iwlwifi: mvm: remove wrt support of page dumps in gen2
  (FATE#322675).
- iwlwifi: pcie: rename iwl_trans_check_hw_rf_kill() to pcie
  (FATE#322675).
- iwlwifi: pcie: support page dumping in wrt in gen2
  (FATE#322675).
- iwlwifi: Add fw_name_pre_rf_next_step to support different rf
  steps (FATE#322675).
- iwlwifi: mvm: require AP_LINK_PS for TVQM (FATE#322675).
- iwlwifi: mvm: remove unused TX_CMD_NEXT_FRAME_* (FATE#322675).
- iwlwifi: mvm: simplify bufferable MMPDU check (FATE#322675).
- iwlwifi: kernel-doc: make proper links (FATE#322675).
- iwlwifi: mvm: rename p2p-specific sta functions to include
  p2p in the names (FATE#322675).
- iwlwifi: mvm: fix many kernel-doc warnings (FATE#322675).
- iwlwifi: mvm: remove non-DQA mode (FATE#322675).
- iwlwifi: add wait for tx queue empty (FATE#322675).
- iwlwifi: mvm: don't retake the pointer to skb's CB
  (FATE#322675).
- iwlwifi: mvm: add AMSDU flag to offload assist (FATE#322675).
- iwlwifi: mvm: remove useless condition in LED code
  (FATE#322675).
- iwlwifi: mvm: document RX structures (FATE#322675).
- iwlwifi: mvm: use firmware LED command where applicable
  (FATE#322675).
- iwlwifi: mvm: add const to thermal_cooling_device_ops structure
  (FATE#322675).
- iwlwifi: pcie: add AMSDU to gen2 (FATE#322675).
- iwlwifi: cleanup references to 8000 family in NVM code
  (FATE#322675).
- iwlwifi: mvm: add debugfs to force CT-kill (FATE#322675).
- iwlwifi: change functions that can only return 0 to void
  (FATE#322675).
- iwlwifi: remove references to 8000 B-step devices (FATE#322675).
- iwlwifi: add dbgc_supported to transport configuration
  (FATE#322675).
- iwlwifi: fix a few instances of misaligned kerneldoc parameters
  (FATE#322675).
- iwlwifi: add support of FPGA fw (FATE#322675).
- iwlwifi: mvm: add TLV for NAN API differentiation (FATE#322675).
- iwlwifi: fix a000 RF_ID define (FATE#322675).
- iwlwifi: mvm: support init flow debugging (FATE#322675).
- iwlwifi: add 9000 and A000 device families (FATE#322675).
- iwlwifi: dump smem configuration when firmware crashes
  (FATE#322675).
- iwlwifi: mvm: move a000 device NVM retrieval to a common place
  (FATE#322675).
- iwlwifi: pcie: support dumping FH in a000 hw (FATE#322675).
- iwlwifi: mvm: disable prph collection in a000 hw (FATE#322675).
- iwlwifi: mvm: set the default cTDP budget (FATE#322675).
- iwlwifi: mvm: add and use iwl_mvm_device_running()
  (FATE#322675).
- iwlwifi: mvm: support new beacon template command (FATE#322675).
- iwlwifi: mvm: check firmware is up in debugfs (FATE#322675).
- iwlwifi: mvm: don't send CTDP commands via debugfs if not
  supported (FATE#322675).
- iwlwifi: mvm: add station before allocating a queue
  (FATE#322675).
- iwlwifi: mvm: use schedule_delayed_work() (FATE#322675).
- iwlwifi: mvm: convert ucode_loaded to a status bit
  (FATE#322675).
- iwlwifi: pcie: don't init a Tx queue with an SSN > size of
  the queue (FATE#322675).
- iwlwifi: fix nmi triggering from host (FATE#322675).
- iwlwifi: mvm: clear firmware running bit earlier (FATE#322675).
- iwlwifi: fix a kernel-doc tag (FATE#322675).
- iwlwifi: remove references to unsupported HW (FATE#322675).
- iwlwifi: pcie: free the TSO page when a Tx queue is unmapped
  on A000 devices (FATE#322675).
- iwlwifi: split firmware API from iwl-trans.h (FATE#322675).
- iwlwifi: mvm: fix the coex firmware API (FATE#322675).
- iwlwifi: mvm: link queue cmd docs to A000 command structs
  (FATE#322675).
- iwlwifi: mvm: document structures used for BEACON_TEMPLATE_CMD
  (FATE#322675).
- iwlwifi: mvm: remove the corunning support (FATE#322675).
- iwlwifi: mvm: consider RFKILL during INIT as success
  (FATE#322675).
- iwlwifi: mvm: link to TX commands in documentation
  (FATE#322675).
- iwlwifi: call iwl_remove_notification from iwl_wait_notification
  (FATE#322675).
- iwlwifi: mvm: remove SCAN_GROUP (FATE#322675).
- iwlwifi: fw-api: cleanup cycle includes (FATE#322675).
- iwlwifi: mvm: support new Coex firmware API (FATE#322675).
- iwlwifi: pcie: support short Tx queues for A000 device family
  (FATE#322675).
- iwlwifi: remove unnecessary code in iwl_trans_alloc_tx_cmd
  (FATE#322675).
- commit 833689044e13a3fb8c6c03ad868375670d97010b
  Merge: 63a2f310d040 0ae0bb3f409d Author: Kalle Valo
  <kvalo@codeaurora.org> Date:   Mon Jun 12 19:29:39 2017 +0300
  (FATE#322675).
- iwlwifi: mvm: add command name for FRAME_RELEASE (FATE#322675).
- iwlwifi: mvm: group all dummy SAR function declarations together
  (FATE#322675).
- iwlwifi: mvm: remove txq EMPTYING_DELBA state for DQA
  (FATE#322675).
- iwlwifi: mvm: use mvmsta consistently in rs.c (FATE#322675).
- iwlwifi: remove resp_pkt NULL checks (FATE#322675).
- iwlwifi: mvm: Enable security on new TX API (FATE#322675).
- iwlwifi: mvm: update the firmware API in TX (FATE#322675).
- iwlwifi: mvm: avoid unnecessary cache trashing in Tx path
  (FATE#322675).
- iwlwifi: mvm: remove session protection to allow channel switch
  (FATE#322675).
- iwlwifi: mvm: don't send BAR on flushed frames (FATE#322675).
- iwlwifi: mvm: remove pointless num_stored condition
  (FATE#322675).
- iwlwifi: move BT_MBOX_PRINT macro to common header
  (FATE#322675).
- iwlwifi: mvm: avoid variable shadowing (FATE#322675).
- iwlwifi: Demote messages about fw flags size to info
  (FATE#322675).
- iwlwifi: mvm: use scnprintf() instead of snprintf()
  (FATE#322675).
- iwlwifi: mvm: Fix channel switch in case of count <= 1
  (FATE#322675).
- iwlwifi: use bitfield.h for some registers (FATE#322675).
- iwlwifi: distinguish different RF modules in A000 devices
  (FATE#322675).
- iwlwifi: mvm: track and report IBSS manager status to mac80211
  (FATE#322675).
- iwlwifi: mvm: make D0I3_END_CMD sync during system resume
  (FATE#322675).
- iwlwifi: update channel flags parser (FATE#322675).
- iwlwifi: mvm: change open and close criteria of a BA session
  (FATE#322675).
- iwlwifi: mvm: support D0I3_END_CMD at the start of resume
  (FATE#322675).
- iwlwifi: add workaround to disable wide channels in 5GHz
  (FATE#322675).
- iwlwifi: mvm: make iwl_mvm_update_mcc() easier to follow
  (FATE#322675).
- iwlwifi: fw: fix lar_enabled endian problem in iwl_fw_get_nvm
  (FATE#322675).
- iwlwifi: mvm: rs: add logs for the wrong antenna case
  (FATE#322675).
- iwlwifi: mvm: remove useless argument in iwl_nvm_init()
  (FATE#322675).
- iwlwifi: pcie: pull out common rfkill IRQ handling code
  (FATE#322675).
- iwlwifi: mvm: remove useless check for mvm->cfg in
  iwl_parse_nvm_section() (FATE#322675).
- iwlwifi: pcie: add fake RF-kill to debugfs (FATE#322675).
- iwlwifi: mvm: don't warn in queue sync on RF-kill (FATE#322675).
- iwlwifi: use big-endian for the hw section of the nvm
  (FATE#322675).
- iwlwifi: mvm: Avoid deferring non bufferable frames
  (FATE#322675).
- iwlwifi: pcie: don't report RF-kill enabled while shutting down
  (FATE#322675).
- iwlwifi: mvm: bump API to 34 for 8000 and up (FATE#322675).
- iwlwifi: pcie: remove pointless debugfs parsing for csr file
  (FATE#322675).
- iwlwifi: mvm: document status bits (FATE#322675).
- iwlwifi: mvm: only send LEDS_CMD when the FW supports it
  (FATE#322675).
- iwlwifi: mvm: support aggregations on A000 HW (FATE#322675).
- iwlwifi: pcie: use kstrtou32_from_user() (FATE#322675).
- iwlwifi: mvm: better link scan notification results length
  (FATE#322675).
- iwlwifi: mvm: docs: fix enum link, provide TX response link
  (FATE#322675).
- iwlwifi: mvm: fix fw monitor 7000 HW recollecting (FATE#322675).
- iwlwifi: mvm: disentangle union in TX status struct
  (FATE#322675).
- iwlwifi: mvm: add documentation for enum iwl_debug_cmds
  (FATE#322675).
- iwlwifi: document transmit buffer bits better (FATE#322675).
- iwlwifi: remove useless iwl_free_nvm_data() function
  (FATE#322675).
- iwlwifi: mvm: fix nvm_data leak (FATE#322675).
- iwlwifi: pcie: don't disable bh when handling FW errors
  (FATE#322675).
- iwlwifi: mvm: reset the HW before dumping if HW error is
  detected (FATE#322675).
- iwlwifi: mvm: don't mark TIDs that are not idle wrt BA as
  inactive (FATE#322675).
- iwlwifi: add a W/A for a scheduler hardware bug (FATE#322675).
- iwlwifi: pcie: make iwl_pcie_apm_stop_master() return void
  (FATE#322675).
- iwlwifi: mvm: set assoc_beacon_arrive_time (FATE#322675).
- iwlwifi: mvm: support new flush API (FATE#322675).
- iwlwifi: mvm: document assoc_beacon_arrive_time (FATE#322675).
- iwlwifi: mvm: print base HW address during init (FATE#322675).
- iwlwifi: pcie: reduce unwanted noise in the logs (FATE#322675).
- iwlwifi: pcie: delete the Tx queue timer earlier upon firmware
  crash (FATE#322675).
- iwlwifi: mvm: fix typo in CTDP_CMD_OPERATION_REPORT description
  (FATE#322675).
- iwlwifi: pcie: work around suspend/resume issue (FATE#322675).
- iwlwifi: mvm: support TX on MONITOR iface (FATE#322675).
- iwlwifi: mvm: refactor geo init (FATE#322675).
- iwlwifi: mvm: Add debugfs entry to retrieve SAR geographic
  profile (FATE#322675).
- iwlwifi: mvm: remove some CamelCase from firmware API
  (FATE#322675).
- iwlwifi: mvm: fix various "Excess ... description" kernel-doc
  warnings (FATE#322675).
- iwlwifi: mvm: remove various unused command IDs/structs
  (FATE#322675).
- iwlwifi: mvm: use __le16 even for reserved fields (FATE#322675).
- iwlwifi: mvm: add documentation for all command IDs
  (FATE#322675).
- iwlwifi: mvm: fix a bunch of kernel-doc warnings (FATE#322675).
- iwlwifi: dvm: use macros for format strings (FATE#322675).
- iwlwifi: pcie: only apply retention workaround on 9000-series
  A-step (FATE#322675).
- iwlwifi: pcie: fix 9000-series RF-kill interrupt propagation
  (FATE#322675).
- iwlwifi: mvm: simplify CHECK_MLME_TRIGGER macro (FATE#322675).
- iwlwifi: add the new a000_2ax series (FATE#322675).
- iwlwifi: add twelve new 9560 series PCI IDs (FATE#322675).
- iwlwifi: mvm: use proper CDB check in PHY context modify
  (FATE#322675).
- iwlwifi: pcie: improve "invalid queue" warning (FATE#322675).
- iwlwifi: mvm: support aggs of 64 frames in A000 family
  (FATE#322675).
- iwlwifi: pcie: improve debug in iwl_pcie_rx_handle_rb()
  (FATE#322675).
- iwlwifi: mvm: change when the BT_COEX is sent (FATE#322675).
- iwlwifi: mvm: support multi tid ba notif (FATE#322675).
- iwlwifi: unify external & internal modparam names (FATE#322675).
- iwlwifi: pcie: make ctxt-info free idempotent (FATE#322675).
- iwlwifi: pcie: warn if paging is already initialized during init
  (FATE#322675).
- iwlwifi: mvm: rename iwl_shared_mem_cfg_v1 to the correct _v2
  (FATE#322675).
- iwlwifi: create new subdirectory for FW interaction
  (FATE#322675).
- iwlwifi: move notification wait into fw/ (FATE#322675).
- iwlwifi: move configuration into sub-directory (FATE#322675).
- iwlwifi: mvm: remove version 2 of paging command (FATE#322675).
- iwlwifi: pcie: add MSI-X interrupt tracing (FATE#322675).
- iwlwifi: mvm: properly enable IP header checksumming
  (FATE#322675).
- iwlwifi: mvm: map cab_queue to real one earlier (FATE#322675).
- iwlwifi: mvm: fix mac80211's hw_queue in DQA mode (FATE#322675).
- iwlwifi: mvm: remove DQA non-STA client mode special case
  (FATE#322675).
- iwlwifi: mvm: update rx statistics cmd api (FATE#322675).
- iwlwifi: pcie: propagate iwl_pcie_apm_init's status
  (FATE#322675).
- iwlwifi: pcie: wait longer after device reset (FATE#322675).
- iwlwifi: bump MAX API for 8000/9000/A000 to 33 (FATE#322675).
- iwlwifi: pcie: fix unused txq NULL pointer dereference
  (FATE#322675).
- iwlwifi: mvm: defer setting IWL_MVM_STATUS_IN_HW_RESTART
  (FATE#322675).
- iwlwifi: add TLV for MLME offload firmware capability
  (FATE#322675).
- iwlwifi: split the regulatory rules when the bandwidth flags
  require it (FATE#322675).
- iwlwifi: mvm: set A-MPDU bit upon empty BA notification from FW
  (FATE#322675).
- iwlwifi: mvm: rs: fix TLC statistics collection (FATE#322675).
- iwlwifi: fix fw_pre_next_step to apply also for C step
  (FATE#322675).
- iwlwifi: add the new 9000 series PCI IDs (FATE#322675).
- iwlwifi: mvm: Fix a memory leak in an error handling path in
  'iwl_mvm_sar_get_wgds_table()' (FATE#322675).
- iwlwifi: mvm: start mac queues when deferred tx frames are
  purged (FATE#322675).
- iwlwifi: mvm: don't WARN when a legit race happens in A-MPDU
  (FATE#322675).
- mac80211: add api to start ba session timer expired flow
  (FATE#322675).
- iwlwifi: mvm: send delba upon rx ba session timeout
  (FATE#322675).
- iwlwifi: pcie: move rx workqueue initialization to
  iwl_trans_pcie_alloc() (FATE#322675).
- Refresh
  patches.drivers/iwlwifi-mvm-don-t-warn-in-queue-sync-on-RF-kill.
- Refresh
  patches.drivers/iwlwifi-mvm-fix-a-NULL-pointer-dereference-of-error-.
- Refresh patches.drivers/iwlwifi-mvm-fix-mac80211-queue-tracking.
- Refresh
  patches.drivers/iwlwifi-mvm-quietly-accept-non-sta-disassoc-frames.
- Refresh
  patches.drivers/iwlwifi-mvm-remove-DQA-non-STA-client-mode-special-c.
- Refresh
  patches.drivers/iwlwifi-pcie-fix-TVQM-queue-ID-range-check.
- Refresh
  patches.drivers/iwlwifi-pcie-fix-command-completion-name-debug.
- Refresh
  patches.drivers/iwlwifi-pcie-reconfigure-MSI-X-HW-on-resume.
- Refresh patches.suse/iwlwifi-expose-default-fallback-ucode-api.
- Delete
  patches.drivers/iwlwifi-mvm-reset-the-fw_dump_desc-pointer-after-ASS.
- commit 318dcaf
* Mon Oct 16 2017 jslaby@suse.cz
- arm64: futex: Fix undefined behaviour with FUTEX_OP_OPARG_SHIFT usage
  (bnc#1005915).
- commit f68b002
* Mon Oct 16 2017 jslaby@suse.cz
- futex: Remove duplicated code and fix undefined behaviour
  (bnc#1005915).
- commit 3ab315a
* Mon Oct 16 2017 mhocko@suse.cz
- mm: page_vma_mapped: ensure pmd is loaded with READ_ONCE
  outside of lock (bnc#1063517).
- commit f9d9f6b
* Mon Oct 16 2017 mhocko@suse.cz
- mm: meminit: mark init_reserved_page as __meminit (bnc#1063509).
- commit f1081d0
* Mon Oct 16 2017 mhocko@suse.cz
- mm/memory_hotplug: define find_{smallest|biggest}_section_pfn
  as unsigned long (bnc#1063520).
- commit 5a4bbdf
* Mon Oct 16 2017 mhocko@suse.cz
- blacklist.conf: blacklist pure doc update
- commit 44bb57c
* Mon Oct 16 2017 mhocko@suse.cz
- mm/memory_hotplug: change pfn_to_section_nr/section_nr_to_pfn
  macro to inline function (bnc#1063501).
- commit 093a972
* Mon Oct 16 2017 mhocko@suse.cz
- mm/backing-dev.c: fix an error handling path in 'cgwb_create()'
  (bnc#1063475).
- commit 5def433
* Mon Oct 16 2017 mgorman@suse.de
- Refresh
  patches.suse/mm-mempolicy-fix-numa_interleave_hit-counter.patch.
- commit 6574465
* Fri Oct 13 2017 msuchanek@suse.de
- Revert "rpm/constraints.in: Lower default disk space requirement from 25G to 24G"
  This reverts commit 406abda1467c038842febffe264faae1fa2e3c1d.
  ok, did not wait long enough to see the failure.
- commit ed99981
* Fri Oct 13 2017 msuchanek@suse.de
- rpm/constraints.in: Lower default disk space requirement from 25G to 24G
  25G is rejected by the build service on ARM.
- commit 406abda
* Fri Oct 13 2017 bpoirier@suse.com
- Add marker for the end of the sorted section.
- commit 5add254
* Fri Oct 13 2017 jlee@suse.com
- Delete
  patches.suse/0001-MODSIGN-Support-the-old-style-signature-format.patch.
  SLE15 kernel only suppports PKCS#7 signature for module.
- commit 8f5ab3d
* Fri Oct 13 2017 jlee@suse.com
- Delete
  patches.fixes/0001-X.509-Fix-test-for-self-signed-certificate.patch.
  This patches did not accept by kernel mainline but David Howells's
  6c2dc5ae4 patch in v4.7-rc1 has similar logic to fix issue.
- commit 6fa04b9
* Fri Oct 13 2017 jlee@suse.com
- Delete
  patches.drivers/0001-acpi-nfit-treat-virtual-spa-region-as-r-v4.patch.
  This patch was merged in v4.8-rc1 on upstream.
- commit b8a49c5
* Fri Oct 13 2017 jlee@suse.com
- Refresh
  patches.suse/0003-Add-external-no-support-as-bad-taint-module.patch.
- commit 5af8e7d
* Fri Oct 13 2017 colyli@suse.de
- md/raid5: preserve STRIPE_ON_UNPLUG_LIST in
  break_stripe_batch_list (fate#323095).
- md: notify about new spare disk in the container (fate#323095).
- md: Runtime support for multiple ppls (fate#323095).
- raid5-ppl: Recovery support for multiple partial parity logs
  (fate#323095).
- raid5-ppl: don't resync after rebuild (fate#323095).
- raid5-ppl: check recovery_offset when performing ppl recovery
  (fate#323095).
- commit cf8b210
* Thu Oct 12 2017 jkosina@suse.cz
- series.conf: drop already merged printk patch from patches marked for review
- commit 48eb86a
* Thu Oct 12 2017 pmladek@suse.com
- printk/console: Enhance the check for consoles using init memory
  (bsc#1063026).
- printk/console: Always disable boot consoles that use init
  memory before it is freed (bsc#1063026).
- commit 39bffbf
* Thu Oct 12 2017 pmladek@suse.com
- Refresh and enable
  patches.suse/printk-console-Correctly-mark-console-that-is-used-w.patch
  printk/console: Correctly mark console that is used when
  opening /dev/console (bsc#1040020).
- commit 1f1f97c
* Thu Oct 12 2017 msuchanek@suse.de
- Refresh vanilla config.
- commit de6c979
* Thu Oct 12 2017 msuchanek@suse.de
- ibmvnic: Set state UP (bsc#1062962).
- commit d037007
* Thu Oct 12 2017 jthumshirn@suse.de
- scsi: mpt3sas: Bump mpt3sas driver version to v16.100.00.00
  (bsc#1049527,FATE#322938).
- scsi: mpt3sas: Adding support for SAS3616 HBA device
  (bsc#1049527,FATE#322938).
- scsi: mpt3sas: Fix possibility of using invalid Enclosure Handle
  for SAS device after host reset (bsc#1049527,FATE#322938).
- scsi: mpt3sas: Display chassis slot information of the drive
  (bsc#1049527,FATE#322938).
- scsi: mpt3sas: Updated MPI headers to v2.00.48
  (bsc#1049527,FATE#322938).
- scsi: mpt3sas: Fix IO error occurs on pulling out
  a drive from RAID1 volume created on two SATA drive
  (bsc#1049527,FATE#322938).
- scsi: mpt3sas: Fix removal and addition of vSES device during
  host reset (bsc#1049527,FATE#322938).
- scsi: mpt3sas: Reduce memory footprint in kdump kernel
  (bsc#1049527,FATE#322938).
- scsi: mpt3sas: Fixed memory leaks in driver
  (bsc#1049527,FATE#322938).
- scsi: mpt3sas: Processing of Cable Exception events
  (bsc#1049527,FATE#322938).
- scsi: mpt3sas: remove redundant copy_from_user in
  _ctl_getiocinfo (bsc#1049527,FATE#322938).
- scsi: mpt3sas: fix pr_info message continuation
  (bsc#1049527,FATE#322938).
- commit 51e999e
* Thu Oct 12 2017 lduncan@suse.com
- fs: fix kernel_write prototype (fate#323946).
- tcmu: free old string on reconfig (fate#323946).
- tcmu: Fix possible to/from address overflow when doing the
  memcpy (fate#323946).
- tcmu: clean up the code and with one small fix (fate#323946).
- target: export lio pgr/alua support as device attr
  (fate#323946).
- target: Fix return sense reason in target_scsi3_emulate_pr_out
  (fate#323946).
- target: Fix cmd size for PR-OUT in passthrough_parse_cdb
  (fate#323946).
- tcmu: Fix dev_config_store (fate#323946).
- target: pscsi: Introduce TYPE_ZBC support (fate#323946).
- target: Use macro for WRITE_VERIFY_32 operation codes
  (fate#323946).
- target: fix SAM_STAT_BUSY/TASK_SET_FULL handling (fate#323946).
- target: remove transport_complete (fate#323946).
- pscsi: finish cmd processing from pscsi_req_done (fate#323946).
- tcmu: fix sense handling during completion (fate#323946).
- target: add helper to copy sense to se_cmd buffer (fate#323946).
- target: do not require a transport_complete for
  SCF_TRANSPORT_TASK_SENSE (fate#323946).
- target: make device_mutex and device_list static (fate#323946).
- tcmu: fix multiple uio open/close sequences (fate#323946).
- tcmu: drop configured check in destroy (fate#323946).
- target: remove g_device_list (fate#323946).
- xcopy: loop over devices using idr helper (fate#323946).
- target: add helper to iterate over devices (fate#323946).
- tcmu: perfom device add, del and reconfig synchronously
  (fate#323946).
- target: add helper to find se_device by dev_index (fate#323946).
- target: use idr for se_device dev index (fate#323946).
- target: break up free_device callback (fate#323946).
- tcmu: reconfigure netlink attr changes (fate#323946).
- tcmu: make array tcmu_attrib_attrs static const (fate#323946).
- tcmu: Fix module removal due to stuck unmap_thread thread again
  (fate#323946).
- tcmu: Add Type of reconfig into netlink (fate#323946).
- tcmu: Make dev_config configurable (fate#323946).
- tcmu: Make dev_size configurable via userspace (fate#323946).
- tcmu: Add netlink for device reconfiguration (fate#323946).
- tcmu: Support emulate_write_cache (fate#323946).
- target/iscsi: Remove dead code from iscsit_process_scsi_cmd()
  (fate#323946).
- target/iscsi: Simplify iscsit_free_cmd() (fate#323946).
- target/iscsi: Remove second argument of __iscsit_free_cmd()
  (fate#323946).
- target/tcm_loop: Make TMF processing slightly faster
  (fate#323946).
- target/tcm_loop: Use target_submit_tmr() instead of open-coding
  this function (fate#323946).
- target/tcm_loop: Replace a waitqueue and a counter by a
  completion (fate#323946).
- target/tcm_loop: Merge struct tcm_loop_cmd and struct
  tcm_loop_tmr (fate#323946).
- target: Introduce a function that shows the command state
  (fate#323946).
- iscsi-target: Kill left-over iscsi_target_do_cleanup
  (fate#323946).
- target: Fix a deadlock between the XCOPY code and iSCSI session
  shutdown (fate#323946).
- target: Use {get,put}_unaligned_be*() instead of open coding
  these functions (fate#323946).
- target: Fix transport_init_se_cmd() (fate#323946).
- target: Remove se_device.dev_list (fate#323946).
- target: Use symbolic value for WRITE_VERIFY_16 (fate#323946).
- target: Add TARGET_SCF_LOOKUP_LUN_FROM_TAG support for
  ABORT_TASK (fate#323946).
- target: Add support for TMR percpu reference counting
  (fate#323946).
- target: reject COMPARE_AND_WRITE if emulate_caw is not set
  (fate#323946).
- iscsi: ensure RNG is seeded before use (fate#323946).
- random: add get_random_{bytes,u32,u64,int,long,once}_wait family
  (fate#323946).
- random: add wait_for_random_bytes() API (fate#323946).
- iscsi-target: Avoid holding ->tpg_state_lock during param update
  (fate#323946).
- target/configfs: Kill se_lun->lun_link_magic (fate#323946).
- target/configfs: Kill se_device->dev_link_magic (fate#323946).
- target/iblock: Convert WRITE_SAME to blkdev_issue_zeroout
  (fate#323946).
- target: remove dead code (fate#323946).
- commit 7cc5b73
* Thu Oct 12 2017 bpoirier@suse.com
- Update subsystem names
  They are now generated automatically from the remote url and branch name.
- commit 3f61bda
* Thu Oct 12 2017 bpoirier@suse.com
- Refresh
  patches.drivers/0008-Revert-commit-1a8b6d76dc5b-net-add-one-common-config.patch.
- net: ixgbe: Use new PCI_DEV_FLAGS_NO_RELAXED_ORDERING flag
  (bsc#1056419).
- commit 90521fa
* Wed Oct 11 2017 mwilck@suse.com
- scsi: sd: Do not override max_sectors_kb sysfs setting
  (bsc#1025461).
- commit ddec827
* Wed Oct 11 2017 bp@suse.de
- Refresh
  patches.drivers/03-edac-ghes-remove-symbol-exports.patch.
- Refresh
  patches.drivers/04-edac-ghes-model-a-single-logical-memory-controller.patch.
- Refresh patches.drivers/05-edac-ghes-add-platform-check.patch.
- Refresh
  patches.drivers/06-edac-add-helper-which-returns-the-loaded-platform-driver.patch.
- Refresh
  patches.drivers/07-edac-add-owner-check-to-the-x86-platform-drivers.patch.
- commit 25bfcf5
* Wed Oct 11 2017 mwilck@suse.com
- Fix patch ordering in "scsi for-next" section
- commit fa6ad69
* Wed Oct 11 2017 jlee@suse.com
- Update config files. (bsc#1049122)
- Enabling module signature verification for PKCS#7 support. (bsc#1049122)
- Enabling module signature verification on ARM64.
- commit f366940
* Wed Oct 11 2017 bp@suse.de
- ACPI / blacklist: add acpi_match_platform_list() (bsc#1042420).
- commit a2737a9
* Wed Oct 11 2017 msuchanek@suse.de
- powerpc/64s: Use emergency stack for kernel TM Bad Thing
  program checks (CVE-2017-1000255 bsc#1061633).
- commit bf589f7
* Wed Oct 11 2017 tiwai@suse.de
- ALSA: seq: Fix use-after-free at creating a port
  (CVE-2017-15265, bsc#1062520).
- commit fd32f35
* Wed Oct 11 2017 jthumshirn@suse.de
- mtip32xx: quiesce request queues to make sure no submissions
  are inflight (FATE#322582).
- commit 5051e53
* Tue Oct 10 2017 mfleming@suse.de
- sched/core: Address more wake_affine() regressions
  (bsc#1061593).
- sched/core: Fix wake_affine() performance regression
  (bsc#1061593).
- sched/fair: Fix wake_affine_llc() balancing rules (bsc#1061593).
- sched/fair: Fix wake_affine() for !NUMA_BALANCING (bsc#1061593).
- commit 2d3e2a7
* Tue Oct 10 2017 mkubecek@suse.cz
- config: drop obsolete network drivers (fate#323372)
  CONFIG_PCNET32        - AMD PCnet32
  CONFIG_ATL2           - Atheros L2
  CONFIG_NET_VENDOR_DEC - DEC Tulip family
  CONFIG_NE2K_PCI       - PCI NE2000 and clones
  CONFIG_ATP            - AT-LAN-TEC/Realtek pocket adapter
  CONFIG_SIS900         - SiS 900
  CONFIG_EPIC100        - SMC EtherPower II
  CONFIG_HAPPYMEAL      - Sun Happy Meal
- commit 09e0cef
* Tue Oct 10 2017 mkubecek@suse.cz
- Refresh
  patches.drivers/i40e-add-private-flag-to-control-source-pruning.patch.
- update upstream reference
- move to net-next section
- commit 0c27bbf
* Tue Oct 10 2017 mkubecek@suse.cz
- series.conf: restore repository names
  (just executed series_sort.py)
- commit fcbee0f
* Tue Oct 10 2017 mkubecek@suse.cz
- Update patches.fixes/inetpeer-fix-RCU-lookup-again.patch
  upstream reference and move it to sorted section
- commit fe35cb6
* Mon Oct  9 2017 tbogendoerfer@suse.de
- RDMA/iwpm: Properly mark end of NL messages (bsc#1046306
  FATE#322942).
- commit 8db3fd1
* Mon Oct  9 2017 tbogendoerfer@suse.de
- RDMA/qedr: Parse VLAN ID correctly and ignore the value of zero
  (bsc#1050545 FATE#322893).
- RDMA/qedr: Parse vlan priority as sl (bsc#1050545 FATE#322893).
- Refresh
  patches.drivers/RDMA-qedr-Rename-the-qedr_cm-file-as-a-preparation-f.patch.
- commit 49c1725
* Mon Oct  9 2017 msuchanek@suse.de
- cxl: Add support for POWER9 DD2 (bsc#1055014).
- commit c6a99b3
* Mon Oct  9 2017 vbabka@suse.cz
- Fix series.conf whitespace.
- commit a7d3388
* Mon Oct  9 2017 vbabka@suse.cz
- mm: memcontrol: fix NULL pointer crash in
  test_clear_page_writeback() (VM Functionality, bsc#1061849).
- commit 0cd7f9e
* Mon Oct  9 2017 tbogendoerfer@suse.de
- IB/mlx5: Fix label order in error path handling (bsc#1046305
  FATE#322943).
- net/mlx5: Fix wrong indentation in enable SRIOV code
  (bsc#1046303 FATE#322944).
- net/mlx5: Fix static checker warning on steering tracepoints
  code (bsc#1046303 FATE#322944).
- net/mlx5e: Fix calculated checksum offloads counters
  (bsc#1046303 FATE#322944).
- net/mlx5e: Don't add/remove 802.1ad rules when changing 802.1Q
  VLAN filter (bsc#1046303 FATE#322944).
- net/mlx5e: Print netdev features correctly in error message
  (bsc#1046303 FATE#322944).
- net/mlx5e: Check encap entry state when offloading tunneled
  flows (bsc#1046303 FATE#322944).
- net/mlx5e: Disallow TC offloading of unsupported match/action
  combinations (bsc#1046303 FATE#322944).
- net/mlx5e: Fix erroneous freeing of encap header buffer
  (bsc#1046303 FATE#322944).
- net/mlx5: Check device capability for maximum flow counters
  (bsc#1046303 FATE#322944).
- net/mlx5: Fix FPGA capability location (bsc#1046303
  FATE#322944).
- net/mlx5e: IPoIB, Fix access to invalid memory address
  (bsc#1046303 FATE#322944).
- IB/mlx5: Simplify mlx5_ib_cont_pages (bsc#1046305 FATE#322943).
- commit 14b0a3d
* Mon Oct  9 2017 tbogendoerfer@suse.de
- Re-sorted sorted section
- commit 1999b85
* Mon Oct  9 2017 jthumshirn@suse.de
- nvme: fix visibility of "uuid" ns attribute (FATE#323952,
  FATE#322506).
- commit ca3cd08
* Mon Oct  9 2017 hare@suse.de
- Remove obsolete patches
- Delete patches.fixes/ch-add-refcounting.patch.
- Delete
  patches.fixes/ses-Fix-racy-cleanup-of-sys-in-remove_dev.patch.
- commit f705316
* Mon Oct  9 2017 hare@suse.de
- scsi: Rework handling of scsi_device.vpd_pg8[03] (bsc#1061782).
- scsi: Rework the code for caching Vital Product Data (VPD)
  (bsc#1061782).
- scsi: rcu: Introduce rcu_swap_protected() (bsc#1061782).
- commit aec4a2a
* Fri Oct  6 2017 mwilck@suse.com
- watchdog: Revert "iTCO_wdt: all versions count down twice"
  (bsc#1061556).
- commit dd4ee65
* Fri Oct  6 2017 rgoldwyn@suse.com
- apparmor: Add socket, mount, signal mediation (FATE#323500)
- apparmor: Fix shadowed local variable in unpack_trans_table()
  (FATE#323500).
- apparmor: Fix logical error in verify_header() (FATE#323500).
- apparmor: Fix an error code in aafs_create() (FATE#323500).
- apparmor: Redundant condition: prev_ns. in [label.c:1498]
  (FATE#323500).
- apparmor: add the ability to mediate signals (FATE#323500).
- apparmor: add mount mediation (FATE#323500).
- apparmor: cleanup conditional check for label in label_print
  (FATE#323500).
- apparmor: add support for absolute root view based labels
  (FATE#323500).
- apparmor: make policy_unpack able to audit different info
  messages (FATE#323500).
- apparmor: add more debug asserts to apparmorfs (FATE#323500).
- apparmor: add base infastructure for socket mediation
  (FATE#323500).
- apparmor: move new_null_profile to after profile lookup fns()
  (FATE#323500).
- apparmor: fix race condition in null profile creation
  (FATE#323500).
- apparmor: ensure unconfined profiles have dfas initialized
  (FATE#323500).
- apparmor: fix incorrect type assignment when freeing proxies
  (FATE#323500).
- apparmor: fix build failure on sparc caused by undeclared
  signals (FATE#323500).
- apparmor: fix apparmorfs DAC access permissions (FATE#323500).
- Delete
  patches.apparmor/apparmor-basic-networking-rules-4.11-rc1.patch.
- Delete patches.apparmor/apparmor-basic-networking-rules.patch.
- Delete
  patches.apparmor/apparmor-fix-quieting-of-audit-messages-for-network-mediation.patch.
- commit f4b43e1
* Fri Oct  6 2017 msuchanek@suse.de
- rpm/kernel-binary.spec.in: add the kernel-binary dependencies to
  kernel-binary-base (bsc#1060333).
- commit 955681c
* Fri Oct  6 2017 hare@suse.de
- scsi: ses: Fix racy cleanup of /sys in remove_dev()
  (bsc#1061782).
- scsi: ch: add refcounting (bsc#1061782).
- scsi: ses: make page2 support optional (bsc#1061782).
- scsi: ses: Fixup error message 'failed to get diagnostic page
  0xffffffea' (bsc#1061782).
- scsi: ses: check return code from ses_recv_diag() (bsc#1061782).
- scsi: ses: Fix wrong page error (bsc#1061782).
- commit 26418a1
* Fri Oct  6 2017 hare@suse.de
- Drop obsolete hpsa patches
- Delete
  patches.drivers/hpsa-allow-hpsa-to-claim-compaq-smartarray-devices.
- Delete
  patches.drivers/hpsa-handle-unsupported-devices-more-gracefully.
- Delete
  patches.drivers/hpsa-mark-older-boards-as-unsupported.patch.
- commit a441a63
* Fri Oct  6 2017 hare@suse.de
- Update config files to remove cciss driver
- commit e1fae76
* Fri Oct  6 2017 hare@suse.de
- scsi: hpsa: remove the smp_handler stub
  (bsc#1049517,FATE#322892).
- scsi: hpsa: fix the device_id in hpsa_update_device_info()
  (bsc#1049517,FATE#322892).
- scsi: hpsa: Remove 'hpsa_allow_any' module option
  (bsc#1049517,FATE#322892).
- scsi: cciss: Drop obsolete driver
  (bsc#1049517,FATE#322892,FATE#323833).
- scsi: hpsa: do not print errors for unsupported report luns
  format (bsc#1049517,FATE#322892).
- scsi: hpsa: Ignore errors for unsupported LV_DEVICE_ID VPD page
  (bsc#1049517,FATE#322892).
- scsi: hpsa: disable volume status check for legacy boards
  (bsc#1049517,FATE#322892).
- scsi: hpsa: add support for legacy boards
  (bsc#1049517,FATE#322892).
- commit a5fea5d
* Fri Oct  6 2017 msuchanek@suse.de
- powerpc/64s: Implement system reset idle wakeup reason
  (bsc#1055121).
- commit 4c3f65a
* Fri Oct  6 2017 msuchanek@suse.de
- rpm/kernel-docs.spec.in: Require xmlto unconditionally.
  Getting the condition right is too challenging it seems.
- commit fa08731
* Fri Oct  6 2017 msuchanek@suse.de
- powerpc/64s/idle: Process interrupts from system reset wakeup
  (bsc#1055121).
- commit 68b4938
* Fri Oct  6 2017 jthumshirn@suse.de
- libnvdimm, namespace: fix btt claim class crash (FATE#323731).
- libnvdimm, namespace: record 'lbasize' for pmem namespaces
  (FATE#323731).
- commit 285bf96
* Fri Oct  6 2017 jthumshirn@suse.de
- libnvdimm, btt: rework error clearing (FATE#323731).
- libnvdimm: fix potential deadlock while clearing errors
  (FATE#323731).
- libnvdimm, btt: cache sector_size in arena_info (FATE#323731).
- libnvdimm, btt: ensure that flags were also unchanged during
  a map_read (FATE#323731).
- libnvdimm, btt: refactor map entry operations with macros
  (FATE#323731).
- libnvdimm, btt: fix a missed NVDIMM_IO_ATOMIC case in the
  write path (FATE#323731).
- libnvdimm, btt: check memory allocation failure (FATE#323731).
- libnvdimm, btt: BTT updates for UEFI 2.7 format (FATE#323731).
- libnvdimm, label: switch to using v1.2 labels by default
  (FATE#323731).
- libnvdimm, label: add address abstraction identifiers
  (FATE#323731).
- libnvdimm, label: add v1.2 label checksum support (FATE#323731).
- libnvdimm, label: update 'nlabel' and 'position' handling for
  local namespaces (FATE#323731).
- libnvdimm, label: populate 'isetcookie' for blk-aperture
  namespaces (FATE#323731).
- libnvdimm, label: populate the type_guid property for v1.2
  namespaces (FATE#323731).
- libnvdimm, label: honor the lba size specified in v1.2 labels
  (FATE#323731).
- libnvdimm, label: add v1.2 interleave-set-cookie algorithm
  (FATE#323731).
- libnvdimm, label: add v1.2 nvdimm label definitions
  (FATE#323731).
- commit 9d14158
* Fri Oct  6 2017 pmladek@suse.com
- Delete
  patches.suse/ftrace-x86-xen-use-kernel-identity-mapping-only-when.patch.
  The change is not longer needed with PVOPS Xen (bsc#873195).
- commit 7b3f924
* Fri Oct  6 2017 jthumshirn@suse.de
- scsi: smartpqi: update driver version to 1.1.2-126
  (FATE#323891,bsc#1049514).
- scsi: smartpqi: cleanup raid map warning message
  (FATE#323891,bsc#1049514).
- scsi: smartpqi: update controller ids (FATE#323891,bsc#1049514).
- scsi: smartpqi: remove the smp_handler stub
  (FATE#323891,bsc#1049514).
- scsi: smartpqi: change driver version to 1.1.2-125
  (FATE#323891,bsc#1049514).
- scsi: smartpqi: add in new controller ids
  (FATE#323891,bsc#1049514).
- scsi: smartpqi: update kexec and power down support
  (FATE#323891,bsc#1049514).
- scsi: smartpqi: cleanup doorbell register usage
  (FATE#323891,bsc#1049514).
- scsi: smartpqi: update pqi passthru ioctl
  (FATE#323891,bsc#1049514).
- scsi: smartpqi: enhance BMIC cache flush
  (FATE#323891,bsc#1049514).
- scsi: smartpqi: add pqi reset quiesce support
  (FATE#323891,bsc#1049514).
- scsi: smartpqi: mark PM functions as __maybe_unused
  (FATE#323891,bsc#1049514).
- commit 1882c7b
* Fri Oct  6 2017 jthumshirn@suse.de
- Re-sorted series.conf to the correct order of lpfc patches.
- Refresh
  patches.drivers/scsi-lpfc-Fix-crash-receiving-ELS-while-detaching-dr.patch.
- Refresh
  patches.drivers/scsi-lpfc-Make-ktime-sampling-more-accurate.patch.
- Refresh
  patches.drivers/scsi-lpfc-Move-CQ-processing-to-a-soft-IRQ.patch.
- Refresh
  patches.drivers/scsi-lpfc-fix-pci-hot-plug-crash-in-timer-management.patch.
- Refresh
  patches.drivers/scsi-lpfc-remove-redundant-null-check-on-eqe.patch.
- commit d1bbb42
* Thu Oct  5 2017 msuchanek@suse.de
- Refresh configs.
- commit 1eb97f0
* Thu Oct  5 2017 msuchanek@suse.de
- Add ARMv7 configs.
- commit 97f0e22
* Thu Oct  5 2017 msuchanek@suse.de
- README: branch name
- commit e68e42d
* Thu Oct  5 2017 msuchanek@suse.de
- Build in Leap project.
- commit e6f1ae6
* Thu Oct  5 2017 bpoirier@suse.com
- sfc: Add ethtool -m support for QSFP modules (bsc#1058169
  FATE#322922).
- commit acd2839
* Thu Oct  5 2017 bpoirier@suse.com
- Refresh
  patches.drivers/scsi-lpfc-Cocci-spatch-pool_zalloc-simple.patch.
- Refresh
  patches.drivers/scsi-lpfc-Ensure-io-aborts-interlocked-with-the-targ.patch.
- Refresh
  patches.drivers/scsi-lpfc-Fix-crash-in-lpfc_nvme_fcp_io_submit-durin.patch.
- Refresh
  patches.drivers/scsi-lpfc-Fix-crash-receiving-ELS-while-detaching-dr.patch.
- Refresh
  patches.drivers/scsi-lpfc-Fix-lpfc-nvme-host-rejecting-IO-with-Not-R.patch.
- Refresh
  patches.drivers/scsi-lpfc-Fix-oops-if-nvmet_fc_register_targetport-f.patch.
- Refresh
  patches.drivers/scsi-lpfc-Fix-warning-messages-when-NVME_TARGET_FC-n.patch.
- Refresh
  patches.drivers/scsi-lpfc-Make-ktime-sampling-more-accurate.patch.
- Refresh
  patches.drivers/scsi-lpfc-Move-CQ-processing-to-a-soft-IRQ.patch.
- Refresh
  patches.drivers/scsi-lpfc-PLOGI-failures-during-NPIV-testing.patch.
- Refresh
  patches.drivers/scsi-lpfc-Reduce-log-spew-on-controller-reconnects.patch.
- Refresh
  patches.drivers/scsi-lpfc-change-version-to-11.4.0.4.patch.
- Refresh
  patches.drivers/scsi-lpfc-correct-nvme-sg-segment-count-check.patch.
- Refresh
  patches.drivers/scsi-lpfc-fix-pci-hot-plug-crash-in-timer-management.patch.
- Refresh
  patches.drivers/scsi-lpfc-remove-redundant-null-check-on-eqe.patch.
  Johannes reported that when a subsystem repository is not listed in
  git_sort.py head_names, the patches for it are silently not ordered by
  qdoit. The problem is avoided for now by adding this scsi tree to
  head_names. A more general solution will be needed later.
  I've reordered the patches and refreshed them. There is no difference in
  the expanded tree.
- commit 949fce3
* Thu Oct  5 2017 jeffm@suse.com
- Delete patches.rpmify/cloneconfig.diff.
- commit 3aaafe7
* Thu Oct  5 2017 colyli@suse.de
- block: fix integer overflow in __blkdev_sectors_to_bio_pages()
  (fate#322738,fate#322919,fate#322950,fate#323773).
- commit 249ef28
* Thu Oct  5 2017 colyli@suse.de
- md/r5cache: call mddev_lock/unlock() in r5c_journal_mode_set
  (fate#322738,fate#322919,fate#322950,fate#323773).
- commit c74127c
* Thu Oct  5 2017 msuchanek@suse.de
- powerpc/64s: Add workaround for P9 vector CI load issue
  (bsc#1055117).
- powerpc/mce: Move 64-bit machine check code into mce.c
  (bsc#1055117).
- powerpc/64s: Machine check handle ifetch from foreign real
  address for POWER9 (bsc#1055117).
- commit e6af293
* Thu Oct  5 2017 msuchanek@suse.de
- powerpc: Fix action argument for cpufeatures-based TLB flush
  (bsc#1055117).
- powerpc: Fix workaround for spurious MCE on POWER9
  (bsc#1055117).
- powerpc: Handle MCE on POWER9 with only DSISR bit 30 set
  (bsc#1055117).
- commit 783697a
* Thu Oct  5 2017 msuchanek@suse.de
- powerpc/powernv: Fix local TLB flush for boot and MCE on POWER9
  (bsc#1055117).
- commit df999ef
* Thu Oct  5 2017 msuchanek@suse.de
- powerpc/powernv: Use early_radix_enabled in POWER9 tlb flush
  (bsc#1055117).
- commit b5bc2ee
* Thu Oct  5 2017 msuchanek@suse.de
- powerpc/xive: Clear XIVE internal structures when a CPU is
  removed (fate#322438).
- commit 12dbb32
* Thu Oct  5 2017 msuchanek@suse.de
- powerpc/xive: Fix IPI reset (fate#322438).
- commit 6f5e307
* Thu Oct  5 2017 tiwai@suse.de
- Update cherry-picked drm/i915 ids
  blacklist.conf
  patches.drivers/drm-i915-Initialize-data-in-intel_dsi_dcs_backlight.
- commit 3e26bd9
* Thu Oct  5 2017 tiwai@suse.de
- drm/i915: Add __rcu to radix tree slot pointer (bsc#1051510).
- commit 73cdd3f
* Thu Oct  5 2017 tiwai@suse.de
- iwlwifi: mvm: set the RTS_MIMO_PROT bit in flag mask when
  sending sta to fw (bsc#1051510).
- iwlwifi: mvm: fix TCP CSUM offload with WEP and A000 series
  (bsc#1051510).
- iwlwifi: mvm: don't warn in queue sync on RF-kill (bsc#1051510).
- commit a8def16
* Thu Oct  5 2017 tiwai@suse.de
- drm/i915: remove unused function declaration (bsc#1051510).
- drm/i915/bxt: set min brightness from VBT (bsc#1051510).
- drm/i915: Suppress switch_mm emission between the same
  aliasing_ppgtt (bsc#1051510).
- drm/i915: Quietly cancel FBC activation if CRTC is turned off
  before worker (bsc#1051510).
- drm/i915: Initialize 'data' in intel_dsi_dcs_backlight.c
  (bsc#1051510).
- drm/i915: Always wake the device to flush the GTT (bsc#1051510).
- Revert "drm/i915/bxt: Disable device ready before shutdown
  command" (bsc#1051510).
- commit a5aceb8
* Thu Oct  5 2017 tiwai@suse.de
- ALSA: hda/ca0132 - Fix memory leak at error path (bsc#1052235).
- ALSA: hda: Fix regression of hdmi eld control created based
  on invalid pcm (bsc#1052235).
- commit c5a6ca0
* Thu Oct  5 2017 msuchanek@suse.de
- cxl: Fix memory page not handled (bsc#1055014).
- commit 904cf45
* Thu Oct  5 2017 msuchanek@suse.de
- KVM: PPC: Book3S: Fix server always zero from
  kvmppc_xive_get_xive() (bsc#1061840).
- commit a04c301
* Thu Oct  5 2017 msuchanek@suse.de
- KVM: PPC: Book3S HV: Fix bug causing host SLB to be restored
  incorrectly (bsc#1061840).
- commit fcb992f
* Thu Oct  5 2017 msuchanek@suse.de
- KVM: PPC: Book3S HV: Don't access XIVE PIPR register using
  byte accesses (bsc#1061840).
- commit 6a8e0e7
* Thu Oct  5 2017 msuchanek@suse.de
- KVM: PPC: Book3S HV: Add missing barriers to XIVE code and
  document them (bsc#1061840).
- commit 5efae32
* Thu Oct  5 2017 msuchanek@suse.de
- KVM: PPC: Book3S HV: Workaround POWER9 DD1.0 bug causing IPB
  bit loss (bsc#1061840).
- commit f582f45
* Thu Oct  5 2017 msuchanek@suse.de
- ibmveth: Support to enable LSO/CSO for Trunk VEA (bsc#1061843).
- commit e982073
* Thu Oct  5 2017 jroedel@suse.de
- PCI: Mark Broadcom HT2100 Root Port Extended Tags as broken
  (bsc#1061880).
- commit d31f3a4
* Thu Oct  5 2017 jroedel@suse.de
- x86/ldt: Fix off by one in get_segment_base() (bsc#1061872).
- x86/ldt: Rename ldt_struct::size to ::nr_entries (bsc#1061872).
- commit aaef532
* Thu Oct  5 2017 bpoirier@suse.com
- Refresh patch order in sorted section
  In case of absent remotes, series_sort reordered and renamed subsystem
  sections. This should now be fixed as long as the subsystem is listed in
  series_sort.py head_names.
- commit 0257dde
* Thu Oct  5 2017 tiwai@suse.de
- Refresh QXL fixes: they've been upstreamed
  patches.drivers/qxl-fix-pinning.patch
  patches.drivers/qxl-fix-primary-surface-handling.patch
- commit 133bed7
* Thu Oct  5 2017 tbogendoerfer@suse.de
- Refresh
  patches.drivers/net-mlx5-Introduce-trigger_health_work-function.patch.
- commit f064ef2
* Thu Oct  5 2017 hare@suse.de
- libata: check for trusted computing in IDENTIFY DEVICE data
  (bsc#1061782).
- libata: implement SECURITY PROTOCOL IN/OUT (bsc#1061782).
- libata: factor out a ata_identify_page_supported helper
  (bsc#1061782).
- libata: clarify log page naming / grouping (bsc#1061782).
- libata: factor out a ata_log_supported helper (bsc#1061782).
- libata: move ata_read_log_page to libata-core.c (bsc#1061782).
- commit 37e3e92
* Thu Oct  5 2017 vbabka@suse.cz
- mm/page_alloc.c: apply gfp_allowed_mask before the first
  allocation attempt (VM Functionality, git fixes).
- commit 9d48e99
* Thu Oct  5 2017 hare@suse.de
- scsi: scsi-sysfs: Adjust error returned for adapter reset
  request (bsc#1061782).
- scsi: make 'state' device attribute pollable (bsc#1061782).
- scsi: scsi_lib: rework scsi_internal_device_unblock_nowait()
  (bsc#1061782).
- scsi: fc: start decoupling fc_block_scsi_eh from scsi_cmnd
  (bsc#1061782).
- scsi: remove DRIVER_ATTR() usage (bsc#1061782).
- scsi: sd_zbc: Write unlock zone from sd_uninit_cmnd()
  (bsc#1061782).
- scsi: isci: fix typo in function names (bsc#1061782).
- scsi: sas: scsi_queue_work can fail, so make callers aware
  (bsc#1061782).
- scsi: sd: Use sysfs_match_string() (bsc#1061782).
- scsi: scsi_dh_alua: remove synchronous STPG support
  (bsc#1061782).
- scsi: remove various unused blist flags (bsc#1061782).
- scsi: xen-scsifront: Remove code that zeroes driver-private
  command data (bsc#1061782).
- scsi: virtio_scsi: Remove code that zeroes driver-private
  command data (bsc#1061782).
- scsi: snic: Remove code that zeroes driver-private command data
  (bsc#1061782).
- scsi: Make scsi_mq_prep_fn() call scsi_init_command()
  (bsc#1061782).
- scsi: Introduce scsi_mq_sgl_size() (bsc#1061782).
- scsi: Only add commands to the device command list if required
  by the LLD (bsc#1061782).
- commit 4360116
* Thu Oct  5 2017 hare@suse.de
- scsi: Make __scsi_remove_device go straight from BLOCKED to DEL
  (bsc#1061782).
- commit e9b1984
* Thu Oct  5 2017 hare@suse.de
- scsi: Introduce scsi_start_queue() (bsc#1061782).
- scsi: Protect SCSI device state changes with a mutex
  (bsc#1061782).
- commit e63b6b2
* Thu Oct  5 2017 hare@suse.de
- scsi: Create two versions of scsi_internal_device_unblock()
  (bsc#1061782).
- commit e74af46
* Thu Oct  5 2017 hare@suse.de
- scsi: Split scsi_internal_device_block() (bsc#1061782).
- commit 31782b2
* Thu Oct  5 2017 hare@suse.de
- sd: add support for TCG OPAL self encrypting disks
  (bsc#1061782).
- commit db34dbf
* Thu Oct  5 2017 tbogendoerfer@suse.de
- RDMA/qedr: Fix rdma_type initialization (bsc#1050545
  FATE#322893).
- IB: Move PCI dependency from root KConfig to HW's KConfigs
  (bsc#1046306 FATE#322942).
- RDMA/qedr: fix build error without ipv6 (bsc#1050545
  FATE#322893).
- RDMA/qedr: Missing error code in qedr_init_user_queue()
  (bsc#1050545 FATE#322893).
- RDMA/qedr: Add support for iWARP in user space (bsc#1050545
  FATE#322893).
- RDMA/qedr: Add iWARP connection management functions
  (bsc#1050545 FATE#322893).
- RDMA/qedr: Add iWARP connection management qp related callbacks
  (bsc#1050545 FATE#322893).
- RDMA/qedr: Add support for read with invalidate, supported in
  iWARP (bsc#1050545 FATE#322893).
- RDMA/qedr: Add iWARP support in existing verbs (bsc#1050545
  FATE#322893).
- RDMA/qedr: Add support for registering an iWARP device
  (bsc#1050545 FATE#322893).
- RDMA/qedr: Rename the qedr_cm file as a preparation for iWARP
  support (bsc#1050545 FATE#322893).
- commit 1e6b3ed
* Thu Oct  5 2017 tbogendoerfer@suse.de
- re-sorted series.conf
- commit d2e8138
* Thu Oct  5 2017 jroedel@suse.de
- KVM: x86: Fix immediate_exit handling for uninitialized AP
  (bsc#1061813).
- commit 4ed06fa
* Thu Oct  5 2017 jroedel@suse.de
- iommu/amd: pr_err() strings should end with newlines
  (bsc#1043261).
- commit 2281132
* Thu Oct  5 2017 hare@suse.de
- scsi: aacraid: error: testing array offset 'bus' after use
  (bsc#1049519,FATE#322889).
- scsi: aacraid: Fix command send race condition
  (bsc#1049519,FATE#322889).
- scsi: aacraid: report -ENOMEM to upper layer from
  aac_convert_sgraw2() (bsc#1049519,FATE#322889).
- scsi: aacraid: get rid of one level of indentation
  (bsc#1049519,FATE#322889).
- scsi: aacraid: fix indentation errors (bsc#1049519,FATE#322889).
- scsi: aacraid: complete all commands during bus reset
  (bsc#1049519,FATE#322889).
- scsi: aacraid: add fib flag to mark scsi command callback
  (bsc#1049519,FATE#322889).
- scsi: aacraid: enable sending of TMFs from aac_hba_send()
  (bsc#1049519,FATE#322889).
- scsi: aacraid: use aac_tmf_callback for reset fib
  (bsc#1049519,FATE#322889).
- scsi: aacraid: split off device, target, and bus reset
  (bsc#1049519,FATE#322889).
- scsi: aacraid: split off host reset (bsc#1049519,FATE#322889).
- scsi: aacraid: split off functions to generate reset FIB
  (bsc#1049519,FATE#322889).
- commit 8d89ea9
* Thu Oct  5 2017 jkosina@suse.cz
- series.conf: restore upstream ordering which I broke by mistake
- commit 1757725
* Thu Oct  5 2017 hare@suse.de
- Reshuffle series.conf to include scsi-misc branch
- commit 9845e26
* Thu Oct  5 2017 vbabka@suse.cz
- mm: fix data corruption caused by lazyfree page (VM
  Functionality, bsc#1061775).
- mm: avoid marking swap cached page as lazyfree (VM
  Functionality, bsc#1061775).
- commit 791a9bf
* Thu Oct  5 2017 hare@suse.de
- scsi: megaraid_mbox: drop duplicate bus reset and device reset
  function (bsc#1049528,FATE#322937).
- scsi: megaraid_sas: driver version upgrade
  (bsc#1049528,FATE#322937).
- scsi: megaraid_sas: call megasas_dump_frame with correct IO
  frame size (bsc#1049528,FATE#322937).
- scsi: megaraid_sas: modified few prints in OCR and IOC INIT path
  (bsc#1049528,FATE#322937).
- scsi: megaraid_sas: replace internal FALSE/TRUE definitions
  with false/true (bsc#1049528,FATE#322937).
- scsi: megaraid_sas: Return pended IOCTLs with
  cmd_status MFI_STAT_WRONG_STATE in case adapter is dead
  (bsc#1049528,FATE#322937).
- scsi: megaraid_sas: use vmalloc for crash dump buffers and
  driver's local RAID map (bsc#1049528,FATE#322937).
- scsi: megaraid_sas: Use SMID for Task abort case only
  (bsc#1049528,FATE#322937).
- scsi: megaraid_sas: Check valid aen class range to avoid kernel
  panic (bsc#1049528,FATE#322937).
- scsi: megaraid_sas: Fix endianness issues in DCMD handling
  (bsc#1049528,FATE#322937).
- scsi: megaraid_sas: Do not re-fire shutdown DCMD after OCR
  (bsc#1049528,FATE#322937).
- scsi: megaraid_sas: Call megasas_complete_cmd_dpc_fusion
  every 1 second while there are pending commands
  (bsc#1049528,FATE#322937).
- scsi: megaraid_sas: Use synchronize_irq in target reset case
  (bsc#1049528,FATE#322937).
- scsi: megaraid_sas: set minimum value of resetwaittime to be
  1 secs (bsc#1049528,FATE#322937).
- scsi: megaraid_sas: mismatch of allocated MFI frame
  size and length exposed in MFI MPT pass through command
  (bsc#1049528,FATE#322937).
- scsi: megaraid_sas: fix allocate instance->pd_info twice
  (bsc#1049528,FATE#322937).
- scsi: megaraid: fix format-overflow warning
  (bsc#1049528,FATE#322937).
- scsi: megaraid: Replace PCI pool old API
  (bsc#1049528,FATE#322937).
- scsi: megaraid_sas: fix error handle in megasas_probe_one
  (bsc#1049528,FATE#322937).
- scsi: megaraid_sas: fix memleak in megasas_alloc_cmdlist_fusion
  (bsc#1049528,FATE#322937).
- scsi: megaraid: Fix a sleep-in-atomic bug
  (bsc#1049528,FATE#322937).
- commit 83ffcac
* Thu Oct  5 2017 ohering@suse.de
- add mainline tags to hyperv patches
- commit 529ce16
* Thu Oct  5 2017 mkubecek@suse.cz
- inetpeer: fix RCU lookup() again (bsc#1061739).
- inetpeer: fix RCU lookup() (bsc#1061739).
- inetpeer: remove AVL implementation in favor of RB tree
  (bsc#1061739).
- net: convert inet_peer.refcnt from atomic_t to refcount_t
  (bsc#1061739).
- commit 3cca9a9
* Thu Oct  5 2017 tbogendoerfer@suse.de
- Update config files.
- commit d121c2b
* Thu Oct  5 2017 tbogendoerfer@suse.de
- net/mlx5e: Distribute RSS table among all RX rings (bsc#1046305
  FATE#322943).
- net/mlx5e: Stop NAPI when irq balancer changes affinity
  (bsc#1046305 FATE#322943).
- net/mlx5e: Use kernel's mechanism to avoid missing NAPIs
  (bsc#1046305 FATE#322943).
- net/mlx5e: Slightly increase RX page-cache size (bsc#1046305
  FATE#322943).
- net/mlx5e: Don't recycle page if moved to far NUMA (bsc#1046305
  FATE#322943).
- net/mlx5e: Remove unnecessary fields in ICO SQ (bsc#1046305
  FATE#322943).
- net/mlx5e: Type-specific optimizations for RX post WQEs function
  (bsc#1046305 FATE#322943).
- net/mlx5e: Non-atomic RQ state indicator for UMR WQE in progress
  (bsc#1046305 FATE#322943).
- net/mlx5e: Non-atomic indicator for ring enabled state
  (bsc#1046305 FATE#322943).
- net/mlx5e: Refactor data-path lro header function (bsc#1046305
  FATE#322943).
- net/mlx5e: Early-return on empty completion queues (bsc#1046305
  FATE#322943).
- net/mlx5e: NAPI busy-poll when UMR post is in progress
  (bsc#1046305 FATE#322943).
- net/mlx5e: Small enhancements for RX MPWQE allocation and free
  (bsc#1046305 FATE#322943).
- net/mlx5e: Use memset to init skbs_frags array to zeros
  (bsc#1046305 FATE#322943).
- net/mlx5e: Remove unnecessary wqe_sz field from RQ buffer
  (bsc#1046305 FATE#322943).
- net/mlx5e: Replace multiplication by stride size with a shift
  (bsc#1046305 FATE#322943).
- net/mlx5e: Reorganize struct mlx5e_rq (bsc#1046305 FATE#322943).
- net/mlx5e: Support RSS for GRE tunneled packets (bsc#1046305
  FATE#322943).
- net/mlx5e: Support TSO and TX checksum offloads for GRE tunnels
  (bsc#1046305 FATE#322943).
- net/mlx5e: Use IP version matching to classify IP traffic
  (bsc#1046305 FATE#322943).
- net/mlx5: Add tracepoints (bsc#1046305 FATE#322943).
- net/mlx5: Add hash table for flow groups in flow table
  (bsc#1046305 FATE#322943).
- net/mlx5: Add hash table to search FTEs in a flow-group
  (bsc#1046305 FATE#322943).
- net/mlx5: Don't store reserved part in FTEs and FGs (bsc#1046305
  FATE#322943).
- net/mlx5: Convert linear search for free index to ida
  (bsc#1046305 FATE#322943).
- net/mlx5e: Fix wrong code indentation in conditional statement
  (bsc#1046305 FATE#322943).
- net/mlx5: Remove a leftover unused variable (bsc#1046305
  FATE#322943).
- net/mlx5: Add a blank line after declarations V2 (bsc#1046305
  FATE#322943).
- net/mlx5e: make mlx5e_profile const (bsc#1046305 FATE#322943).
- net/mlx5e: Use size_t to store byte offset in statistics
  descriptors (bsc#1046305 FATE#322943).
- net/mlx5e: Use kernel types instead of uint*_t in ethtool
  callbacks (bsc#1046305 FATE#322943).
- net/mlx5e: Place constants on the right side of comparisons
  (bsc#1046305 FATE#322943).
- net/mlx5e: Avoid using multiple blank lines (bsc#1046305
  FATE#322943).
- net/mlx5e: Properly indent within conditional statements
  (bsc#1046305 FATE#322943).
- net/mlx5: Add a blank line after declarations (bsc#1046305
  FATE#322943).
- net/mlx5: Avoid blank lines after/before open/close brace
  (bsc#1046305 FATE#322943).
- net/mlx5e: Add outbound PCI buffer overflow counter (bsc#1046305
  FATE#322943).
- net/mlx5e: Add RX buffer fullness counters (bsc#1046305
  FATE#322943).
- net/mlx5: Add RX buffer fullness counters infrastructure
  (bsc#1046305 FATE#322943).
- net/mlx5e: Add PCIe outbound stalls counters (bsc#1046305
  FATE#322943).
- net/mlx5: Add PCIe outbound stalls counters infrastructure
  (bsc#1046305 FATE#322943).
- net/mlx5e: IPoIB, Add support for get_link_ksettings in ethtool
  (bsc#1046305 FATE#322943).
- net/mlx5e: Send PAOS command on interface up/down (bsc#1046305
  FATE#322943).
- mlx5: ensure 0 is returned when vport is zero (bsc#1046305
  FATE#322943).
- mlx5: remove unnecessary pci_set_drvdata() (bsc#1046305
  FATE#322943).
- net/mlx5: Increase the maximum flow counters supported
  (bsc#1046305 FATE#322943).
- net/mlx5: Fix counter list hardware structure (bsc#1046305
  FATE#322943).
- net/mlx5: Delay events till ib registration ends (bsc#1046305
  FATE#322943).
- net/mlx5: Add CONFIG_MLX5_ESWITCH Kconfig (bsc#1046305
  FATE#322943).
- net/mlx5: Separate between E-Switch and MPFS (bsc#1046305
  FATE#322943).
- net/mlx5: Unify vport manager capability check (bsc#1046305
  FATE#322943).
- net/mlx5e: NIC netdev init flow cleanup (bsc#1046305
  FATE#322943).
- net/mlx5e: Rearrange netdevice ops structures (bsc#1046305
  FATE#322943).
- commit 16606b3
* Thu Oct  5 2017 jthumshirn@suse.de
- scsi: lpfc: PLOGI failures during NPIV testing
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Fix oops of nvme host during driver unload
  (bsc#1050239,FATE#322918).
- scsi: lpfc: change version to 11.4.0.4 (FATE#324028).
- scsi: lpfc: Fix secure firmware updates
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Fix lpfc nvme host rejecting IO with Not Ready
  message (bsc#1050239,FATE#322918).
- scsi: lpfc: fix pci hot plug crash in list_add call
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Fix warning messages when NVME_TARGET_FC not defined
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Cocci spatch "pool_zalloc-simple"
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Ensure io aborts interlocked with the target
  (bsc#1050239,FATE#322918).
- scsi: lpfc: remove redundant null check on eqe (bsc#1050239,
  FATE#322918).
- scsi: lpfc: Extend RDP support (bsc#1050239,FATE#322918).
- scsi: lpfc: Set missing abort context (bsc#1050239,FATE#322918).
- scsi: lpfc: Disable NPIV support if NVME is enabled
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Fix FCP hba_wqidx assignment
  (bsc#1050239,FATE#322918).
- scsi: lpfc: fix pci hot plug crash in timer management routines
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Revise NVME module parameter descriptions for
  better clarity (bsc#1050239,FATE#322918).
- scsi: lpfc: Fix oops if nvmet_fc_register_targetport fails
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Fix crash receiving ELS while detaching driver
  (bsc#1050239,FATE#322918).
- scsi: lpfc: correct nvme sg segment count check
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Make ktime sampling more accurate
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Move CQ processing to a soft IRQ
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Reduce log spew on controller reconnects
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Fix crash in lpfc_nvme_fcp_io_submit during LIP
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Don't return internal MBXERR_ERROR code from probe
  function (bsc#1050239,FATE#322918).
- scsi: lpfc: avoid false-positive gcc-8 warning
  (bsc#1050239,FATE#322918).
- scsi: lpfc: avoid an unused function warning
  (bsc#1050239,FATE#322918).
- scsi: lpfc: lpfc version bump 11.4.0.3
  (bsc#1050239,FATE#322918).
- scsi: lpfc: fix "integer constant too large" error on 32bit
  archs (bsc#1050239,FATE#322918).
- scsi: lpfc: Add Buffer to Buffer credit recovery support
  (bsc#1050239,FATE#322918).
- scsi: lpfc: remove console log clutter
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Fix bad sgl reposting after 2nd adapter reset
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Fix nvme target failure after 2nd adapter reset
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Fix relative offset error on large nvmet target ios
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Fix MRQ > 1 context list handling
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Limit amount of work processed in IRQ
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Correct issues with FAWWN and FDISCs
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Fix NVME PRLI handling during RSCN
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Fix crash in lpfc nvmet when fc port is reset
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Fix duplicate NVME rport entries and namespaces
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Fix handling of FCP and NVME FC4 types in Pt2Pt
  topology (bsc#1050239,FATE#322918).
- scsi: lpfc: Correct return error codes to align with nvme_fc
  transport (bsc#1050239,FATE#322918).
- scsi: lpfc: convert info messages to standard messages
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Fix oops when NVME Target is discovered in a
  nonNVME environment (bsc#1050239,FATE#322918).
- scsi: lpfc: Fix rediscovery on switch blade pull
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Fix loop mode target discovery
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Fix plogi collision that causes illegal state
  transition (bsc#1050239,FATE#322918).
- scsi: lpfc: remove useless code in lpfc_sli4_bsg_link_diag_test
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Replace PCI pool old API (bsc#1050239,FATE#322918).
- lpfc: support nvmet_fc defer_rcv callback
  (bsc#1050239,FATE#322918).
- scsi: lpfc: don't double count abort errors
  (bsc#1050239,FATE#322918).
- scsi: lpfc: spin_lock_irq() is not nestable
  (bsc#1050239,FATE#322918).
- scsi: lpfc: fix refcount error on node list
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Fix nvme io stoppage after link bounce
  (bsc#1050239,FATE#322918).
- scsi: lpfc: update to revision to 11.4.0.1
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Driver responds LS_RJT to Beacon Off ELS - Linux
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Fix crash in lpfc_sli_ringtxcmpl_put when nvmet
  gets an abort request (bsc#1050239,FATE#322918).
- scsi: lpfc: Fix crash doing IO with resets
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Fix crash after firmware flash when IO is running
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Fix SLI3 drivers attempting NVME ELS commands
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Break up IO ctx list into a separate get and put
  list (bsc#1050239,FATE#322918).
- scsi: lpfc: Reduce time spent in IRQ for received NVME commands
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Vport creation is failing with "Link Down" error
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Fix nvme_info sysfs output to be consistent
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Fix system panic when express lane enabled
  (bsc#1050239,FATE#322918).
- scsi: lpfc: update to revision to 11.4.0.0
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Add auto EQ delay logic (bsc#1050239,FATE#322918).
- scsi: lpfc: Fix defects reported by Coverity Scan
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Fix vports not logging into target
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Fix PRLI retry handling when target rejects it
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Null pointer dereference when log_verbose is set
  to 0xffffffff (bsc#1050239,FATE#322918).
- scsi: lpfc: Fix System panic after loading the driver
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Fix crash on powering off BFS VM with passthrough
  device (bsc#1050239,FATE#322918).
- scsi: lpfc: Fix return value of board_mode store routine in
  case of online failure (bsc#1050239,FATE#322918).
- scsi: lpfc: Fix counters so outstandng NVME IO count is accurate
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Fix Port going offline after multiple resets
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Fix nvmet node ref count handling
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Fix Lun Priority level shown as NA
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Add changes to assist in NVMET debugging
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Fix nvme port role handling in sysfs and debugfs
  handlers (bsc#1050239,FATE#322918).
- commit 5d26711
* Thu Oct  5 2017 vbabka@suse.cz
- mm: oom: let oom_reap_task and exit_mmap run concurrently
  (VM Functionality, bsc#1061755).
- mm, hugetlb: do not allocate non-migrateable gigantic pages
  from movable zones (bsc#1061756, bnc#1027153, bnc#1030659,
  fate#323634).
- commit 60f16a2
* Thu Oct  5 2017 mkubecek@suse.cz
- udp: remove unreachable ufo branches (bsc#1061739).
- net: Kill NETIF_F_UFO and SKB_GSO_UDP (bsc#1061739).
- inet: Remove software UFO fragmenting code (bsc#1061739).
- net: Remove all references to SKB_GSO_UDP (bsc#1061739).
- inet: Stop generating UFO packets (bsc#1061739).
- net: Remove references to NETIF_F_UFO from ethtool
  (bsc#1061739).
- net: Remove references to NETIF_F_UFO in netdev_fix_features()
  (bsc#1061739).
- virtio_net: Remove references to NETIF_F_UFO (bsc#1061739).
- dummy: Remove references to NETIF_F_UFO (bsc#1061739).
- tun/tap: Remove references to NETIF_F_UFO (bsc#1061739).
- macvlan/macvtap: Remove NETIF_F_UFO advertisement (bsc#1061739).
- ipvlan: Stop advertising NETIF_F_UFO support (bsc#1061739).
- macb: Remove bogus reference to NETIF_F_UFO (bsc#1061739).
- s2io: Remove UFO support (bsc#1061739).
- commit e43998f
* Thu Oct  5 2017 hare@suse.de
- scsi: csiostor: Avoid content leaks and casts (FATE#322932).
- scsi: csiostor: Replace PCI pool old API (FATE#322932).
- scsi: csiostor: add check for supported fw version
  (FATE#322932).
- scsi: csiostor: add support for Chelsio T6 adapters
  (FATE#322932).
- scsi: csiostor: fail probe if fw does not support FCoE
  (FATE#322932).
- scsi: csiostor: update module version (FATE#322932).
- scsi: fcoe: Fix few small typos in fcoe.c (FATE#322932).
- scsi: fcoe: Remove an extra out label in _fcoe_create function
  (FATE#322932).
- scsi: fix typos and grammar in comments of scsi_transport_fc.c
  (FATE#322918).
- scsi: fnic: Zero io_cmpl_skip on fw reset completion
  (FATE#322783).
- scsi: fnic: added timestamp reporting in fnic debug stats
  (FATE#322783).
- scsi: fnic: correct speed display and add support for 25,40
  and 100G (FATE#322783).
- scsi: fnic: fix format string overflow warning (FATE#322783).
- scsi: libfc: pass an error pointer to fc_disc_error()
  (FATE#322783).
- commit ac9dc66
* Thu Oct  5 2017 jthumshirn@suse.de
- scsi: lpfc: Fix transition nvme-i rport handling to nport only
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Add nvme initiator devloss support
  (bsc#1050239,FATE#322918).
- scsi: lpfc: make a couple of functions static
  (bsc#1050239,FATE#322918).
- scsi: lpfc: fix spelling mistake "entrys" -> "entries"
  (bsc#1050239,FATE#322918).
- lpfc debugfs: get rid of pointless access_ok()
  (bsc#1050239,FATE#322918).
- commit cfc608f
* Thu Oct  5 2017 vbabka@suse.cz
- mm/sparse.c: fix typo in online_mem_sections (bnc#1027153,
  bnc#1030659, fate#323634).
- commit 4d2d8e0
* Thu Oct  5 2017 tbogendoerfer@suse.de
- Re-sorted sorted section
- commit d20aa5b
* Thu Oct  5 2017 oneukum@suse.com
- xhci: set missing SuperSpeedPlus Link Protocol bit in roothub
  descriptor (bsc#1060807).
- commit c584666
* Thu Oct  5 2017 mhocko@suse.cz
- memremap: add scheduling point to devm_memremap_pages
  (bnc#1057079).
- mm, page_alloc: add scheduling point to memmap_init_zone
  (bnc#1057079).
- mm, memory_hotplug: add scheduling point to __add_pages
  (bnc#1057079).
- commit 7fdee39
* Thu Oct  5 2017 neilb@suse.com
- NFS: Fix NFSv2 security settings (git-fixes).
- commit dc322d2
* Thu Oct  5 2017 dchang@suse.com
- be2net: fix TSO6/GSO issue causing TX-stall on Lancer/BEx
  (bsc#1050252 FATE#322920).
- benet: fix set but not used warning (bsc#1050252 FATE#322920).
- commit a8eb98a
* Thu Oct  5 2017 dchang@suse.com
- tg3: clean up redundant initialization of tnapi (bsc#1050260
  FATE#322917).
- tg3: Be drop monitor friendly (bsc#1050260 FATE#322917).
- commit 8771a11
* Thu Oct  5 2017 dchang@suse.com
- qlge: fix duplicated code for different branches (bsc#1050529
  FATE#322902).
- commit 69f8b35
* Thu Oct  5 2017 dchang@suse.com
- qlcnic: remove redundant zero check on retries counter
  (bsc#1050540 FATE#322896).
- qlogic: make device_attribute const (bsc#1050540 FATE#322896).
- qlcnic: add const to bin_attribute structure (bsc#1050540
  FATE#322896).
- qlcnic: remove unnecessary static in qlcnic_dump_fw()
  (bsc#1050540 FATE#322896).
- commit 544316b
* Wed Oct  4 2017 bpoirier@suse.com
- igb: support BCM54616 PHY (bsc#1056651 FATE#322191 bsc#1056643
  FATE#322192).
- igbvf: convert msleep to mdelay in atomic context (bsc#1056651
  FATE#322191 bsc#1056643 FATE#322192).
- igbvf: after mailbox write, wait for reply (bsc#1056651
  FATE#322191 bsc#1056643 FATE#322192).
- igbvf: add lock around mailbox ops (bsc#1056651 FATE#322191
  bsc#1056643 FATE#322192).
- igb: do not drop PF mailbox lock after read of VF message
  (bsc#1056651 FATE#322191 bsc#1056643 FATE#322192).
- igb: expose mailbox unlock method (bsc#1056651 FATE#322191
  bsc#1056643 FATE#322192).
- igb: add argument names to mailbox op function declarations
  (bsc#1056651 FATE#322191 bsc#1056643 FATE#322192).
- igb: Remove incorrect "unexpected SYS WRAP" log message
  (bsc#1056651 FATE#322191 bsc#1056643 FATE#322192).
- igb: protect TX timestamping from API misuse (bsc#1056651
  FATE#322191 bsc#1056643 FATE#322192).
- igb: Fix error of RX network flow classification (bsc#1056651
  FATE#322191 bsc#1056643 FATE#322192).
- commit 89da50e
* Wed Oct  4 2017 bpoirier@suse.com
- i40e SLE15 update, part 2
- i40e: 25G FEC status improvements (bsc#1056658 FATE#322188
  bsc#1056662 FATE#322186).
- i40e: Detect ATR HW Evict NVM issue and disable the feature
  (bsc#1056658 FATE#322188 bsc#1056662 FATE#322186).
- i40e: Fix a bug with VMDq RSS queue allocation (bsc#1056658
  FATE#322188 bsc#1056662 FATE#322186).
- i40e: Fix for trace found with S4 state (bsc#1056658 FATE#322188
  bsc#1056662 FATE#322186).
- i40e: Fix for unused value issue found by static analysis
  (bsc#1056658 FATE#322188 bsc#1056662 FATE#322186).
- i40e: Handle admin Q timeout when releasing NVM (bsc#1056658
  FATE#322188 bsc#1056662 FATE#322186).
- i40e: Store the requested FEC information (bsc#1056658
  FATE#322188 bsc#1056662 FATE#322186).
- i40e: Update state variable for adminq subtask (bsc#1056658
  FATE#322188 bsc#1056662 FATE#322186).
- i40e: Use correct flag to enable egress traffic for unicast
  promisc (bsc#1056658 FATE#322188 bsc#1056662 FATE#322186).
- i40e: display correct UDP tunnel type name (bsc#1056658
  FATE#322188 bsc#1056662 FATE#322186).
- i40e: fix incorrect variable assignment (bsc#1056658 FATE#322188
  bsc#1056662 FATE#322186).
- i40e: fix odd formatting and indent (bsc#1056658 FATE#322188
  bsc#1056662 FATE#322186).
- i40e: fix up 32 bit timespec references (bsc#1056658 FATE#322188
  bsc#1056662 FATE#322186).
- i40e: force VMDQ device name truncation (bsc#1056658 FATE#322188
  bsc#1056662 FATE#322186).
- i40e: handle setting administratively set MAC address back to
  zero (bsc#1056658 FATE#322188 bsc#1056662 FATE#322186).
- i40e/i40evf: adjust packet size to account for double VLANs
  (bsc#1056658 FATE#322188 bsc#1056662 FATE#322186).
- i40e/i40evf: avoid dynamic ITR updates when polling or low
  packet rate (bsc#1056658 FATE#322188 bsc#1056662 FATE#322186).
- i40e/i40evf: make IPv6 ATR code clearer (bsc#1056658 FATE#322188
  bsc#1056662 FATE#322186).
- i40e/i40evf: remove ULTRA latency mode (bsc#1056658 FATE#322188
  bsc#1056662 FATE#322186).
- i40e/i40evf: remove mismatched type warnings (bsc#1056658
  FATE#322188 bsc#1056662 FATE#322186).
- i40e/i40evf: rename vf_offload_flags to vf_cap_flags in struct
  virtchnl_vf_resource (bsc#1056658 FATE#322188 bsc#1056662
  FATE#322186).
- i40e/i40evf: support for VF VLAN tag stripping control
  (bsc#1056658 FATE#322188 bsc#1056662 FATE#322186).
- i40e/i40evf: use cmpxchg64 when updating private flags in
  ethtool (bsc#1056658 FATE#322188 bsc#1056662 FATE#322186).
- i40e: initialize our affinity_mask based on cpu_possible_mask
  (bsc#1056658 FATE#322188 bsc#1056662 FATE#322186).
- i40e: invert logic for checking incorrect cpu vs irq affinity
  (bsc#1056658 FATE#322188 bsc#1056662 FATE#322186).
- i40e: move check for avoiding VID=0 filters into
  i40e_vsi_add_vlan (bsc#1056658 FATE#322188 bsc#1056662
  FATE#322186).
- i40e: move enabling icr0 into i40e_update_enable_itr
  (bsc#1056658 FATE#322188 bsc#1056662 FATE#322186).
- i40e: prevent changing ITR if adaptive-rx/tx enabled
  (bsc#1056658 FATE#322188 bsc#1056662 FATE#322186).
- i40e: prevent snprintf format specifier truncation (bsc#1056658
  FATE#322188 bsc#1056662 FATE#322186).
- i40e: remove WQ_UNBOUND and the task limit of our workqueue
  (bsc#1056658 FATE#322188 bsc#1056662 FATE#322186).
- i40e: remove workaround for Open Firmware MAC address
  (bsc#1056658 FATE#322188 bsc#1056662 FATE#322186).
- i40e: remove workaround for resetting XPS (bsc#1056658
  FATE#322188 bsc#1056662 FATE#322186).
- i40e: report BPF prog id during XDP_QUERY_PROG (bsc#1056658
  FATE#322188 bsc#1056662 FATE#322186).
- i40e: separate hw_features from runtime changing flags
  (bsc#1056658 FATE#322188 bsc#1056662 FATE#322186).
- i40e: synchronize nvmupdate command and adminq subtask
  (bsc#1056658 FATE#322188 bsc#1056662 FATE#322186).
- i40e: use cpumask_copy instead of direct assignment (bsc#1056658
  FATE#322188 bsc#1056662 FATE#322186).
- i40evf: Use le32_to_cpu before evaluating HW desc fields
  (bsc#1056658 FATE#322188 bsc#1056662 FATE#322186).
- i40evf: add some missing includes (bsc#1056658 FATE#322188
  bsc#1056662 FATE#322186).
- i40evf: fix possible snprintf truncation of q_vector->name
  (bsc#1056658 FATE#322188 bsc#1056662 FATE#322186).
- i40evf: prevent VF close returning before state transitions
  to DOWN (bsc#1056658 FATE#322188 bsc#1056662 FATE#322186).
- i40evf: remove unnecessary __packed (bsc#1056658 FATE#322188
  bsc#1056662 FATE#322186).
- i40evf: use netdev variable in reset task (bsc#1056658
  FATE#322188 bsc#1056662 FATE#322186).
- Refresh
  patches.drivers/i40e-add-private-flag-to-control-source-pruning.patch.
- Refresh
  patches.drivers/i40e-avoid-NVM-acquire-deadlock-during-NVM-update.patch.
- Refresh
  patches.drivers/i40e-point-wb_desc-at-the-nvm_wb_desc-during-i40e_re.patch.
- commit 8d65ed4
* Wed Oct  4 2017 bpoirier@suse.com
- ixgbe: Disable flow control for XFI (bsc#1056657 FATE#322189
  bsc#1056653 FATE#322190).
- ixgbe: Do not support flow control autonegotiation for X553
  (bsc#1056657 FATE#322189 bsc#1056653 FATE#322190).
- ixgbe: Update NW_MNG_IF_SEL support for X553 (bsc#1056657
  FATE#322189 bsc#1056653 FATE#322190).
- ixgbe: Enable LASI interrupts for X552 devices (bsc#1056657
  FATE#322189 bsc#1056653 FATE#322190).
- ixgbe: Ensure MAC filter was added before setting MACVLAN
  (bsc#1056657 FATE#322189 bsc#1056653 FATE#322190).
- ixgbe: NULL xdp_tx rings on resource cleanup (bsc#1056657
  FATE#322189 bsc#1056653 FATE#322190).
- commit ae3ddc3
* Wed Oct  4 2017 bpoirier@suse.com
- e1000e: Initial Support for IceLake (bsc#1056664 FATE#322185).
- e1000e: add check on e1e_wphy() return value (bsc#1056664
  FATE#322185).
- commit 875d96b
* Wed Oct  4 2017 yousaf.kaukab@suse.com
- arm64: cn99xx: drop iort/smmu workaround
  References: bsc#1039695
- Delete
  patches.drivers/0007-iommu-arm-smmu-ACPI-Enable-Cavium-SMMU-v2.patch.
- Delete
  patches.drivers/0008-iommu-arm-smmu-ACPI-Enable-Cavium-SMMU-v3.patch.
- Delete
  patches.drivers/0009-acpi-iort-thunderx2-enable-smmu-resource-size-errata.patch.
- commit 8768934
* Wed Oct  4 2017 tbogendoerfer@suse.de
- s390/diag: add diag26c support (bsc#1061024 FATE#323301).
- commit 829f7d6
* Wed Oct  4 2017 tbogendoerfer@suse.de
- qeth: VNIC Characteristics support (bsc#1061024 FATE#323301).
- commit 014a65c
* Wed Oct  4 2017 tbogendoerfer@suse.de
- s390/qeth: add VNICC get/set timeout support (bsc#1061024
  FATE#323301).
- s390/qeth: add VNICC enable/disable support (bsc#1061024
  FATE#323301).
- s390/qeth: add basic VNICC support (bsc#1061024 FATE#323301).
- s390/qeth: use skb_cow_head() for L2 OSA xmit (bsc#1061024
  FATE#323301).
- s390/qeth: unify code to build header elements (bsc#1061024
  FATE#323301).
- s390/qeth: pass full IQD header length to fill_buffer()
  (bsc#1061024 FATE#323301).
- s390/qeth: pass TSO data offset to fill_buffer() (bsc#1061024
  FATE#323301).
- s390/qeth: pass TSO header length to fill_buffer() (bsc#1061024
  FATE#323301).
- s390/qeth: pass full data length to l2_fill_header()
  (bsc#1061024 FATE#323301).
- s390/qeth: split L2 xmit paths (bsc#1061024 FATE#323301).
- s390/qeth: fix using of ref counter for rxip addresses
  (bsc#1061024 FATE#323301).
- s390/qeth: fix trace-messages for deleting rxip addresses
  (bsc#1061024 FATE#323301).
- s390/qeth: reject multicast rxip addresses (bsc#1061024
  FATE#323301).
- s390/qeth: extract bridgeport cmd builder (bsc#1061024
  FATE#323301).
- s390/net: reduce inlining (bsc#1061024 FATE#323301).
- s390/qeth: make more use of skb API (bsc#1061024 FATE#323301).
- s390/qeth: clean up fill_buffer() offset logic (bsc#1061024
  FATE#323301).
- s390/qeth: straighten out fill_buffer() interface (bsc#1061024
  FATE#323301).
- s390/qeth: simplify fragment type selection (bsc#1061024
  FATE#323301).
- s390/qeth: remove extra L3 adapterparms query (bsc#1061024
  FATE#323301).
- s390/qeth: remove extra L2 adapterparms query (bsc#1061024
  FATE#323301).
- s390/qeth: don't access skb after transmission (bsc#1061024
  FATE#323301).
- s390/qeth: constify attribute_group structures (bsc#1061024
  FATE#323301).
- s390/qeth: fix L3 next-hop in xmit qeth hdr (bsc#1061024
  FATE#323301).
- drivers: s390: move static and inline before return type
  (bsc#1061024 FATE#323301).
- s390/qeth: use diag26c to get MAC address on L2 (bsc#1061024
  FATE#323301).
- s390/qeth: fix packing buffer statistics (bsc#1061024
  FATE#323301).
- s390/qeth: add ipa return codes for bridgeport (bsc#1061024
  FATE#323301).
- s390/qeth: do early device setup for z/VM IQD NICs (bsc#1061024
  FATE#323301).
- s390/qeth: add support for early L3 device setup (bsc#1061024
  FATE#323301).
- s390/qeth: silence qeth_fix_features() (bsc#1061024
  FATE#323301).
- s390/qeth: consolidate pack buffer flushing (bsc#1061024
  FATE#323301).
- s390/qeth: add missing strings for IPA return codes (bsc#1061024
  FATE#323301).
- s390/qeth: log bridgeport capabilities (bsc#1061024
  FATE#323301).
- s390/qeth: query IPv6 IPA support on HiperSockets (bsc#1061024
  FATE#323301).
- s390/qeth: remove skb_is_nonlinear() check on IQD (bsc#1061024
  FATE#323301).
- s390/qeth: remove support for IPA_IP_FRAGMENTATION (bsc#1061024
  FATE#323301).
- s390: drivers: convert to use DRIVER_ATTR_RO/WO (bsc#1061024
  FATE#323301).
- commit 7d25fa3
* Wed Oct  4 2017 mfleming@suse.de
- sched/cpuset/pm: Fix cpuset vs. suspend-resume bugs
  (bsc#1061593).
- commit 8f70090
* Wed Oct  4 2017 jeffm@suse.com
- Delete patches.fixes/block-copy-bi_vcnt-in-_bio_clone_fast.
- commit 471096c
* Wed Oct  4 2017 hare@suse.de
- scsi: bnx2fc: Update version number to 2.11.8 (FATE#322911).
- scsi: bnx2fc: Make rport_terminate_io callback a NOOP
  (FATE#322911).
- scsi: bnx2fc: If IO is still in cleanup then do not return to
  SCSI layer (FATE#322911).
- scsi: bnx2fc: Adjust bnx2fc_npiv_create_vports for WWNNs from
  NVRAM that are zero (FATE#322911).
- scsi: bnx2fc: Update copyright for 2017 (FATE#322911).
- scsi: bnx2fc: Check for connection offload before sending RRQ
  (FATE#322911).
- scsi: bnx2fc: Add filters to the non-offload FCoE receive path
  (FATE#322911).
- commit 68f3019
* Wed Oct  4 2017 jthumshirn@suse.de
- libnvdimm, nfit: export an 'ecc_unit_size' sysfs attribute
  (FATE#324028).
- mm, devm_memremap_pages: use multi-order radix for ZONE_DEVICE
  lookups (FATE#324028).
- commit 1cd0d92
* Wed Oct  4 2017 hare@suse.de
- Move iSCSI and FCoE patches to ordered section
- commit 222f486
* Wed Oct  4 2017 hare@suse.de
- Move device-mapper and MD patches to ordered section
- commit b850033
* Wed Oct  4 2017 jslaby@suse.cz
- orc: mark it as reliable (bnc#1058115).
- Update config files.
- commit cb41042
* Wed Oct  4 2017 jslaby@suse.cz
- x86/asm: Use register variable to get stack pointer value
  (bnc#1058115).
- commit 7e6a014
* Wed Oct  4 2017 jslaby@suse.cz
- x86/asm: Fix inline asm call constraints for GCC 4.4
  (bnc#1058115).
- commit 98f2e81
* Wed Oct  4 2017 hare@suse.de
- Delete patches.fixes/sd_liberal_28_sense_invalid.diff.
- Delete patches.suse/dm-emulate-blkrrpart-ioctl.
- commit 0422451
* Wed Oct  4 2017 mgorman@suse.de
- mm/mempolicy: fix NUMA_INTERLEAVE_HIT counter (VM Performance,
  bnc#959436).
- commit 7934624
* Wed Oct  4 2017 lduncan@suse.com
- scsi: scsi_transport_iscsi: fix the issue that iscsi_if_rx
  doesn't parse nlmsg properly (bsc#1059051 CVE-2017-14489).
- commit 180de31
* Wed Oct  4 2017 agraf@suse.de
- Delete patches.arch/arm-OMAP-Fix-missing-usb.h-include.patch.
  (no longer needed)
- Delete patches.arch/arm-arndale-usb.patch. (no longer needed)
- Delete
  patches.arch/arm64-0006-arm64-Select-reboot-driver-for-X-Gene-platform.patch.
  (not needed, our config already includes the driver)
- Delete patches.arch/ppc64le-build-vmlinux.patch. (no longer needed)
- commit 986bfef
* Tue Oct  3 2017 jeffm@suse.com
- Delete patches.suse/binutils2_26.patch.
  The issue addressed by this patch should be handled via upstream
  commit 6d92bc9d483 (x86/build: Build compressed x86 kernels as PIE).
- commit 4e90692
* Tue Oct  3 2017 msuchanek@suse.de
- ctcm_fsms: Convert skb->user accesses to refcount_t (fix
  s390x build).
- commit 3dd2c06
* Tue Oct  3 2017 jeffm@suse.com
- Delete
  patches.suse/btrfs-account-for-pinned-bytes-in-should_alloc_chunk.patch.
- commit bc115ae
* Tue Oct  3 2017 msuchanek@suse.de
- Refresh vanilla config.
- commit e14f2e8
* Tue Oct  3 2017 mgorman@suse.de
- Delete patches.suse/connector-read-mostly.
- commit 038f6d3
* Tue Oct  3 2017 jeffm@suse.com
- series.conf: remove commented out lines for removed patches
- commit 2bff591
* Tue Oct  3 2017 mkubecek@suse.cz
- config: merge openSUSE configs from stable branch
- commit 2ed2011
* Tue Oct  3 2017 jeffm@suse.com
- Delete patches.arch/arm-refresh-mach-types.diff.
  It was marked for refresh in 12/2016 and hasn't been updated.
- commit d18cac1
* Tue Oct  3 2017 neilb@suse.com
- getcwd: Close race with d_move called by lustre (bsc#1052593).
- commit 930e552
* Mon Oct  2 2017 tbogendoerfer@suse.de
- qed: remove unnecessary call to memset (bsc#1050536
  FATE#322898).
- scsi: qedi: off by one in qedi_get_cmd_from_tid() (bsc#1050534
  FATE#322899).
- scsi: qedf: drop bus reset handler (bsc#1050530 FATE#322901).
- scsi: qedf: Update driver version to 8.20.5.0 (bsc#1050530
  FATE#322901).
- scsi: qedf: Fix up modinfo parameter name for 'debug' in
  modinfo output (bsc#1050530 FATE#322901).
- scsi: qedf: Covert single-threaded workqueues to regular
  workqueues (bsc#1050530 FATE#322901).
- scsi: qedf: Corrent VLAN tag insertion in fallback VLAN case
  (bsc#1050530 FATE#322901).
- scsi: qedf: Use granted MAC from the FCF for the FCoE source
  address if it is available (bsc#1050530 FATE#322901).
- scsi: qedf: Set WWNN and WWPN based on values from qed
  (bsc#1050530 FATE#322901).
- scsi: qedi: Limit number for CQ queues (bsc#1050534
  FATE#322899).
- qed: fix spelling mistake: "calescing" -> "coalescing"
  (bsc#1050536 FATE#322898).
- qed: enhanced per queue max coalesce value (bsc#1050536
  FATE#322898).
- qed: Read per queue coalesce from hardware (bsc#1050536
  FATE#322898).
- qed: Add support for vf coalesce configuration (bsc#1050536
  FATE#322898).
- qede: Add ethtool support for Energy efficient ethernet
  (bsc#1050538 FATE#322897).
- qed: Add support for Energy efficient ethernet (bsc#1050536
  FATE#322898).
- qed/qede: Add setter APIs support for RX flow classification
  (bsc#1050536 FATE#322898 bsc#1050538 FATE#322897).
- qede: Add getter APIs support for RX flow classification
  (bsc#1050538 FATE#322897).
- RDMA/qedr: fix spelling mistake: "invlaid" -> "invalid"
  (bsc#1050545 FATE#322893).
- RDMA/qedr: notify user application of supported WIDs
  (bsc#1050545 FATE#322893).
- RDMA/qedr: notify user application if DPM is supported
  (bsc#1050545 FATE#322893).
- commit a0c198b
* Mon Oct  2 2017 msuchanek@suse.de
- powerpc/eeh: Create PHB PEs after EEH is initialized
  (bsc#1055120, git-fixes 5cb1f8fdddb7).
- commit d07b84d
* Mon Oct  2 2017 tbogendoerfer@suse.de
- net: sched: cls_flower: fix ndo_setup_tc type for stats call
  (bsc#1056787).
- commit f625cbb
* Mon Oct  2 2017 msuchanek@suse.de
- powerpc/perf: Factor out PPMU_ONLY_COUNT_RUN check code from
  power8 (fate#321438, git-fixes efe881afdd999, bsc#1056686).
- commit 9850b2a
* Mon Oct  2 2017 jslaby@suse.cz
- driver core: platform: fix race condition with driver_override
  (bnc#1060662).
- RDMA/uverbs: Check port number supplied by user verbs cmds
  (bnc#1060662).
- usb: dwc3: replace %%p with %%pK (bnc#1060662).
- USB: serial: cp210x: add ID for CEL EM3588 USB ZigBee stick
  (bnc#1060662).
- usb: usbip: set buffer pointers to NULL after free
  (bnc#1060662).
- Add USB quirk for HVR-950q to avoid intermittent device resets
  (bnc#1060662).
- usb: Fix typo in the definition of Endpoint[out]Request
  (bnc#1060662).
- USB: core: fix device node leak (bnc#1060662).
- USB: serial: option: add two Longcheer device ids (bnc#1060662).
- USB: serial: qcserial: new Sierra Wireless EM7305 device ID
  (bnc#1060662).
- xhci: Limit USB2 port wake support for AMD Promontory hosts
  (bnc#1060662).
- gfs2: Fix glock rhashtable rcu bug (bnc#1060662).
- Add "shutdown" to "struct class" (bnc#1060662).
- tpm: Issue a TPM2_Shutdown for TPM2 devices (bnc#1060662).
- tpm: fix a kernel memory leak in tpm-sysfs.c (bnc#1060662).
- powerpc/powernv: Fix CPU_HOTPLUG=n idle.c compile error
  (bnc#1060662).
- x86/uaccess: Optimize copy_user_enhanced_fast_string() for
  short strings (bnc#1060662).
- sched/fair, cpumask: Export for_each_cpu_wrap() (bnc#1060662).
- sched/core: Implement new approach to scale select_idle_cpu()
  (bnc#1060662).
- sched/numa: Use down_read_trylock() for the mmap_sem
  (bnc#1060662).
- sched/numa: Override part of migrate_degrades_locality()
  when idle balancing (bnc#1060662).
- sched/fair: Simplify wake_affine() for the single socket case
  (bnc#1060662).
- sched/numa: Implement NUMA node level wake_affine()
  (bnc#1060662).
- sched/fair: Remove effective_load() (bnc#1060662).
- sched/numa: Hide numa_wake_affine() from UP build (bnc#1060662).
- xen: avoid deadlock in xenbus driver (bnc#1060662).
- crypto: drbg - Fixes panic in wait_for_completion call
  (bnc#1060662).
- Linux 4.12.1 (bnc#1060662).
- Delete patches.kernel.org/patch-4.12.1.
  Expand 4.12.1.
- commit 4505d70
* Mon Oct  2 2017 jslaby@suse.cz
- mqueue: fix a use-after-free in sys_mq_notify() (bnc#1060662).
- imx-serial: RX DMA startup latency (bnc#1060662).
- proc: Fix proc_sys_prune_dcache to hold a sb reference
  (bnc#1060662).
- locking/rwsem-spinlock: Fix EINTR branch in
  __down_write_common() (bnc#1060662).
- staging: vt6556: vnt_start Fix missing call to
  vnt_key_init_table (bnc#1060662).
- staging: comedi: fix clean-up of comedi_class in comedi_init()
  (bnc#1060662).
- crypto: caam - fix gfp allocation flags (part I) (bnc#1060662).
- crypto: rsa-pkcs1pad - use constant time memory comparison
  for MACs (bnc#1060662).
- ext4: check return value of kstrtoull correctly in
  reserved_clusters_store (bnc#1060662).
- x86/mm/pat: Don't report PAT on CPUs that don't support it
  (bnc#1060662).
- Linux 4.12.2 (bnc#1060662).
- Delete patches.kernel.org/patch-4.12.1-2.
  Expand 4.12.2.
- commit ead2cb8
* Mon Oct  2 2017 jslaby@suse.cz
- staging: android: uapi: drop definitions of removed
  ION_IOC_{FREE,SHARE} ioctls (bnc#1060662).
- net/mlx5: Fix driver load error flow when firmware is stuck
  (bnc#1060662).
- net/mlx5: Cancel delayed recovery work when unloading the driver
  (bnc#1060662).
- net/mlx5e: Fix TX carrier errors report in get stats ndo
  (bnc#1060662).
- ipv6: dad: don't remove dynamic addresses if link is down
  (bnc#1060662).
- vxlan: fix hlist corruption (bnc#1060662).
- geneve: fix hlist corruption (bnc#1060662).
- net: core: Fix slab-out-of-bounds in netdev_stats_to_stats64
  (bnc#1060662).
- liquidio: fix bug in soft reset failure detection (bnc#1060662).
- net: ipv6: Compare lwstate in detecting duplicate nexthops
  (bnc#1060662).
- vrf: fix bug_on triggered by rx when destroying a vrf
  (bnc#1060662).
- virtio-net: fix leaking of ctx array (bnc#1060662).
- rds: tcp: use sock_create_lite() to create the accept socket
  (bnc#1060662).
- net/mlx5e: Initialize CEE's getpermhwaddr address buffer to 0xff
  (bnc#1060662).
- cxgb4: fix BUG() on interrupt deallocating path of ULD
  (bnc#1060662).
- tap: convert a mutex to a spinlock (bnc#1060662).
- bridge: mdb: fix leak on complete_info ptr on fail path
  (bnc#1060662).
- brcmfmac: fix possible buffer overflow in
  brcmf_cfg80211_mgmt_tx() (bnc#1060662 CVE-2017-7541
  bsc#1049645).
- sfc: don't read beyond unicast address list (bnc#1060662).
- Adding asm-prototypes.h for genksyms to generate crc
  (bnc#1060662).
- sed regex in Makefile.build requires line break between exported
  symbols (bnc#1060662).
- Adding the type of exported symbols (bnc#1060662).
- sparc64: Fix gup_huge_pmd (bnc#1060662).
- brcmfmac: Fix a memory leak in error handling path in
  'brcmf_cfg80211_attach' (bnc#1060662).
- brcmfmac: Fix glom_skb leak in brcmf_sdiod_recv_chain
  (bnc#1060662).
- efi: Process the MEMATTR table only if EFI_MEMMAP is enabled
  (bnc#1060662).
- cfg80211: Define nla_policy for
  NL80211_ATTR_LOCAL_MESH_POWER_MODE (bnc#1060662).
- cfg80211: Validate frequencies nested in
  NL80211_ATTR_SCAN_FREQUENCIES (bnc#1060662).
- cfg80211: Check if PMKID attribute is of expected size
  (bnc#1060662).
- cfg80211: Check if NAN service ID is of expected size
  (bnc#1060662).
- drm/amdgpu/gfx6: properly cache mc_arb_ramcfg (bnc#1060662).
- KVM: ARM64: fix phy counter access failure in guest
  (bnc#1060662).
- KVM: PPC: Book3S: Fix typo in XICS-on-XIVE state saving code
  (bnc#1060662).
- kvm-vfio: Decouple only when we match a group (bnc#1060662).
- irqchip/gic-v3: Fix out-of-bound access in gic_set_affinity
  (bnc#1060662).
- parisc: Report SIGSEGV instead of SIGBUS when running out of
  stack (bnc#1060662).
- parisc: use compat_sys_keyctl() (bnc#1060662).
- parisc: DMA API: return error instead of BUG_ON for dma ops
  on non dma devs (bnc#1060662).
- parisc/mm: Ensure IRQs are off in switch_mm() (bnc#1060662).
- tools/lib/lockdep: Reduce MAX_LOCK_DEPTH to avoid overflowing
  lock_chain/: Depth (bnc#1060662).
- compiler, clang: always inline when CONFIG_OPTIMIZE_INLINING
  is disabled (bnc#1060662).
- thp, mm: fix crash due race in MADV_FREE handling (bnc#1060662).
- kernel/extable.c: mark core_kernel_text notrace (bnc#1060662).
- mm/list_lru.c: fix list_lru_count_node() to be race free
  (bnc#1060662).
- fs/dcache.c: fix spin lockup issue on nlru->lock (bnc#1060662).
- checkpatch: silence perl 5.26.0 unescaped left brace warnings
  (bnc#1060662).
- binfmt_elf: use ELF_ET_DYN_BASE only for PIE (bnc#1060662).
- arm: move ELF_ET_DYN_BASE to 4MB (bnc#1060662).
- arm64: move ELF_ET_DYN_BASE to 4GB / 4MB (bnc#1060662).
- powerpc: move ELF_ET_DYN_BASE to 4GB / 4MB (bnc#1060662).
- s390: reduce ELF_ET_DYN_BASE (bnc#1060662).
- exec: Limit arg stack to at most 75%% of _STK_LIM (bnc#1060662).
- powerpc/kexec: Fix radix to hash kexec due to IAMR/AMOR
  (bnc#1060662).
- ARM64: dts: marvell: armada37xx: Fix timer interrupt specifiers
  (bnc#1060662).
- arm64: Preventing READ_IMPLIES_EXEC propagation (bnc#1060662).
- vt: fix unchecked __put_user() in tioclinux ioctls
  (bnc#1060662).
- rcu: Add memory barriers for NOCB leader wakeup (bnc#1060662).
- nvmem: core: fix leaks on registration errors (bnc#1060662).
- Drivers: hv: vmbus: Close timing hole that can corrupt per-cpu
  page (bnc#1060662).
- mnt: In umount propagation reparent in a separate pass
  (bnc#1060662).
- mnt: In propgate_umount handle visiting mounts in any order
  (bnc#1060662).
- mnt: Make propagate_umount less slow for overlapping mount
  propagation trees (bnc#1060662).
- selftests/capabilities: Fix the test_execve test (bnc#1060662).
- mm: fix overflow check in expand_upwards() (bnc#1060662).
- crypto: talitos - Extend max key length for SHA384/512-HMAC
  and AEAD (bnc#1060662).
- crypto: atmel - only treat EBUSY as transient if backlog
  (bnc#1060662).
- crypto: sha1-ssse3 - Disable avx2 (bnc#1060662).
- crypto: caam - properly set IV after {en,de}crypt (bnc#1060662).
- crypto: caam - fix signals handling (bnc#1060662).
- KEYS: DH: validate __spare field (bnc#1060662).
- sched/headers/uapi: Fix linux/sched/types.h userspace
  compilation errors (bnc#1060662).
- sched/topology: Fix building of overlapping sched-groups
  (bnc#1060662).
- sched/topology: Optimize build_group_mask() (bnc#1060662).
- sched/topology: Fix overlapping sched_group_mask (bnc#1060662).
- PM / wakeirq: Convert to SRCU (bnc#1060662).
- pstore: Fix leaked pstore_record in pstore_get_backend_records()
  (bnc#1060662).
- ALSA: x86: Clear the pdata.notify_lpe_audio pointer before
  teardown (bnc#1060662).
- ALSA: hda/realtek - change the location for one of two front
  microphones (bnc#1060662).
- PM / QoS: return -EINVAL for bogus strings (bnc#1060662).
- kvm: vmx: Do not disable intercepts for BNDCFGS (bnc#1060662).
- kvm: x86: Guest BNDCFGS requires guest MPX support
  (bnc#1060662).
- kvm: vmx: Check value written to IA32_BNDCFGS (bnc#1060662).
- kvm: vmx: allow host to access guest MSR_IA32_BNDCFGS
  (bnc#1060662).
- Linux 4.12.3 (bnc#1060662).
- Delete patches.kernel.org/patch-4.12.2-3.
  Expand 4.12.3.
- commit bebe2f3
* Mon Oct  2 2017 tbogendoerfer@suse.de
- Update config files.
- commit 7cd64fe
* Mon Oct  2 2017 tbogendoerfer@suse.de
- bnxt_re: Don't issue cmd to delete GID for QP1 GID entry before
  the QP is destroyed (bsc#1050244 FATE#322915).
- bnxt_re: Fix memory leak in FRMR path (bsc#1050244 FATE#322915).
- bnxt_re: Remove RTNL lock dependency in bnxt_re_query_port
  (bsc#1050244 FATE#322915).
- bnxt_re: Fix race between the netdev register and unregister
  events (bsc#1050244 FATE#322915).
- bnxt_re: Free up devices in module_exit path (bsc#1050244
  FATE#322915).
- bnxt_re: Fix compare and swap atomic operands (bsc#1050244
  FATE#322915).
- bnxt_re: Stop issuing further cmds to FW once a cmd times out
  (bsc#1050244 FATE#322915).
- bnxt_re: Fix update of qplib_qp.mtu when modified (bsc#1050244
  FATE#322915).
- IB/bnxt_re: Fix frame stack compilation warning (bsc#1050244
  FATE#322915).
- commit 28ebe60
* Mon Oct  2 2017 tbogendoerfer@suse.de
- bnxt_en: check for ingress qdisc in flower offload (bsc#1050242
  FATE#32291).
- bnxt_en: add a dummy definition for bnxt_vf_rep_get_fid()
  (bsc#1050242 FATE#32291).
- bnxt_en: add code to query TC flower offload stats (bsc#1050242
  FATE#32291).
- bnxt_en: add TC flower offload flow_alloc/free FW cmds
  (bsc#1050242 FATE#32291).
- bnxt_en: bnxt: add TC flower filter offload support (bsc#1050242
  FATE#32291).
- bnxt_en: Reduce default rings on multi-port cards (bsc#1050242
  FATE#32291).
- bnxt_en: Improve -ENOMEM logic in NAPI poll loop (bsc#1050242
  FATE#32291).
- bnxt: initialize board_info values with proper enums
  (bsc#1050242 FATE#32291).
- bnxt: Add PCIe device IDs for bcm58802/bcm58808 (bsc#1050242
  FATE#32291).
- bnxt_en: assign CPU affinity hints to bnxt_en IRQs (bsc#1050242
  FATE#322914).
- bnxt_en: Improve tx ring reservation logic (bsc#1050242
  FATE#322914).
- bnxt_en: Update firmware interface spec. to 1.8.1.4 (bsc#1050242
  FATE#322914).
- bnxt_en: fix spelling mistake: "swtichdev" -> "switchdev"
  (bsc#1050242 FATE#322914).
- commit a61ddf9
* Mon Oct  2 2017 jslaby@suse.cz
- disable new gcc-7.1.1 warnings for now (bnc#1060662).
- ir-core: fix gcc-7 warning on bool arithmetic (bnc#1060662).
- s5p-jpeg: don't return a random width/height (bnc#1060662).
- thermal: max77620: fix device-node reference imbalance
  (bnc#1060662).
- thermal: cpu_cooling: Avoid accessing potentially freed
  structures (bnc#1060662).
- ath9k: fix tx99 use after free (bnc#1060662).
- ath9k: fix tx99 bus error (bnc#1060662).
- ath9k: fix an invalid pointer dereference in ath9k_rng_stop()
  (bnc#1060662).
- iwlwifi: mvm: fix the recovery flow while connecting
  (bnc#1060662).
- NFC: fix broken device allocation (bnc#1060662).
- NFC: nfcmrvl_uart: add missing tty-device sanity check
  (bnc#1060662).
- NFC: nfcmrvl: do not use device-managed resources (bnc#1060662).
- NFC: nfcmrvl: use nfc-device for firmware download
  (bnc#1060662).
- NFC: nfcmrvl: fix firmware-management initialisation
  (bnc#1060662).
- nfc: Ensure presence of required attributes in the
  activate_target handler (bnc#1060662).
- nfc: Fix the sockaddr length sanitization in llcp_sock_connect
  (bnc#1060662).
- NFC: Add sockaddr length checks before accessing sa_family in
  bind handlers (bnc#1060662).
- perf intel-pt: Move decoder error setting into one condition
  (bnc#1060662).
- perf intel-pt: Improve sample timestamp (bnc#1060662).
- perf intel-pt: Fix missing stack clear (bnc#1060662).
- perf intel-pt: Ensure IP is zero when state is
  INTEL_PT_STATE_NO_IP (bnc#1060662).
- perf intel-pt: Fix last_ip usage (bnc#1060662).
- perf intel-pt: Ensure never to set 'last_ip' when packet
  'count' is zero (bnc#1060662).
- perf intel-pt: Use FUP always when scanning for an IP
  (bnc#1060662).
- perf intel-pt: Clear FUP flag on error (bnc#1060662).
- Bluetooth: use constant time memory comparison for secret values
  (bnc#1060662).
- wlcore: fix 64K page support (bnc#1060662).
- pstore: Don't warn if data is uncompressed and type is not
  PSTORE_TYPE_DMESG (bnc#1060662).
- mwifiex: fixup error cases in mwifiex_add_virtual_intf()
  (bnc#1060662).
- Btrfs: fix invalid extent maps due to hole punching
  (bnc#1060662).
- btrfs: Don't clear SGID when inheriting ACLs (bnc#1060662).
- Btrfs: incremental send, fix invalid memory access
  (bnc#1060662).
- igb: Explicitly select page 0 at initialization (bnc#1060662).
- spi: atmel: fix corrupted data issue on SAM9 family SoCs
  (bnc#1060662).
- ASoC: zx-i2s: flip I2S master/slave mode (bnc#1060662).
- ASoC: compress: Derive substream from stream based on direction
  (bnc#1060662).
- ASoC: atmel: tse850: fix off-by-one in the "ANA" enumeration
  count (bnc#1060662).
- PM / Domains: Fix unsafe iteration over modified list of device
  links (bnc#1060662).
- PM / Domains: Fix unsafe iteration over modified list of domain
  providers (bnc#1060662).
- PM / Domains: Fix unsafe iteration over modified list of domains
  (bnc#1060662).
- scsi: ses: do not add a device to an enclosure if
  enclosure_add_links() fails (bnc#1060662).
- scsi: virtio_scsi: let host do exception handling (bnc#1060662).
- scsi: qla2xxx: Allow ABTS, PURX, RIDA on ATIOQ for ISP83XX/27XX
  (bnc#1060662).
- scsi: Add STARGET_CREATED_REMOVE state to scsi_target_state
  (bnc#1060662).
- scsi: Avoid that scsi_exit_rq() triggers a use-after-free
  (bnc#1060662).
- iscsi-target: Add login_keys_workaround attribute for non RFC
  initiators (bnc#1060662).
- xen/scsiback: Fix a TMR related use-after-free (bnc#1060662).
- scsi: virtio_scsi: always read VPD pages for multiqueue too
  (bnc#1060662).
- powerpc/mm/radix: Only add X for pages overlapping kernel text
  (bnc#1060662).
- powerpc/pseries: Fix passing of pp0 in updatepp() and
  updateboltedpp() (bnc#1060662).
- powerpc/mm/radix: Fix execute permissions for interrupt_vectors
  (bnc#1060662).
- powerpc/64: Fix atomic64_inc_not_zero() to return an int
  (bnc#1060662).
- powerpc: Fix emulation of mcrf in emulate_step() (bnc#1060662).
- powerpc: Fix emulation of mfocrf in emulate_step()
  (bnc#1060662).
- powerpc/asm: Mark cr0 as clobbered in mftb() (bnc#1060662).
- powerpc/mm/radix: Properly clear process table entry
  (bnc#1060662).
- powerpc/perf: Fix SDAR_MODE value for continous sampling on
  Power9 (bnc#1060662).
- xen/x86: fix cpu hotplug (bnc#1060662).
- PCI: vmd: Move SRCU cleanup after bus, child device removal
  (bnc#1060662).
- PCI: Work around poweroff & suspend-to-RAM issue on Macbook
  Pro 11 (bnc#1060662).
- PCI: rockchip: Use normal register bank for config accessors
  (bnc#1060662).
- PCI/PM: Restore the status of PCI devices across hibernation
  (bnc#1060662).
- PCI/MSI: Ignore affinity if pre/post vector count is more than
  min_vecs (bnc#1060662).
- usb: xhci: fix spinlock recursion for USB2 test mode
  (bnc#1060662).
- xhci: fix memleak in xhci_run() (bnc#1060662).
- xhci: fix 20000ms port resume timeout (bnc#1060662).
- xhci: Fix NULL pointer dereference when cleaning up streams
  for removed host (bnc#1060662).
- xhci: Bad Ethernet performance plugged in ASM1042A host
  (bnc#1060662).
- mxl111sf: Fix driver to use heap allocate buffers for USB
  messages (bnc#1060662).
- usb: storage: return on error to avoid a null pointer
  dereference (bnc#1060662).
- USB: cdc-acm: add device-id for quirky printer (bnc#1060662).
- usb: renesas_usbhs: fix usbhsc_resume() for
  !USBHSF_RUNTIME_PWCTRL (bnc#1060662).
- usb: renesas_usbhs: gadget: disable all eps when the driver
  stops (bnc#1060662).
- HID: multitouch: do not blindly set EV_KEY or EV_ABS bits
  (bnc#1060662).
- md: don't use flush_signals in userspace processes
  (bnc#1060662).
- md: fix deadlock between mddev_suspend() and md_write_start()
  (bnc#1060662).
- x86/xen: allow userspace access during hypercalls (bnc#1060662).
- cx88: Fix regression in initial video standard setting
  (bnc#1060662).
- rc-core: fix input repeat handling (bnc#1060662).
- tools/testing/nvdimm: fix nfit_test buffer overflow
  (bnc#1060662).
- libnvdimm, btt: fix btt_rw_page not returning errors
  (bnc#1060662).
- libnvdimm: fix the clear-error check in nsio_rw_bytes
  (bnc#1060662).
- libnvdimm: fix badblock range handling of ARS range
  (bnc#1060662).
- ext2: Don't clear SGID when inheriting ACLs (bnc#1060662).
- dm raid: stop using BUG() in __rdev_sectors() (bnc#1060662).
- Raid5 should update rdev->sectors after reshape (bnc#1060662).
- s390/syscalls: Fix out of bounds arguments access (bnc#1060662).
- drm/amdgpu/gfx8: drop per-APU CU limits (bnc#1060662).
- drm/amdgpu: fix vblank_time when displays are off (bnc#1060662).
- drm/amdgpu/cgs: always set reference clock in mode_info
  (bnc#1060662).
- drm/amd/amdgpu: Return error if initiating read out of range
  on vram (bnc#1060662).
- drm/amdgpu: fix the memory corruption on S3 (bnc#1060662).
- drm/amdgpu: Don't call amd_powerplay_destroy() if we don't
  have powerplay (bnc#1060662).
- drm/radeon/ci: disable mclk switching for high refresh rates
  (v2) (bnc#1060662).
- drm/radeon: Fix eDP for single-display iMac10,1 (v2)
  (bnc#1060662).
- drm/ttm: Fix use-after-free in ttm_bo_clean_mm (bnc#1060662).
- drm/etnaviv: Expose our reservation object when exporting a
  dmabuf (bnc#1060662).
- ipmi: use rcu lock around call to intf->handlers->sender()
  (bnc#1060662).
- ipmi:ssif: Add missing unlock in error branch (bnc#1060662).
- xfs: Don't clear SGID when inheriting ACLs (bnc#1060662).
- CIFS: Reconnect expired SMB sessions (bnc#1060662).
- f2fs: load inode's flag from disk (bnc#1060662).
- f2fs: wake up all waiters in f2fs_submit_discard_endio
  (bnc#1060662).
- f2fs: sanity check checkpoint segno and blkoff (bnc#1060662).
- f2fs: try to freeze in gc and discard threads (bnc#1060662).
- f2fs: Do not issue small discards in LFS mode (bnc#1060662).
- f2fs: sanity check size of nat and sit cache (bnc#1060662).
- f2fs: use spin_{,un}lock_irq{save,restore} (bnc#1060662).
- f2fs: Don't clear SGID when inheriting ACLs (bnc#1060662).
- serial: st-asc: Potential error pointer dereference
  (bnc#1060662).
- serial: sh-sci: Uninitialized variables in sysfs files
  (bnc#1060662).
- ovl: mark parent impure on ovl_link() (bnc#1060662).
- ovl: fix random return value on mount (bnc#1060662).
- drm/amd/powerplay: fix memory leak in cz_hwmgr backend
  (bnc#1060662).
- drm/i915: Disable MSI for all pre-gen5 (bnc#1060662).
- vfio: Fix group release deadlock (bnc#1060662).
- vfio: New external user group/file match (bnc#1060662).
- vfio: Remove unnecessary uses of vfio_container.group_lock
  (bnc#1060662).
- nvme-rdma: remove race conditions from IB signalling
  (bnc#1060662).
- ftrace: Fix uninitialized variable in match_records()
  (bnc#1060662).
- iommu/arm-smmu: Plumb in new ACPI identifiers (bnc#1060662).
- drm/i915/gvt: Fix inconsistent locks holding sequence
  (bnc#1060662).
- drm/atomic: Add missing drm_atomic_state_clear to
  atomic_remove_fb (bnc#1060662).
- MIPS: Fix mips_atomic_set() retry condition (bnc#1060662).
- MIPS: Fix mips_atomic_set() with EVA (bnc#1060662).
- MIPS: Negate error syscall return in trace (bnc#1060662).
- mtd: nand: tango: Fix incorrect use of SEQIN command
  (bnc#1060662).
- ubifs: Correctly evict xattr inodes (bnc#1060662).
- ubifs: Don't leak kernel memory to the MTD (bnc#1060662).
- ubifs: Don't encrypt special files on creation (bnc#1060662).
- ubifs: Set double hash cookie also for RENAME_EXCHANGE
  (bnc#1060662).
- ACPI / EC: Drop EC noirq hooks to fix a regression
  (bnc#1060662).
- Revert "ACPI / EC: Enable event freeze mode..." to fix a
  regression (bnc#1060662).
- x86/acpi: Prevent out of bound access caused by broken ACPI
  tables (bnc#1060662 CVE-2017-11473 bsc#1049603).
- x86/ioapic: Pass the correct data to unmask_ioapic_irq()
  (bnc#1060662).
- MIPS: Fix MIPS I ISA /proc/cpuinfo reporting (bnc#1060662).
- MIPS: Save static registers before sysmips (bnc#1060662).
- MIPS: Actually decode JALX in `__compute_return_epc_for_insn'
  (bnc#1060662).
- MIPS: Fix unaligned PC interpretation in `compute_return_epc'
  (bnc#1060662).
- MIPS: math-emu: Prevent wrong ISA mode instruction emulation
  (bnc#1060662).
- MIPS: Send SIGILL for BPOSGE32 in
  `__compute_return_epc_for_insn' (bnc#1060662).
- MIPS: Rename `sigill_r6' to `sigill_r2r6' in
  `__compute_return_epc_for_insn' (bnc#1060662).
- MIPS: Send SIGILL for linked branches in
  `__compute_return_epc_for_insn' (bnc#1060662).
- MIPS: Send SIGILL for R6 branches in
  `__compute_return_epc_for_insn' (bnc#1060662).
- MIPS: Fix a typo: s/preset/present/ in r2-to-r6 emulation
  error message (bnc#1060662).
- Input: i8042 - fix crash at boot time (bnc#1060662).
- IB/iser: Fix connection teardown race condition (bnc#1060662).
- IB/core: Namespace is mandatory input for address resolution
  (bnc#1060662).
- sunrpc: use constant time memory comparison for mac
  (bnc#1060662).
- net/sunrpc/xprt_sock: fix regression in connection error
  reporting (bnc#1060662).
- NFS: Fix initialization of nfs_page_array->npages (bnc#1060662).
- PNFS fix EACCESS on commit to DS handling (bnc#1060662).
- NFS: only invalidate dentrys that are clearly invalid
  (bnc#1060662 bsc#1047118).
- udf: Fix races with i_size changes during readpage
  (bnc#1060662).
- udf: Fix deadlock between writeback and udf_setsize()
  (bnc#1060662).
- target: Fix COMPARE_AND_WRITE caw_sem leak during se_cmd quiesce
  (bnc#1060662).
- iser-target: Avoid isert_conn->cm_id dereference in
  isert_login_recv_done (bnc#1060662).
- perf annotate: Fix broken arrow at row 0 connecting jmp
  instruction to its target (bnc#1060662).
- perf/core: Fix scheduling regression of pinned groups
  (bnc#1060662).
- Revert "perf/core: Drop kernel samples even though :u is
  specified" (bnc#1060662).
- staging: rtl8188eu: add TL-WN722N v2 support (bnc#1060662).
- staging: comedi: ni_mio_common: fix AO timer off-by-one
  regression (bnc#1060662).
- staging: sm750fb: avoid conflicting vesafb (bnc#1060662).
- staging: lustre: ko2iblnd: check copy_from_iter/copy_to_iter
  return code (bnc#1060662).
- ceph: fix race in concurrent readdir (bnc#1060662).
- RDMA/uverbs: Fix the check for port number (bnc#1060662).
- RDMA/core: Initialize port_num in qp_attr (bnc#1060662).
- drm/mst: Fix error handling during MST sideband message
  reception (bnc#1060662).
- drm/mst: Avoid dereferencing a NULL mstb in
  drm_dp_mst_handle_up_req() (bnc#1060662).
- drm/mst: Avoid processing partially received up/down message
  transactions (bnc#1060662).
- drm/i915: Make DP-MST connector info work (bnc#1060662).
- mlx5: Avoid that mlx5_ib_sg_to_klms() overflows the klms[]
  array (bnc#1060662).
- hfsplus: Don't clear SGID when inheriting ACLs (bnc#1060662).
- vtime, sched/cputime: Remove vtime_account_user() (bnc#1060662
  bnc#978907).
- sched/cputime: Always set tsk->vtime_snap_whence after
  accounting vtime (bnc#1060662 bnc#978907).
- sched/cputime: Rename vtime fields (bnc#1060662 bnc#978907).
- sched/cputime: Move the vtime task fields to their own struct
  (bnc#1060662 bnc#978907).
- sched/cputime: Accumulate vtime on top of nsec clocksource
  (bnc#1060662 bnc#978907).
- sched/fair: Fix load_balance() affinity redo path (bnc#1060662
  bnc#978907).
- percpu_counter: Rename __percpu_counter_add to
  percpu_counter_add_batch (bnc#1060662 bnc#971975).
- writeback: rework wb_[dec|inc]_stat family of functions
  (bnc#1060662 bnc#971975).
- kernel/fork.c: virtually mapped stacks: do not disable
  interrupts (bnc#1060662 bnc#978907).
- acpi/nfit: Fix memory corruption/Unregister mce decoder on
  failure (bnc#1060662).
- vmbus: re-enable channel tasklet (bnc#1060662).
- cpufreq: intel_pstate: Correct the busy calculation for KNL
  (bnc#1060662).
- spmi: Include OF based modalias in device uevent (bnc#1060662).
- reiserfs: Don't clear SGID when inheriting ACLs (bnc#1060662).
- device-dax: fix sysfs duplicate warnings (bnc#1060662).
- drm/imx: parallel-display: Accept drm_of_find_panel_or_bridge
  failure (bnc#1060662).
- PM / Domains: defer dev_pm_domain_set() until genpd->attach_dev
  succeeds if present (bnc#1060662).
- tracing: Fix kmemleak in instance_rmdir (bnc#1060662).
- drm/i915/fbdev: Check for existence of ifbdev->vma before
  operations (bnc#1060662).
- drm/i915: Hold RPM wakelock while initializing OA buffer
  (bnc#1060662).
- drm/i915: reintroduce VLV/CHV PFI programming power domain
  workaround (bnc#1060662).
- smp/hotplug: Move unparking of percpu threads to the control
  CPU (bnc#1060662).
- smp/hotplug: Replace BUG_ON and react useful (bnc#1060662).
- alarmtimer: don't rate limit one-shot timers (bnc#1060662).
- sched/cputime: Don't use smp_processor_id() in preemptible
  context (bnc#1060662).
- Linux 4.12.4 (bnc#1060662).
- Delete patches.kernel.org/patch-4.12.3-4.
  Expand 4.12.4.
- commit 9cb5903
* Mon Oct  2 2017 jthumshirn@suse.de
- scsi: qla2xxx: add missing includes for qla_isr (FATE#322910).
  Refresh
  patches.drivers/0036-scsi-qla2xxx-Add-FC-NVMe-command-handling.patch.
- commit 474a2df
* Mon Oct  2 2017 jthumshirn@suse.de
- scsi: aacraid: Add a small delay after IOP reset (FATE#322889,
  bsc#1049519).
- commit 2a43d5a
* Mon Oct  2 2017 jthumshirn@suse.de
- series.conf: fix patch ordering
- commit affbdfb
* Mon Oct  2 2017 jslaby@suse.cz
- jfs: Don't clear SGID when inheriting ACLs (bnc#1060662).
- ALSA: fm801: Initialize chip after IRQ handler is registered
  (bnc#1060662 bsc#1051510).
- ALSA: hda - Add missing NVIDIA GPU codec IDs to patch table
  (bnc#1060662).
- ALSA: hda - Add mute led support for HP ProBook 440 G4
  (bnc#1060662).
- parisc: Prevent TLB speculation on flushed pages on CPUs that
  only support equivalent aliases (bnc#1060662).
- parisc: Extend disabled preemption in copy_user_page
  (bnc#1060662).
- parisc: Suspend lockup detectors before system halt
  (bnc#1060662).
- powerpc/pseries: Fix of_node_put() underflow during reconfig
  remove (bnc#1060662).
- mmc: sunxi: Keep default timing phase settings for new timing
  mode (bnc#1060662).
- NFS: invalidate file size when taking a lock (bnc#1060662).
- NFSv4.1: Fix a race where CB_NOTIFY_LOCK fails to wake a waiter
  (bnc#1060662).
- scripts/dtc: dtx_diff - update include dts paths to match build
  (bnc#1060662).
- crypto: brcm - Fix SHA3-512 algorithm failure (bnc#1060662).
- crypto: brcm - remove BCM_PDC_MBOX dependency in Kconfig
  (bnc#1060662).
- crypto: authencesn - Fix digest_null crash (bnc#1060662).
- KVM: PPC: Book3S HV: Enable TM before accessing TM registers
  (bnc#1060662).
- KVM: PPC: Book3S HV: Fix host crash on changing HPT size
  (bnc#1060662).
- dm integrity: fix inefficient allocation of journal space
  (bnc#1060662).
- dm integrity: test for corrupted disk format during table load
  (bnc#1060662).
- md: remove 'idx' from 'struct resync_pages' (bnc#1060662
  bsc#1049599).
- md/raid1: fix writebehind bio clone (bnc#1060662).
- md/raid5: add thread_group worker async_tx_issue_pending_all
  (bnc#1060662).
- drm/vmwgfx: Fix gcc-7.1.1 warning (bnc#1060662).
- drm/vmwgfx: Limit max desktop dimensions to 8Kx8K (bnc#1060662).
- drm/nouveau/disp/nv50-: bump max chans to 21 (bnc#1060662).
- drm/nouveau/bar/gf100: fix access to upper half of BAR2
  (bnc#1060662).
- drm/i915: Fix scaler init during CRTC HW state readout
  (bnc#1060662).
- isdn/i4l: fix buffer overflow (bnc#1060662).
- ipmi/watchdog: fix watchdog timeout set on reboot (bnc#1060662).
- dentry name snapshots (bnc#1060662 bsc#1049483).
- mmc: tmio-mmc: fix bad pointer math (bnc#1060662).
- Linux 4.12.5 (bnc#1060662).
- Delete patches.kernel.org/patch-4.12.4-5.
  Expand 4.12.5.
- commit d481b6d
* Mon Oct  2 2017 jeffm@suse.com
- Moved powerpc-Blacklist-GCC-5.4-6.1-and-6.2.patch to patches.rpmify.
  It's a compiler blacklist addition and should be applied to vanilla too.
- commit cfc7e71
* Mon Oct  2 2017 tbogendoerfer@suse.de
- iw_cxgb4: remove the stid on listen create failure (bsc#1046543
  FATE#322927).
- iw_cxgb4: drop listen destroy replies if no ep found
  (bsc#1046543 FATE#322927).
- iw_cxgb4: put ep reference in pass_accept_req() (bsc#1046543
  FATE#322927).
- commit b8f72a3
* Mon Oct  2 2017 jslaby@suse.cz
- parisc: Increase thread and stack size to 32kb (bnc#1060662).
- parisc: Handle vma's whose context is not current in
  flush_cache_range (bnc#1060662).
- scsi: lpfc: fix linking against modular NVMe support
  (bnc#1060662).
- ACPI / LPSS: Only call pwm_add_table() for the first PWM
  controller (bnc#1060662).
- cgroup: don't call migration methods if there are no tasks to
  migrate (bnc#1060662).
- cgroup: create dfl_root files on subsys registration
  (bnc#1060662).
- cgroup: fix error return value from cgroup_subtree_control()
  (bnc#1060662).
- libata: array underflow in ata_find_dev() (bnc#1060662).
- workqueue: restore WQ_UNBOUND/max_active==1 to be ordered
  (bnc#1060662).
- iwlwifi: dvm: prevent an out of bounds access (bnc#1060662).
- brcmfmac: fix memleak due to calling brcmf_sdiod_sgtable_alloc()
  twice (bnc#1060662).
- NFSv4: Fix EXCHANGE_ID corrupt verifier issue (bnc#1060662).
- mmc: sdhci-of-at91: force card detect value for non removable
  devices (bnc#1060662).
- mmc: core: Use device_property_read instead of of_property_read
  (bnc#1060662).
- mmc: dw_mmc: Use device_property_read instead of
  of_property_read (bnc#1060662).
- mm, mprotect: flush TLB if potentially racing with a parallel
  reclaim leaving stale TLB entries (bnc#1060662).
- mm/hugetlb.c: __get_user_pages ignores certain
  follow_hugetlb_page errors (bnc#1060662).
- userfaultfd: non-cooperative: notify about unmap of destination
  during mremap (bnc#1060662).
- userfaultfd_zeropage: return -ENOSPC in case mm has gone
  (bnc#1060662).
- userfaultfd: non-cooperative: flush event_wqh at release time
  (bnc#1060662).
- cpuset: fix a deadlock due to incomplete patching of
  cpusets_enabled() (bnc#1060662).
- ocfs2: don't clear SGID when inheriting ACLs (bnc#1060662).
- ALSA: hda - Fix speaker output from VAIO VPCL14M1R
  (bnc#1060662).
- drm/amdgpu: fix header on gfx9 clear state (bnc#1060662).
- drm/amdgpu: Fix undue fallthroughs in golden registers
  initialization (bnc#1060662).
- ASoC: fix pcm-creation regression (bnc#1060662).
- ASoC: ux500: Restore platform DAI assignments (bnc#1060662).
- ASoC: do not close shared backend dailink (bnc#1060662).
- KVM: arm/arm64: Handle hva aging while destroying the vm
  (bnc#1060662).
- KVM: async_pf: make rcu irq exit if not triggered from idle task
  (bnc#1060662).
- timers: Fix overflow in get_next_timer_interrupt (bnc#1060662).
- powerpc/tm: Fix saving of TM SPRs in core dump (bnc#1060662).
- powerpc/64: Fix __check_irq_replay missing decrementer interrupt
  (bnc#1060662).
- iommu/amd: Enable ga_log_intr when enabling guest_mode
  (bnc#1060662 bsc#1052533).
- ARM64: dts: marvell: armada-37xx: Fix the number of GPIO on
  south bridge (bnc#1060662).
- gpiolib: skip unwanted events, don't convert them to opposite
  edge (bnc#1060662).
- ext4: fix SEEK_HOLE/SEEK_DATA for blocksize < pagesize
  (bnc#1060662).
- ext4: fix overflow caused by missing cast in ext4_resize_fs()
  (bnc#1060662).
- MIPS: ralink: Fix build error due to missing header
  (bnc#1060662).
- clk: sunxi-ng: sun5i: Add clk_set_rate_parent to the CPU clock
  (bnc#1060662).
- ARM: mvebu: use __pa_symbol in the mv98dx3236 platform SMP code
  (bnc#1060662).
- ARM: dts: armada-38x: Fix irq type for pca955 (bnc#1060662).
- ARM: dts: tango4: Request RGMII RX and TX clock delays
  (bnc#1060662).
- media: pulse8-cec: persistent_config should be off by default
  (bnc#1060662).
- media: lirc: LIRC_GET_REC_RESOLUTION should return microseconds
  (bnc#1060662).
- media: platform: davinci: return -EINVAL for
  VPFE_CMD_S_CCDC_RAW_PARAMS ioctl (bnc#1060662).
- ir-spi: Fix issues with lirc API (bnc#1060662).
- tcmu: Fix flushing cmd entry dcache page (bnc#1060662).
- tcmu: Fix possbile memory leak / OOPs when recalculating cmd
  base size (bnc#1060662).
- ext4: preserve i_mode if __ext4_set_acl() fails (bnc#1060662).
- ext4: Don't clear SGID when inheriting ACLs (bnc#1060662).
- Btrfs: fix early ENOSPC due to delalloc (bnc#1060662).
- blk-mq: Include all present CPUs in the default queue mapping
  (bnc#1060662).
- blk-mq: Create hctx for each present CPU (bnc#1060662).
- block: disable runtime-pm for blk-mq (bnc#1060662).
- saa7164: fix double fetch PCIe access condition (bnc#1060662
  CVE-2017-8831 bsc#1037994).
- sctp: fix an array overflow when all ext chunks are set
  (bnc#1060662).
- tcp_bbr: cut pacing rate only if filled pipe (bnc#1060662).
- tcp_bbr: introduce bbr_bw_to_pacing_rate() helper (bnc#1060662).
- tcp_bbr: introduce bbr_init_pacing_rate_from_rtt() helper
  (bnc#1060662).
- tcp_bbr: remove sk_pacing_rate=0 transient during init
  (bnc#1060662).
- tcp_bbr: init pacing rate on first RTT sample (bnc#1060662).
- ipv4: ipv6: initialize treq->txhash in cookie_v[46]_check()
  (bnc#1060662).
- wireless: wext: terminate ifr name coming from userspace
  (bnc#1060662).
- net: Zero terminate ifr_name in dev_ifname() (bnc#1060662).
- net: dsa: mv88e6xxx: Enable CMODE config support for 6390X
  (bnc#1060662).
- Revert "rtnetlink: Do not generate notifications for CHANGEADDR
  event" (bnc#1060662).
- ipv6: avoid overflow of offset in ip6_find_1stfragopt
  (bnc#1060662 CVE-2017-7542 bsc#1049882).
- net: dsa: b53: Add missing ARL entries for BCM53125
  (bnc#1060662).
- ipv4: initialize fib_trie prior to register_netdev_notifier call
  (bnc#1060662).
- rtnetlink: allocate more memory for dev_set_mac_address()
  (bnc#1060662).
- net: bonding: Fix transmit load balancing in balance-alb mode
  (bnc#1060662).
- mcs7780: Fix initialization when CONFIG_VMAP_STACK is enabled
  (bnc#1060662).
- openvswitch: fix potential out of bound access in parse_ct
  (bnc#1060662).
- packet: fix use-after-free in prb_retire_rx_blk_timer_expired()
  (bnc#1060662).
- ipv6: Don't increase IPSTATS_MIB_FRAGFAILS twice in
  ip6_fragment() (bnc#1060662).
- net: ethernet: nb8800: Handle all 4 RGMII modes identically
  (bnc#1060662).
- bonding: commit link status change after propose (bnc#1060662).
- dccp: fix a memleak that dccp_ipv6 doesn't put reqsk properly
  (bnc#1060662).
- dccp: fix a memleak that dccp_ipv4 doesn't put reqsk properly
  (bnc#1060662).
- dccp: fix a memleak for dccp_feat_init err process
  (bnc#1060662).
- net/mlx5: Consider tx_enabled in all modes on remap
  (bnc#1060662).
- net/mlx5: Fix command completion after timeout access invalid
  structure (bnc#1060662).
- net/mlx5: Fix command bad flow on command entry allocation
  failure (bnc#1060662).
- sctp: don't dereference ptr before leaving _sctp_walk_{params,
  errors}() (bnc#1060662).
- sctp: fix the check for _sctp_walk_params and _sctp_walk_errors
  (bnc#1060662).
- net/mlx5e: IPoIB, Modify add/remove underlay QPN flows
  (bnc#1060662).
- net/mlx5e: Fix outer_header_zero() check size (bnc#1060662).
- net/mlx5: Fix mlx5_ifc_mtpps_reg_bits structure size
  (bnc#1060662).
- net/mlx5e: Add field select to MTPPS register (bnc#1060662).
- net/mlx5e: Fix broken disable 1PPS flow (bnc#1060662).
- net/mlx5e: Change 1PPS out scheme (bnc#1060662).
- net/mlx5e: Add missing support for PTP_CLK_REQ_PPS request
  (bnc#1060662).
- net/mlx5e: Fix wrong delay calculation for overflow check
  scheduling (bnc#1060662).
- net/mlx5e: Schedule overflow check work to mlx5e workqueue
  (bnc#1060662).
- net/mlx5: Fix mlx5_add_flow_rules call with correct num of dests
  (bnc#1060662).
- udp6: fix socket leak on early demux (bnc#1060662).
- net: phy: Correctly process PHY_HALTED in phy_stop_machine()
  (bnc#1060662).
- workqueue: implicit ordered attribute should be overridable
  (bnc#1060662).
- ipv4: fib: Fix NULL pointer deref during fib_sync_down_dev()
  (bnc#1060662).
- virtio_net: fix truesize for mergeable buffers (bnc#1060662).
- sparc64: Measure receiver forward progress to avoid send mondo
  timeout (bnc#1060662).
- sparc64: Prevent perf from running during super critical
  sections (bnc#1060662).
- sparc64: Register hugepages during arch init (bnc#1060662).
- sparc64: Fix exception handling in UltraSPARC-III memcpy
  (bnc#1060662).
- drm/vmwgfx: Fix cursor hotspot issue with Wayland on Fedora
  (bnc#1060662).
- Linux 4.12.6 (bnc#1060662).
- Delete patches.kernel.org/patch-4.12.5-6.
  Expand 4.12.6.
- commit c435580
* Mon Oct  2 2017 tbogendoerfer@suse.de
- cxgb4: Ignore MPS_TX_INT_CAUSE for T6 (bsc#1046540 FATE#322930).
- cxgb4: Fix pause frame count in t4_get_port_stats (bsc#1046540
  FATE#322930).
- cxgb4: fix memory leak (bsc#1046540 FATE#322930).
- cxgb4/cxgbvf: Handle 32-bit fw port capabilities (bsc#1046540
  FATE#322930 bsc#1046542 FATE#322928).
- cxgb4: Clear On FLASH config file after a FW upgrade
  (bsc#1046540 FATE#322930).
- commit 9ed00a3
* Mon Oct  2 2017 tbogendoerfer@suse.de
- net/sched: Fix the logic error to decide the ingress qdisc
  (bsc#1056787).
- net: sched: use newly added classid identity helpers
  (bsc#1056787).
- net: sched: propagate classid down to offload drivers
  (bsc#1056787).
- net: sched: Add helpers to identify classids (bsc#1056787).
- net: sched: get rid of struct tc_to_netdev (bsc#1056787).
- net: sched: change return value of ndo_setup_tc for driver
  supporting mqprio only (bsc#1056787).
- commit 3fa59d0
* Mon Oct  2 2017 jslaby@suse.cz
- ppp: Fix false xmit recursion detect with two ppp devices
  (bnc#1060662).
- ppp: fix xmit recursion detection on ppp channels (bnc#1060662).
- tcp: avoid setting cwnd to invalid ssthresh after cwnd reduction
  states (bnc#1060662).
- net: fix keepalive code vs TCP_FASTOPEN_CONNECT (bnc#1060662).
- ipv6: set rt6i_protocol properly in the route when it is
  installed (bnc#1060662).
- bpf, s390: fix jit branch offset related to ldimm64
  (bnc#1060662).
- net/mlx4_en: don't set CHECKSUM_COMPLETE on SCTP packets
  (bnc#1060662).
- net: sched: set xt_tgchk_param par.net properly in
  ipt_init_target (bnc#1060662).
- net: sched: set xt_tgchk_param par.nft_compat as 0 in
  ipt_init_target (bnc#1060662).
- tcp: fastopen: tcp_connect() must refresh the route
  (bnc#1060662).
- qmi_wwan: fix NULL deref on disconnect (bnc#1060662).
- net: avoid skb_warn_bad_offload false positives on UFO
  (bnc#1060662).
- igmp: Fix regression caused by igmp sysctl namespace code
  (bnc#1060662).
- udp: consistently apply ufo or fragmentation (bnc#1060662).
- packet: fix tp_reserve race in packet_set_ring (bnc#1060662).
- scsi: sg: only check for dxfer_len greater than 256M
  (bnc#1060662).
- btrfs: Remove false alert when fiemap range is smaller than
  on-disk extent (bnc#1060662).
- Linux 4.12.7 (bnc#1060662).
- Delete patches.kernel.org/patch-4.12.6-7.
  Expand 4.12.7.
- commit 8cebe24
* Mon Oct  2 2017 jslaby@suse.cz
- mm: ratelimit PFNs busy info message (bnc#1060662).
- mm: fix list corruptions on shmem shrinklist (bnc#1060662).
- futex: Remove unnecessary warning from get_futex_key
  (bnc#1060662).
- xtensa: fix cache aliasing handling code for WT cache
  (bnc#1060662).
- xtensa: mm/cache: add missing EXPORT_SYMBOLs (bnc#1060662).
- xtensa: don't limit csum_partial export by CONFIG_NET
  (bnc#1060662).
- xfs: Fix leak of discard bio (bnc#1060662).
- pinctrl: armada-37xx: Fix number of pin in south bridge
  (bnc#1060662).
- mtd: nand: atmel: Fix DT backward compatibility in pmecc.c
  (bnc#1060662).
- mtd: nand: Fix timing setup for NANDs that do not support SET
  FEATURES (bnc#1060662).
- mtd: nand: Declare tBERS, tR and tPROG as u64 to avoid integer
  overflow (bnc#1060662).
- iscsi-target: fix memory leak in iscsit_setup_text_cmd()
  (bnc#1060662).
- iscsi-target: Fix iscsi_np reset hung task during parallel
  delete (bnc#1060662).
- usb-storage: fix deadlock involving host lock and scsi_done
  (bnc#1060662).
- target: Fix node_acl demo-mode + uncached dynamic shutdown
  regression (bnc#1060662).
- fuse: initialize the flock flag in fuse_file on allocation
  (bnc#1060662).
- i2c: designware: Some broken DSTDs use 1MiHz instead of 1MHz
  (bnc#1060662).
- nand: fix wrong default oob layout for small pages using soft
  ecc (bnc#1060662).
- mmc: mmc: correct the logic for setting HS400ES signal voltage
  (bnc#1060662).
- nfs/flexfiles: fix leak of nfs4_ff_ds_version arrays
  (bnc#1060662).
- drm/bridge: tc358767: fix probe without attached output node
  (bnc#1060662).
- drm/etnaviv: Fix off-by-one error in reloc checking
  (bnc#1060662).
- drm/i915: Fix out-of-bounds array access in bdw_load_gamma_lut
  (bnc#1060662).
- USB: serial: option: add D-Link DWM-222 device ID (bnc#1060662).
- USB: serial: cp210x: add support for Qivicon USB ZigBee dongle
  (bnc#1060662).
- USB: serial: pl2303: add new ATEN device id (bnc#1060662).
- usb: musb: fix tx fifo flush handling again (bnc#1060662).
- USB: hcd: Mark secondary HCD as dead if the primary one died
  (bnc#1060662).
- staging:iio:resolver:ad2s1210 fix negative IIO_ANGL_VEL read
  (bnc#1060662).
- iio: aspeed-adc: wait for initial sequence (bnc#1060662).
- iio: accel: st_accel: add SPI-3wire support (bnc#1060662).
- iio: accel: bmc150: Always restore device to normal mode after
  suspend-resume (bnc#1060662).
- iio: pressure: st_pressure_core: disable multiread by default
  for LPS22HB (bnc#1060662).
- iio: light: tsl2563: use correct event code (bnc#1060662).
- iio: adc: Revert "axp288: Drop bogus AXP288_ADC_TS_PIN_CTRL
  register modifications" (bnc#1060662).
- staging: comedi: comedi_fops: do not call blocking ops when
  !TASK_RUNNING (bnc#1060662).
- uas: Add US_FL_IGNORE_RESIDUE for Initio Corporation INIC-3069
  (bnc#1060662).
- firmware: fix batched requests - wake all waiters (bnc#1060662).
- firmware: fix batched requests - send wake up on failure on
  direct lookups (bnc#1060662).
- firmware: avoid invalid fallback aborts by using killable wait
  (bnc#1060662).
- block: Make blk_mq_delay_kick_requeue_list() rerun the queue
  at a quiet time (bnc#1060662).
- usb: gadget: udc: renesas_usb3: Fix
  usb_gadget_giveback_request() calling (bnc#1060662).
- usb: renesas_usbhs: Fix UGCTRL2 value for R-Car Gen3
  (bnc#1060662).
- USB: Check for dropped connection before switching to full speed
  (bnc#1060662).
- usb: core: unlink urbs from the tail of the endpoint's urb_list
  (bnc#1060662).
- usb: quirks: Add no-lpm quirk for Moshi USB to Ethernet Adapter
  (bnc#1060662).
- usb:xhci:Add quirk for Certain failing HP keyboard on reset
  after resume (bnc#1060662).
- PCI: Protect pci_error_handlers->reset_notify() usage with
  device_lock() (bnc#1060662).
- PCI: Remove __pci_dev_reset() and pci_dev_reset() (bnc#1060662).
- PCI: Add pci_reset_function_locked() (bnc#1060662).
- xhci: Reset Renesas uPD72020x USB controller for 32-bit DMA
  issue (bnc#1060662).
- iio: adc: vf610_adc: Fix VALT selection value for REFSEL bits
  (bnc#1060662).
- pnfs/blocklayout: require 64-bit sector_t (bnc#1060662).
- pinctrl: cherryview: Add Setzer models to the Chromebook DMI
  quirk (bnc#1060662).
- pinctrl: sunxi: add a missing function of A10/A20 pinctrl driver
  (bnc#1060662).
- pinctrl: intel: merrifield: Correct UART pin lists
  (bnc#1060662).
- pinctrl: uniphier: fix WARN_ON() of pingroups dump on LD11
  (bnc#1060662).
- pinctrl: uniphier: fix WARN_ON() of pingroups dump on LD20
  (bnc#1060662).
- pinctrl: samsung: Remove bogus irq_[un]mask from resource
  management (bnc#1060662).
- pinctrl: meson-gxbb: Add missing GPIODV_18 pin entry
  (bnc#1060662).
- pinctrl: meson-gxl: Add missing GPIODV_18 pin entry
  (bnc#1060662).
- MIPS: DEC: Fix an int-handler.S CPU_DADDI_WORKAROUNDS regression
  (bnc#1060662).
- Revert "MIPS: Don't unnecessarily include kmalloc.h into
  <asm/cache.h>." (bnc#1060662).
- MIPS: Octeon: Fix broken EDAC driver (bnc#1060662).
- powerpc: Fix /proc/cpuinfo revision for POWER9 DD2 (bnc#1060662
  bsc#1046789).
- Linux 4.12.8 (bnc#1060662).
- Delete patches.kernel.org/patch-4.12.7-8.
  Expand 4.12.8.
- commit e01e9dd
* Mon Oct  2 2017 bpoirier@suse.com
- Update marker for sorted section in series.conf
  The section now contains patches related to more than just networking.
- commit 987899b
* Mon Oct  2 2017 bpoirier@suse.com
- Refresh
  patches.apparmor/0024-apparmor-speed-up-transactional-queries.patch.
- Refresh
  patches.apparmor/0030-apparmor-cleanup-__find_child.patch.
- Refresh
  patches.apparmor/0031-apparmor-add-namespace-lookup-fns.patch.
- Refresh
  patches.drivers/0009-thunderbolt-Convert-switch-to-a-device.patch.
  Fix broken Git-commit tags
- commit 4f9ee19
* Mon Oct  2 2017 jslaby@suse.cz
- audit: Fix use after free in audit_remove_watch_rule()
  (bnc#1060662).
- parisc: pci memory bar assignment fails with 64bit kernels on
  dino/cujo (bnc#1060662).
- crypto: ixp4xx - Fix error handling path in 'aead_perform()'
  (bnc#1060662).
- crypto: x86/sha1 - Fix reads beyond the number of blocks passed
  (bnc#1060662).
- drm/i915: Perform an invalidate prior to executing golden
  renderstate (bnc#1060662).
- drm/amdgpu: save list length when fence is signaled
  (bnc#1060662).
- Input: elan_i2c - add ELAN0608 to the ACPI table (bnc#1060662).
- Input: elan_i2c - Add antoher Lenovo ACPI ID for upcoming
  Lenovo NB (bnc#1060662).
- md: fix test in md_write_start() (bnc#1060662).
- md: always clear ->safemode when md_check_recovery gets the
  mddev lock (bnc#1060662).
- MD: not clear ->safemode for external metadata array
  (bnc#1060662).
- ALSA: seq: 2nd attempt at fixing race creating a queue
  (bnc#1060662).
- ALSA: usb-audio: Apply sample rate quirk to Sennheiser headset
  (bnc#1060662 bsc#1052580).
- ALSA: usb-audio: Add mute TLV for playback volumes on C-Media
  devices (bnc#1060662).
- ALSA: usb-audio: add DSD support for new Amanero PID
  (bnc#1060662).
- mm: discard memblock data later (bnc#1060662).
- slub: fix per memcg cache leak on css offline (bnc#1060662).
- mm: fix double mmap_sem unlock on MMF_UNSTABLE enforced SIGBUS
  (bnc#1060662).
- mm/cma_debug.c: fix stack corruption due to sprintf usage
  (bnc#1060662).
- mm/mempolicy: fix use after free when calling get_mempolicy
  (bnc#1060662).
- mm/vmalloc.c: don't unconditonally use __GFP_HIGHMEM
  (bnc#1060662).
- mm: revert x86_64 and arm64 ELF_ET_DYN_BASE base changes
  (bnc#1060662).
- xen: fix bio vec merging (bnc#1060662).
- ARM: dts: imx6qdl-nitrogen6_som2: fix PCIe reset (bnc#1060662).
- blk-mq-pci: add a fallback when pci_irq_get_affinity returns
  NULL (bnc#1060662).
- powerpc: Fix VSX enabling/flushing to also test MSR_FP and
  MSR_VEC (bnc#1060662).
- xen-blkfront: use a right index when checking requests
  (bnc#1060662).
- perf/x86: Fix RDPMC vs. mm_struct tracking (bnc#1060662).
- x86/asm/64: Clear AC on NMI entries (bnc#1060662).
- x86: Fix norandmaps/ADDR_NO_RANDOMIZE (bnc#1060662).
- x86/elf: Remove the unnecessary ADDR_NO_RANDOMIZE checks
  (bnc#1060662).
- irqchip/atmel-aic: Fix unbalanced of_node_put() in
  aic_common_irq_fixup() (bnc#1060662).
- irqchip/atmel-aic: Fix unbalanced refcount in
  aic_common_rtc_irq_fixup() (bnc#1060662).
- genirq: Restore trigger settings in irq_modify_status()
  (bnc#1060662).
- genirq/ipi: Fixup checks against nr_cpu_ids (bnc#1060662).
- kernel/watchdog: Prevent false positives with turbo modes
  (bnc#1060662).
- Sanitize 'move_pages()' permission checks (bnc#1060662).
- pids: make task_tgid_nr_ns() safe (bnc#1060662).
- debug: Fix WARN_ON_ONCE() for modules (bnc#1060662 bnc#1049599).
- usb: optimize acpi companion search for usb port devices
  (bnc#1060662).
- usb: qmi_wwan: add D-Link DWM-222 device ID (bnc#1060662).
- Linux 4.12.9 (bnc#1060662).
- Delete patches.kernel.org/patch-4.12.8-9.
  Expand 4.12.9.
- commit 87e5f9e
* Mon Oct  2 2017 jslaby@suse.cz
- sparc64: remove unnecessary log message (bnc#1060662).
- bonding: require speed/duplex only for 802.3ad, alb and tlb
  (bnc#1060662).
- bonding: ratelimit failed speed/duplex update warning
  (bnc#1060662).
- af_key: do not use GFP_KERNEL in atomic contexts (bnc#1060662).
- dccp: purge write queue in dccp_destroy_sock() (bnc#1060662).
- dccp: defer ccid_hc_tx_delete() at dismantle time (bnc#1060662).
- ipv4: fix NULL dereference in free_fib_info_rcu() (bnc#1060662).
- net_sched/sfq: update hierarchical backlog when drop packet
  (bnc#1060662).
- net_sched: remove warning from qdisc_hash_add (bnc#1060662).
- bpf: fix bpf_trace_printk on 32 bit archs (bnc#1060662).
- net: igmp: Use ingress interface rather than vrf device
  (bnc#1060662).
- openvswitch: fix skb_panic due to the incorrect actions attrlen
  (bnc#1060662).
- ptr_ring: use kmalloc_array() (bnc#1060662 bsc#1055945).
- ipv4: better IP_MAX_MTU enforcement (bnc#1060662).
- nfp: fix infinite loop on umapping cleanup (bnc#1060662).
- tun: handle register_netdevice() failures properly
  (bnc#1060662).
- sctp: fully initialize the IPv6 address in sctp_v6_to_addr()
  (bnc#1060662).
- tipc: fix use-after-free (bnc#1060662).
- ipv6: reset fn->rr_ptr when replacing route (bnc#1060662).
- ipv6: repair fib6 tree in failure case (bnc#1060662).
- tcp: when rearming RTO, if RTO time is in past then fire RTO
  ASAP (bnc#1060662).
- net/mlx4_core: Enable 4K UAR if SRIOV module parameter is not
  enabled (bnc#1060662).
- irda: do not leak initialized list.dev to userspace
  (bnc#1060662).
- net: sched: fix NULL pointer dereference when action calls
  some targets (bnc#1060662).
- net_sched: fix order of queue length updates in qdisc_replace()
  (bnc#1060662).
- bpf, verifier: add additional patterns to evaluate_reg_imm_alu
  (bnc#1060662).
- bpf: fix mixed signed/unsigned derived min/max value bounds
  (bnc#1060662 bsc#1050081).
- bpf/verifier: fix min/max handling in BPF_SUB (bnc#1060662
  bsc#1050081).
- Input: trackpoint - add new trackpoint firmware ID
  (bnc#1060662).
- Input: elan_i2c - add ELAN0602 ACPI ID to support Lenovo Yoga310
  (bnc#1060662).
- Input: ALPS - fix two-finger scroll breakage in right side on
  ALPS touchpad (bnc#1060662 bsc#1050582).
- KVM: s390: sthyi: fix sthyi inline assembly (bnc#1060662).
- KVM: s390: sthyi: fix specification exception detection
  (bnc#1060662).
- KVM: x86: simplify handling of PKRU (bnc#1060662 bsc#1055935).
- KVM, pkeys: do not use PKRU value in vcpu->arch.guest_fpu.state
  (bnc#1060662 bsc#1055935).
- KVM: x86: block guest protection keys unless the host has them
  enabled (bnc#1060662 bsc#1055935).
- ALSA: usb-audio: Add delay quirk for H650e/Jabra 550a USB
  headsets (bnc#1060662).
- ALSA: core: Fix unexpected error at replacing user TLV
  (bnc#1060662).
- ALSA: hda - Add stereo mic quirk for Lenovo G50-70 (17aa:3978)
  (bnc#1060662 bsc#1020657).
- ALSA: firewire: fix NULL pointer dereference when releasing
  uninitialized data of iso-resource (bnc#1060662).
- ALSA: firewire-motu: destroy stream data surely at failure of
  card initialization (bnc#1060662).
- ARCv2: SLC: Make sure busy bit is set properly for region ops
  (bnc#1060662).
- ARCv2: PAE40: Explicitly set MSB counterpart of SLC region
  ops addresses (bnc#1060662).
- ARCv2: PAE40: set MSB even if !CONFIG_ARC_HAS_PAE40 but PAE
  exists in SoC (bnc#1060662).
- PM/hibernate: touch NMI watchdog when creating snapshot
  (bnc#1060662).
- mm, shmem: fix handling
  /sys/kernel/mm/transparent_hugepage/shmem_enabled (bnc#1060662).
- dax: fix deadlock due to misaligned PMD faults (bnc#1060662).
- i2c: designware: Fix system suspend (bnc#1060662).
- mm/madvise.c: fix freeing of locked page with MADV_FREE
  (bnc#1060662).
- fork: fix incorrect fput of ->exe_file causing use-after-free
  (bnc#1060662).
- mm/memblock.c: reversed logic in memblock_discard()
  (bnc#1060662).
- arm64: fpsimd: Prevent registers leaking across exec
  (bnc#1060662).
- drm: Fix framebuffer leak (bnc#1060662).
- drm: Release driver tracking before making the object available
  again (bnc#1060662).
- drm/sun4i: Implement drm_driver lastclose to restore fbdev
  console (bnc#1060662).
- drm/atomic: Handle -EDEADLK with out-fences correctly
  (bnc#1060662).
- drm/atomic: If the atomic check fails, return its value first
  (bnc#1060662).
- drm/i915/vbt: ignore extraneous child devices for a port
  (bnc#1060662).
- drm/i915/gvt: Fix the kernel null pointer error (bnc#1060662).
- Revert "drm/amdgpu: fix vblank_time when displays are off"
  (bnc#1060662).
- ACPI: device property: Fix node lookup in
  acpi_graph_get_child_prop_value() (bnc#1060662).
- tracing: Call clear_boot_tracer() at lateinit_sync
  (bnc#1060662).
- tracing: Missing error code in tracer_alloc_buffers()
  (bnc#1060662).
- tracing: Fix kmemleak in tracing_map_array_free() (bnc#1060662).
- tracing: Fix freeing of filter in create_filter() when set_str
  is false (bnc#1060662).
- RDMA/uverbs: Initialize cq_context appropriately (bnc#1060662).
- kbuild: linker script do not match C names unless
  LD_DEAD_CODE_DATA_ELIMINATION is configured (bnc#1060662).
- cifs: Fix df output for users with quota limits (bnc#1060662).
- cifs: return ENAMETOOLONG for overlong names in
  cifs_open()/cifs_lookup() (bnc#1060662).
- nfsd: Limit end of page list when decoding NFSv4 WRITE
  (bnc#1060662).
- ring-buffer: Have ring_buffer_alloc_read_page() return error
  on offline CPU (bnc#1060662).
- virtio_pci: fix cpu affinity support (bnc#1060662).
- ftrace: Check for null ret_stack on profile function graph
  entry function (bnc#1060662).
- perf/core: Fix group {cpu,task} validation (bnc#1060662).
- timers: Fix excessive granularity of new timers after a nohz
  idle (bnc#1060662).
- x86/mm: Fix use-after-free of ldt_struct (bnc#1060662).
- net: sunrpc: svcsock: fix NULL-pointer exception (bnc#1060662).
- netfilter: expect: fix crash when putting uninited expectation
  (bnc#1060662 bnc#1048935).
- netfilter: nat: fix src map lookup (bnc#1060662).
- netfilter: nfnetlink: Improve input length sanitization in
  nfnetlink_rcv (bnc#1060662).
- Bluetooth: hidp: fix possible might sleep error in
  hidp_session_thread (bnc#1060662 bnc#1014351).
- Bluetooth: cmtp: fix possible might sleep error in cmtp_session
  (bnc#1060662).
- Bluetooth: bnep: fix possible might sleep error in bnep_session
  (bnc#1060662).
- Revert "android: binder: Sanity check at binder ioctl"
  (bnc#1060662).
- binder: use group leader instead of open thread (bnc#1060662).
- binder: Use wake up hint for synchronous transactions
  (bnc#1060662).
- ANDROID: binder: fix proc->tsk check (bnc#1060662).
- iio: imu: adis16480: Fix acceleration scale factor for adis16480
  (bnc#1060662).
- iio: hid-sensor-trigger: Fix the race with user space powering
  up sensors (bnc#1060662).
- iio: magnetometer: st_magn: fix status register address for
  LSM303AGR (bnc#1060662).
- iio: magnetometer: st_magn: remove ihl property for LSM303AGR
  (bnc#1060662).
- staging: rtl8188eu: add RNX-N150NUB support (bnc#1060662).
- iommu: Fix wrong freeing of iommu_device->dev (bnc#1060662).
- Clarify (and fix) MAX_LFS_FILESIZE macros (bnc#1060662).
- ntb: ntb_test: ensure the link is up before trying to configure
  the mws (bnc#1060662).
- ntb: transport shouldn't disable link due to bogus values in
  SPADs (bnc#1060662).
- ACPI: APD: Fix HID for Hisilicon Hip07/08 (bnc#1060662).
- ACPI: EC: Fix regression related to wrong ECDT initialization
  order (bnc#1060662).
- powerpc/mm: Ensure cpumask update is ordered (bnc#1060662).
- Linux 4.12.10 (bnc#1060662).
- Delete patches.kernel.org/patch-4.12.9-10.
  Expand 4.12.10.
- commit 6b3564b
* Mon Oct  2 2017 jslaby@suse.cz
- arm64: mm: abort uaccess retries upon fatal signal
  (bnc#1060662).
- x86/io: Add "memory" clobber to insb/insw/insl/outsb/outsw/outsl
  (bnc#1060662).
- irqchip: mips-gic: SYNC after enabling GIC region (bnc#1060662).
- Input: synaptics - fix device info appearing different on
  reconnect (bnc#1060662).
- Input: xpad - fix PowerA init quirk for some gamepad models
  (bnc#1060662).
- crypto: chacha20 - fix handling of chunked input (bnc#1060662).
- i2c: ismt: Don't duplicate the receive length for block reads
  (bnc#1060662).
- i2c: ismt: Return EMSGSIZE for block reads with bogus length
  (bnc#1060662).
- crypto: algif_skcipher - only call put_page on referenced and
  used pages (bnc#1060662).
- mm, uprobes: fix multiple free of ->uprobes_state.xol_area
  (bnc#1060662).
- mm, madvise: ensure poisoned pages are removed from per-cpu
  lists (bnc#1060662).
- ceph: fix readpage from fscache (bnc#1060662).
- cpumask: fix spurious cpumask_of_node() on non-NUMA multi-node
  configs (bnc#1060662).
- cpuset: Fix incorrect memory_pressure control file mapping
  (bnc#1060662).
- alpha: uapi: Add support for __SANE_USERSPACE_TYPES__
  (bnc#1060662).
- CIFS: Fix maximum SMB2 header size (bnc#1060662 bsc#1056185).
- CIFS: remove endian related sparse warning (bnc#1060662).
- dm mpath: do not lock up a CPU with requeuing activity
  (bnc#1060662).
- drm/vmwgfx: Fix F26 Wayland screen update issue (bnc#1060662).
- wl1251: add a missing spin_lock_init() (bnc#1060662).
- mmc: sdhci-xenon: add set_power callback (bnc#1060662).
- lib/mpi: kunmap after finishing accessing buffer (bnc#1060662).
- xfrm: policy: check policy direction value (bnc#1060662).
- drm/ttm: Fix accounting error when fail to get pages for pool
  (bnc#1060662).
- nvme: fix the definition of the doorbell buffer config support
  bit (bnc#1060662).
- drm/nouveau/i2c/gf119-: add support for address-only
  transactions (bnc#1060662).
- epoll: fix race between ep_poll_callback(POLLFREE) and
  ep_free()/ep_remove() (bnc#1060662).
- Linux 4.12.11 (bnc#1060662).
- Delete patches.kernel.org/patch-4.12.10-11.
  Expand 4.12.11.
- commit b96a777
* Mon Oct  2 2017 jslaby@suse.cz
- usb: quirks: add delay init quirk for Corsair Strafe RGB
  keyboard (bnc#1060662).
- USB: serial: option: add support for D-Link DWM-157 C1
  (bnc#1060662).
- usb: Add device quirk for Logitech HD Pro Webcam C920-C
  (bnc#1060662).
- usb:xhci:Fix regression when ATI chipsets detected
  (bnc#1060662).
- USB: musb: fix external abort on suspend (bnc#1060662).
- ANDROID: binder: add padding to binder_fd_array_object
  (bnc#1060662).
- ANDROID: binder: add hwbinder,vndbinder to BINDER_DEVICES
  (bnc#1060662).
- USB: core: Avoid race of async_completed() w/ usbdev_release()
  (bnc#1060662).
- staging/rts5208: fix incorrect shift to extract upper nybble
  (bnc#1060662).
- iio: adc: ti-ads1015: fix incorrect data rate setting update
  (bnc#1060662).
- iio: adc: ti-ads1015: fix scale information for ADS1115
  (bnc#1060662).
- iio: adc: ti-ads1015: enable conversion when CONFIG_PM is not
  set (bnc#1060662).
- iio: adc: ti-ads1015: avoid getting stale result after runtime
  resume (bnc#1060662).
- iio: adc: ti-ads1015: don't return invalid value from buffer
  setup callbacks (bnc#1060662).
- iio: adc: ti-ads1015: add adequate wait time to get correct
  conversion (bnc#1060662).
- driver core: bus: Fix a potential double free (bnc#1060662).
- HID: wacom: Do not completely map WACOM_HID_WD_TOUCHRINGSTATUS
  usage (bnc#1060662).
- binder: free memory on error (bnc#1060662).
- crypto: caam/qi - fix compilation with
  CONFIG_DEBUG_FORCE_WEAK_PER_CPU=y (bnc#1060662).
- crypto: caam/qi - fix compilation with DEBUG enabled
  (bnc#1060662).
- fpga: altera-hps2fpga: fix multiple init of l3_remap_lock
  (bnc#1060662).
- intel_th: pci: Add Cannon Lake PCH-H support (bnc#1060662
  FATE#321195).
- intel_th: pci: Add Cannon Lake PCH-LP support (bnc#1060662
  FATE#321195).
- ath10k: fix memory leak in rx ring buffer allocation
  (bnc#1060662).
- Input: trackpoint - assume 3 buttons when buttons detection
  fails (bnc#1060662).
- rtlwifi: rtl_pci_probe: Fix fail path of _rtl_pci_find_adapter
  (bnc#1060662).
- Bluetooth: Add support of 13d3:3494 RTL8723BE device
  (bnc#1060662).
- iwlwifi: pci: add new PCI ID for 7265D (bnc#1060662).
- dlm: avoid double-free on error path in
  dlm_device_{register,unregister} (bnc#1060662).
- mwifiex: correct channel stat buffer overflows (bnc#1060662).
- MCB: add support for SC31 to mcb-lpc (bnc#1060662).
- s390/mm: avoid empty zero pages for KVM guests to avoid postcopy
  hangs (bnc#1060662).
- s390/mm: fix BUG_ON in crst_table_upgrade (bnc#1060662).
- drm/nouveau/pci/msi: disable MSI on big-endian platforms by
  default (bnc#1060662).
- drm/nouveau: Fix error handling in nv50_disp_atomic_commit
  (bnc#1060662).
- workqueue: Fix flag collision (bnc#1060662).
- ahci: don't use MSI for devices with the silly Intel NVMe
  remapping scheme (bnc#1060662).
- cs5536: add support for IDE controller variant (bnc#1060662).
- scsi: sg: protect against races between mmap() and
  SG_SET_RESERVED_SIZE (bnc#1060662).
- scsi: sg: recheck MMAP_IO request length with lock held
  (bnc#1060662).
- of/device: Prevent buffer overflow in of_device_modalias()
  (bnc#1060662).
- rtlwifi: Fix memory leak when firmware request fails
  (bnc#1060662).
- rtlwifi: Fix fallback firmware loading (bnc#1060662).
- Linux 4.12.12 (bnc#1060662).
- Delete patches.kernel.org/patch-4.12.11-12.
  Expand 4.12.12.
- commit 2a3fe1e
* Mon Oct  2 2017 tbogendoerfer@suse.de
- net: sched: move prio into cls_common (bsc#1056787).
- net: sched: push cls related args into cls_common structure
  (bsc#1056787).
- nfp: change flows in apps that offload ndo_setup_tc
  (bsc#1055968).
- dsa: push cls_matchall setup_tc processing into a separate
  function (bsc#1056787).
- mlxsw: spectrum: rename cls arg in matchall processing
  (bsc#1056787).
- mlxsw: spectrum: push cls_flower and cls_matchall setup_tc
  processing into separate functions (bsc#1056787).
- mlx5e_rep: push cls_flower setup_tc processing into a separate
  function (bsc#1046303 FATE#322944).
- mlx5e: push cls_flower and mqprio setup_tc processing into
  separate functions (bsc#1046303 FATE#322944).
- ixgbe: push cls_u32 and mqprio setup_tc processing into separate
  functions (bsc#1056657 FATE#322189).
- cxgb4: push cls_u32 setup_tc processing into a separate function
  (bsc#1046540 FATE#322930).
- net: sched: make egress_dev flag part of flower offload struct
  (bsc#1056787).
- net: sched: rename TC_SETUP_MATCHALL to TC_SETUP_CLSMATCHALL
  (bsc#1056787).
- net: sched: make type an argument for ndo_setup_tc
  (bsc#1056787).
- net: sched: change names of action number helpers to be aligned
  with the rest (bsc#1056787).
- commit ed4a685
* Mon Oct  2 2017 yousaf.kaukab@suse.com
- config: arm64: enable xgene pmu
  References: bsc#1036737
- commit c789476
* Mon Oct  2 2017 tbogendoerfer@suse.de
- resorted sorted section
- commit 053446a
* Mon Oct  2 2017 tbogendoerfer@suse.de
- Delete
  patches.drivers/0007-RDMA-bnxt_re-Fix-race-between-netdev-register-and-un.patch.
- Delete
  patches.drivers/0012-RDMA-bnxt_re-Add-vlan-tag-for-untagged-RoCE-traffic-.patch.
- Delete
  patches.drivers/0018-RDMA-bnxt_re-Update-the-driver-version.patch.
- Delete
  patches.drivers/0020-RDMA-bnxt_re-Allow-posting-when-QPs-are-in-error.patch.
- commit 99f359a
* Mon Oct  2 2017 tiwai@suse.de
- Update config files: set CONFIG_SND_SOC=m for arm64 (bsc#1060104).
- commit 880aeac
* Mon Oct  2 2017 tiwai@suse.de
- Update config files: update to 4.12.4
- commit 4e103ba
* Mon Oct  2 2017 jslaby@suse.cz
- x86/head: Add unwind hint annotations (bnc#1058115).
- x86/xen: Add unwind hint annotations (bnc#1058115).
- x86/xen: Fix xen head ELF annotations (bnc#1058115).
- x86/boot: Annotate verify_cpu() as a callable function
  (bnc#1058115).
- x86/head: Fix head ELF function annotations (bnc#1058115).
- x86/head: Remove unused 'bad_address' code (bnc#1058115).
- x86/head: Remove confusing comment (bnc#1058115).
- objtool: Don't report end of section error after an empty
  unwind hint (bnc#1058115).
- commit d144576
* Mon Oct  2 2017 jslaby@suse.cz
- crypto: x86/twofish - Fix RBP usage (bnc#1058115).
- crypto: sha512-avx2 - Fix RBP usage (bnc#1058115).
- crypto: x86/sha256-ssse3 - Fix RBP usage (bnc#1058115).
- crypto: x86/sha256-avx2 - Fix RBP usage (bnc#1058115).
- crypto: x86/sha256-avx - Fix RBP usage (bnc#1058115).
- crypto: x86/sha1-ssse3 - Fix RBP usage (bnc#1058115).
- crypto: x86/sha1-avx2 - Fix RBP usage (bnc#1058115).
- crypto: x86/des3_ede - Fix RBP usage (bnc#1058115).
- crypto: x86/cast6 - Fix RBP usage (bnc#1058115).
- crypto: x86/cast5 - Fix RBP usage (bnc#1058115).
- crypto: x86/camellia - Fix RBP usage (bnc#1058115).
- crypto: x86/blowfish - Fix RBP usage (bnc#1058115).
- commit 51691cb
* Sat Sep 30 2017 gqjiang@suse.com
- md/bitmap: disable bitmap_resize for file-backed bitmaps
  (bsc#1061174).
- commit a897895
* Fri Sep 29 2017 tbogendoerfer@suse.de
- IB/hfi1: Unsuccessful PCIe caps tuning should not fail driver
  load (bsc#1060463 FATE#323043).
- IB/hfi1: Check eeprom config partition validity (bsc#1060463
  FATE#323043).
- IB/mlx5: Fix NULL deference on mlx5_ib_update_xlt failure
  (bsc#1046305 FATE#322943).
- IB/ipoib: Fix sysfs Pkey create<->remove possible deadlock
  (bsc#1046307 FATE#322941).
- IB/core: Fix qp_sec use after free access (bsc#1046306
  FATE#322942).
- IB/core: Fix typo in the name of the tag-matching cap struct
  (bsc#1046306 FATE#322942).
- IB/mlx5: fix debugfs cleanup (bsc#1046305 FATE#322943).
- bnxt_en: fix clearing devlink ptr from bnxt struct (bsc#1050242
  FATE#322914).
- bnxt_re: add MAY_USE_DEVLINK dependency (bsc#1050242
  FATE#322914).
- commit ea21d80
* Fri Sep 29 2017 tbogendoerfer@suse.de
- IB/mlx5: Support IB_SRQT_TM (bsc#1046305 FATE#322943).
- net/mlx5: Add XRQ support (bsc#1046303 FATE#322944).
- IB/mlx5: Fill XRQ capabilities (bsc#1046305 FATE#322943).
- commit 3ba7f43
* Fri Sep 29 2017 tbogendoerfer@suse.de
- i40iw: Add support for port reuse on active side connections
  (bsc#1058659 FATE#322535).
- i40iw: Add missing VLAN priority (bsc#1058659 FATE#322535).
- i40iw: Call i40iw_cm_disconn on modify QP to disconnect
  (bsc#1058659 FATE#322535).
- i40iw: Prevent multiple netdev event notifier registrations
  (bsc#1058659 FATE#322535).
- i40iw: Fail open if there are no available MSI-X vectors
  (bsc#1058659 FATE#322535).
- i40iw: make some structures const (bsc#1058659 FATE#322535).
- RDMA/i40iw: Remove unused argument (bsc#1058659 FATE#322535).
- i40iw: Improve CQP timeout logic (bsc#1058659 FATE#322535).
- i40iw: fix spelling mistake: "allloc_buf" -> "alloc_buf"
  (bsc#1058659 FATE#322535).
- i40iw: Fixes for static checker warnings (bsc#1058659
  FATE#322535).
- i40iw: Simplify code (bsc#1058659 FATE#322535).
- commit 3ae25bf
* Fri Sep 29 2017 tbogendoerfer@suse.de
- Update config files.
- commit 28fee52
* Fri Sep 29 2017 tbogendoerfer@suse.de
- RDMA/vmw_pvrdma: Fix reporting correct opcodes for completion
  (bsc#1046306 FATE#322942).
- IB/ocrdma: fix incorrect fall-through on switch statement
  (bsc#1058513 FATE#322520).
- IB/ipoib: Suppress the retry related completion errors
  (bsc#1046307 FATE#322941).
- rdma core: Add rdma_rw_mr_payload() (bsc#1046306 FATE#322942).
- RDMA/netlink: clean up message validity array initializer
  (bsc#1046306 FATE#322942).
- RDAM/netlink: Fix out-of-bound access while checking message
  validity (bsc#1046306 FATE#322942).
- IB/core: Expose ioctl interface through experimental Kconfig
  (bsc#1046306 FATE#322942).
- IB/core: Assign root to all drivers (bsc#1046306 FATE#322942).
- IB/core: Add completion queue (cq) object actions (bsc#1046306
  FATE#322942).
- IB/core: Add legacy driver's user-data (bsc#1046306
  FATE#322942).
- IB/core: Export ioctl enum types to user-space (bsc#1046306
  FATE#322942).
- IB/core: Explicitly destroy an object while keeping uobject
  (bsc#1046306 FATE#322942).
- IB/core: Add macros for declaring methods and attributes
  (bsc#1046306 FATE#322942).
- IB/core: Add uverbs merge trees functionality (bsc#1046306
  FATE#322942).
- IB/core: Add DEVICE object and root tree structure (bsc#1046306
  FATE#322942).
- IB/core: Declare an object instead of declaring only type
  attributes (bsc#1046306 FATE#322942).
- IB/core: Add new ioctl interface (bsc#1046306 FATE#322942).
- RDMA/vmw_pvrdma: Fix a signedness (bsc#1046306 FATE#322942).
- RDMA/vmw_pvrdma: Report network header type in WC (bsc#1046306
  FATE#322942).
- IB/core: Add might_sleep() annotation to ib_init_ah_from_wc()
  (bsc#1046306 FATE#322942).
- IB/cm: Fix sleeping in atomic when RoCE is used (bsc#1046306
  FATE#322942).
- IB/core: Add support to finalize objects in one transaction
  (bsc#1046306 FATE#322942).
- IB/core: Add a generic way to execute an operation on a uobject
  (bsc#1046306 FATE#322942).
- IB/uverbs: Expose XRQ capabilities (bsc#1046306 FATE#322942).
- IB/uverbs: Add new SRQ type IB_SRQT_TM (bsc#1046306
  FATE#322942).
- IB/uverbs: Add XRQ creation parameter to UAPI (bsc#1046306
  FATE#322942).
- IB/core: Add new SRQ type IB_SRQT_TM (bsc#1046306 FATE#322942).
- IB/core: Add XRQ capabilities (bsc#1046306 FATE#322942).
- IB/usnic: check for allocation failure (bsc#1046306
  FATE#322942).
- commit 0db1996
* Fri Sep 29 2017 tbogendoerfer@suse.de
- IB/rxe: Handle NETDEV_CHANGE events (bsc#1050662 FATE#323951).
- IB/rxe: Avoid ICRC errors by copying into the skb first
  (bsc#1050662 FATE#323951).
- IB/rxe: Remove unneeded initialization in prepare6()
  (bsc#1050662 FATE#323951).
- IB/rxe: Fix up rxe_qp_cleanup() (bsc#1050662 FATE#323951).
- IB/rxe: Add dst_clone() in prepare_ipv6_hdr() (bsc#1050662
  FATE#323951).
- IB/rxe: Fix destination cache for IPv6 (bsc#1050662
  FATE#323951).
- IB/rxe: Fix up the responder's find_resources() function
  (bsc#1050662 FATE#323951).
- IB/rxe: Remove dangling prototype (bsc#1050662 FATE#323951).
- IB/rxe: Disable completion upcalls when a CQ is destroyed
  (bsc#1050662 FATE#323951).
- commit a819614
* Fri Sep 29 2017 tbogendoerfer@suse.de
- IB/rdmavt: Handle dereg of inuse MRs properly (bsc#1058717
  FATE#322789).
- IB/qib: Convert qp_stats debugfs interface to use new iterator
  API (bsc#1027067 FATE#322649).
- IB/hfi1: Convert qp_stats debugfs interface to use new iterator
  API (bsc#1060463 FATE#323043).
- IB/hfi1: Convert hfi1_error_port_qps() to use new QP iterator
  (bsc#1060463 FATE#323043).
- IB/rdmavt: Add QP iterator API for QPs (bsc#1058717
  FATE#322789).
- IB/hfi1: Use accessor to determine ring size (bsc#1060463
  FATE#323043).
- IB/qib: Stricter bounds checking for copy to buffer (bsc#1027067
  FATE#322649).
- IB/hif1: Remove static tracing from SDMA hot path (bsc#1060463
  FATE#323043).
- IB/hfi1: Acquire QSFP cable information on loopback (bsc#1060463
  FATE#323043).
- IB/hfi1: constify vm_operations_struct (bsc#1060463
  FATE#323043).
- IB/hfi1: Add opcode states to qp_stats (bsc#1060463
  FATE#323043).
- IB/hfi1: Add received request info to qp_stats (bsc#1060463
  FATE#323043).
- IB/hfi1: Fix whitespace alignment issue for MAD (bsc#1060463
  FATE#323043).
- IB/hfi1: Move structure and MACRO definitions in user_sdma.c
  to user_sdma.h (bsc#1060463 FATE#323043).
- IB/hfi1: Move structure definitions from user_exp_rcv.c to
  user_exp_rcv.h (bsc#1060463 FATE#323043).
- IB/hfi1: Remove duplicate definitions of num_user_pages()
  function (bsc#1060463 FATE#323043).
- IB/hfi1: Fix the bail out code in pin_vector_pages() function
  (bsc#1060463 FATE#323043).
- IB/hfi1: Clean up pin_vector_pages() function (bsc#1060463
  FATE#323043).
- IB/hfi1: Clean up user_sdma_send_pkts() function (bsc#1060463
  FATE#323043).
- IB/hfi1: Clean up hfi1_user_exp_rcv_setup function (bsc#1060463
  FATE#323043).
- IB/hfi1: Improve local kmem_cache_alloc performance (bsc#1060463
  FATE#323043).
- IB/hfi1: Ratelimit prints from sdma_interrupt (bsc#1060463
  FATE#323043).
- IB/qib: Stricter bounds checking for copy and array access
  (bsc#1027067 FATE#322649).
- IB/qib: Remove unnecessary memory allocation for boardname
  (bsc#1027067 FATE#322649).
- IB/{qib, hfi1}: Avoid flow control testing for RDMA write
  operation (bsc#1060463 FATE#323043 bsc#1027067 FATE#322649).
- IB/rdmavt: Use rvt_put_swqe() in rvt_clear_mr_ref() (bsc#1058717
  FATE#322789).
- commit 983d8f2
* Fri Sep 29 2017 tbogendoerfer@suse.de
- IB/mlx4: Remove redundant attribute in mlx4_ib_create_qp_rss
  struct (bsc#1046302 FATE#322945).
- RDMA/mlx4: Fix create qp command alignment (bsc#1046302
  FATE#322945).
- commit fbdeecb
* Fri Sep 29 2017 bp@suse.de
- x86/mm: Make the SME mask a u64 (fate#322123).
- commit 2c6cff6
* Fri Sep 29 2017 tbogendoerfer@suse.de
- net/mlx4_core: Use ARRAY_SIZE macro (bsc#1046300 FATE#322946).
- net/mlx4_core: fix incorrect size allocation for
  dev->caps.spec_qps (bsc#1046300 FATE#322946).
- net/mlx4_core: fix memory leaks on error exit path (bsc#1046300
  FATE#322946).
- net/mlx4: Add user mac FW update support (bsc#1046300
  FATE#322946).
- net/mlx4_core: Fix misplaced brackets of sizeof (bsc#1046300
  FATE#322946).
- net/mlx4_core: Make explicit conversion to 64bit value
  (bsc#1046300 FATE#322946).
- net/mlx4_core: Dynamically allocate structs at mlx4_slave_cap
  (bsc#1046300 FATE#322946).
- net/mlx4_core: make mlx4_profile const (bsc#1046300
  FATE#322946).
- net/mlx4: fix spelling mistake: "availible" -> "available"
  (bsc#1046300 FATE#322946).
- mlx4: sizeof style usage (bsc#1046300 FATE#322946).
- mlx4: remove unnecessary pci_set_drvdata() (bsc#1046300
  FATE#322946).
- mlx4_en: remove unnecessary error check (bsc#1046299
  FATE#322947).
- mlx4_en: remove unnecessary returned value (bsc#1046299
  FATE#322947).
- commit 1ab797e
* Fri Sep 29 2017 tbogendoerfer@suse.de
- IB/mlx4: fix sprintf format warning (bsc#1046302 FATE#322945).
- RDMA/mlx4: Properly annotate link layer variable (bsc#1046302
  FATE#322945).
- IB/mlx4: Check that reserved fields in mlx4_ib_create_qp_rss
  are zero (bsc#1046302 FATE#322945).
- IB/mlx4: Fix struct mlx4_ib_create_wq alignment (bsc#1046302
  FATE#322945).
- IB/mlx4: Fix RSS QP type in creation verb (bsc#1046302
  FATE#322945).
- IB/mlx4: Fix some spelling mistakes (bsc#1046302 FATE#322945).
- RDMA/mlx4: Remove gfp_mask argument from acquire_group call
  (bsc#1046302 FATE#322945).
- RDMA/mlx4: Don't use uninitialized variable (bsc#1046302
  FATE#322945).
- IB/mlx4: use kvmalloc_array to allocate wrid (bsc#1046302
  FATE#322945).
- commit 104a064
* Fri Sep 29 2017 tbogendoerfer@suse.de
- IB/core: Separate CQ handle in SRQ context (bsc#1046306
  FATE#322942).
- net/mlx5: Update HW layout definitions (bsc#1046303
  FATE#322944).
- IB/mlx5: Report mlx5 enhanced multi packet WQE capability
  (bsc#1046305 FATE#322943).
- IB/mlx5: Allow posting multi packet send WQEs if hardware
  supports (bsc#1046305 FATE#322943).
- IB/mlx5: Add support for multi underlay QP (bsc#1046305
  FATE#322943).
- IB/mlx5: Fix integer overflow when page_shift == 31 (bsc#1046305
  FATE#322943).
- IB/mlx5: Fix memory leak in clean_mr error path (bsc#1046305
  FATE#322943).
- IB/mlx5: Decouple MR allocation and population flows
  (bsc#1046305 FATE#322943).
- IB/mlx5: Enable UMR for MRs created with reg_create (bsc#1046305
  FATE#322943).
- IB/mlx5: Expose software parsing for Raw Ethernet QP
  (bsc#1046305 FATE#322943).
- RDMA/mlx5: Limit scope of get vector affinity local function
  (bsc#1046305 FATE#322943).
- IB/mlx5: Add necessary delay drop assignment (bsc#1046305
  FATE#322943).
- IB/mlx5: Fix some spelling mistakes (bsc#1046305 FATE#322943).
- IB/mlx5: use kvmalloc_array for mlx5_ib_wq (bsc#1046305
  FATE#322943).
- mlx5: Replace PCI pool old API (bsc#1046303 FATE#322944).
- mlx5: support ->get_vector_affinity (bsc#1046305 FATE#322943).
- mlx5: move affinity hints assignments to generic code
  (bsc#1046303 FATE#322944).
- mlx5e: don't assume anything on the irq affinity mappings of
  the device (bsc#1046303 FATE#322944).
- mlx5: convert to generic pci_alloc_irq_vectors (bsc#1046303
  FATE#322944).
- commit 24ced8f
* Fri Sep 29 2017 tbogendoerfer@suse.de
- RDMA/nes: Remove zeroed parameter from port query callback
  (bsc#1046306 FATE#322942).
- IB/rxe: Make rxe_counter_name static (bsc#1050662 FATE#323951).
- IB/ipoib: Sync between remove_one to sysfs calls that use
  rtnl_lock (bsc#1046307 FATE#322941).
- RDMA/mthca: Make explicit conversion to 64bit value (bsc#1046306
  FATE#322942).
- RDMA/usnic: Fix remove address space warning (bsc#1046306
  FATE#322942).
- RDMA/core: Refactor get link layer wrapper (bsc#1046306
  FATE#322942).
- RDMA/core: Delete BUG() from unreachable flow (bsc#1046306
  FATE#322942).
- RDMA/core: Cleanup device capability enum (bsc#1046306
  FATE#322942).
- RDMA/(core, ulp): Convert register/unregister event handler
  to be void (bsc#1046306 FATE#322942).
- IB/uverbs: Introduce and use helper functions to copy ah
  attributes (bsc#1046306 FATE#322942).
- IB/cma: Fix erroneous validation of supported default GID type
  (bsc#1046306 FATE#322942).
- IB: Avoid ib_modify_port() failure for RoCE devices (bsc#1046306
  FATE#322942).
- RDMA/vmw_pvrdma: Update device query parameters and port caps
  (bsc#1046306 FATE#322942).
- RDMA/vmw_pvrdma: Add RoCEv2 support (bsc#1046306 FATE#322942).
- IB/ipoib: Enable ioctl for to IPoIB rdma netdevs (bsc#1046307
  FATE#322941).
- rdma: Autoload netlink client modules (bsc#1046306 FATE#322942).
- rdma: Allow demand loading of NETLINK_RDMA (bsc#1046306
  FATE#322942).
- IB/pvrdma: Remove unused function (bsc#1046306 FATE#322942).
- IB/mthca: Replace PCI pool old API (bsc#1046306 FATE#322942).
- infiniband: avoid overflow warning (bsc#1046306 FATE#322942).
- IB/rxe: Remove unneeded check (bsc#1050662 FATE#323951).
- IB/rxe: Convert pr_info to pr_warn (bsc#1050662 FATE#323951).
- commit 88ef93a
* Fri Sep 29 2017 tbogendoerfer@suse.de
- IB/hfi1: Add kernel receive context info to debugfs (bsc#1060463
  FATE#323043).
- IB/hfi1: Remove HFI1_VERBS_31BIT_PSN option (bsc#1060463
  FATE#323043).
- IB/hfi1: Remove pstate from hfi1_pportdata (bsc#1060463
  FATE#323043).
- IB/hfi1: Stricter bounds checking of MAD trap index (bsc#1060463
  FATE#323043).
- IB/hfi1: Load fallback platform configuration per HFI device
  (bsc#1060463 FATE#323043).
- IB/hfi1: Add flag for platform config scratch register read
  (bsc#1060463 FATE#323043).
- IB/hfi1: Document phys port state bits not used in IB
  (bsc#1060463 FATE#323043).
- IB/hfi1: Check xchg returned value for queuing link down entry
  (bsc#1060463 FATE#323043).
- IB/hfi1: fix spelling mistake: "Maximim" -> "Maximum"
  (bsc#1060463 FATE#323043).
- IB/hfi1: Enable RDMA_CAP_OPA_AH in hfi driver to support
  extended LIDs (bsc#1060463 FATE#323043).
- IB/hfi1: Enhance PIO/SDMA send for 16B (bsc#1060463
  FATE#323043).
- IB/hfi1: Add 16B RC/UC support (bsc#1060463 FATE#323043).
- IB/rdmavt, hfi1, qib: Enhance rdmavt and hfi1 to use 32 bit lids
  (bsc#1060463 FATE#323043 bsc#1027067 FATE#322649 bsc#1058717
  FATE#322789).
- IB/hfi1: Add 16B trace support (bsc#1060463 FATE#323043).
- IB/hfi1: Add 16B UD support (bsc#1060463 FATE#323043).
- IB/hfi1: Determine 9B/16B L2 header type based on Address handle
  (bsc#1060463 FATE#323043).
- IB/hfi1: Add support to process 16B header errors (bsc#1060463
  FATE#323043).
- IB/hfi1: Add support to send 16B bypass packets (bsc#1060463
  FATE#323043).
- IB/hfi1: Add support to receive 16B bypass packets (bsc#1060463
  FATE#323043).
- IB/rdmavt, hfi1, qib: Modify check_ah() to account for
  extended LIDs (bsc#1060463 FATE#323043 bsc#1027067 FATE#322649
  bsc#1058717 FATE#322789).
- IB/hf1: User context locking is inconsistent (bsc#1060463
  FATE#323043).
- IB/hfi1: Protect context array set/clear with spinlock
  (bsc#1060463 FATE#323043).
- IB/hfi1: Use host_link_state to read state when DC is shut down
  (bsc#1060463 FATE#323043).
- IB/hfi1: Remove lstate from hfi1_pportdata (bsc#1060463
  FATE#323043).
- IB/hfi1: Remove pmtu from the QP structure (bsc#1060463
  FATE#323043).
- IB/hfi1: Revert egress pkey check enforcement (bsc#1060463
  FATE#323043).
- IB/hfi1: add const to bin_attribute structures (bsc#1060463
  FATE#323043).
- IB/qib: add const to bin_attribute structures (bsc#1027067
  FATE#322649).
- IB/hfi1: fix spelling mistake in variable name continious
  (bsc#1060463 FATE#323043).
- IB/qib: fix spelling mistake: "failng" -> "failing" (bsc#1027067
  FATE#322649).
- commit 043fee2
* Fri Sep 29 2017 tbogendoerfer@suse.de
- IB/core: Fix input len in multiple user verbs (bsc#1046306
  FATE#322942).
- Add OPA extended LID support (bsc#1046306 FATE#322942).
- infiniband: pvrdma: constify pci_device_id (bsc#1046306
  FATE#322942).
- infiniband: nes: constify pci_device_id (bsc#1046306
  FATE#322942).
- infiniband: mthca: constify pci_device_id (bsc#1046306
  FATE#322942).
- PCI/IB: add support for pci driver attribute groups (bsc#1046306
  FATE#322942).
- iwcm: Don't allocate iwcm workqueue with WQ_MEM_RECLAIM
  (bsc#1046306 FATE#322942).
- cm: Don't allocate ib_cm workqueue with WQ_MEM_RECLAIM
  (bsc#1046306 FATE#322942).
- RDMA/core: make ib_device.add method optional (bsc#1046306
  FATE#322942).
- RDMA/netlink: Export node_type (bsc#1046306 FATE#322942).
- RDMA/netlink: Provide port state and physical link state
  (bsc#1046306 FATE#322942).
- RDMA/netlink: Export LID mask control (LMC) (bsc#1046306
  FATE#322942).
- RDMA/netink: Export lids and sm_lids (bsc#1046306 FATE#322942).
- RDMA/netlink: Advertise IB subnet prefix (bsc#1046306
  FATE#322942).
- RDMA/netlink: Export node_guid and sys_image_guid (bsc#1046306
  FATE#322942).
- RDMA/netlink: Export FW version (bsc#1046306 FATE#322942).
- RDMA: Simplify get firmware interface (bsc#1046306 FATE#322942).
- RDMA/netlink: Expose device and port capability masks
  (bsc#1046306 FATE#322942).
- RDMA/netlink: Implement nldev port doit callback (bsc#1046306
  FATE#322942).
- RDMA/netlink: Add nldev port dumpit implementation (bsc#1046306
  FATE#322942).
- RDMA/netlink: Add nldev device doit implementation (bsc#1046306
  FATE#322942).
- RDMA/netlink: Implement nldev device dumpit calback (bsc#1046306
  FATE#322942).
- RDMA/netlink: Add nldev initialization flows (bsc#1046306
  FATE#322942).
- RDMA/netlink: Add netlink device definitions to UAPI
  (bsc#1046306 FATE#322942).
- RDMA/netlink: Update copyright (bsc#1046306 FATE#322942).
- RDMA/netlink: Convert LS to doit callback (bsc#1046306
  FATE#322942).
- RDMA/netlink: Reduce indirection access to cb_table (bsc#1046306
  FATE#322942).
- RDMA/netlink: Add and implement doit netlink callback
  (bsc#1046306 FATE#322942).
- RDMA/core: Add and expose static device index (bsc#1046306
  FATE#322942).
- RDMA/core: Add iterator over ib_devices (bsc#1046306
  FATE#322942).
- RDMA/netlink: Rename netlink callback struct (bsc#1046306
  FATE#322942).
- RDMA/netlink: Simplify and rename ibnl_chk_listeners
  (bsc#1046306 FATE#322942).
- RDMA/netlink: Rename and remove redundant parameter from
  ibnl_multicast (bsc#1046306 FATE#322942).
- RDMA/netlink: Rename and remove redundant parameter from
  ibnl_unicast* (bsc#1046306 FATE#322942).
- RDMA/netlink: Simplify the put_msg and put_attr (bsc#1046306
  FATE#322942).
- RDMA/netlink: Add flag to consolidate common handling
  (bsc#1046306 FATE#322942).
- RDMA/iwcm: Remove extra EXPORT_SYMBOLS (bsc#1046306
  FATE#322942).
- RDMA/iwcm: Remove useless check of netlink client validity
  (bsc#1046306 FATE#322942).
- RDMA/netlink: Avoid double pass for RDMA netlink messages
  (bsc#1046306 FATE#322942).
- RDMA/netlink: Remove redundant owner option for netlink
  callbacks (bsc#1046306 FATE#322942).
- RDMA/netlink: Remove netlink clients infrastructure (bsc#1046306
  FATE#322942).
- RDMA/core: Add wait/retry version of ibnl_unicast (bsc#1046306
  FATE#322942).
- RDMA/core: expose affinity mappings per completion vector
  (bsc#1046306 FATE#322942).
- IB/CM: Set appropriate slid and dlid when handling CM request
  (bsc#1046306 FATE#322942).
- IB/CM: Create appropriate path records when handling CM request
  (bsc#1046306 FATE#322942).
- IB/CM: Add OPA Path record support to CM (bsc#1046306
  FATE#322942).
- IB/core: Change wc.slid from 16 to 32 bits (bsc#1046306
  FATE#322942).
- IB/core: Change port_attr.sm_lid from 16 to 32 bits (bsc#1046306
  FATE#322942).
- IB/core: Change port_attr.lid size from 16 to 32 bits
  (bsc#1046306 FATE#322942).
- IB/mad: Change slid in RMPP recv from 16 to 32 bits (bsc#1046306
  FATE#322942).
- IB/IPoIB: Increase local_lid to 32 bits (bsc#1046306
  FATE#322942).
- IB/srpt: Increase lid and sm_lid to 32 bits (bsc#1046306
  FATE#322942).
- IB/core: Convert ah_attr from OPA to IB when copying to user
  (bsc#1046306 FATE#322942).
- IB: nes: convert to use DRIVER_ATTR_RW (bsc#1046306
  FATE#322942).
- commit 0b03922
* Fri Sep 29 2017 jroedel@suse.de
- iommu/vt-d: Avoid calling virt_to_phys() on null pointer
  (bsc#1061067).
- commit 1047702
* Fri Sep 29 2017 tbogendoerfer@suse.de
- Delete
  patches.drivers/RDMA-Simplify-get-firmware-interface.patch.
- commit 60fa778
* Fri Sep 29 2017 tbogendoerfer@suse.de
- IB/hfi1: Always perform offline transition (bsc#1060463
  FATE#323043).
- IB/hfi1: Prevent link down request double queuing (bsc#1060463
  FATE#323043).
- IB/hfi1: Create workqueue for link events (bsc#1060463
  FATE#323043).
- IB/hfi1: Disambiguate corruption and uninitialized error cases
  (bsc#1060463 FATE#323043).
- IB/hfi1: Only set fd pointer when base context is completely
  initialized (bsc#1060463 FATE#323043).
- IB/hfi1: Do not enable disabled port on cable insert
  (bsc#1060463 FATE#323043).
- IB/hfi1: Harden state transition to Armed and Active
  (bsc#1060463 FATE#323043).
- IB/hfi1: Split copy_to_user data copy for better security
  (bsc#1060463 FATE#323043).
- IB/hfi1: Verify port data VLs credits on transition to Armed
  (bsc#1060463 FATE#323043).
- IB/hfi1: Move saving PCI values to a separate function
  (bsc#1060463 FATE#323043).
- IB/hfi1: Fix initialization failure for debug firmware
  (bsc#1060463 FATE#323043).
- IB/hfi1: Fix code consistency for if/else blocks in chip.c
  (bsc#1060463 FATE#323043).
- IB/hfi1: Send MAD traps until repressed (bsc#1060463
  FATE#323043).
- IB/hfi1: Pass the context pointer rather than the index
  (bsc#1060463 FATE#323043).
- IB/hfi1: Use context pointer rather than context index
  (bsc#1060463 FATE#323043).
- IB/hfi1: Size rcd array index correctly and consistently
  (bsc#1060463 FATE#323043).
- IB/hfi1: Remove unused user context data members (bsc#1060463
  FATE#323043).
- IB/hfi1: Assign context does not clean up file descriptor
  correctly on error (bsc#1060463 FATE#323043).
- IB/hfi1: Serve the most starved iowait entry first (bsc#1060463
  FATE#323043).
- IB/hfi1: Fix bar0 mapping to use write combining (bsc#1060463
  FATE#323043).
- IB/hfi1: Check return values from PCI config API calls
  (bsc#1060463 FATE#323043).
- IB/hfi1: Add receiving queue info to qp_stats (bsc#1060463
  FATE#323043).
- IB/qib: remove duplicate code (bsc#1027067 FATE#322649).
- commit 6163efb
* Fri Sep 29 2017 jroedel@suse.de
- PCI: pciehp: Report power fault only once until we clear it
  (bsc#1061046).
- commit c7e1a71
* Fri Sep 29 2017 tbogendoerfer@suse.de
- bnxt_en: fix switchdev port naming for external-port-rep and
  vf-reps (bsc#1050242 FATE#322914).
- bnxt_en: use SWITCHDEV_SET_OPS() for setting
  vf_rep_switchdev_ops (bsc#1050242 FATE#322914).
- bnxt_en: include bnxt_vfr.c code under CONFIG_BNXT_SRIOV switch
  (bsc#1050242 FATE#322914).
- bnxt: fix unused variable warnings (bsc#1050242 FATE#322914).
- bnxt: fix unsigned comparsion with 0 (bsc#1050242 FATE#322914).
- bnxt_en: Use SWITCHDEV_SET_OPS() (bsc#1050242 FATE#322914).
- bnxt_en: add support for port_attr_get and and
  get_phys_port_name (bsc#1050242 FATE#322914).
- bnxt_en: add vf-rep RX/TX and netdev implementation (bsc#1050242
  FATE#322914).
- bnxt_en: add support to enable VF-representors (bsc#1050242
  FATE#322914).
- bnxt_en: Set ETS min_bw parameter for older firmware
  (bsc#1050242 FATE#322914).
- bnxt_en: Report firmware DCBX agent (bsc#1050242 FATE#322914).
- bnxt_en: Allow the user to set ethtool stats-block-usecs to 0
  (bsc#1050242 FATE#322914).
- bnxt_en: Add bnxt_get_num_stats() to centrally get the number
  of ethtool stats (bsc#1050242 FATE#322914).
- bnxt_en: Implement ndo_bridge_{get|set}link methods (bsc#1050242
  FATE#322914).
- bnxt_en: Retrieve the hardware bridge mode from the firmware
  (bsc#1050242 FATE#322914).
- bnxt_en: Update firmware interface spec to 1.8.0 (bsc#1050242
  FATE#322914).
- commit aa23996
* Fri Sep 29 2017 tbogendoerfer@suse.de
- RDMA/bnxt_re: remove unnecessary call to memset (bsc#1050244
  FATE#322915).
- RDMA: Fix return value check for ib_get_eth_speed() (bsc#1050244
  FATE#322915).
- RDMA/bnxt_re: Implement the alloc/get_hw_stats callback
  (bsc#1050244 FATE#322915).
- RDMA/bnxt_re: Allocate multiple notification queues (bsc#1050244
  FATE#322915).
- RDMA/bnxt_re: fix spelling mistake: "Deallocte" -> "Deallocate"
  (bsc#1050244 FATE#322915).
- RDMA/bnxt_re: Allow posting when QPs are in error (bsc#1050244
  FATE#322915).
- RDMA/bnxt_re: Add vlan tag for untagged RoCE traffic when PFC
  is configured (bsc#1050244 FATE#322915).
- RDMA/bnxt_re: Delete unsupported modify_port function
  (bsc#1050244 FATE#322915).
- commit 94e058a
* Fri Sep 29 2017 tbogendoerfer@suse.de
- IB/cma: Fix default RoCE type setting (bsc#1046306 FATE#322942).
- IB/core: Add generic function to extract IB speed from netdev
  (bsc#1046306 FATE#322942).
- IB/usnic: Implement get_netdev hook (bsc#1046306 FATE#322942).
- IB/cma: Set default gid type to RoCEv2 (bsc#1046306
  FATE#322942).
- commit 1582933
* Fri Sep 29 2017 tbogendoerfer@suse.de
- mlx4: Replace PCI pool old API (bsc#1046300 FATE#322946).
- IB/mlx4: Expose RSS capabilities (bsc#1046302 FATE#322945).
- IB/mlx4: Add support for RSS QP (bsc#1046302 FATE#322945).
- IB/mlx4: Add support for WQ indirection table related verbs
  (bsc#1046302 FATE#322945).
- IB/mlx4: Add support for WQ related verbs (bsc#1046302
  FATE#322945).
- (IB, net)/mlx4: Add resource utilization support (bsc#1046302
  FATE#322945 bsc#1046300 FATE#322946 bsc#1046299 FATE#322947).
- IB/mlx4: Add inline-receive support (bsc#1046302 FATE#322945).
- commit 8e2d33f
* Fri Sep 29 2017 tbogendoerfer@suse.de
- net/mlx5: fix spelling mistake: "alloated" -> "allocated"
  (bsc#1046303 FATE#322944).
- IB/mlx5: Expose extended error counters (bsc#1046305
  FATE#322943).
- IB/mlx5: Fix cached MR allocation flow (bsc#1046305
  FATE#322943).
- IB/mlx5: Report RX checksum capabilities for IPoIB (bsc#1046305
  FATE#322943).
- net/mlx5: Report enhanced capabilities for IPoIB (bsc#1046303
  FATE#322944).
- IB/mlx5: Add multicast flow steering support for underlay QP
  (bsc#1046305 FATE#322943).
- IB/mlx5: Add support for QP with a given source QPN (bsc#1046305
  FATE#322943).
- IB/mlx5: Add delay drop configuration and statistics
  (bsc#1046305 FATE#322943).
- IB/mlx5: Add support to dropless RQ (bsc#1046305 FATE#322943).
- net/mlx5: Introduce general notification event (bsc#1046303
  FATE#322944).
- net/mlx5: Introduce set delay drop command (bsc#1046303
  FATE#322944).
- IB/mlx5: Restore IB guid/policy for virtual functions
  (bsc#1046305 FATE#322943).
- IB/mlx5: Add debug control parameters for congestion control
  (bsc#1046305 FATE#322943).
- IB/mlx5: Change logic for dispatching IB events for port state
  (bsc#1046305 FATE#322943).
- net/mlx5e: Enable local loopback in loopback selftest
  (bsc#1046303 FATE#322944).
- IB/mlx5: Add raw ethernet local loopback support (bsc#1046305
  FATE#322943).
- net/mlx5: Add raw ethernet local loopback firmware command
  (bsc#1046303 FATE#322944).
- commit 08c6c4f
* Fri Sep 29 2017 jroedel@suse.de
- KVM: VMX: do not change SN bit in vmx_update_pi_irte()
  (bsc#1061017).
- KVM: nVMX: Update vmcs12->guest_linear_address on nested VM-exit
  (bsc#1061017).
- KVM: async_pf: Fix #DF due to inject "Page not Present" and
  "Page Ready" exceptions simultaneously (bsc#1061017).
- KVM: VMX: remove WARN_ON_ONCE in
  kvm_vcpu_trigger_posted_interrupt (bsc#1061017).
- KVM: SVM: Add a missing 'break' statement (bsc#1061017).
- commit 037fe31
* Fri Sep 29 2017 jroedel@suse.de
- Delete patches.arch/0002-KVM-Don-t-accept-obviously-wrong-gsi-values-via-KVM_.patch.
  Patch was reverted upstream.
- commit b3eafff
* Fri Sep 29 2017 jroedel@suse.de
- Refresh patches.arch/0001-KVM-VMX-Do-not-BUG-on-out-of-bounds-guest-IRQ.patch.
  Add upstream commit-id and Patch-mainline information.
- commit 546cb89
* Thu Sep 28 2017 mgorman@suse.de
- Update config files.
- commit e7bab09
* Wed Sep 27 2017 dbueso@suse.de
- kvm,mips: Fix potential swait_active() races (bsc#1060747).
- kvm,powerpc: Serialize wq active checks in ops->vcpu_kick
  (bsc#1060747).
- kvm: Serialize wq active checks in kvm_vcpu_wake_up()
  (bsc#1060747).
- kvm,x86: Fix apf_task_wake_one() wq serialization (bsc#1060747).
- kvm,lapic: Justify use of swait_active() (bsc#1060747).
- kvm,async_pf: Use swq_has_sleeper() (bsc#1060747).
- sched/wait: Add swq_has_sleeper() (bsc#1060747).
- swait: Add idle variants which don't contribute to load average
  (bsc#1060747).
- commit e57f3cb
* Wed Sep 27 2017 jslaby@suse.cz
- Linux 4.12.14 (bnc#1060662).
- ipv6: accept 64k - 1 packet length in ip6_find_1stfragopt()
  (bnc#1060662).
- ipv6: add rcu grace period before freeing fib6_node
  (bnc#1060662).
- ipv6: fix sparse warning on rt6i_node (bnc#1060662).
- macsec: add genl family module alias (bnc#1060662).
- udp: on peeking bad csum, drop packets even if not at head
  (bnc#1060662).
- bpf: fix map value attribute for hash of maps (bnc#1060662).
- fsl/man: Inherit parent device and of_node (bnc#1060662).
- sctp: Avoid out-of-bounds reads from address storage
  (bnc#1060662).
- tipc: Fix tipc_sk_reinit handling of -EAGAIN (bnc#1060662).
- net: systemport: Be drop monitor friendly (bnc#1060662).
- net: bcmgenet: Be drop monitor friendly (bnc#1060662).
- net: systemport: Free DMA coherent descriptors on errors
  (bnc#1060662).
- netvsc: fix deadlock betwen link status and removal
  (bnc#1060662).
- udp6: set rx_dst_cookie on rx_dst updates (bnc#1060662).
- net: mvpp2: fix the mac address used when using PPv2.2
  (bnc#1060662).
- ipv6: set dst.obsolete when a cached route has expired
  (bnc#1060662).
- ipv6: do not set sk_destruct in IPV6_ADDRFORM sockopt
  (bnc#1060662).
- packet: Don't write vnet header beyond end of buffer
  (bnc#1060662).
- kcm: do not attach PF_KCM sockets to avoid deadlock
  (bnc#1060662).
- net: dsa: bcm_sf2: Fix number of CFP entries for BCM7278
  (bnc#1060662).
- Revert "net: phy: Correctly process PHY_HALTED in
  phy_stop_machine()" (bnc#1060662).
- net: fec: Allow reception of frames bigger than 1522 bytes
  (bnc#1060662).
- mlxsw: spectrum: Forbid linking to devices that have uppers
  (bnc#1060662).
- bridge: switchdev: Clear forward mark when transmitting packet
  (bnc#1060662).
- Revert "net: use lib/percpu_counter API for fragmentation mem
  accounting" (bnc#1060662).
- Revert "net: fix percpu memory leaks" (bnc#1060662).
- gianfar: Fix Tx flow control deactivation (bnc#1060662).
- vhost_net: correctly check tx avail during rx busy polling
  (bnc#1060662).
- ip6_gre: update mtu properly in ip6gre_err (bnc#1060662).
- ipv6: fix memory leak with multiple tables during netns
  destruction (bnc#1060662).
- ipv6: fix typo in fib6_net_exit() (bnc#1060662).
- sctp: fix missing wake ups in some situations (bnc#1060662).
- f2fs: let fill_super handle roll-forward errors (bnc#1060662).
- f2fs: check hot_data for roll-forward recovery (bnc#1060662).
- x86/fsgsbase/64: Fully initialize FS and GS state in
  start_thread_common (bnc#1060662).
- x86/fsgsbase/64: Report FSBASE and GSBASE correctly in core
  dumps (bnc#1060662).
- x86/switch_to/64: Rewrite FS/GS switching yet again to fix
  AMD CPUs (bnc#1060662).
- fuse: allow server to run in different pid_ns (bnc#1060662).
- idr: remove WARN_ON_ONCE() when trying to replace negative ID
  (bnc#1060662).
- md/raid1/10: reset bio allocated from mempool (bnc#1060662).
- md/raid5: release/flush io in raid5_do_work() (bnc#1060662).
- ipv6: Fix may be used uninitialized warning in rt6_check
  (bnc#1060662).
- Refresh
  patches.drivers/net-sock-factor-out-dequeue-peek-with-offset-code.patch.
- Refresh
  patches.suse/0001-x86-entry-64-Refactor-IRQ-stacks-and-make-them-NMI-s.patch.
- commit ffd2366
* Wed Sep 27 2017 mgorman@suse.de
- mm: hugetlb: clear target sub-page last when clearing huge page
  (bnc#971975 VM performance -- thp).
- commit ba31982
* Wed Sep 27 2017 jack@suse.cz
- Disable CONFIG_DEBUG_LIST (bsc#1060256)
  CONFIG_DEBUG_LIST adds some consistency checks into list handling
  operations. Additional fetches resulting from this are visible in the
  perf profile accounting for about 3.5%% of the pagecache truncation path.
  Disable the option to avoid the overhead as it was enabled more or less
  inadvertedly.
  We also have to disable CONFIG_BUG_ON_DATA_CORRUPTION as that selects
  CONFIG_DEBUG_LIST.
- commit 1748d9c
* Tue Sep 26 2017 tbogendoerfer@suse.de
- IB/core: Fix for core panic (bsc#1046306 FATE#322942).
- IB/{rdmavt, hfi1, qib}: Fix panic with post receive and SGE
  compression (bsc#1058717 FATE#322789).
- commit 92c6c71
* Tue Sep 26 2017 tbogendoerfer@suse.de
- IB/uverbs: Enable QP creation with a given source QP number
  (bsc#1046306 FATE#322942).
- IB/core: Enable QP creation with a given source QP number
  (bsc#1046306 FATE#322942).
- IB/core: Add support for RoCEv2 multicast (bsc#1046306
  FATE#322942).
- IB/core: Set RoCEv2 MGID according to spec (bsc#1046306
  FATE#322942).
- IB/core: Fix the validations of a multicast LID in attach or
  detach operations (bsc#1046306 FATE#322942).
- IB/core: Introduce delay drop for a WQ (bsc#1046306
  FATE#322942).
- commit 4537464
* Tue Sep 26 2017 tbogendoerfer@suse.de
- IB/rxe: Constify static rxe_vm_ops (bsc#1050662 FATE#323951).
- IB/rxe: Use __func__ to print function's name (bsc#1050662
  FATE#323951).
- IB/rxe: Use DEVICE_ATTR_RO macro to show parent field
  (bsc#1050662 FATE#323951).
- IB/rxe: Prefer 'unsigned int' to bare use of 'unsigned'
  (bsc#1050662 FATE#323951).
- IB/rxe: Use "foo *bar" instead of "foo * bar" (bsc#1050662
  FATE#323951).
- commit fab70b3
* Tue Sep 26 2017 tbogendoerfer@suse.de
- IB/hfi1: Handle missing magic values in config file (bsc#1060463
  FATE#323043).
- IB/hfi1: Resolve kernel panics by reference counting receive
  contexts (bsc#1060463 FATE#323043).
- IB/hfi1: Initialize TID lists to avoid crash on cleanup
  (bsc#1060463 FATE#323043).
- IB/qib: Replace deprecated pci functions with new API
  (bsc#1027067 FATE#322649).
- IB/hfi1: Add traces for TID operations (bsc#1060463
  FATE#323043).
- IB/hfi1: Use a template for tid reg/unreg (bsc#1060463
  FATE#323043).
- IB/hfi1: Remove reading platform configuration from EFI variable
  (bsc#1060463 FATE#323043).
- IB/hfi1: Create common expected receive verbs/PSM code
  (bsc#1060463 FATE#323043).
- IB/hfi1: Set proper logging levels on QSFP cable error events
  (bsc#1060463 FATE#323043).
- IB/hfi1: Fix DC 8051 host info flag array (bsc#1060463
  FATE#323043).
- IB/hfi1,qib: Do not send QKey trap for UD qps (bsc#1060463
  FATE#323043).
- IB/hfi1: Modify handling of physical link state by Host Driver
  (bsc#1060463 FATE#323043).
- IB/core: Allow QP state transition from reset to error
  (bsc#1046306 FATE#322942).
- IB/hfi1: Add error checking for buffer overrun in OPA aggregate
  (bsc#1060463 FATE#323043).
- IB/hfi1: Remove subtraction of uninitialized value (bsc#1060463
  FATE#323043).
- IB/hfi1: Use QPN mask to avoid overflow (bsc#1060463
  FATE#323043).
- IB/hfi1: Fix spelling mistake in linkdown reason (bsc#1060463
  FATE#323043).
- IB/rdmavt: Remove duplicated functions (bsc#1058717
  FATE#322789).
- IB/hfi1: Fix up sdma_init function comment (bsc#1060463
  FATE#323043).
- IB/hfi1: Reclassify type of messages printed for platform
  config logic (bsc#1060463 FATE#323043).
- IB/hfi1: Remove atomic SDMA_REQ_HAS_ERROR bit operation
  (bsc#1060463 FATE#323043).
- IB/hfi1: Remove atomic SDMA_REQ_SEND_DONE bit operation
  (bsc#1060463 FATE#323043).
- IB/core,rdmavt,hfi1,opa-vnic: Send OPA cap_mask3 in trap
  (bsc#1060463 FATE#323043 bsc#1058717 FATE#322789 bsc#1046306
  FATE#322942).
- IB/hfi1: Replace deprecated pci functions with new API
  (bsc#1060463 FATE#323043).
- IB/hfi1: Name function prototype parameters for affinity module
  (bsc#1060463 FATE#323043).
- IB/hfi1: Optimize cachelines for user SDMA request structure
  (bsc#1060463 FATE#323043).
- IB/hfi1: Don't remove RB entry when not needed (bsc#1060463
  FATE#323043).
- IB/rdmavt: Compress adjacent SGEs in rvt_lkey_ok() (bsc#1058717
  FATE#322789).
- IB/hfi1: Setup common IB fields in hfi1_packet struct
  (bsc#1060463 FATE#323043).
- IB/hfi1: Separate input/output header tracing (bsc#1060463
  FATE#323043).
- IB/hfi1: Add functions to parse BTH/IB headers (bsc#1060463
  FATE#323043).
- IB/hfi1: Remove unused mk_qpn function (bsc#1060463
  FATE#323043).
- IB/hfi1: Remove unnecessary initialization from tx request
  (bsc#1060463 FATE#323043).
- commit 0a0be08
* Tue Sep 26 2017 bp@suse.de
- EDAC: Add owner check to the x86 platform drivers (bsc#1042420).
- Update config files.
- EDAC: Add helper which returns the loaded platform driver
  (bsc#1042420).
- EDAC, ghes: Add platform check (bsc#1042420).
- EDAC, ghes: Model a single, logical memory controller
  (bsc#1042420).
- EDAC, ghes: Remove symbol exports (bsc#1042420).
- intel_pstate: convert to use acpi_match_platform_list()
  (bsc#1042420).
- commit 0ef43b8
* Tue Sep 26 2017 tonyj@suse.de
- Refresh
  patches.arch/perf-vendor-events-powerpc-remove-duplicate-events.patch.
- commit 7117699
* Tue Sep 26 2017 tbogendoerfer@suse.de
- nfp: only use direct firmware requests (bsc#1055968).
- nfp: look for firmware image by device serial number and PCI
  name (bsc#1055968).
- nfp: remove the probe deferral when FW not present
  (bsc#1055968).
- nfp: set config bit (ifup/ifdown) on netdev open/close
  (bsc#1055968).
- commit 2e0e280
* Tue Sep 26 2017 tbogendoerfer@suse.de
- cxgb4: ethtool forward error correction management support
  (bsc#1046540 FATE#322930).
- cxgb4: core hardware/firmware support for Forward Error
  Correction on a link (bsc#1046540 FATE#322930).
- net: ethtool: add support for forward error correction modes
  (bsc#1046540 FATE#322930).
- cxgb4: display serial config and vpd versions (bsc#1046540
  FATE#322930).
- cxgb4: Update register ranges of T4/T5/T6 adapters (bsc#1046540
  FATE#322930).
- cxgb4: Remove some dead code (bsc#1046540 FATE#322930).
- commit 8b2ccca
* Tue Sep 26 2017 tbogendoerfer@suse.de
- RDMA: Simplify get firmware interface (bsc#1046543 FATE#322927).
- RDMA: Remove useless MODULE_VERSION (bsc#1046543 FATE#322927).
- commit 28a0467
* Tue Sep 26 2017 jthumshirn@suse.de
- fs/fcntl: use copy_to/from_user() for u64 types (FATE#323952,
  FATE#322506).
- commit aa1d84c
* Mon Sep 25 2017 jslaby@suse.cz
- x86/asm: Fix inline asm call constraints for Clang
  (bnc#1058115).
- objtool: Handle another GCC stack pointer adjustment bug
  (bnc#1058115).
- commit a2e1012
* Mon Sep 25 2017 jslaby@suse.cz
- Linux 4.12.13 (bnc#1060662).
- mtd: nand: make Samsung SLC NAND usable again (bnc#1060662).
- mtd: nand: hynix: add support for 20nm NAND chips (bnc#1060662).
- mtd: nand: mxc: Fix mxc_v1 ooblayout (bnc#1060662).
- mtd: nand: qcom: fix read failure without complete bootchain
  (bnc#1060662).
- mtd: nand: qcom: fix config error for BCH (bnc#1060662).
- nvme-fabrics: generate spec-compliant UUID NQNs (bnc#1060662).
- btrfs: resume qgroup rescan on rw remount (bnc#1060662).
- rtlwifi: btcoexist: Fix breakage of ant_sel for rtl8723be
  (bnc#1060662).
- radix-tree: must check __radix_tree_preload() return value
  (bnc#1060662).
- selftests/x86/fsgsbase: Test selectors 1, 2, and 3
  (bnc#1060662).
- mm: kvfree the swap cluster info if the swap file is
  unsatisfactory (bnc#1060662).
- mm/swapfile.c: fix swapon frontswap_map memory leak on error
  (bnc#1060662).
- mm/memory.c: fix mem_cgroup_oom_disable() call missing
  (bnc#1060662).
- ALSA: msnd: Optimize / harden DSP and MIDI loops (bnc#1060662).
- KVM: SVM: Limit PFERR_NESTED_GUEST_PAGE error_code check to
  L1 guest (bnc#1060662).
- Bluetooth: Properly check L2CAP config option output buffer
  length (bnc#1060662 bnc#1057389 CVE-2017-1000251).
- ARM64: dts: marvell: armada-37xx: Fix GIC maintenance interrupt
  (bnc#1060662).
- ARM: 8692/1: mm: abort uaccess retries upon fatal signal
  (bnc#1060662).
- NFS: Fix 2 use after free issues in the I/O code (bnc#1060662).
- NFS: Sync the correct byte range during synchronous writes
  (bnc#1060662).
- NFSv4: Fix up mirror allocation (bnc#1060662).
- xfs: XFS_IS_REALTIME_INODE() should be false if no rt device
  present (bnc#1060662).
- commit 5f5d623
* Mon Sep 25 2017 jthumshirn@suse.de
- PCI: Split ->reset_notify() method into ->reset_prepare()
  and ->reset_done() (FATE#323952, FATE#322506).
- fs: add fcntl() interface for setting/getting write life time
  hints (FATE#323952, FATE#322506).
- lightnvm: propagate right error code to target (FATE#323952,
  FATE#322506).
- nvme: Allocate queues for all possible CPUs (FATE#323952,
  FATE#322506).
- nvme: Don't allow to reset a reconnecting controller
  (FATE#323952, FATE#322506).
- nvme: Makefile: remove dead build rule (FATE#323952,
  FATE#322506).
- nvme: Move transports to use nvme-core workqueue (FATE#323952,
  FATE#322506).
- nvme: Quirks for PM1725 controllers (FATE#323952, FATE#322506).
- nvme: Remove SCSI translations (FATE#323952, FATE#322506,
  FATE#323537).
- nvme: add fields into identify controller data structure
  (FATE#323952, FATE#322506).
- nvme: add hostid token to fabric options (FATE#323952,
  FATE#322506).
- nvme: add support for streams and directives (FATE#323952,
  FATE#322506).
- nvme: also provide a UUID in the WWID sysfs attribute
  (FATE#323952, FATE#322506).
- nvme: don't hard code size of struct t10_pi_tuple (FATE#323952,
  FATE#322506).
- nvme: explicitly disable APST on quirked devices (FATE#323952,
  FATE#322506).
- nvme: fabrics commands should use the fctype field for data
  direction (FATE#323952, FATE#322506).
- nvme-fabrics: fix reporting of unrecognized options
  (FATE#323952, FATE#322506).
- nvme-fabrics: verify that a controller returns the correct NQN
  (FATE#323952, FATE#322506).
- nvme-fc: address target disconnect race conditions in fcp io
  submit (FATE#323952, FATE#322506).
- nvme-fc: don't override opts->nr_io_queues (FATE#323952,
  FATE#322506).
- nvme-fc: merge init_request methods (FATE#323952, FATE#322506).
- nvme-fc: quiesce/unquiesce admin_q instead of start/stop its
  hw queues (FATE#323952, FATE#322506).
- nvme-fc: revise TRADDR parsing (FATE#323952, FATE#322506).
- nvme-fc: update tagset nr_hw_queues after queues reinit
  (FATE#323952, FATE#322506).
- nvme-fc: use blk_mq_delay_run_hw_queue instead of open-coding it
  (FATE#323952, FATE#322506).
- nvme: fix byte swapping in the streams code (FATE#323952,
  FATE#322506).
- nvme: fix directive command numd calculation (FATE#323952,
  FATE#322506).
- nvme: fix nvme reset command timeout handling (FATE#323952,
  FATE#322506).
- nvme: get list of namespace descriptors (FATE#323952,
  FATE#322506).
- nvme: host: unquiesce queue in nvme_kill_queues() (FATE#323952,
  FATE#322506).
- nvme: implement NS Optimal IO Boundary from 1.3 Spec
  (FATE#323952, FATE#322506).
- nvme: introduce NVMe Namespace Identification Descriptor
  structures (FATE#323952, FATE#322506).
- nvme: kick requeue list when requeueing a request instead of
  when starting the queues (FATE#323952, FATE#322506).
- nvme-lightnvm: use blk_execute_rq in nvme_nvm_submit_user_cmd
  (FATE#323952, FATE#322506).
- nvme-loop: get rid of unused controller lock (FATE#323952,
  FATE#322506).
- nvme-loop: merge init_request methods (FATE#323952,
  FATE#322506).
- nvme-loop: quiesce/unquiesce admin_q instead of start/stop
  its hw queues (FATE#323952, FATE#322506).
- nvme-loop: update tagset nr_hw_queues after
  reconnecting/resetting (FATE#323952, FATE#322506).
- nvme: mark shutdown_timeout static (FATE#323952, FATE#322506).
- nvme: move ctrl cap to struct nvme_ctrl (FATE#323952,
  FATE#322506).
- nvme: move nr_reconnects to nvme_ctrl (FATE#323952,
  FATE#322506).
- nvme: move protection information check into nvme_setup_rw
  (FATE#323952, FATE#322506).
- nvme: move queue_count to the nvme_ctrl (FATE#323952,
  FATE#322506).
- nvme: move reset workqueue handling to common code (FATE#323952,
  FATE#322506).
- nvme: no need to wait for the reset when keepalive fails
  (FATE#323952, FATE#322506).
- nvme-pci: Fix an error handling path in 'nvme_probe()'
  (FATE#323952, FATE#322506).
- nvme-pci: Introduce nvme_ring_cq_doorbell (FATE#323952,
  FATE#322506).
- nvme-pci: Remove nvme_setup_prps BUG_ON (FATE#323952,
  FATE#322506).
- nvme-pci: Remove watchdog timer (FATE#323952, FATE#322506).
- nvme-pci: add another device ID with stripe quirk (FATE#323952,
  FATE#322506).
- nvme-pci: add module parameter for io queue depth (FATE#323952,
  FATE#322506).
- nvme-pci: compile warnings in nvme_alloc_host_mem()
  (FATE#323952, FATE#322506).
- nvme-pci: factor out cqe handling into a dedicated routine
  (FATE#323952, FATE#322506).
- nvme-pci: factor out the cqe reading mechanics from
  __nvme_process_cq (FATE#323952, FATE#322506).
- nvme-pci: fix CMB sysfs file removal in reset path (FATE#323952,
  FATE#322506).
- nvme-pci: fix HMB size calculation (FATE#323952, FATE#322506).
- nvme-pci: implement host memory buffer support (FATE#323952,
  FATE#322506).
- nvme-pci: merge init_request methods (FATE#323952, FATE#322506).
- nvme-pci: open-code polling logic in nvme_poll (FATE#323952,
  FATE#322506).
- nvme-pci: quiesce/unquiesce admin_q instead of start/stop its
  hw queues (FATE#323952, FATE#322506).
- nvme-pci: remap BAR0 to cover admin CQ doorbell for large stride
  (FATE#323952, FATE#322506).
- nvme-pci: remove redundant includes (FATE#323952, FATE#322506).
- nvme-pci: rename to nvme_pci_configure_admin_queue (FATE#323952,
  FATE#322506).
- nvme-pci: set cqe_seen on polled completions (FATE#323952,
  FATE#322506).
- nvme-pci: use dma memory for the host memory buffer descriptors
  (FATE#323952, FATE#322506).
- nvme: provide UUID value to userspace (FATE#323952,
  FATE#322506).
- nvme: queue ns scanning and async request from nvme_wq
  (FATE#323952, FATE#322506).
- nvme-rdma: Don't rearm the CQ when polling directly
  (FATE#323952, FATE#322506).
- nvme-rdma: Get rid of CONNECTED state (FATE#323952,
  FATE#322506).
- nvme-rdma: Make queue flags bit numbers and not shifts
  (FATE#323952, FATE#322506).
- nvme-rdma: default MR page size to 4k (FATE#323952,
  FATE#322506).
- nvme-rdma: fix error code in nvme_rdma_create_ctrl()
  (FATE#323952, FATE#322506).
- nvme-rdma: get rid of unused ctrl lock (FATE#323952,
  FATE#322506).
- nvme-rdma: make nvme_rdma_[create|destroy]_queue_ib symmetrical
  (FATE#323952, FATE#322506).
- nvme-rdma: merge init_request and exit_request methods
  (FATE#323952, FATE#322506).
- nvme-rdma: quiesce/unquiesce admin_q instead of start/stop
  its hw queues (FATE#323952, FATE#322506).
- nvme-rdma: rework rdma connection establishment error path
  (FATE#323952, FATE#322506).
- nvme-rdma: unconditionally recycle the request mr (FATE#323952,
  FATE#322506).
- nvme-rdma: update tagset nr_hw_queues after
  reconnecting/resetting (FATE#323952, FATE#322506).
- nvme: read the subsystem NQN from Identify Controller
  (FATE#323952, FATE#322506).
- nvme: remove a misleading comment on struct nvme_ns
  (FATE#323952, FATE#322506).
- nvme: rename uuid to nguid in nvme_ns (FATE#323952,
  FATE#322506).
- nvme: save hmpre and hmmin in struct nvme_ctrl (FATE#323952,
  FATE#322506).
- nvme: simplify nvme_dev_attrs_are_visible (FATE#323952,
  FATE#322506).
- nvme: split nvme_uninit_ctrl into stop and uninit (FATE#323952,
  FATE#322506).
- nvme: strip trailing 0-bytes in wwid_show (FATE#323952,
  FATE#322506).
- nvme: switch to uuid_t (FATE#323952, FATE#322506).
- nvme: use a single NVME_AQ_DEPTH and relax it to 32
  (FATE#323952, FATE#322506).
- nvme: use ctrl->device consistently for logging (FATE#323952,
  FATE#322506).
- nvme: validate admin queue before unquiesce (FATE#323952,
  FATE#322506).
- nvme.h: add dword 12 - 15 fields to struct nvme_features
  (FATE#323952, FATE#322506).
- nvme.h: add struct nvme_host_mem_buf_desc and HMB flags
  (FATE#323952, FATE#322506).
- nvme_fc: Fix crash when nvme controller connection fails
  (FATE#323952, FATE#322506).
- nvme_fc: fix double calls to nvme_cleanup_cmd() (FATE#323952,
  FATE#322506).
- nvme_fc: fix error recovery on link down (FATE#323952,
  FATE#322506).
- nvme_fc/nvmet_fc: revise Create Association descriptor length
  (FATE#323952, FATE#322506).
- nvme_fc: replace ioabort msleep loop with completion
  (FATE#323952, FATE#322506).
- nvmet: Move serial number from controller to subsystem
  (FATE#323952, FATE#322506).
- nvmet: add uuid field to nvme_ns and populate via configfs
  (FATE#323952, FATE#322506).
- nvmet: allow overriding the NVMe VS via configfs (FATE#323952,
  FATE#322506).
- nvmet: avoid unneeded assignment of submit_bio return value
  (FATE#323952, FATE#322506).
- nvmet: don't overwrite identify sn/fr with 0-bytes (FATE#323952,
  FATE#322506).
- nvmet: don't report 0-bytes in serial number (FATE#323952,
  FATE#322506).
- nvmet-fc: Remove a set-but-not-used variable (FATE#323952,
  FATE#322506).
- nvmet-fc: correct use after free on list teardown (FATE#323952,
  FATE#322506).
- nvmet-fc: eliminate incorrect static markers on local variables
  (FATE#323952, FATE#322506).
- nvmet-fc: fix byte swapping in nvmet_fc_ls_create_association
  (FATE#323952, FATE#322506).
- nvmet: implement namespace identify descriptor list
  (FATE#323952, FATE#322506).
- nvmet: prefix version configfs file with attr (FATE#323952,
  FATE#322506).
- nvmet: preserve controller serial number between reboots
  (FATE#323952, FATE#322506).
- nvmet-rdma: register ib_client to not deadlock in device removal
  (FATE#323952, FATE#322506).
- nvmet: use NVME_IDENTIFY_DATA_SIZE (FATE#323952, FATE#322506).
- nvmet_fc: Accept variable pad lengths on Create Association LS
  (FATE#323952, FATE#322506).
- nvmet_fc: add defer_req callback for deferment of cmd buffer
  return (FATE#323952, FATE#322506).
- nvmet_fc: fix crashes on bad opcodes (FATE#323952, FATE#322506).
- nvmf: keep track of nvmet connect error status (FATE#323952,
  FATE#322506).
- scatterlist: add sg_zero_buffer() helper (FATE#323952,
  FATE#322506).
- Delete
  patches.suse/0001-lightnvme-fix-compiling-error-for-blk_status_t.patch.
- commit b7fe62e
* Mon Sep 25 2017 mgorman@suse.de
- cpufreq, ondemand: Set default up_threshold to 40 on multi-core
  systems (bnc#464461,bnc#981838).
- commit 91e0473
* Mon Sep 25 2017 jthumshirn@suse.de
- series.conf: Move block-layer patches into sorted patch section
  Refresh
  patches.suse/0004-cfq-iosched-Delete-unused-function-min_vdisktime.patch.
- commit fec2137
* Mon Sep 25 2017 jthumshirn@suse.de
- series.conf: Let SCSI patches follow the upstream order and place them
  into the ordered section of series.conf
- commit 7b4f251
* Sun Sep 24 2017 msuchanek@suse.de
- rpm/kernel-binary.spec.in: only rewrite modules.dep if non-zero in size
  (bsc#1056979).
- commit 75691fd
* Sat Sep 23 2017 agraf@suse.de
- supported.conf: follow upstream rename of bcm2835-sdio to bcm2835
- commit e19f882
* Fri Sep 22 2017 tbogendoerfer@suse.de
- nfp: add whitelist of supported flow dissector (bsc#1055968).
- commit b6ed7d2
* Fri Sep 22 2017 tbogendoerfer@suse.de
- net_sched: fix reference counting of tc filter chain
  (bsc#1056787).
- commit 157c20a
* Fri Sep 22 2017 tbogendoerfer@suse.de
- move pcie relaxed order patches to sorted section for cxgb4
- commit 1ddb2fb
* Fri Sep 22 2017 lduncan@suse.com
- scsi: be2iscsi: Replace PCI pool old API (bsc#1050253).
- commit c409c57
* Thu Sep 21 2017 lduncan@suse.com
- scsi: bnx2i: Simplify cpu hotplug code (bsc#1050314).
- scsi: bnx2i: Prevent recursive cpuhotplug locking (bsc#1050314).
- commit 6746c96
* Thu Sep 21 2017 jroedel@suse.de
- KVM: SVM: Add irqchip_split() checks before enabling AVIC
  (bsc#1044503).
- KVM: Add struct kvm_vcpu pointer parameter to get_enable_apicv()
  (bsc#1044503).
- KVM: SVM: Refactor AVIC vcpu initialization into
  avic_init_vcpu() (bsc#1044503).
- commit ffdf86f
* Thu Sep 21 2017 jroedel@suse.de
- iommu/amd: Fix section mismatch warning (bsc#1043261).
- iommu/amd: Fix compiler warning in copy_device_table()
  (bsc#1043261).
- iommu/amd: Check if domain is NULL in get_domain() and return
  - EBUSY (bsc#1043261).
- iommu/amd: Disable iommu only if amd_iommu=off is specified
  (bsc#1043261).
- iommu/amd: Don't copy GCR3 table root pointer (bsc#1043261).
- iommu/amd: Allocate memory below 4G for dev table if translation
  pre-enabled (bsc#1043261).
- iommu/amd: Use is_attach_deferred call-back (bsc#1043261).
- iommu: Add is_attach_deferred call-back to iommu-ops
  (bsc#1043261).
- iommu/amd: Do sanity check for address translation and irq
  remap of old dev table entry (bsc#1043261).
- iommu/amd: Copy old trans table from old kernel (bsc#1043261).
- iommu/amd: Add function copy_dev_tables() (bsc#1043261).
- iommu/amd: Define bit fields for DTE particularly (bsc#1043261).
- Revert "iommu/amd: Suppress IO_PAGE_FAULTs in kdump kernel"
  (bsc#1043261).
- iommu/amd: Add several helper functions (bsc#1043261).
- iommu/amd: Detect pre enabled translation (bsc#1043261).
- commit 655c694
* Wed Sep 20 2017 mcgrof@suse.com
- xfs: XFS_IS_REALTIME_INODE() should be false if no rt device present (bsc#1058524).
- commit 72f8d25
* Wed Sep 20 2017 mcgrof@suse.com
- nl80211: check for the required netlink attributes presence (bsc#1058410 CVE-2017-12153).
- commit 8769ee8
* Wed Sep 20 2017 oneukum@suse.com
- ACPI / scan: Enable GPEs before scanning the namespace
  (FATE#323948).
- ACPICA: Dispatch active GPEs at init time (FATE#323948).
- ACPICA: Make it possible to enable runtime GPEs earlier
  (FATE#323948).
- Refresh patches.suse/0001-cpuidle-Fix-idle-time-tracking.patch.
- commit 029df21
* Wed Sep 20 2017 jroedel@suse.de
- KVM: SVM: delete avic_vm_id_bitmap (2 megabyte static array)
  (bsc#1059500).
- commit 6783c4c
* Wed Sep 20 2017 jroedel@suse.de
- KVM: SVM: Enable Virtual GIF feature (fate#323405).
- KVM: SVM: Add Virtual GIF feature definition (fate#323405).
- KVM: SVM: suppress unnecessary NMI singlestep on GIF=0 and
  nested exit (fate#323405).
- KVM: SVM: don't NMI singlestep over event injection
  (fate#323405).
- KVM: SVM: hide TF/RF flags used by NMI singlestep (fate#323405).
- KVM: nSVM: do not forward NMI window singlestep VM exits to L1
  (fate#323405).
- KVM: SVM: introduce disable_nmi_singlestep helper (fate#323405).
- commit 82b8a75
* Wed Sep 20 2017 jroedel@suse.de
- PCI: Restore PRI and PASID state after Function-Level Reset
  (fate#322865).
- PCI: Cache PRI and PASID bits in pci_dev (fate#322865).
- commit 085d4a7
* Wed Sep 20 2017 tiwai@suse.de
- qxl: fix pinning (bsc#1057241,bsc#1057123).
- qxl: fix primary surface handling (bsc#1057241,bsc#1057123).
- commit 7c6173e
* Tue Sep 19 2017 jslaby@suse.cz
- objtool: Fix object file corruption (bnc#1058115).
- objtool: Do not retrieve data from empty sections (bnc#1058115).
- objtool: Fix memory leak in elf_create_rela_section()
  (bnc#1058115).
- commit 964c24f
* Mon Sep 18 2017 jthumshirn@suse.de
- Update
  patches.suse/0123-blk-mq-map-all-HWQ-also-in-hyperthreaded-system.patch
  (FATE#1054937).
  The patch has a FATE entry for itself, tag it correctly.
- commit 822ef07
* Mon Sep 18 2017 jack@suse.cz
- orangefs: Don't clear SGID when inheriting ACLs (bsc#1052766).
- commit a58e862
* Mon Sep 18 2017 colyli@suse.de
- Delete patches.drivers/0003-dm-integrity-test-for-corrupted-disk-format-during-t.patch,
  it is in patches.kernel.org/patch-4.12.4-5 already.
- commit cbab9c7
* Sun Sep 17 2017 colyli@suse.de
- lightnvme: fix compiling error for blk_status_t
  (fate#322738,fate#322919,fate#322950,fate#323773).
- commit 12a6d58
* Sat Sep 16 2017 mcgrof@suse.com
- supported.conf: add test_firmware to new kselftests-kmp package FATE#323821
  This test drivers is present on vanilla so we also enable it there.
- Update config files.
- supported.conf:
- commit cd2246a
* Sat Sep 16 2017 mcgrof@suse.com
- supported.conf: add test_syctl to new kselftests-kmp package FATE#323821
  As per FATE#323821 we will require new FATE requests per each
  new selftest driver. We don't want to support these module on
  production runs but we do want to support them for QA / testing
  uses. The compromise is to package them into its own package,
  this will be the kselftests-kmp package.
  Selftests can also be used as proof of concept vehicle for issues
  by customers or ourselves.
  Vanilla kernels do not get test_sysctl given that driver was
  using built-in defaults, this also means we cannot run sefltests
  on config/s390x/zfcpdump which does not enable modules.
  Likeweise, since we had to *change* the kernel for test_syctl, it
  it also means we can't test test_syctl with vanilla kernels. It
  should be possible with other selftests drivers if they are
  present in vanilla kernels though.
- Update config files.
- rpm/package-descriptions:
- supported.conf:
- commit 40c878b
* Sat Sep 16 2017 mcgrof@suse.com
- test_firmware: add batched firmware tests (FATE#323821).
- commit b825e51
* Sat Sep 16 2017 mcgrof@suse.com
- test_firmware: add test case for SIGCHLD on sync fallback (FATE#323821).
- commit 616e12d
* Sat Sep 16 2017 mcgrof@suse.com
- firmware: enable a debug print for batched requests (FATE#323821).
- commit 9d0e61c
* Sat Sep 16 2017 mcgrof@suse.com
- firmware: define pr_fmt (FATE#323821).
- commit b59ec48
* Sat Sep 16 2017 mcgrof@suse.com
- firmware: send -EINTR on signal abort on fallback mechanism (FATE#323821).
- commit 47321c2
* Sat Sep 16 2017 mcgrof@suse.com
- test_sysctl: fix sysctl.sh by making it executable (FATE#323821).
- commit 7287239
* Sat Sep 16 2017 mcgrof@suse.com
- test_sysctl: test against int proc_dointvec() array support (FATE#323821).
- commit 291f702
* Sat Sep 16 2017 mcgrof@suse.com
- test_sysctl: add simple proc_douintvec() case (FATE#323821).
- commit 3e388c4
* Sat Sep 16 2017 mcgrof@suse.com
- test_sysctl: add simple proc_dointvec() case (FATE#323821).
- commit 12b82e3
* Sat Sep 16 2017 mcgrof@suse.com
- test_sysctl: test against PAGE_SIZE for int (FATE#323821).
- commit 59a85c2
* Sat Sep 16 2017 mcgrof@suse.com
- test_sysctl: add generic script to expand on tests (FATE#323821).
- commit c47b649
* Sat Sep 16 2017 mcgrof@suse.com
- test_sysctl: add dedicated proc sysctl test driver (FATE#323821).
- commit e27658a
* Sat Sep 16 2017 mcgrof@suse.com
- tools/testing/selftests/sysctl: Add pre-check to the value of writes_strict (FATE#323821).
- commit 784faa7
* Sat Sep 16 2017 mcgrof@suse.com
- sysctl: add unsigned int range support (FATE#323821).
- commit 9ccbe48
* Sat Sep 16 2017 mcgrof@suse.com
- sysctl: simplify unsigned int support (bsc#1048893).
- commit 5e5055c
* Sat Sep 16 2017 mcgrof@suse.com
- sysctl: fold sysctl_writes_strict checks into helper (bsc#1048893).
- commit c687140
* Sat Sep 16 2017 mcgrof@suse.com
- sysctl: kdoc'ify sysctl_writes_strict (bsc#1048893).
- commit 1c8d7a1
* Sat Sep 16 2017 mcgrof@suse.com
- sysctl: fix lax sysctl_check_table() sanity check (bsc#1048893).
- commit 626023a
* Fri Sep 15 2017 jroedel@suse.de
- kvm: nVMX: Don't allow L2 to access the hardware CR8
  (bsc#1058507, CVE-2017-12154).
- KVM: Don't accept obviously wrong gsi values via KVM_IRQFD
  (bsc#1058038, CVE-2017-1000252).
- KVM: VMX: Do not BUG() on out-of-bounds guest IRQ (bsc#1058038,
  CVE-2017-1000252).
- commit 7aeea59
* Fri Sep 15 2017 jslaby@suse.cz
- objtool: Assume unannotated UD2 instructions are dead ends
  (bnc#1058115).
- objtool: Fix gcov check for older versions of GCC (bnc#1058115).
- objtool: Fix objtool fallthrough detection with function padding
  (bnc#1058115).
- objtool: Fix validate_branch() return codes (bnc#1058115).
- objtool: Handle GCC stack pointer adjustment bug (bnc#1058115).
- x86/asm: Add ASM_UNREACHABLE (bnc#1058115).
- x86/asm: Fix UNWIND_HINT_REGS macro for older binutils
  (bnc#1058115).
- x86/asm: Make objtool unreachable macros independent from GCC
  version (bnc#1058115).
- objtool: Skip unreachable warnings for 'alt' instructions
  (bnc#1058115).
- objtool: Track DRAP separately from callee-saved registers
  (bnc#1058115).
- objtool: Fix '-mtune=atom' decoding support in objtool 2.0
  (bnc#1058115).
- Refresh patches.suse/0001-x86-unwind-Add-the-ORC-unwinder.patch.
  Take all ORC upstream patches to be up-to-date.
- commit 5dc7bd3
* Fri Sep 15 2017 jslaby@suse.cz
- Refresh
  patches.suse/0001-x86-entry-64-Refactor-IRQ-stacks-and-make-them-NMI-s.patch.
- Refresh patches.suse/0001-x86-unwind-Add-the-ORC-unwinder.patch.
- Refresh
  patches.suse/0002-dwarf-do-not-throw-away-unwind-info.patch.
- Refresh
  patches.suse/0002-objtool-x86-Add-several-functions-and-files-to-the-o.patch.
- Refresh
  patches.suse/0002-x86-entry-64-Initialize-the-top-of-the-IRQ-stack-bef.patch.
- Refresh
  patches.suse/0002-x86-kconfig-Make-it-easier-to-switch-to-the-new-ORC-.patch.
- Refresh
  patches.suse/0003-x86-dumpstack-Fix-occasionally-missing-registers.patch.
- Refresh
  patches.suse/0003-x86-kconfig-Consolidate-unwinders-into-multiple-choi.patch.
- Refresh
  patches.suse/0004-x86-dumpstack-Fix-interrupt-and-exception-stack-boun.patch.
- Refresh
  patches.suse/0005-objtool-Add-ORC-unwind-table-generation.patch.
- Refresh
  patches.suse/0006-objtool-x86-Add-facility-for-asm-code-to-provide-unw.patch.
- Refresh
  patches.suse/0007-x86-entry-64-Add-unwind-hint-annotations.patch.
- Refresh
  patches.suse/0008-x86-asm-Add-unwind-hint-annotations-to-sync_core.patch.
- Delete
  patches.suse/0001-linkage-new-macros-for-assembler-symbols.patch.
- Delete
  patches.suse/0002-dwarf-do-not-throw-away-unwind-info.patch.
- Delete
  patches.suse/0003-DWARF-EH-frame-based-stack-unwinding.patch.
- Delete patches.suse/stack-unwind-disable-kasan.patch.
  Update upstream status of ORC and drop already-disabled DWARF
  unwinder.
- commit 87cb5c8
* Fri Sep 15 2017 oneukum@suse.com
- thunderbolt: Fix reset response_type (FATE#323948).
- thunderbolt: Allow clearing the key (FATE#323948).
- thunderbolt: Make key root-only accessible (FATE#323948).
- thunderbolt: Remove superfluous check (FATE#323948).
- thunderbolt: Do not enumerate more ports from DROM than the
  controller has (FATE#323948).
- thunderbolt: icm: Ignore mailbox errors in icm_suspend()
  (FATE#323948).
- thunderbolt: Correct access permissions for active NVM contents
  (FATE#323948).
- thunderbolt: fix spelling mistake: "missmatch" -> "mismatch"
  (FATE#323948).
- thunderbolt: Add support for host and device NVM firmware
  upgrade (FATE#323948).
- thunderbolt: Add support for Internal Connection Manager (ICM)
  (FATE#323948).
- thunderbolt: Do not touch the hardware if the NHI is gone on
  resume (FATE#323948).
- thunderbolt: Add support for DMA configuration based mailbox
  (FATE#323948).
- thunderbolt: Store Thunderbolt generation in the switch
  structure (FATE#323948).
- thunderbolt: Add support for NHI mailbox (FATE#323948).
- thunderbolt: Add new Thunderbolt PCI IDs (FATE#323948).
- thunderbolt: Rework control channel to be more reliable
  (FATE#323948).
- thunderbolt: Let the connection manager handle all notifications
  (FATE#323948).
- thunderbolt: Expose make_header() to other files (FATE#323948).
- thunderbolt: Expose get_route() to other files (FATE#323948).
- thunderbolt: Move control channel messages to tb_msgs.h
  (FATE#323948).
- thunderbolt: Read vendor and device name from DROM
  (FATE#323948).
- thunderbolt: Refactor and fix parsing of port drom entries
  (FATE#323948).
- thunderbolt: Do not fail if DROM data CRC32 is invalid
  (FATE#323948).
- thunderbolt: Fail switch adding operation if reading DROM fails
  (FATE#323948).
- thunderbolt: Convert switch to a device (FATE#323948).
- thunderbolt: Introduce thunderbolt bus and connection manager
  (FATE#323948).
- thunderbolt: Allow passing NULL to tb_ctl_free() (FATE#323948).
- thunderbolt: Rework capability handling (FATE#323948).
- thunderbolt: Add MSI-X support (FATE#323948).
- thunderbolt: Do not warn about newer DROM versions
  (FATE#323948).
- thunderbolt: Do not try to read UID if DROM offset is read as 0
  (FATE#323948).
- commit dc02c6e
* Fri Sep 15 2017 oneukum@suse.com
- thunderbolt: No need to read UID of the root switch on resume
  (FATE#323948).
- thunderbolt: Use const buffer pointer in write operations
  (FATE#323948).
- commit 4cfbced
* Fri Sep 15 2017 mgorman@suse.de
- Refresh
  patches.suse/sched-wait-Break-up-long-wake-list-walk.patch.
- Refresh
  patches.suse/sched-wait-Introduce-wakeup-boomark-in-wake_up_page_bit.patch.
- commit 9f181ab
* Fri Sep 15 2017 mgorman@suse.de
- cpufreq, intel_pstate: Use setpoint of 40%% on servers (bnc#945201).
- commit d39e8fb
* Fri Sep 15 2017 bpoirier@suse.com
- Refresh
  patches.drivers/net-phy-Make-phy_ethtool_ksettings_get-return-void.patch.
  There was a tiny bit of whitespace difference with the upstream commit.
  Correct it in the interest of keeping the expected context.
- commit e744926
* Fri Sep 15 2017 bpoirier@suse.com
- Refresh patch order in networking section
- commit b2d9582
* Thu Sep 14 2017 tbogendoerfer@suse.de
- netpoll: shut up a kernel warning on refcount (bsc#1046306
  FATE#322942 bsc#1056787).
- commit 26241d7
* Thu Sep 14 2017 tbogendoerfer@suse.de
- Update config files.
  Enabled SECURITY_INFINIBAND
- commit 8c7c6ab
* Thu Sep 14 2017 tbogendoerfer@suse.de
- IB/hfi1: update to new mmu_notifier semantic (bsc#1046306
  FATE#322942).
- IB/umem: update to new mmu_notifier semantic (bsc#1046306
  FATE#322942).
- IB/core: Avoid accessing non-allocated memory when inferring
  port type (bsc#1046306 FATE#322942).
- IB/uverbs: Fix NULL pointer dereference during device removal
  (bsc#1046306 FATE#322942).
- IB/core: Protect sysfs entry on ib_unregister_device
  (bsc#1046306 FATE#322942).
- RDMA/vmw_pvrdma: Report CQ missed events (bsc#1046306
  FATE#322942).
- IB/ipoib: Notify on modify QP failure only when relevant
  (bsc#1046307 FATE#322941).
- Revert "IB/core: Allow QP state transition from reset to error"
  (bsc#1046306 FATE#322942).
- IB/ipoib: Remove double pointer assigning (bsc#1046307
  FATE#322941).
- IB/ipoib: Clean error paths in add port (bsc#1046307
  FATE#322941).
- IB/ipoib: Add get statistics support to SRIOV VF (bsc#1046307
  FATE#322941).
- IB/ipoib: Add multicast packets statistics (bsc#1046307
  FATE#322941).
- IB/ipoib: Set IPOIB_NEIGH_TBL_FLUSH after flushed completion
  initialization (bsc#1046307 FATE#322941).
- IB/ipoib: Prevent setting negative values to max_nonsrq_conn_qp
  (bsc#1046307 FATE#322941).
- IB/ipoib: Make sure no in-flight joins while leaving that mcast
  (bsc#1046307 FATE#322941).
- IB/ipoib: Use cancel_delayed_work_sync when needed (bsc#1046307
  FATE#322941).
- IB/ipoib: Fix race between light events and interface restart
  (bsc#1046307 FATE#322941).
- IB/uverbs: Fix device cleanup (bsc#1046306 FATE#322942).
- RDMA/uverbs: Prevent leak of reserved field (bsc#1046306
  FATE#322942).
- IB/core: Fix race condition in resolving IP to MAC (bsc#1046306
  FATE#322942).
- IB/cma: Fix reference count leak when no ipv4 addresses are set
  (bsc#1046306 FATE#322942).
- IB/rdmavt: Setting of QP timeout can overflow jiffies
  computation (bsc#1058717 FATE#322789).
- IB/core: Fix sparse warnings (bsc#1046306 FATE#322942).
- IB/IPoIB: Fix error code in ipoib_add_port() (bsc#1046307
  FATE#322941).
- IB/core: Allow QP state transition from reset to error
  (bsc#1046306 FATE#322942).
- IB/ipoib: Let lower driver handle get_stats64 call (bsc#1046307
  FATE#322941).
- IB/core: Add ordered workqueue for RoCE GID management
  (bsc#1046306 FATE#322942).
- IB/core: Remove NOIO QP create flag (bsc#1046306 FATE#322942).
- IB/{rdmavt, qib, hfi1}: Remove gfp flags argument (bsc#1046306
  FATE#322942 bsc#1027067 FATE#322649 bsc#1058717 FATE#322789).
- IB/IPoIB: Convert IPoIB to memalloc_noio_* calls (bsc#1046307
  FATE#322941).
- IB/IPoIB: Forward MTU change to driver below (bsc#1046307
  FATE#322941).
- IB/uverbs: Make use of ib_modify_qp variant to avoid resolving
  DMAC (bsc#1046306 FATE#322942).
- IB/core: Introduce modify QP operation with udata (bsc#1046306
  FATE#322942).
- IB/core: Don't resolve IP address to the loopback device
  (bsc#1046306 FATE#322942).
- RDMA/core: Document confusing code (bsc#1046306 FATE#322942).
- IB/hfi1: Ensure dd->gi_mask can not be overflowed (bsc#1046306
  FATE#322942).
- IB/srpt: Make a debug statement in srpt_abort_cmd() more
  informative (bsc#1046306 FATE#322942).
- IB/core: Fix static analysis warning in ib_policy_change_task
  (bsc#1046306 FATE#322942).
- IB/core: Fix uninitialized variable use in
  check_qp_port_pkey_settings (bsc#1046306 FATE#322942).
- IB/core, opa_vnic, hfi1, mlx5: Properly free rdma_netdev
  (bsc#1046306 FATE#322942 bsc#1046305 FATE#322943).
- IB/opa_vnic: Use spinlock instead of mutex for stats_lock
  (bsc#1046306 FATE#322942).
- IB/opa_vnic: Use GFP_ATOMIC while sending trap (bsc#1046306
  FATE#322942).
- net: convert sk_buff.users from atomic_t to refcount_t
  (bsc#1046306 FATE#322942 bsc#1056787).
- net: add netlink_ext_ack argument to rtnl_link_ops.changelink
  (bsc#1046306 FATE#322942 bsc#1056787).
- net: add netlink_ext_ack argument to rtnl_link_ops.newlink
  (bsc#1046306 FATE#322942 bsc#1056787).
- IB/core: Enforce security on management datagrams (bsc#1046306
  FATE#322942).
- selinux lsm IB/core: Implement LSM notification system
  (bsc#1046306 FATE#322942).
- IB/core: Enforce PKey security on QPs (bsc#1046306 FATE#322942).
- IB/core: IB cache enhancements to support Infiniband security
  (bsc#1046306 FATE#322942).
- commit 2779070
* Thu Sep 14 2017 tbogendoerfer@suse.de
- Delete
  patches.drivers/IB-core-opa_vnic-hfi1-mlx5-Properly-free-rdma_netdev.patch.
  Patch will be re-done during IBcore commits
- commit 080979b
* Thu Sep 14 2017 msuchanek@suse.de
- powerpc/perf: POWER9 PMU stops after idle workaround
  (bsc#1056686).
- commit e5b99d6
* Thu Sep 14 2017 acho@suse.com
- Bluetooth: Properly check L2CAP config option output buffer
  length (bsc#1057389 CVE-2017-1000251).
- commit 6e305d4
* Thu Sep 14 2017 tbogendoerfer@suse.de
- IB/cxgb3: Fix error codes in iwch_alloc_mr() (bsc#1046534
  FATE#322935).
- commit fb70667
* Thu Sep 14 2017 colyli@suse.de
- blacklist.conf: update not-backport commit id
- commit 65bc4e8
* Thu Sep 14 2017 colyli@suse.de
- dm mpath: retry BLK_STS_RESOURCE errors
  (fate#322738,fate#322919,fate#322950,fate#323773).
- blacklist.conf: add not-backport commits
- dm: fix the second dec_pending()
  argument in __split_and_process_bio()
  (fate#322738,fate#322919,fate#322950,fate#323773).
- block: Fix two comments that refer to .queue_rq() return values
  (fate#322738,fate#322919,fate#322950,fate#323773).
- commit 1bf9ecf
* Thu Sep 14 2017 tbogendoerfer@suse.de
- i40iw: Fix potential fcn_id_array out of bounds (bsc#1058659
  FATE#322535).
- i40iw: Use correct alignment for CQ0 memory (bsc#1058659
  FATE#322535).
- i40iw: Fix typecast of tcp_seq_num (bsc#1058659 FATE#322535).
- i40iw: Correct variable names (bsc#1058659 FATE#322535).
- i40iw: Fix parsing of query/commit FPM buffers (bsc#1058659
  FATE#322535).
- IB/i40iw: Fix error code in i40iw_create_cq() (bsc#1058659
  FATE#322535).
- i40iw: Free QP PBLEs when the QP is destroyed (bsc#1058659
  FATE#322535).
- i40iw: Avoid memory leak of CQP request objects (bsc#1058659
  FATE#322535).
- i40iw: Update list correctly (bsc#1058659 FATE#322535).
- i40iw: Add missing memory barrier (bsc#1058659 FATE#322535).
- i40iw: Free QP resources on CQP destroy QP failure (bsc#1058659
  FATE#322535).
- i40iw: Release cm_id ref on PCI function reset (bsc#1058659
  FATE#322535).
- i40iw: Utilize iwdev->reset during PCI function reset
  (bsc#1058659 FATE#322535).
- i40iw: Do not poll CCQ after it is destroyed (bsc#1058659
  FATE#322535).
- i40iw: Fix order of cleanup in close (bsc#1058659 FATE#322535).
- commit eebe943
* Thu Sep 14 2017 tbogendoerfer@suse.de
- Resorted network driver section
- commit c5fe18c
* Wed Sep 13 2017 colyli@suse.de
- MD: fix warnning for UP case
  (fate#322738,fate#322919,fate#322950,fate#323773).
- md: simplify code with bio_io_error
  (fate#322738,fate#322919,fate#322950,fate#323773).
- md: raid1-10: move raid1/raid10 common code into raid1-10.c
  (fate#322738,fate#322919,fate#322950,fate#323773).
- md: raid1/raid10: initialize bvec table via bio_add_page()
  (fate#322738,fate#322919,fate#322950,fate#323773).
- raid5-ppl: use BIOSET_NEED_BVECS when creating bioset
  (fate#322738,fate#322919,fate#322950,fate#323773).
- md/bitmap: don't read page from device with Bitmap_sync
  (fate#322738,fate#322919,fate#322950,fate#323773).
- block: add support for write hints in a bio
  (fate#322738,fate#322919,fate#322950,fate#323773).
- MD: fix a null dereference
  (fate#322738,fate#322919,fate#322950,fate#323773).
- commit dbbe938
* Wed Sep 13 2017 colyli@suse.de
- series.conf: change patche apply order.
- move patches.suse/0036-md-cluster-remove-EXPERIMENTAL-info.patch to
  be applied after patches.fixes/0001-md-use-a-separate-bio_set-for-synchronous-IO.patch
- commit 2979567
* Wed Sep 13 2017 tiwai@suse.de
- rpm/kernel-docs.spec.in: Fix a thinko for xmlto buildreq condition
- commit 9d160ac
* Wed Sep 13 2017 msuchanek@suse.de
- powerpc/perf: Update default sdar_mode value for power9
  (bsc#1056686).
- commit 5c31f3d
* Wed Sep 13 2017 msuchanek@suse.de
- powerpc/perf: Cleanup of PM_BR_CMPL vs. PM_BRU_CMPL in Power9
  event list (bsc#1056686).
- commit ad2bb5c
* Wed Sep 13 2017 jkosina@suse.cz
- Update config files: enable USB-C in -vanilla as well
  Fixes: 7e26cc6a2a52f439e815997690146c51503f56dd
- commit c5e1b9f
* Wed Sep 13 2017 msuchanek@suse.de
- powerpc/perf: Avoid spurious PMU interrupts after idle
  (bsc#1056686).
- commit 21fff50
* Wed Sep 13 2017 msuchanek@suse.de
- powerpc/64s: Invalidate ERAT on powersave wakeup for POWER9
  (bsc#1056686).
- commit 037cb86
* Wed Sep 13 2017 colyli@suse.de
- dm kcopyd: add sequential write feature
  (fate#322738,fate#322919,fate#322950,fate#323773).
- dm linear: add support for zoned block devices
  (fate#322738,fate#322919,fate#322950,fate#323773).
- dm flakey: add support for zoned block devices
  (fate#322738,fate#322919,fate#322950,fate#323773).
- dm: introduce dm_remap_zone_report()
  (fate#322738,fate#322919,fate#322950,fate#323773).
- dm: fix REQ_OP_ZONE_REPORT bio handling
  (fate#322738,fate#322919,fate#322950,fate#323773).
- dm: fix REQ_OP_ZONE_RESET bio handling
  (fate#322738,fate#322919,fate#322950,fate#323773).
- dm table: add zoned block devices validation
  (fate#322738,fate#322919,fate#322950,fate#323773).
- dm crypt: add big-endian variant of plain64 IV
  (fate#322738,fate#322919,fate#322950,fate#323773).
- dm bio prison: use rb_entry() rather than container_of()
  (fate#322738,fate#322919,fate#322950,fate#323773).
- dm ioctl: report event number in DM_LIST_DEVICES
  (fate#322738,fate#322919,fate#322950,fate#323773).
- dm ioctl: add a new DM_DEV_ARM_POLL ioctl
  (fate#322738,fate#322919,fate#322950,fate#323773).
- dm: add basic support for using the select or poll function
  (fate#322738,fate#322919,fate#322950,fate#323773).
- dm verity fec: fix GFP flags used with mempool_alloc()
  (fate#322738,fate#322919,fate#322950,fate#323773).
- dm zoned: use GFP_NOIO in I/O path
  (fate#322738,fate#322919,fate#322950,fate#323773).
- dm zoned: remove test for impossible REQ_OP_FLUSH conditions
  (fate#322738,fate#322919,fate#322950,fate#323773).
- dm raid: bump target version
  (fate#322738,fate#322919,fate#322950,fate#323773).
- dm raid: avoid mddev->suspended access
  (fate#322738,fate#322919,fate#322950,fate#323773).
- dm raid: fix activation check in validate_raid_redundancy()
  (fate#322738,fate#322919,fate#322950,fate#323773).
- dm raid: remove WARN_ON() in raid10_md_layout_to_format()
  (fate#322738,fate#322919,fate#322950,fate#323773).
- dm bufio: fix error code in dm_bufio_write_dirty_buffers()
  (fate#322738,fate#322919,fate#322950,fate#323773).
- dm integrity: test for corrupted disk format during table load
  (fate#322738,fate#322919,fate#322950,fate#323773).
- dm integrity: WARN_ON if variables
  representing journal usage get out of sync
  (fate#322738,fate#322919,fate#322950,fate#323773).
- dm integrity: use plugging when writing the journal
  (fate#322738,fate#322919,fate#322950,fate#323773).
- commit 1a13da0
* Wed Sep 13 2017 colyli@suse.de
- Allow a queue to request that timeouts don't get rounded up
  (bnc#768084).
- mtd: blkdevs: Fix mtd block write failure
  (fate#322738,fate#322919,fate#322950,fate#323773).
- bio-integrity: only verify integrity on the lowest stacked
  driver (fate#322738,fate#322919,fate#322950,fate#323773).
- bio-integrity: Fix regression if profile verify_fn is NULL
  (fate#322738,fate#322919,fate#322950,fate#323773).
- xen-blkfront: Fix handling of non-supported operations
  (fate#322738,fate#322919,fate#322950,fate#323773).
- blk-mq: map queues to all present CPUs
  (fate#322738,fate#322919,fate#322950,fate#323773).
- blk-mq: map all HWQ also in hyperthreaded system
  (fate#322738,fate#322919,fate#322950,fate#323773).
- bcache.txt: standardize document format
  (fate#322738,fate#322919,fate#322950,fate#323773).
- bfq: dispatch request to prevent queue
  stalling after the request completion
  (fate#322738,fate#322919,fate#322950,fate#323773).
- bfq: fix typos in comments about B-WF2Q+ algorithm
  (fate#322738,fate#322919,fate#322950,fate#323773).
- block: call bio_uninit in bio_endio
  (fate#322738,fate#322919,fate#322950,fate#323773).
- block: Fix __blkdev_issue_zeroout loop
  (fate#322738,fate#322919,fate#322950,fate#323773).
- dm zoned: fix overflow when converting zone ID to sectors
  (fate#322738,fate#322919,fate#322950,fate#323773).
- bio-integrity: fix boolreturn.cocci warnings
  (fate#322738,fate#322919,fate#322950,fate#323773).
- bio-integrity: stop abusing bi_end_io
  (fate#322738,fate#322919,fate#322950,fate#323773).
- bio-integrity: Restore original iterator on verify stage
  (fate#322738,fate#322919,fate#322950,fate#323773).
- block: remove the unused bio_to_phys macro
  (fate#322738,fate#322919,fate#322950,fate#323773).
- bio: add bvec_iter rewind API
  (fate#322738,fate#322919,fate#322950,fate#323773).
- block: guard bvec iteration logic
  (fate#322738,fate#322919,fate#322950,fate#323773).
- bio-integrity: fold bio_integrity_enabled to bio_integrity_prep
  (fate#322738,fate#322919,fate#322950,fate#323773).
- bio-integrity: fix interface for bio_integrity_trim
  (fate#322738,fate#322919,fate#322950,fate#323773).
- bio-integrity: bio_integrity_advance must update integrity seed
  (fate#322738,fate#322919,fate#322950,fate#323773).
- bio-integrity: bio_trim should truncate integrity vector
  accordingly (fate#322738,fate#322919,fate#322950,fate#323773).
- blk-mq-sched: fix performance regression of mq-deadline
  (fate#322738,fate#322919,fate#322950,fate#323773).
- block, bfq: don't change ioprio class for a bfq_queue on a
  service tree (fate#322738,fate#322919,fate#322950,fate#323773).
- block, bfq: update wr_busy_queues if needed on a queue split
  (fate#322738,fate#322919,fate#322950,fate#323773).
- dm: don't set bounce limit
  (fate#322738,fate#322919,fate#322950,fate#323773).
- block: don't set bounce limit in blk_init_queue
  (fate#322738,fate#322919,fate#322950,fate#323773).
- block: don't set bounce limit in blk_init_allocated_queue
  (fate#322738,fate#322919,fate#322950,fate#323773).
- blk-mq: don't bounce by default
  (fate#322738,fate#322919,fate#322950,fate#323773).
- block: don't bother with bounce limits for make_request drivers
  (fate#322738,fate#322919,fate#322950,fate#323773).
- block: remove the queue_bounce_pfn helper
  (fate#322738,fate#322919,fate#322950,fate#323773).
- block: move bounce declarations to block/blk.h
  (fate#322738,fate#322919,fate#322950,fate#323773).
- blk-map: call blk_queue_bounce from blk_rq_append_bio
  (fate#322738,fate#322919,fate#322950,fate#323773).
- blk-mq: expose write hints through debugfs
  (fate#322738,fate#322919,fate#322950,fate#323773).
- dm zoned: drive-managed zoned block device target
  (fate#322738,fate#322919,fate#322950,fate#323773).
  Update: add DM_ZONED (is not set) to configs due to pick the above patch.
- blk-mq: remove double set queue_num
  (fate#322738,fate#322919,fate#322950,fate#323773).
- blk-mq: Make it safe to quiesce and unquiesce from an interrupt
  handler (fate#322738,fate#322919,fate#322950,fate#323773).
- block: Fix off-by-one errors in
  blk_status_to_errno() and print_req_error()
  (fate#322738,fate#322919,fate#322950,fate#323773).
- block: Declare local symbols static
  (fate#322738,fate#322919,fate#322950,fate#323773).
- block: Add fallthrough markers to switch statements
  (fate#322738,fate#322919,fate#322950,fate#323773).
- blk-mq: Warn when attempting to run a hardware queue that is
  not mapped (fate#322738,fate#322919,fate#322950,fate#323773).
- block: Constify disk_type
  (fate#322738,fate#322919,fate#322950,fate#323773).
- blk-mq: Document locking assumptions
  (fate#322738,fate#322919,fate#322950,fate#323773).
- block: Document what queue type each function is intended for
  (fate#322738,fate#322919,fate#322950,fate#323773).
- block: Check locking assumptions at runtime
  (fate#322738,fate#322919,fate#322950,fate#323773).
- blk-mq: Initialize .rq_flags in blk_mq_rq_ctx_init()
  (fate#322738,fate#322919,fate#322950,fate#323773).
- block: Change argument type of scsi_req_init()
  (fate#322738,fate#322919,fate#322950,fate#323773).
- block: Make most scsi_req_init() calls implicit
  (fate#322738,fate#322919,fate#322950,fate#323773).
- block: Introduce request_queue.initialize_rq_fn()
  (fate#322738,fate#322919,fate#322950,fate#323773).
- block: Make request operation type argument declarations
  consistent (fate#322738,fate#322919,fate#322950,fate#323773).
- blk-mq: Reduce blk_mq_hw_ctx size
  (fate#322738,fate#322919,fate#322950,fate#323773).
- block: return on congested block device
  (fate#322738,fate#322919,fate#322950,fate#323773).
- Revert "blk-mq: don't use sync workqueue flushing from drivers"
  (fate#322738,fate#322919,fate#322950,fate#323773).
- blk-mq: clarify dispatch may not be drained/blocked by stopping
  queue (fate#322738,fate#322919,fate#322950,fate#323773).
- blk-mq: don't stop queue for quiescing
  (fate#322738,fate#322919,fate#322950,fate#323773).
- blk-mq: update comments on blk_mq_quiesce_queue()
  (fate#322738,fate#322919,fate#322950,fate#323773).
- blk-mq: use QUEUE_FLAG_QUIESCED to quiesce queue
  (fate#322738,fate#322919,fate#322950,fate#323773).
- blk-mq: use the introduced blk_mq_unquiesce_queue()
  (fate#322738,fate#322919,fate#322950,fate#323773).
- blk-mq: introduce blk_mq_unquiesce_queue
  (fate#322738,fate#322919,fate#322950,fate#323773).
- blk-mq: introduce blk_mq_quiesce_queue_nowait()
  (fate#322738,fate#322919,fate#322950,fate#323773).
- blk-mq: move blk_mq_quiesce_queue() into include/linux/blk-mq.h
  (fate#322738,fate#322919,fate#322950,fate#323773).
- block: don't check for BIO_MAX_PAGES in blk_bio_segment_split()
  (fate#322738,fate#322919,fate#322950,fate#323773).
- block: remove bio_clone() and all references
  (fate#322738,fate#322919,fate#322950,fate#323773).
- xen-blkfront: remove bio splitting
  (fate#322738,fate#322919,fate#322950,fate#323773).
- rbd: use bio_clone_fast() instead of bio_clone()
  (fate#322738,fate#322919,fate#322950,fate#323773).
- drbd: use bio_clone_fast() instead of bio_clone()
  (fate#322738,fate#322919,fate#322950,fate#323773).
- pktcdvd: Check queue type before attaching to a queue
  (fate#322738,fate#322919,fate#322950,fate#323773).
- pktcdvd: remove the call to blk_queue_bounce
  (fate#322738,fate#322919,fate#322950,fate#323773).
- pktcdvd: use bio_clone_fast() instead of bio_clone()
  (fate#322738,fate#322919,fate#322950,fate#323773).
- pktcdvd: use class_groups instead of class_attrs
  (fate#322738,fate#322919,fate#322950,fate#323773).
- bcache: use kmalloc to allocate bio in bch_data_verify()
  (fate#322738,fate#322919,fate#322950,fate#323773).
- block: Improvements to bounce-buffer handling
  (fate#322738,fate#322919,fate#322950,fate#323773).
- blk: use non-rescuing bioset for q->bio_split
  (fate#322738,fate#322919,fate#322950,fate#323773).
- blk: make the bioset rescue_workqueue optional
  (fate#322738,fate#322919,fate#322950,fate#323773).
- blk: replace bioset_create_nobvec() with a flags arg to bioset_create()
  (fate#322738,fate#322919,fate#322950,fate#323773).
  Update: patches.fixes/0001-md-use-a-separate-bio_set-for-synchronous-IO.patch
  rebase this patch to follow change of bioset_create() from the above patch.
- blk: remove bio_set arg from blk_queue_split()
  (fate#322738,fate#322919,fate#322950,fate#323773).
- blk-mq: remove __blk_mq_alloc_request
  (fate#322738,fate#322919,fate#322950,fate#323773).
- blk-mq-sched: unify request prepare methods
  (fate#322738,fate#322919,fate#322950,fate#323773).
- blk-mq: refactor blk_mq_sched_assign_ioc
  (fate#322738,fate#322919,fate#322950,fate#323773).
- bfq-iosched: fix NULL ioc check in bfq_get_rq_private
  (fate#322738,fate#322919,fate#322950,fate#323773).
- blk-mq: streamline blk_mq_get_request
  (fate#322738,fate#322919,fate#322950,fate#323773).
- blk-mq: simplify blk_mq_free_request
  (fate#322738,fate#322919,fate#322950,fate#323773).
- blk-mq-sched: unify request finished methods
  (fate#322738,fate#322919,fate#322950,fate#323773).
- blk-mq: remove blk_mq_sched_{get,put}_rq_priv
  (fate#322738,fate#322919,fate#322950,fate#323773).
- blk-mq: move blk_mq_sched_{get,put}_request to blk-mq.c
  (fate#322738,fate#322919,fate#322950,fate#323773).
- blk-mq: mark blk_mq_rq_ctx_init static
  (fate#322738,fate#322919,fate#322950,fate#323773).
- md: change the initialization value for
  a spare device spot to MD_DISK_ROLE_SPARE
  (fate#322738,fate#322919,fate#322950,fate#323773).
- md/raid1: remove unused bio in sync_request_write
  (fate#322738,fate#322919,fate#322950,fate#323773).
- md/raid10: fix FailFast test for wrong device
  (fate#322738,fate#322919,fate#322950,fate#323773).
- block: swim3: make of_device_ids const
  (fate#322738,fate#322919,fate#322950,fate#323773).
- block: Dedicated error code fixups
  (fate#322738,fate#322919,fate#322950,fate#323773).
- dm: missing break in process_queued_bios()
  (fate#322738,fate#322919,fate#322950,fate#323773).
- x86, uaccess: introduce copy_from_iter_flushcache
  for pmem / cache-bypass operations
  (fate#322738,fate#322919,fate#322950,fate#323773).
- block: switch bios to blk_status_t
  (fate#322738,fate#322919,fate#322950,fate#323773).
- blk-mq: switch ->queue_rq return value to blk_status_t
  (fate#322738,fate#322919,fate#322950,fate#323773).
- fs: simplify dio_bio_complete
  (fate#322738,fate#322919,fate#322950,fate#323773).
- fs: remove the unused error argument to dio_end_io()
  (fate#322738,fate#322919,fate#322950,fate#323773).
- gfs2: remove the unused sd_log_error field
  (fate#322738,fate#322919,fate#322950,fate#323773).
- block_dev: propagate bio_iov_iter_get_pages
  error in __blkdev_direct_IO
  (fate#322738,fate#322919,fate#322950,fate#323773).
- nvme-rdma: fix merge error
  (fate#322738,fate#322919,fate#322950,fate#323773).
- block: introduce new block status code type
  (fate#322738,fate#322919,fate#322950,fate#323773).
- dm: change ->end_io calling convention
  (fate#322738,fate#322919,fate#322950,fate#323773).
- dm: don't return errnos from ->map
  (fate#322738,fate#322919,fate#322950,fate#323773).
- dm mpath: merge do_end_io_bio into multipath_end_io_bio
  (fate#322738,fate#322919,fate#322950,fate#323773).
- dm: fix REQ_RAHEAD handling
  (fate#322738,fate#322919,fate#322950,fate#323773).
- bsg: Check queue type before attaching to a queue
  (fate#322738,fate#322919,fate#322950,fate#323773).
- commit 056fe48
* Wed Sep 13 2017 colyli@suse.de
- block: Introduce queue flag QUEUE_FLAG_SCSI_PASSTHROUGH
  (fate#322738,fate#322919,fate#322950,fate#323773).
- Refresh patches.drivers/0001-cciss-initialize-struct-scsi_req.patch.
- commit fe7d9b8
* Wed Sep 13 2017 colyli@suse.de
- blk-mq-debugfs: Add 'kick' operation
  (fate#322738,fate#322919,fate#322950,fate#323773).
- blk-mq-debugfs: Show busy requests
  (fate#322738,fate#322919,fate#322950,fate#323773).
- blk-mq-debugfs: Show requeue list
  (fate#322738,fate#322919,fate#322950,fate#323773).
- blk-mq-debugfs: Show atomic request flags
  (fate#322738,fate#322919,fate#322950,fate#323773).
- cfq-iosched: Delete unused function min_vdisktime()
  (fate#322738,fate#322919,fate#322950,fate#323773).
- blk-mq: make per-sw-queue bio merge as default .bio_merge
  (fate#322738,fate#322919,fate#322950,fate#323773).
- blk-mq: merge bio into sw queue before plugging
  (fate#322738,fate#322919,fate#322950,fate#323773).
- lib/raid6: Add log-of-2 table for RAID6 HW requiring disk
  position (fate#322738,fate#322919,fate#322950,fate#323773).
- commit 63ce229
* Wed Sep 13 2017 colyli@suse.de
- mtip32xx: avoid to read HOST_CAP from HW in .queue_rq()
  (fate#322738,fate#322919,fate#322950,fate#323773).
- cciss: initialize struct scsi_req
  (fate#322738,fate#322919,fate#322950,fate#323773).
- commit 865ae42
* Wed Sep 13 2017 colyli@suse.de
- btrfs: use new block error code
  (fate#322738,fate#322919,fate#322950,fate#323773).
- commit 4707260
* Wed Sep 13 2017 colyli@suse.de
- Prepare for SLE15 block layer backport, the following patches will be
  replaced in the backport patch set.
- Delete patches.suse/0007-block-return-on-congested-block-device.patch.
- Delete patches.suse/blk-timeout-no-round.
- commit 898bc16
* Wed Sep 13 2017 tbogendoerfer@suse.de
- IB/rxe: Another fix for broken receive queue draining
  (bsc#1050662 FATE#323951).
- IB/rxe: Move refcounting earlier in rxe_send() (bsc#1050662
  FATE#323951).
- commit 232e612
* Wed Sep 13 2017 tbogendoerfer@suse.de
- rxe: fix broken receive queue draining (bsc#1050662
  FATE#323951).
- IB/rxe: Set dma_mask and coherent_dma_mask (bsc#1050662
  FATE#323951).
- IB/rxe: Fix kernel panic from skb destructor (bsc#1050662
  FATE#323951).
- IB/rxe: do not copy extra stack memory to skb (bsc#1050662
  FATE#323951).
- commit 0a634d2
* Wed Sep 13 2017 tbogendoerfer@suse.de
- RDMA/ocrdma: Fix error codes in ocrdma_create_srq() (bsc#1058513
  FATE#322520).
- RDMA/ocrdma: Fix an error code in ocrdma_alloc_pd() (bsc#1058513
  FATE#322520).
- commit 1505b7c
* Wed Sep 13 2017 mkubecek@suse.cz
- config: disable IPX (fate#323372)
  Also drop the ipx line from supported.conf
- commit fd722f1
* Wed Sep 13 2017 dchang@suse.com
- bnx2x: fix format overflow warning (bsc#1050319 FATE#322906).
- net: broadcom: bnx2x: make a couple of const arrays static
  (bsc#1050319 FATE#322906).
- bnx2x: Remove open coded carrier check (bsc#1050319
  FATE#322906).
- commit 1244565
* Wed Sep 13 2017 dchang@suse.com
- net: phy: Make phy_ethtool_ksettings_get return void
  (bsc#1050260 FATE#322917).
- commit 6fbf90a
* Wed Sep 13 2017 jlee@suse.com
- Update config files. (fate#322251)
  Enabling CONFIG_IMA_KEXEC on ppc64le kernel. (fate#322251)
- commit a83dbdc
* Wed Sep 13 2017 dchang@suse.com
- be2net: Update the driver version to 11.4.0.0 (bsc#1050252
  FATE#322920).
- be2net: Fix UE detection logic for BE3 (bsc#1050252
  FATE#322920).
- commit 4374b1f
* Wed Sep 13 2017 dchang@suse.com
- netxen: fix incorrect loop counter decrement (bsc#1050526
  FATE#322905).
- netxen_nic: Remove unused pointer hdr in netxen_setup_minidump()
  (bsc#1050526 FATE#322905).
- netxen: remove writeq/readq function definitions (bsc#1050526
  FATE#322905).
- commit dba6746
* Wed Sep 13 2017 dchang@suse.com
- qlge: avoid memcpy buffer overflow (bsc#1050529 FATE#322902).
- commit 33f6a43
* Wed Sep 13 2017 dchang@suse.com
- Refresh patch order in network section
- commit e712677
* Wed Sep 13 2017 neilb@suse.com
- NFSv4.1: don't use machine credentials for CLOSE when using
  'sec=sys' (bsc#972003).
- Delete patches.fixes/nfs4_close.fix.
  Replace patch with slightly-improved upstream version.
- commit d4a102c
* Wed Sep 13 2017 neilb@suse.com
- md/raid5: fix a race condition in stripe batch (linux-stable).
- NFS: flush data when locking a file to ensure cache coherence
  for mmap (bsc#981309).
- commit 42452b8
* Tue Sep 12 2017 oneukum@suse.com
- Update config files. Readd CONFIG_UCSI
  It was killed by the type C FATEs (bsc#1058307)
- commit 4a9daca
* Tue Sep 12 2017 oneukum@suse.com
- Update config files. Drop ancient USB drivers (FATE#323891)
- commit f78046a
* Tue Sep 12 2017 msuchanek@suse.de
- rpm/kernel-docs.spec.in: make unpack scripts executable
- commit 1ba3766
* Tue Sep 12 2017 oneukum@suse.com
- usb:xhci:Fix regression when ATI chipsets detected
  (bsc#1055044).
- commit 8847613
* Tue Sep 12 2017 oneukum@suse.com
- Update config files. Kill analog TV (FATE#323883)
- commit 56e4a2a
* Tue Sep 12 2017 tbogendoerfer@suse.de
- bnxt_en: Do not setup MAC address in bnxt_hwrm_func_qcaps()
  (bsc#1050242 FATE#322914).
- bnxt_en: Free MSIX vectors when unregistering the device from
  bnxt_re (bsc#1050242 FATE#322914).
- bnxt_en: Fix .ndo_setup_tc() to include XDP rings (bsc#1050242
  FATE#322914).
- RDMA/bnxt_re: Fix the value reported for local ack delay
  (bsc#1050244 FATE#322915).
- RDMA/bnxt_re: Report MISSED_EVENTS in req_notify_cq (bsc#1050244
  FATE#322915).
- RDMA/bnxt_re: Fix return value of poll routine (bsc#1050244
  FATE#322915).
- RDMA/bnxt_re: Enable atomics only if host bios supports
  (bsc#1050244 FATE#322915).
- RDMA/bnxt_re: checking for NULL instead of IS_ERR() (bsc#1050244
  FATE#322915).
- bnxt_en: Fix SRIOV on big-endian architecture (bsc#1050242
  FATE#322914).
- bnxt_en: Fix bug in ethtool -L (bsc#1050242 FATE#322914).
- bnxt_en: Fix race conditions in .ndo_get_stats64() (bsc#1050242
  FATE#322914).
- bpf: bnxt: Report bpf_prog ID during XDP_QUERY_PROG (bsc#1050242
  FATE#322914).
- bnxt_en: Fix xmit_more with BQL (bsc#1050242 FATE#322914).
- bnxt_en: Pass in sh parameter to bnxt_set_dflt_rings()
  (bsc#1050242 FATE#322914).
- bnxt_en: Implement xmit_more (bsc#1050242 FATE#322914).
- bnxt_en: Optimize doorbell write operations for newer chips
  (bsc#1050242 FATE#322914).
- bnxt_en: Add additional chip ID definitions (bsc#1050242
  FATE#322914).
- bnxt_en: Add a callback to inform RDMA driver during PCI
  shutdown (bsc#1050242 FATE#322914).
- bnxt_en: Add PCI IDs for BCM57454 VF devices (bsc#1050242
  FATE#322914).
- bnxt_en: Support for Short Firmware Message (bsc#1050242
  FATE#322914).
- bnxt: add dma mapping attributes (bsc#1050242 FATE#322914).
- commit a791793
* Tue Sep 12 2017 tbogendoerfer@suse.de
- Moved bnxt_re patches into sorted network driver section
- commit e77ab1e
* Tue Sep 12 2017 jslaby@suse.cz
- blacklist.conf: add 2 more entries
- commit 93d993d
* Mon Sep 11 2017 lduncan@suse.com
- mtip32xx: fix up the checking for internal command failure
  (bsc#1058157).
- commit f712234
* Mon Sep 11 2017 bpoirier@suse.com
- sfc: don't try and read ef10 data on non-ef10 NIC (bsc#1058169
  FATE#322922).
- sfc: correct comment on efx_mcdi_process_event (bsc#1058169
  FATE#322922).
- sfc: change Unknown MCDI event message to print full event
  (bsc#1058169 FATE#322922).
- commit 55d76f6
* Mon Sep 11 2017 bpoirier@suse.com
- i40e: point wb_desc at the nvm_wb_desc during i40e_read_nvm_aq
  (bsc#1056658 FATE#322188).
- i40e: avoid NVM acquire deadlock during NVM update (bsc#1056658
  FATE#322188).
- commit 0715187
* Mon Sep 11 2017 tonyj@suse.de
- perf vendor events powerpc: Remove duplicate events
  (FATE#322450, bsc#1050145).
- commit ad444e5
* Mon Sep 11 2017 bpoirier@suse.com
- Refresh patch order in networking section
- commit ae6b192
* Mon Sep 11 2017 tbogendoerfer@suse.de
- scsi: qedf: Fix a potential NULL pointer dereference
  (bsc#1050530 FATE#322901).
- scsi: qedf: Limit number of CQs (bsc#1050530 FATE#322901).
- scsi: qedf: fix spelling mistake: "offlading" -> "offloading"
  (bsc#1050530 FATE#322901).
- scsi: qedf: Merge a few quoted strings split across lines
  (bsc#1050530 FATE#322901).
- scsi: qedf: Use 'dma_zalloc_coherent' to reduce code verbosity
  (bsc#1050530 FATE#322901).
- scsi: qedf: Fix a return value in case of error in
  'qedf_alloc_global_queues' (bsc#1050530 FATE#322901).
- commit 943143a
* Mon Sep 11 2017 tbogendoerfer@suse.de
- Moved qedf patches to sorted network section
- commit f5a68e3
* Mon Sep 11 2017 tbogendoerfer@suse.de
- qed: Fix a memory allocation failure test in
  'qed_mcp_cmd_init()' (bsc#1050536 FATE#322898 bsc#1050538
  FATE#322897).
- scsi: qedi: Fix return code in qedi_ep_connect() (bsc#1050534
  FATE#322899).
- scsi: qedi: Add ISCSI_BOOT_SYSFS to Kconfig (bsc#1050534
  FATE#322899).
- RDMA/qedr: Prevent memory overrun in verbs' user responses
  (bsc#1050545 FATE#322893).
- scsi: qedi: fix another spelling mistake: "alloction" ->
  "allocation" (bsc#1050534 FATE#322899).
- scsi: qedi: Add support for Boot from SAN over iSCSI offload
  (bsc#1050534 FATE#322899).
- qed: Fix printk option passed when printing ipv6 addresses
  (bsc#1050536 FATE#322898 bsc#1050538 FATE#322897).
- scsi: qedi: Remove comparison of u16 idx with zero (bsc#1050534
  FATE#322899).
- qed: initialize ll2_syn_handle at start of function (bsc#1050536
  FATE#322898 bsc#1050538 FATE#322897).
- qed: Add iWARP support for physical queue allocation
  (bsc#1050536 FATE#322898 bsc#1050545 FATE#322893).
- qed: Add iWARP protocol support in context allocation
  (bsc#1050536 FATE#322898 bsc#1050545 FATE#322893).
- qed: iWARP CM add error handling (bsc#1050536 FATE#322898
  bsc#1050545 FATE#322893).
- qed: iWARP implement disconnect flows (bsc#1050536 FATE#322898
  bsc#1050545 FATE#322893).
- qed: iWARP CM add active side connect (bsc#1050536 FATE#322898
  bsc#1050545 FATE#322893).
- qed: iWARP CM add passive side connect (bsc#1050536 FATE#322898
  bsc#1050545 FATE#322893).
- qed: iWARP CM add listener functions and initial SYN processing
  (bsc#1050536 FATE#322898 bsc#1050545 FATE#322893).
- qed: iWARP CM - setup a ll2 connection for handling SYN packets
  (bsc#1050536 FATE#322898 bsc#1050545 FATE#322893).
- qed: Add iWARP support in ll2 connections (bsc#1050536
  FATE#322898 bsc#1050545 FATE#322893).
- qed: Rename some ll2 related defines (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- qed: Implement iWARP initialization, teardown and qp operations
  (bsc#1050536 FATE#322898 bsc#1050545 FATE#322893).
- qed: Introduce iWARP personality (bsc#1050536 FATE#322898
  bsc#1050545 FATE#322893).
- qed*: Rename qed_roce_if.h to qed_rdma_if.h (bsc#1050536
  FATE#322898 bsc#1050538 FATE#322897).
- qed: Split rdma content between qed_rdma and qed_roce
  (bsc#1050536 FATE#322898 bsc#1050538 FATE#322897).
- qed: Duplicate qed_roce. to qed_rdma.[ch] (bsc#1050536
  FATE#322898 bsc#1050538 FATE#322897).
- qed: Cleanup qed_roce before duplicating it (bsc#1050536
  FATE#322898 bsc#1050538 FATE#322897).
- qede: Fix compilation without QED_RDMA (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- qed: SPQ async callback registration (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- qed: Wait for resources before FUNC_CLOSE (bsc#1050536
  FATE#322898 bsc#1050538 FATE#322897).
- qed*: Set rdma generic functions prefix (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- qed*: qede_roce. -> qede_rdma.[ch] (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- qed: Disable RoCE dpm when DCBx change occurs (bsc#1050536
  FATE#322898 bsc#1050538 FATE#322897).
- qed: RoCE EDPM to honor PFC (bsc#1050536 FATE#322898 bsc#1050538
  FATE#322897).
- qed: Chain support for external PBL (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- bpf: qede: Report bpf_prog ID during XDP_QUERY_PROG (bsc#1050536
  FATE#322898 bsc#1050538 FATE#322897).
- qed: Fix an off by one bug (bsc#1050536 FATE#322898 bsc#1050538
  FATE#322897).
- qed: add qed_int_sb_init() stub function (bsc#1050536
  FATE#322898 bsc#1050538 FATE#322897).
- qed: collect GSI port statistics (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- qed: Call rx_release_cb() when flushing LL2 (bsc#1050536
  FATE#322898 bsc#1050538 FATE#322897).
- qed: No need for LL2 frags indication (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- qed*: LL2 callback operations (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- qed: LL2 code relocations (bsc#1050536 FATE#322898 bsc#1050538
  FATE#322897).
- qed: Cleaner seperation of LL2 inputs (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- qed: Revise ll2 Rx completion (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- qed: LL2 to use packed information for tx (bsc#1050536
  FATE#322898 bsc#1050538 FATE#322897).
- qede: VF XDP support (bsc#1050536 FATE#322898 bsc#1050538
  FATE#322897).
- qed: VF XDP support (bsc#1050536 FATE#322898 bsc#1050538
  FATE#322897).
- qed: VFs to try utilizing the doorbell bar (bsc#1050536
  FATE#322898 bsc#1050538 FATE#322897).
- qed: Multiple qzone queues for VFs (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- qed: IOV db support multiple queues per qzone (bsc#1050536
  FATE#322898 bsc#1050538 FATE#322897).
- qed: Make VF legacy a bitfield (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- qed: Assign a unique per-queue index to queue-cid (bsc#1050536
  FATE#322898 bsc#1050538 FATE#322897).
- qed: Pass vf_params when creating a queue-cid (bsc#1050536
  FATE#322898 bsc#1050538 FATE#322897).
- qed*: L2 interface to use the SB structures directly
  (bsc#1050536 FATE#322898 bsc#1050538 FATE#322897).
- qed: Create L2 queue database (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- qed: Add bitmaps for VF CIDs (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- qed: Add support for changing iSCSI mac (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- qed: Support NVM-image reading API (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- qed: Share additional information with qedf (bsc#1050536
  FATE#322898 bsc#1050538 FATE#322897).
- qed: Correct order of wwnn and wwpn (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- qed: No need to reset SBs on IOV init (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- qed: Reset IGU CAM to default on init (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- qed: Hold a single array for SBs (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- qed: Provide auxiliary for getting free VF SB (bsc#1050536
  FATE#322898 bsc#1050538 FATE#322897).
- qed: Remove assumption on SB order in IGU (bsc#1050536
  FATE#322898 bsc#1050538 FATE#322897).
- qed: Encapsulate interrupt counters in struct (bsc#1050536
  FATE#322898 bsc#1050538 FATE#322897).
- qed: Add aux. function translating sb_id -> igu_sb_id
  (bsc#1050536 FATE#322898 bsc#1050538 FATE#322897).
- qed: Distinguish between sb_id and igu_sb_id (bsc#1050536
  FATE#322898 bsc#1050538 FATE#322897).
- qed: IGU read revised (bsc#1050536 FATE#322898 bsc#1050538
  FATE#322897).
- qed: Minor refactoring in interrupt code (bsc#1050536
  FATE#322898 bsc#1050538 FATE#322897).
- qed: Make qed_int_cau_conf_pi() static (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- qed: Cache alignemnt padding to match host (bsc#1050536
  FATE#322898 bsc#1050538 FATE#322897).
- qed: Mask parities after occurance (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- qed: Print multi-bit attentions properly (bsc#1050536
  FATE#322898 bsc#1050538 FATE#322897).
- qed: Diffrentiate adapter-specific attentions (bsc#1050536
  FATE#322898 bsc#1050538 FATE#322897).
- qed: Get rid of the attention-arrays (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- qed: Support dynamic s-tag change (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- qed: QL41xxx VF MSI-x table (bsc#1050536 FATE#322898 bsc#1050538
  FATE#322897).
- qed: Don't inherit RoCE DCBx for V2 (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- qed: Correct DCBx update scheme (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- qed: Add missing static/local dcbx info (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- qed: Replace set_id() api with set_name() (bsc#1050536
  FATE#322898 bsc#1050538 FATE#322897).
- qede: Log probe of PCI device (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- qed: Provide MBI information in dev_info (bsc#1050536
  FATE#322898 bsc#1050538 FATE#322897).
- qed: Enable RoCE parser searching on fp init (bsc#1050536
  FATE#322898 bsc#1050538 FATE#322897).
- qed: Flush slowpath tasklet on stop (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- qed: Remove BB_A0 references (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- qed: Drop the 's' from num_ports_in_engines (bsc#1050536
  FATE#322898 bsc#1050538 FATE#322897).
- qed: Log incorrectly installed board (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- qed: !main_ptt for tunnel configuration (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- qed: Align DP_ERR style with other DP macros (bsc#1050536
  FATE#322898 bsc#1050538 FATE#322897).
- qede: Fix sparse warnings (bsc#1050536 FATE#322898 bsc#1050538
  FATE#322897).
- qede: Support 1G advertisment (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- qed: Fix setting of Management bitfields (bsc#1050536
  FATE#322898 bsc#1050538 FATE#322897).
- qede: qedr closure after setting state (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- qed: Correct print in iscsi error-flow (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- qed: Revise alloc/setup/free flow (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- qede: Don't use an internal MAC field (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- qede: Add missing Status-block free (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- qede: Honor user request for Tx buffers (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- qede: Allow WoL to activate by default (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- qed: Remove unused including <linux/version.h> (bsc#1050536
  FATE#322898 bsc#1050538 FATE#322897).
- qed: Utilize FW 8.20.0.0 (bsc#1050536 FATE#322898 bsc#1050538
  FATE#322897).
- commit 1d42a59
* Mon Sep 11 2017 tbogendoerfer@suse.de
- net: sched: fix memleak for chain zero (bsc#1056657 FATE#322189
  bsc#1056653 FATE#322190 bsc#1056787).
- commit 2088d61
* Mon Sep 11 2017 mgorman@suse.de
- Refresh
  patches.suse/audit-Reduce-overhead-using-a-coarse-clock.patch.
- Refresh
  patches.suse/mm-change-the-call-sites-of-numa-statistics-items.patch.
- Refresh
  patches.suse/mm-consider-the-number-in-local-CPUs-when-reading-NUMA-stats.patch.
- Refresh
  patches.suse/mm-update-NUMA-counter-threshold-size.patch.
- commit d6d62e5
* Mon Sep 11 2017 jthumshirn@suse.de
- scsi: aacraid: Fix out of bounds in aac_get_name_resp
  (FATE#322889, bsc#1049519).
- scsi: aacraid: reading out of bounds (FATE#322889, bsc#1049519).
- scsi: aacraid: Don't copy uninitialized stack memory to
  userspace (FATE#322889, bsc#1049519).
- scsi: aacraid: fix leak of data from stack back to userspace
  (FATE#322889, bsc#1049519).
- scsi: aacraid: Update driver version to 50834 (FATE#322889,
  bsc#1049519).
- scsi: aacraid: Remove reference to Series-9 (FATE#322889,
  bsc#1049519).
- scsi: aacraid: Add reset debugging statements (FATE#322889,
  bsc#1049519).
- scsi: aacraid: Enable ctrl reset for both hba and arc
  (FATE#322889, bsc#1049519).
- scsi: aacraid: Make sure ioctl returns on controller reset
  (FATE#322889, bsc#1049519).
- scsi: aacraid: Use correct function to get ctrl health
  (FATE#322889, bsc#1049519).
- scsi: aacraid: Rework aac_src_restart (FATE#322889,
  bsc#1049519).
- scsi: aacraid: Rework SOFT reset code (FATE#322889,
  bsc#1049519).
- scsi: aacraid: Add periodic checks to see IOP reset status
  (FATE#322889, bsc#1049519).
- scsi: aacraid: Rework IOP reset (FATE#322889, bsc#1049519).
- scsi: aacraid: Using single reset mask for IOP reset
  (FATE#322889, bsc#1049519).
- scsi: aacraid: Print ctrl status before eh reset (FATE#322889,
  bsc#1049519).
- scsi: aacraid: Log count info of scsi cmds before reset
  (FATE#322889, bsc#1049519).
- scsi: aacraid: Change wait time for fib completion (FATE#322889,
  bsc#1049519).
- scsi: aacraid: Remove reset support from check_health
  (FATE#322889, bsc#1049519).
- scsi: aacraid: Set correct Queue Depth for HBA1000 RAW disks
  (FATE#322889, bsc#1049519).
- scsi: aacraid: Added 32 and 64 queue depth for arc natives
  (FATE#322889, bsc#1049519).
- scsi: aacraid: Fix DMAR issues with iommu=pt (FATE#322889,
  bsc#1049519).
- scsi: aacraid: Remove __GFP_DMA for raw srb memory (FATE#322889,
  bsc#1049519).
- commit 4812863
* Mon Sep 11 2017 tbogendoerfer@suse.de
- supported.conf: mark mlxfw as supported
- commit 51723c1
* Mon Sep 11 2017 tbogendoerfer@suse.de
- net/mlx5e: IPoIB, Fix driver name retrieved by ethtool
  (bsc#1046303 FATE#322944).
- commit f0ce489
* Mon Sep 11 2017 tbogendoerfer@suse.de
- Update config files.
  New MLX5 config options
- commit f7e0715
* Mon Sep 11 2017 tbogendoerfer@suse.de
- net/mlx5e: Fix CQ moderation mode not set properly (bsc#1046303
  FATE#322944).
- net/mlx5e: Fix inline header size for small packets (bsc#1046303
  FATE#322944).
- net/mlx5: E-Switch, Unload the representors in the correct order
  (bsc#1046303 FATE#322944).
- net/mlx5e: Properly resolve TC offloaded ipv6 vxlan tunnel
  source address (bsc#1046303 FATE#322944).
- net/mlx5e: Don't override user RSS upon set channels
  (bsc#1046303 FATE#322944).
- net/mlx5e: Fix dangling page pointer on DMA mapping error
  (bsc#1046303 FATE#322944).
- net/mlx5: Remove the flag MLX5_INTERFACE_STATE_SHUTDOWN
  (bsc#1046303 FATE#322944).
- net/mlx5: Skip mlx5_unload_one if mlx5_load_one fails
  (bsc#1046303 FATE#322944).
- net/mlx5: Fix arm SRQ command for ISSI version 0 (bsc#1046303
  FATE#322944).
- net/mlx5e: Fix DCB_CAP_ATTR_DCBX capability for DCBNL getcap
  (bsc#1046303 FATE#322944).
- net/mlx5e: Check for qos capability in dcbnl_initialize
  (bsc#1046303 FATE#322944).
- IB/mlx5: Always return success for RoCE modify port (bsc#1046303
  FATE#322944).
- IB/mlx5: Fix Raw Packet QP event handler assignment (bsc#1046303
  FATE#322944).
- RDMA/mlx5: Fix existence check for extended address vector
  (bsc#1046305 FATE#322943).
- net/mlx5: Clean SRIOV eswitch resources upon VF creation failure
  (bsc#1046303 FATE#322944).
- IB/mlx5: Fix a warning message (bsc#1046303 FATE#322944).
- IB/mlx5: Clean mr_cache debugfs in case of failure (bsc#1046303
  FATE#322944).
- net/mlx5: IPSec, fix 64-bit division correctly (bsc#1046303
  FATE#322944).
- net/mlx5: Add Makefiles for subdirectories (bsc#1046303
  FATE#322944).
- net/mlx5: Build wq.o even if MLX5_CORE_EN is not selected
  (bsc#1046303 FATE#322944).
- net/mlx5: FPGA, Fix datatype mismatch (bsc#1046303 FATE#322944).
- net/mlx5: FPGA, make mlx5_fpga_device_brb static (bsc#1046303
  FATE#322944).
- net/mlx5: IPSec, Fix 64-bit division on 32-bit builds
  (bsc#1046303 FATE#322944).
- net/mlx5: Add missing include in lib/gid.c (bsc#1046303
  FATE#322944).
- IB/core, opa_vnic, hfi1, mlx5: Properly free rdma_netdev
  (bsc#1046305 FATE#322943).
- net/mlxfw: Properly handle dependancy with non-loadable mlx5
  (bsc#1051858).
- net/mlx5: fix memcpy limit? (bsc#1046303 FATE#322944).
- net/mlx5: fix spelling mistake: "Allodating" -> "Allocating"
  (bsc#1046303 FATE#322944).
- net/mlx5e: IPSec, Add IPSec ethtool stats (bsc#1046303
  FATE#322944).
- net/mlx5e: IPSec, Add Innova IPSec offload TX data path
  (bsc#1046303 FATE#322944).
- net/mlx5e: IPSec, Add Innova IPSec offload RX data path
  (bsc#1046303 FATE#322944).
- net/mlx5e: IPSec, Innova IPSec offload infrastructure
  (bsc#1046303 FATE#322944).
- net/mlx5: Accel, Add IPSec acceleration interface (bsc#1046303
  FATE#322944).
- net/mlx5: FPGA, Add SBU infrastructure (bsc#1046303
  FATE#322944).
- net/mlx5: FPGA, Add SBU bypass and reset flows (bsc#1046303
  FATE#322944).
- net/mlx5: FPGA, Add high-speed connection routines (bsc#1046303
  FATE#322944).
- net/mlx5: FPGA, Add FW commands for FPGA QPs (bsc#1046303
  FATE#322944).
- net/mlx5: FPGA, Move FPGA init/cleanup to init_once (bsc#1046303
  FATE#322944).
- net/mlx5: Add QP WQ support (bsc#1046303 FATE#322944).
- net/mlx5: Make get_cqe routine not ethernet-specific
  (bsc#1046303 FATE#322944).
- IB/mlx5: Respect mlx5_core reserved GIDs (bsc#1046303
  FATE#322944).
- net/mlx5: Add support for multiple RoCE enable (bsc#1046303
  FATE#322944).
- net/mlx5: Add reserved-gids support (bsc#1046303 FATE#322944).
- net/mlx5: Set interface flags before cleanup in unload_one
  (bsc#1046303 FATE#322944).
- net/mlx5: Fix offset of hca cap reserved field (bsc#1046303
  FATE#322944).
- net/mlx5e: IPoIB, Support the flash device ethtool callback
  (bsc#1046303 FATE#322944).
- net/mlx5e: Support the flash device ethtool callback
  (bsc#1046303 FATE#322944).
- net/mlx5: Add mlxfw callbacks (bsc#1046303 FATE#322944).
- net/mlx5: Add helper functions to set/query MCC/MCDA/MCQI
  registers (bsc#1046303 FATE#322944).
- net/mlx5: Enhance MCAM reg to allow query on access reg support
  (bsc#1046303 FATE#322944).
- net/mlx5: Add MCC (Management Component Control) register
  definitions (bsc#1046303 FATE#322944).
- mlxfw: Make the module selectable (bsc#1051858).
- net/mlx5e: Add header re-write offloading of IPv6 hop-limit
  (bsc#1046303 FATE#322944).
- net/mlx5e: Use macro for TC header re-write offload field
  mapping (bsc#1046303 FATE#322944).
- net/mlx5e: Offload TC matching on ip ttl (bsc#1046303
  FATE#322944).
- net/mlx5e: Relocate the TC match on ip tos offload code section
  (bsc#1046303 FATE#322944).
- net/mlx5e: Introduce RX Page-Reuse (bsc#1046303 FATE#322944).
- net/mlx5e: Enhance RX SKB headroom logic (bsc#1046303
  FATE#322944).
- net/mlx5e: Build SKB with exact frag_size (bsc#1046303
  FATE#322944).
- net/mlx5e: Use device ID defines (bsc#1046303 FATE#322944).
- net/mlx5e: IPoIB, Add ioctl support to IPoIB device driver
  (bsc#1046303 FATE#322944).
- net/mlx5e: IPoIB, Add PTP support to IPoIB device driver
  (bsc#1046303 FATE#322944).
- net/mlx5e: IPoIB, Get more TX statistics (bsc#1046303
  FATE#322944).
- net/mlx5e: IPoIB, Handle change_mtu (bsc#1046303 FATE#322944).
- net/mlx5e: Use hard_mtu as part of the mlx5e_priv struct
  (bsc#1046303 FATE#322944).
- net/mlx5e: IPoIB, Change parameters default values (bsc#1046303
  FATE#322944).
- net/mlx5e: Add new profile function update_carrier (bsc#1046303
  FATE#322944).
- net/mlx5e: IPoIB, Add ethtool support (bsc#1046303 FATE#322944).
- net/mlx5e: Prevent PFC call for non ethernet ports (bsc#1046303
  FATE#322944).
- net/mlx5e: IPoIB, Move to a separate directory (bsc#1046303
  FATE#322944).
- net/mlx5: Add fast unload support in shutdown flow (bsc#1046303
  FATE#322944).
- net/mlx5: Expose command polling interface (bsc#1046303
  FATE#322944).
- net/mlx5e: Optimize update stats work (bsc#1046303 FATE#322944).
- net/mlx5e: Move and optimize query out of buffer function
  (bsc#1046303 FATE#322944).
- net/mlx5e: Reduce number of heap allocated buffers for update
  stats (bsc#1046303 FATE#322944).
- net/mlx5e: Rename physical symbol errors counter (bsc#1046303
  FATE#322944).
- net/mlx5e: Fix typo in warning if CQ moderation is not supported
  (bsc#1046303 FATE#322944).
- net/mlx5e: Use function to map aRFS into traffic type
  (bsc#1046303 FATE#322944).
- net/mlx5: Undo LAG upon request to create virtual functions
  (bsc#1046303 FATE#322944).
- net/mlx5: Avoid space after casting (bsc#1046303 FATE#322944).
- net/mlx5: Align to match opening parenthesis (bsc#1046303
  FATE#322944).
- net/mlx5: Avoid blank lines before/after closing/opening braces
  (bsc#1046303 FATE#322944).
- net/mlx5: Avoid using multiple blank lines (bsc#1046303
  FATE#322944).
- net/mlx5: Fix some spelling mistakes (bsc#1046303 FATE#322944).
- net/mlx5: Update eqe_type_str() event names (bsc#1046303
  FATE#322944).
- bpf: mlx5e: Report bpf_prog ID during XDP_QUERY_PROG
  (bsc#1046303 FATE#322944).
- net/mlxfw: fix a NULL dereference (bsc#1051858).
- net/mlx5e: Fill advertised and supported port data from Hardware
  info (bsc#1046303 FATE#322944).
- net/mlx5e: Add support for reading connector type from PTYS
  (bsc#1046303 FATE#322944).
- net/mlx5: Update flow table commands layout (bsc#1046303
  FATE#322944).
- net/mlx5e: Support header re-write of partial fields in TC
  pedit offload (bsc#1046303 FATE#322944).
- net/mlx5e: Use modify header ID cache for offloaded TC NIC flows
  (bsc#1046303 FATE#322944).
- net/mlx5e: Use modify header ID cache for offloaded TC E-Switch
  flows (bsc#1046303 FATE#322944).
- net/mlx5e: Add cache for HW modify header IDs (bsc#1046303
  FATE#322944).
- net/mlx5e: Use short attribute form when adding/deleting
  offloaded TC flows (bsc#1046303 FATE#322944).
- net/mlx5e: Remove limitation of single NIC offloaded TC action
  per rule (bsc#1046303 FATE#322944).
- net/mlxfw: remove redundant goto on error check (bsc#1051858).
- net/mlx5e: Offload TC matching on ip tos / traffic-class
  (bsc#1046303 FATE#322944).
- net/mlx5e: Offload TC matching on tcp flags (bsc#1046303
  FATE#322944).
- net/mlxfw: select CONFIG_XZ_DEC (bsc#1051858).
- Add the mlxfw module for Mellanox firmware flash process
  (bsc#1051858).
- IB/mlx5: Bump driver version (bsc#1046303 FATE#322944).
- net/mlx5: Bump driver version (bsc#1046303 FATE#322944).
- net/mlx5: FPGA, Add basic support for Innova (bsc#1046303
  FATE#322944).
- net/mlx5: Introduce trigger_health_work function (bsc#1046303
  FATE#322944).
- net/mlx5: Update the list of the PCI supported devices
  (bsc#1046303 FATE#322944).
- {net, IB}/mlx5: Replace mlx5_vzalloc with kvzalloc (bsc#1046305
  FATE#322943).
- net/mlx5e: Fix possible memory leak (bsc#1046303 FATE#322944).
- commit eb483d0
* Mon Sep 11 2017 jslaby@suse.cz
- rpm/constraints.in: build ARM on at least 2 cpus
- commit b7edeaf
* Mon Sep 11 2017 jslaby@suse.cz
- rpm/constraints.in: increase memory for kernel-syzkaller
  And see if it helps. If so, push it to packaging...
- commit 7193e65
* Sun Sep 10 2017 jslaby@suse.cz
- Linux 4.12.12 (FATE#321195 bnc#1012628).
- Delete
  patches.drivers/0001-intel_th-pci-Add-Cannon-Lake-PCH-LP-support.patch.
- Delete
  patches.drivers/0002-intel_th-pci-Add-Cannon-Lake-PCH-H-support.patch.
- commit 296e98a
* Sat Sep  9 2017 bp@suse.de
- x86/intel_rdt: Turn off most RDT features on Skylake
  (fate#323965).
- commit 2a5c169
* Sat Sep  9 2017 bp@suse.de
- x86/intel_rdt: Add command line options for resource director
  technology (fate#323965).
- commit f5e558a
* Sat Sep  9 2017 bp@suse.de
- x86/intel_rdt: Move special case code for Haswell to a quirk
  function (fate#323965).
- commit c494255
* Sat Sep  9 2017 bp@suse.de
- x86/intel_rdt: Remove redundant ternary operator on return
  (fate#323965).
- commit da06468
* Sat Sep  9 2017 bp@suse.de
- x86/intel_rdt/cqm: Improve limbo list processing (fate#323965).
- commit d7dce5a
* Sat Sep  9 2017 bp@suse.de
- x86/intel_rdt/mbm: Fix MBM overflow handler during CPU hotplug
  (fate#323965).
- commit a86f8e0
* Sat Sep  9 2017 bp@suse.de
- x86/intel_rdt: Modify the intel_pqr_state for better performance
  (fate#323965).
- commit ab298d6
* Sat Sep  9 2017 bp@suse.de
- x86/intel_rdt/cqm: Clear the default RMID during hotcpu
  (fate#323965).
- commit 3c14e89
* Sat Sep  9 2017 bp@suse.de
- x86/intel_rdt: Show bitmask of shareable resource with other
  executing units (fate#323965).
- commit 0ccbd41
* Sat Sep  9 2017 bp@suse.de
- x86/intel_rdt/mbm: Handle counter overflow (fate#323965).
- commit 94ce203
* Sat Sep  9 2017 bp@suse.de
- x86/intel_rdt/mbm: Add mbm counter initialization (fate#323965).
- commit 32e11af
* Sat Sep  9 2017 bp@suse.de
- x86/intel_rdt/mbm: Basic counting of MBM events (total and
  local) (fate#323965).
- commit 12b1bc5
* Sat Sep  9 2017 bp@suse.de
- x86/intel_rdt/cqm: Add CPU hotplug support (fate#323965).
- commit 71658b1
* Sat Sep  9 2017 bp@suse.de
- x86/intel_rdt/cqm: Add sched_in support (fate#323965).
- commit 4198905
* Sat Sep  9 2017 bp@suse.de
- x86/intel_rdt: Introduce rdt_enable_key for scheduling
  (fate#323965).
- commit 16e00d5
* Fri Sep  8 2017 bp@suse.de
- x86/intel_rdt/cqm: Add mount,umount support (fate#323965).
- commit e56f8c1
* Fri Sep  8 2017 bp@suse.de
- x86/intel_rdt/cqm: Add rmdir support (fate#323965).
- commit bac5646
* Fri Sep  8 2017 bp@suse.de
- x86/intel_rdt: Separate the ctrl bits from rmdir (fate#323965).
- commit 6ec17c9
* Fri Sep  8 2017 bp@suse.de
- x86/intel_rdt/cqm: Add mon_data (fate#323965).
- commit 16bb61c
* Fri Sep  8 2017 bp@suse.de
- x86/intel_rdt: Prepare for RDT monitor data support
  (fate#323965).
- commit ebdd847
* Fri Sep  8 2017 bp@suse.de
- x86/intel_rdt/cqm: Add cpus file support (fate#323965).
- commit 11c3fd1
* Fri Sep  8 2017 bp@suse.de
- x86/intel_rdt: Prepare to add RDT monitor cpus file support
  (fate#323965).
- commit 8229971
* Fri Sep  8 2017 bp@suse.de
- x86/intel_rdt/cqm: Add tasks file support (fate#323965).
- commit eebc71b
* Fri Sep  8 2017 bp@suse.de
- x86/intel_rdt: Change closid type from int to u32 (fate#323965).
- commit 6a67176
* Fri Sep  8 2017 bp@suse.de
- x86/intel_rdt/cqm: Add mkdir support for RDT monitoring
  (fate#323965).
- commit bc3130b
* Fri Sep  8 2017 bp@suse.de
- x86/intel_rdt: Prepare for RDT monitoring mkdir support
  (fate#323965).
- commit af2e795
* Fri Sep  8 2017 bp@suse.de
- x86/intel_rdt/cqm: Add info files for RDT monitoring
  (fate#323965).
- commit 18ae4be
* Fri Sep  8 2017 bp@suse.de
- x86/intel_rdt: Simplify info and base file lists (fate#323965).
- commit ae6127b
* Fri Sep  8 2017 bp@suse.de
- x86/intel_rdt/cqm: Add RMID (Resource monitoring ID) management
  (fate#323965).
- commit e234239
* Fri Sep  8 2017 bp@suse.de
- x86/intel_rdt/cqm: Add RDT monitoring initialization
  (fate#323965).
- commit 16f77e6
* Fri Sep  8 2017 bp@suse.de
- x86/intel_rdt: Make rdt_resources_all more readable
  (fate#323965).
- commit 6a43549
* Fri Sep  8 2017 bp@suse.de
- x86/intel_rdt: Cleanup namespace to support RDT monitoring
  (fate#323965).
- commit ace7458
* Fri Sep  8 2017 bp@suse.de
- x86/intel_rdt: Mark rdt_root and closid_alloc as static
  (fate#323965).
- commit b46c4ec
* Fri Sep  8 2017 bp@suse.de
- x86/intel_rdt: Change file names to accommodate RDT monitor code
  (fate#323965).
- commit a90473c
* Fri Sep  8 2017 bp@suse.de
- x86/intel_rdt: Introduce a common compile option for RDT
  (fate#323965).
- commit 38084a6
* Fri Sep  8 2017 bp@suse.de
- x86/intel_rdt/cqm: Documentation for resctrl based RDT
  Monitoring (fate#323965).
- commit b231f22
* Fri Sep  8 2017 bp@suse.de
- x86/perf/cqm: Wipe out perf based cqm (fate#323965).
- commit 7619997
* Fri Sep  8 2017 bp@suse.de
- perf, bpf: Add BPF support to all perf_event types
  (fate#323965).
- commit db63802
* Fri Sep  8 2017 tbogendoerfer@suse.de
- net/mlx4_core: Fixes missing capability bit in flags2 capability
  dump (bsc#1046300 FATE#322946).
- net/mlx4_core: Fix namespace misalignment in QinQ VST support
  commit (bsc#1046300 FATE#322946).
- net/mlx4_core: Fix sl_to_vl_change bit offset in flags2 dump
  (bsc#1046300 FATE#322946).
- net/mlx4_en: Fix wrong indication of Wake-on-LAN (WoL) support
  (bsc#1046299 FATE#322947).
- IB/mlx4: Fix CM REQ retries in paravirt mode (bsc#1046302
  FATE#322945).
- mlx4_en: remove unnecessary returned value check (bsc#1046299
  FATE#322947).
- {net, IB}/mlx4: Remove gfp flags argument (bsc#1046302
  FATE#322945).
- IB: Convert msleep below 20ms to usleep_range (bsc#1046302
  FATE#322945).
- mlx4_en: make mlx4_log_num_mgm_entry_size static (bsc#1046299
  FATE#322947).
- net/mlx4_en: Do not allocate redundant TX queues when TC is
  disabled (bsc#1046299 FATE#322947).
- net/mlx4_en: Add dynamic variable to hold the number of user
  priorities (UP) (bsc#1046299 FATE#322947).
- net/mlx4: fix spelling mistake: "enforcment" -> "enforcement"
  (bsc#1046299 FATE#322947).
- net/mlx4: fix spelling mistake: "coalesing" -> "coalescing"
  (bsc#1046299 FATE#322947).
- bpf: mlx4: Report bpf_prog ID during XDP_QUERY_PROG (bsc#1046299
  FATE#322947).
- net/mlx4_en: Refactor mlx4_en_free_tx_desc (bsc#1046299
  FATE#322947).
- net/mlx4_en: Replace TXBB_SIZE multiplications with shift
  operations (bsc#1046299 FATE#322947).
- net/mlx4_en: Increase default TX ring size (bsc#1046299
  FATE#322947).
- net/mlx4_en: Poll XDP TX completion queue in RX NAPI
  (bsc#1046299 FATE#322947).
- net/mlx4_en: Improve XDP xmit function (bsc#1046299
  FATE#322947).
- net/mlx4_en: Improve stack xmit function (bsc#1046299
  FATE#322947).
- net/mlx4_en: Improve transmit CQ polling (bsc#1046299
  FATE#322947).
- net/mlx4_en: Improve receive data-path (bsc#1046299
  FATE#322947).
- net/mlx4_en: Optimized single ring steering (bsc#1046299
  FATE#322947).
- net/mlx4_en: Remove unused argument in TX datapath function
  (bsc#1046299 FATE#322947).
- IB/mlx4: Bump driver version (bsc#1046302 FATE#322945).
- net/mlx4_en: Bump driver version (bsc#1046299 FATE#322947).
- net/mlx4_core: Bump driver version (bsc#1046300 FATE#322946).
- commit 13e2dc6
* Fri Sep  8 2017 tbogendoerfer@suse.de
- Re-sorted network driver sorted section
- commit 011cd2d
* Fri Sep  8 2017 jslaby@suse.cz
- rpm/kernel-binary.spec.in: package ftrace-mod.o on arm64
  It is needed for building modules since 4.13:
  CC [M]  /suse/jslaby/a/aaa.o
  Building modules, stage 2.
  MODPOST 1 modules
  CC      /suse/jslaby/a/aaa.mod.o
  LD [M]  /suse/jslaby/a/aaa.ko
  ld: cannot find ./arch/arm64/kernel/ftrace-mod.o: No such file or directory
  ...
- commit 07da115
* Fri Sep  8 2017 msuchanek@suse.de
- net: ibm: ibmvnic: constify vio_device_id (fate#323285).
- ibmvnic: Add netdev_dbg output for debugging (fate#323285).
- ibmvnic: Clean up resources on probe failure (fate#323285).
- ibmvnic: Implement .get_channels (fate#323285).
- ibmvnic: Implement .get_ringparam (fate#323285).
- commit 1850d99
* Fri Sep  8 2017 msuchanek@suse.de
- ibmvnic: Convert vnic server reported statistics to cpu endian
  (fate#323285).
- ibmvnic: Implement per-queue statistics reporting (fate#323285).
- commit 1d86bd7
* Thu Sep  7 2017 bpoirier@suse.com
- net/{mii, smsc}: Make mii_ethtool_get_link_ksettings and
  smc_netdev_get_ecmd return void (bsc#1056666 FATE#322183).
- commit c133dc9
* Thu Sep  7 2017 bpoirier@suse.com
- igb: make a few local functions static (bsc#1056651 FATE#322191
  bsc#1056643 FATE#322192).
- igb: Remove useless argument (bsc#1056651 FATE#322191
  bsc#1056643 FATE#322192).
- igb: check for Tx timestamp timeouts during watchdog
  (bsc#1056651 FATE#322191 bsc#1056643 FATE#322192).
- igb: add statistic indicating number of skipped Tx timestamps
  (bsc#1056651 FATE#322191 bsc#1056643 FATE#322192).
- igb: avoid permanent lock of *_PTP_TX_IN_PROGRESS (bsc#1056651
  FATE#322191 bsc#1056643 FATE#322192).
- igb: fix race condition with PTP_TX_IN_PROGRESS bits
  (bsc#1056651 FATE#322191 bsc#1056643 FATE#322192).
- igb: mark PM functions as __maybe_unused (bsc#1056651
  FATE#322191 bsc#1056643 FATE#322192).
- commit 846d7ef
* Thu Sep  7 2017 bpoirier@suse.com
- i40e backport for SLE15
  e3412575488a net: ethernet: update drivers to handle HWTSTAMP_FILTER_NTP_ALL (v4.13-rc1)
  already added as part of e1000e
  eb873fe4d31b i40evf: fix duplicate lines (v4.13-rc1)
  155b0f690051 i40evf: fix merge error in older patch (v4.13-rc1)
  Already applied with ref bsc#1024346 FATE#321239 bsc#1024373
  FATE#321247. Refreshed.
  9d68322e53e6 i40evf: disable unused flags (v4.13-rc1)
  bbc4e7d273b5 i40e: fix race condition with PTP_TX_IN_PROGRESS bits (v4.13-rc1)
  69077577af50 i40e: avoid permanent lock of *_PTP_TX_IN_PROGRESS (v4.13-rc1)
  2955faca0403 i40e: add statistic indicating number of skipped Tx timestamps (v4.13-rc1)
  61189556692e i40e: use pf data structure directly in i40e_ptp_rx_hang (v4.13-rc1)
  0bc0706b46cd i40e: check for Tx timestamp timeouts during watchdog (v4.13-rc1)
  0a4ecc2c5e04 i40e: Check for memory allocation failure (v4.13-rc1)
  392908033308 i40evf: drop i40e_type.h include (v4.13-rc1)
  681bdf80cff6 i40e/i40evf: create and use new unified header file (v4.13-rc1)
  55cdfd48f217 i40e: use new unified virtchnl header file (v4.13-rc1)
  310a2ad92e3f virtchnl: rename i40e to generic virtchnl (v4.13-rc1)
  260e93820ad6 virtchnl: move some code to core driver (v4.13-rc1)
  eedcfef85b15 virtchnl: convert to new macros (v4.13-rc1)
  764430ce6f8c i40e/virtchnl: refactor code for validate checks (v4.13-rc1)
  f0adc6e831ba i40evf/virtchnl: whitespace cleanups (v4.13-rc1)
  ff3f4cc267f6 virtchnl: finish conversion to virtchnl interface (v4.13-rc1)
  735e35c56bbc i40e/virtchnl: move function to virtchnl (v4.13-rc1)
  a33c83c4353b virtchnl: Add pad fields to a couple of structures (v4.13-rc1)
  73556269aab3 virtchnl: Add compile time static asserts to validate structure sizes (v4.13-rc1)
  abf709a1e731 i40evf: Add support for Adaptive Virtual Function (v4.13-rc1)
  a5fcf8a6c968 net: propagate tc filter chain index down the ndo_setup_tc call (v4.13-rc1)
  already applied as part of ixgbe
  4df864c1d9af networking: make skb_put & friends return void pointers (v4.13-rc1)
  already applied with ref bsc#1056787
  0c8493d90b6b i40e: add XDP support for pass and drop actions (v4.13-rc1)
  74608d17fe29 i40e: add support for XDP_TX action (v4.13-rc1)
  65c7006f234c i40evf: assign num_active_queues inside i40evf_alloc_queues (v4.13-rc1)
  7c32b1e65075 i40e/i40evf: update WOL and I40E_AQC_ADDR_VALID_MASK flags (v4.13-rc1)
  59e331e36ef9 i40e: use dev_dbg instead of dev_info when warning about missing routine (v4.13-rc1)
  15d23b4c361f i40e: comment that udp_port must be in host byte order (v4.13-rc1)
  1e99854715c7 i40e: Fix potential out of bound array access (v4.13-rc1)
  68fb13a76774 i40e: Support firmware CEE DCB UP to TC map re-definition (v4.13-rc1)
  83d14c595e01 i40e: Add message for unsupported MFP mode (v4.13-rc1)
  4fc8c6763957 i40e: genericize the partition bandwidth control (v4.13-rc1)
  5bbb2e204544 i40e: Add support for OEM firmware version (v4.13-rc1)
  e58872398684 i40e: fix disabling overflow promiscuous mode (v4.13-rc1)
  2e5c26ea0d08 i40e: clear only cause_ena bit (v4.13-rc1)
  7642984b0876 i40e: Handle PE_CRITERR properly with IWARP enabled (v4.13-rc1)
  dfc4ff644674 i40e: don't hold RTNL lock for the entire reset (v4.13-rc1)
  7d6d06779028 i40e: Initialize 64-bit statistics TX ring seqcount (v4.13-rc5)
- i40e: Add message for unsupported MFP mode (bsc#1056658
  FATE#322188 bsc#1056662 FATE#322186).
- i40e: Add support for OEM firmware version (bsc#1056658
  FATE#322188 bsc#1056662 FATE#322186).
- i40e: Check for memory allocation failure (bsc#1056658
  FATE#322188 bsc#1056662 FATE#322186).
- i40e: Fix potential out of bound array access (bsc#1056658
  FATE#322188 bsc#1056662 FATE#322186).
- i40e: Handle PE_CRITERR properly with IWARP enabled (bsc#1056658
  FATE#322188 bsc#1056662 FATE#322186).
- i40e: Initialize 64-bit statistics TX ring seqcount (bsc#1056658
  FATE#322188 bsc#1056662 FATE#322186).
- i40e: Support firmware CEE DCB UP to TC map re-definition
  (bsc#1056658 FATE#322188 bsc#1056662 FATE#322186).
- i40e: add XDP support for pass and drop actions (bsc#1056658
  FATE#322188 bsc#1056662 FATE#322186).
- i40e: add statistic indicating number of skipped Tx timestamps
  (bsc#1056658 FATE#322188 bsc#1056662 FATE#322186).
- i40e: add support for XDP_TX action (bsc#1056658 FATE#322188
  bsc#1056662 FATE#322186).
- i40e: avoid permanent lock of *_PTP_TX_IN_PROGRESS (bsc#1056658
  FATE#322188 bsc#1056662 FATE#322186).
- i40e: check for Tx timestamp timeouts during watchdog
  (bsc#1056658 FATE#322188 bsc#1056662 FATE#322186).
- i40e: clear only cause_ena bit (bsc#1056658 FATE#322188
  bsc#1056662 FATE#322186).
- i40e: comment that udp_port must be in host byte order
  (bsc#1056658 FATE#322188 bsc#1056662 FATE#322186).
- i40e: don't hold RTNL lock for the entire reset (bsc#1056658
  FATE#322188 bsc#1056662 FATE#322186).
- i40e: fix disabling overflow promiscuous mode (bsc#1056658
  FATE#322188 bsc#1056662 FATE#322186).
- i40e: fix race condition with PTP_TX_IN_PROGRESS bits
  (bsc#1056658 FATE#322188 bsc#1056662 FATE#322186).
- i40e: genericize the partition bandwidth control (bsc#1056658
  FATE#322188 bsc#1056662 FATE#322186).
- i40e/i40evf: create and use new unified header file (bsc#1056658
  FATE#322188 bsc#1056662 FATE#322186).
- i40e/i40evf: update WOL and I40E_AQC_ADDR_VALID_MASK flags
  (bsc#1056658 FATE#322188 bsc#1056662 FATE#322186).
- i40e: use dev_dbg instead of dev_info when warning about missing
  routine (bsc#1056658 FATE#322188 bsc#1056662 FATE#322186).
- i40e: use new unified virtchnl header file (bsc#1056658
  FATE#322188 bsc#1056662 FATE#322186).
- i40e: use pf data structure directly in i40e_ptp_rx_hang
  (bsc#1056658 FATE#322188 bsc#1056662 FATE#322186).
- i40e/virtchnl: move function to virtchnl (bsc#1056658
  FATE#322188 bsc#1056662 FATE#322186).
- i40e/virtchnl: refactor code for validate checks (bsc#1056658
  FATE#322188 bsc#1056662 FATE#322186).
- i40evf: Add support for Adaptive Virtual Function (bsc#1056658
  FATE#322188 bsc#1056662 FATE#322186).
- i40evf: assign num_active_queues inside i40evf_alloc_queues
  (bsc#1056658 FATE#322188 bsc#1056662 FATE#322186).
- i40evf: disable unused flags (bsc#1056658 FATE#322188
  bsc#1056662 FATE#322186).
- i40evf: drop i40e_type.h include (bsc#1056658 FATE#322188
  bsc#1056662 FATE#322186).
- i40evf: fix duplicate lines (bsc#1056658 FATE#322188 bsc#1056662
  FATE#322186).
- i40evf/virtchnl: whitespace cleanups (bsc#1056658 FATE#322188
  bsc#1056662 FATE#322186).
- virtchnl: Add compile time static asserts to validate structure
  sizes (bsc#1056658 FATE#322188 bsc#1056662 FATE#322186).
- virtchnl: Add pad fields to a couple of structures (bsc#1056658
  FATE#322188 bsc#1056662 FATE#322186).
- virtchnl: convert to new macros (bsc#1056658 FATE#322188
  bsc#1056662 FATE#322186).
- virtchnl: finish conversion to virtchnl interface (bsc#1056658
  FATE#322188 bsc#1056662 FATE#322186).
- virtchnl: move some code to core driver (bsc#1056658 FATE#322188
  bsc#1056662 FATE#322186).
- virtchnl: rename i40e to generic virtchnl (bsc#1056658
  FATE#322188 bsc#1056662 FATE#322186).
- Refresh
  patches.drivers/i40evf-fix-merge-error-in-older-patch.patch.
- commit dd418e7
* Thu Sep  7 2017 tbogendoerfer@suse.de
- net: check type when freeing metadata dst (bsc#1056787).
- commit a09d253
* Thu Sep  7 2017 tiwai@suse.de
- rpm/kernel-docs.spec.in: Expand kernel tree directly from sources (bsc#1057199)
- commit a61b4d9
* Thu Sep  7 2017 tbogendoerfer@suse.de
- cisco: enic: Fic an error handling path in
  'vnic_dev_init_devcmd2()' (bsc#1037697).
- enic: Fix format truncation warning (bsc#1037697).
- enic: unmask intr only when napi is complete (bsc#1037697).
- commit c00bce8
* Thu Sep  7 2017 mgorman@suse.de
- Refresh
  patches.suse/exports-from-rcu_idle_exit-and-rcu_idle_enter.patch.
- Refresh
  patches.suse/numa-sched-slow-down-scan-rate-if-shared-faults-dominate.patch.
- Refresh
  patches.suse/page-waitqueue-always-add-new-entries-at-the-end.patch.
- Refresh
  patches.suse/rcu_idle_enter-rely-on-callers-disabling-irqs.patch.
- Refresh
  patches.suse/sched-numa-scale-scan-period-with-tasks-in-group-and-shared-private.patch.
- commit 14198d9
* Thu Sep  7 2017 jack@suse.cz
- gfs2: Don't clear SGID when inheriting ACLs (bsc#1052766).
- commit 6e0baaf
* Thu Sep  7 2017 jack@suse.cz
- xfs: fix inobt inode allocation search optimization
  (bsc#1052766).
- commit d59b124
* Thu Sep  7 2017 oneukum@suse.com
- Update config files.
  Switch off radio support (FATE#323882)
- commit 9ff0bc2
* Thu Sep  7 2017 oneukum@suse.com
- intel_th: pci: Add Cannon Lake PCH-H support (FATE#321195).
- intel_th: pci: Add Cannon Lake PCH-LP support (FATE#321195).
- commit 9fe67df
* Thu Sep  7 2017 tiwai@suse.de
- drm/i915/cfl: Fix Workarounds (FATE#322643 bsc#1055900).
- drm/i915/cfl: Introduce Coffee Lake workarounds (FATE#322643
  bsc#1055900).
- drm/i915: Store 9 bits of PCI Device ID for platforms with a
  LP PCH (FATE#322643 bsc#1055900).
- drm/i915/cfl: Basic DDI plumbing for Coffee Lake (FATE#322643
  bsc#1055900).
- drm/i915/cfl: Coffee Lake reuses Kabylake DMC (FATE#322643
  bsc#1055900).
- drm/i915/huc: Load HuC on Coffee Lake (FATE#322643 bsc#1055900).
- drm/i915/guc: Load GuC on Coffee Lake (FATE#322643 bsc#1055900).
- drm/i915/cfl: Add Coffee Lake PCI IDs for U Sku (FATE#322643
  bsc#1055900).
- drm/i915/cfl: Add Coffee Lake PCI IDs for H Sku (FATE#322643
  bsc#1055900).
- drm/i915/cfl: Add Coffee Lake PCI IDs for S Skus (FATE#322643
  bsc#1055900).
- drm/i915/cfl: Introduce Display workarounds for Coffee Lake
  (FATE#322643 bsc#1055900).
- drm/i915/cfl: Coffee Lake uses CNP PCH (FATE#322643
  bsc#1055900).
- drm/i915/cfl: Introduce Coffee Lake platform definition
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Cannonlake uses CNP PCH (FATE#322643 bsc#1055900).
- drm/i915/cnp: Panel Power sequence changes for CNP PCH
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Introduce Cannonlake platform defition
  (FATE#322643 bsc#1055900).
- drm/i915/cnp: add CNP gmbus support (FATE#322643 bsc#1055900).
- drm/i915/cnp: Backlight support for CNP (FATE#322643
  bsc#1055900).
- drm/i915/cnp: Get/set proper Raw clock frequency on CNP
  (FATE#322643 bsc#1055900).
- drm/i915/cnp: Add PCI ID for Cannonpoint LP PCH (FATE#322643
  bsc#1055900).
- drm/i915/cnp: Introduce Cannonpoint PCH (FATE#322643
  bsc#1055900).
- commit 602378e
* Thu Sep  7 2017 jslaby@suse.cz
- Linux 4.12.11 (bnc#1012628).
- commit bf7fb08
* Wed Sep  6 2017 bpoirier@suse.com
- Update config files.
  Needed because of the backport of 7edaeb6841df ("kernel/watchdog: Prevent
  false positives with turbo modes", v4.13-rc6) added in v4.12.9.
- commit 6d65043
* Wed Sep  6 2017 bpoirier@suse.com
- net: Fix parisc SCM_TIMESTAMPING_PKTINFO value (bsc#1056664
  FATE#322185).
- net: Define SCM_TIMESTAMPING_PKTINFO on all architectures
  (bsc#1056664 FATE#322185).
- commit ad597de
* Wed Sep  6 2017 bpoirier@suse.com
- ixgbe: Initialize 64-bit stats seqcounts (bsc#1056657
  FATE#322189 bsc#1056653 FATE#322190).
- bpf: ixgbe: Report bpf_prog ID during XDP_QUERY_PROG
  (bsc#1056657 FATE#322189 bsc#1056653 FATE#322190).
- net: Add IFLA_XDP_PROG_ID (bsc#1056657 FATE#322189 bsc#1056653
  FATE#322190).
- ixgbe: pci_set_drvdata must be called before register_netdev
  (bsc#1056657 FATE#322189 bsc#1056653 FATE#322190).
- ixgbe: Resolve cppcheck format string warning (bsc#1056657
  FATE#322189 bsc#1056653 FATE#322190).
- ixgbe: fix writes to PFQDE (bsc#1056657 FATE#322189 bsc#1056653
  FATE#322190).
- ixgbevf: Bump version number (bsc#1056657 FATE#322189
  bsc#1056653 FATE#322190).
- ixgbe: Bump version number (bsc#1056657 FATE#322189 bsc#1056653
  FATE#322190).
- ixgbe: check for Tx timestamp timeouts during watchdog
  (bsc#1056657 FATE#322189 bsc#1056653 FATE#322190).
- ixgbe: add statistic indicating number of skipped Tx timestamps
  (bsc#1056657 FATE#322189 bsc#1056653 FATE#322190).
- ixgbe: avoid permanent lock of *_PTP_TX_IN_PROGRESS (bsc#1056657
  FATE#322189 bsc#1056653 FATE#322190).
- ixgbe: fix race condition with PTP_TX_IN_PROGRESS bits
  (bsc#1056657 FATE#322189 bsc#1056653 FATE#322190).
- net: propagate tc filter chain index down the ndo_setup_tc call
  (bsc#1056657 FATE#322189 bsc#1056653 FATE#322190).
- bpf: Introduce bpf_prog ID (bsc#1056657 FATE#322189 bsc#1056653
  FATE#322190).
- ixgbe: fix incorrect status check (bsc#1056657 FATE#322189
  bsc#1056653 FATE#322190).
- ixgbe: add missing configuration for rate select 1 (bsc#1056657
  FATE#322189 bsc#1056653 FATE#322190).
- ixgbe: always call setup_mac_link for multispeed fiber
  (bsc#1056657 FATE#322189 bsc#1056653 FATE#322190).
- ixgbe: add write flush when configuring CS4223/7 (bsc#1056657
  FATE#322189 bsc#1056653 FATE#322190).
- ixgbe: correct CS4223/7 PHY identification (bsc#1056657
  FATE#322189 bsc#1056653 FATE#322190).
- ixgbevf: Resolve warnings for -Wimplicit-fallthrough
  (bsc#1056657 FATE#322189 bsc#1056653 FATE#322190).
- ixgbevf: Resolve truncation warning for q_vector->name
  (bsc#1056657 FATE#322189 bsc#1056653 FATE#322190).
- ixgbe: Resolve warnings for -Wimplicit-fallthrough (bsc#1056657
  FATE#322189 bsc#1056653 FATE#322190).
- ixgbe: Resolve truncation warning for q_vector->name
  (bsc#1056657 FATE#322189 bsc#1056653 FATE#322190).
- ixgbe: Add error checking to setting VF MAC (bsc#1056657
  FATE#322189 bsc#1056653 FATE#322190).
- ixgbe: Correct thermal sensor event check (bsc#1056657
  FATE#322189 bsc#1056653 FATE#322190).
- ixgbe: enable L3/L4 filtering for Tx switched packets
  (bsc#1056657 FATE#322189 bsc#1056653 FATE#322190).
- ixgbe: Remove MAC X550EM_X 1Gbase-t led_[on|off] support
  (bsc#1056657 FATE#322189 bsc#1056653 FATE#322190).
- ixgbe: initialize u64_stats_sync structures early at ixgbe_probe
  (bsc#1056657 FATE#322189 bsc#1056653 FATE#322190).
- ixgbe/ixgbevf: Enables TSO for MPLS encapsulated packets
  (bsc#1056657 FATE#322189 bsc#1056653 FATE#322190).
- net: sched: add termination action to allow goto chain
  (bsc#1056657 FATE#322189 bsc#1056653 FATE#322190).
- net: sched: push tp down to action init (bsc#1056657 FATE#322189
  bsc#1056653 FATE#322190).
- net: sched: introduce multichain support for filters
  (bsc#1056657 FATE#322189 bsc#1056653 FATE#322190).
- net: sched: push chain dump to a separate function (bsc#1056657
  FATE#322189 bsc#1056653 FATE#322190).
- net: sched: introduce helpers to work with filter chains
  (bsc#1056657 FATE#322189 bsc#1056653 FATE#322190).
- net: sched: move TC_H_MAJ macro call into tcf_auto_prio
  (bsc#1056657 FATE#322189 bsc#1056653 FATE#322190).
- net: sched: replace nprio by a bool to make the function more
  readable (bsc#1056657 FATE#322189 bsc#1056653 FATE#322190).
- net: sched: rename tcf_destroy_chain helper (bsc#1056657
  FATE#322189 bsc#1056653 FATE#322190).
- net: sched: introduce tcf block infractructure (bsc#1056657
  FATE#322189 bsc#1056653 FATE#322190).
- net: sched: move tc_classify function to cls_api.c (bsc#1056657
  FATE#322189 bsc#1056653 FATE#322190).
- commit fe2f3a3
* Wed Sep  6 2017 bpoirier@suse.com
- e1000e: Undo e1000e_pm_freeze if __e1000_shutdown fails
  (bsc#1056664 FATE#322185).
- e1000e: use disable_hardirq() also for MSIX vectors in
  e1000_netpoll() (bsc#1056664 FATE#322185).
- e1000e: add statistic indicating number of skipped Tx timestamps
  (bsc#1056664 FATE#322185).
- e1000e: fix race condition around skb_tstamp_tx() (bsc#1056664
  FATE#322185).
- net: ethernet: update drivers to make both SW and HW TX
  timestamps (bsc#1056664 FATE#322185).
- net: allow simultaneous SW and HW transmit timestamping
  (bsc#1056664 FATE#322185).
- net: fix documentation of struct scm_timestamping (bsc#1056664
  FATE#322185).
- net: add new control message for incoming HW-timestamped packets
  (bsc#1056664 FATE#322185).
- net: add function to retrieve original skb device using NAPI ID
  (bsc#1056664 FATE#322185).
- net: ethernet: update drivers to handle HWTSTAMP_FILTER_NTP_ALL
  (bsc#1056664 FATE#322185).
- net: define receive timestamp filter for NTP (bsc#1056664
  FATE#322185).
- commit ac365e2
* Wed Sep  6 2017 tiwai@suse.de
- rpm/kernel-docs.spec.in: Re-add xmlto buildreq conditionally for SLE15 & co
- commit 259b49e
* Wed Sep  6 2017 mchandras@suse.de
- rpm/group-source-files.pl: Add arch/*/tools/* files to the devel package
  Commit b71c9ffb1405 ("powerpc: Add arch/powerpc/tools directory")
  introduced in v4.12-rc1 release, moved the scripts into the tools
  directory. However, this location is not considered for the kernel devel
  package and the following error occurs when building a kmp for powerpc
  make[2]: /usr/src/linux-4.12.9-1/arch/powerpc/tools/gcc-check-mprofile-kernel.sh: Command not found
- commit 5f1ff53
* Tue Sep  5 2017 mbrugger@suse.com
- Delete
  patches.drivers/0002-hns-set-relation-between-hns_roce-and-hns_enet_drv.patch.
- commit 1532f7a
* Tue Sep  5 2017 mbrugger@suse.com
- Delete
  patches.arch/arm64-1-5-arm64-perf-Basic-uncore-counter-support-for-Cavium-ThunderX.patch.
- Delete
  patches.arch/arm64-2-5-arm64-perf-Cavium-ThunderX-L2C-TAD-uncore-support.patch.
- Delete
  patches.arch/arm64-3-5-arm64-perf-Cavium-ThunderX-L2C-CBC-uncore-support.patch.
- Delete
  patches.arch/arm64-4-5-arm64-perf-Cavium-ThunderX-LMC-uncore-support.patch.
- Delete
  patches.arch/arm64-5-5-arm64-perf-Cavium-ThunderX-OCX-TLK-uncore-support.patch.
  Delete not upstreamed driver
- commit 68629cf
* Tue Sep  5 2017 mbrugger@suse.com
- Delete
  patches.suse/arm64-0075-kdump-kexec-arm64-Add-kernel-parameter-to-enable-kexec.patch.
- commit 0bb01f6
* Tue Sep  5 2017 mbrugger@suse.com
- Delete
  patches.arch/arm64-0001-arm64-insn-Do-not-disable-irqs-during-patching.patch.
- Delete
  patches.arch/arm64-0002-arm64-Implement-IPI-based-TLB-invalidation.patch.
- Delete
  patches.arch/arm64-0003-KVM-arm-arm64-Check-for-broadcast-TLBI-support.patch.
- Delete
  patches.arch/arm64-0005-arm64-Add-workaround-for-Cavium-erratum-26026.patch.
  HW which needed this workaround is no longer supported
- commit bfc65a0
* Tue Sep  5 2017 jlee@suse.com
- Update config files. (fate#323414)
  Enable IMA kernel configuration on arm64 and s390x. (fate#323414)
- commit 39207d0
* Tue Sep  5 2017 jthumshirn@suse.de
- Update config files, enable NVMe on S/390x (FATE#323773).
- commit 6e56e74
* Tue Sep  5 2017 tbogendoerfer@suse.de
- cxgb4: Fix stack out-of-bounds read due to wrong size to
  t4_record_mbox() (bsc#1046540).
- iw_cxgb4: fix misuse of integer variable (bsc#1046543).
- iw_cxgb4: don't use WR keys/addrs for 0 byte reads
  (bsc#1046543).
- cxgb4: Fix error codes in c4iw_create_cq() (bsc#1046540).
- cxgb4: ptp_clock_register() returns error pointers (bsc#1046540
  bsc#1046648).
- cxgb4: add new T5 pci device id's (bsc#1046540).
- crypto: chcr - Avoid algo allocation in softirq (bsc#1046548).
- cxgb4: Support for get_ts_info ethtool method (bsc#1046540
  bsc#1046648).
- cxgb4: Add PTP Hardware Clock (PHC) support (bsc#1046540
  bsc#1046648).
- cxgb4: time stamping interface for PTP (bsc#1046540
  bsc#1046648).
- cxgb4: Use Firmware params to get buffer-group map
  (bsc#1046540).
- cxgb4: Update T6 Buffer Group and Channel Mappings
  (bsc#1046540).
- net: introduce __skb_put_[zero, data, u8] (bsc#1056787).
- cxgb4: add new T6 pci device id's (bsc#1046540).
- cxgb4: fix a NULL dereference (bsc#1046540).
- cxgb4: handle serial flash interrupt (bsc#1046540).
- cxgb4: fix memory leak in init_one() (bsc#1046540).
- cxgb4: handle interrupt raised when FW crashes (bsc#1046540).
- cxgb4: fix to bring link down after adapter crash (bsc#1046540).
- tcp: add a struct net parameter to tcp_parse_options()
  (bsc#1046543).
  Refresh
  patches.drivers/networking-make-skb_push-__skb_push-return-void-poin.patch.
- crypto: chcr - Select device in Round Robin fashion
  (bsc#1046548).
- crypto: chcr - Ensure Destination sg entry size less than 2k
  (bsc#1046548).
- chcr - Add debug counters (bsc#1046548).
- crypto: chcr - Add ctr mode and process large sg entries for
  cipher (bsc#1046548).
  Refresh
  patches.drivers/networking-make-skb_put-friends-return-void-pointers.patch.
- crypto: chcr - Avoid changing request structure (bsc#1046548).
- crypto: chcr - Return correct error code (bsc#1046548).
- crypto: chcr - Fix fallback key setting (bsc#1046548).
- crypto: chcr - Pass lcb bit setting to firmware (bsc#1046548).
- commit dd52566
* Tue Sep  5 2017 tiwai@suse.de
- drm/dp/mst: Handle errors from
  drm_atomic_get_private_obj_state() correctly (bsc#1055493).
- drm/i915: Track MST link bandwidth (bsc#1055493).
- drm/dp: Add DP MST helpers to atomically find and release vcpi
  slots (bsc#1055493).
- drm/dp: Introduce MST topology state to track available link
  bandwidth (bsc#1055493).
- drm: Add driver-private objects to atomic state (bsc#1055493).
- commit 5bd7bf1
* Tue Sep  5 2017 lduncan@suse.com
- cxgbit: fix sg_nents calculation (bsc#1046545).
- iscsi-target: fix invalid flags in text response (bsc#1046545).
- cxgbit: add missing __kfree_skb() (bsc#1046545).
- commit 053e1ff
* Tue Sep  5 2017 lduncan@suse.com
- RDMA/iser: don't send an rkey if all data is written as
  immadiate-data (bsc#1046647).
- IB/iser: Handle lack of memory management extentions correctly
  (bsc#1046647).
- commit e8af9ba
* Tue Sep  5 2017 dbueso@suse.de
- x86/nmi: Use raw lock (bsc#1050549).
- locking/rwsem-xadd: Add killable versions of
  rwsem_down_read_failed() (bsc#1050549).
- locking/rwsem-spinlock: Add killable versions of __down_read()
  (bsc#1050549).
- locking/pvqspinlock: Relax cmpxchg's to improve performance
  on some architectures (bsc#1050549).
- smp: Avoid using two cache lines for struct call_single_data
  (bsc#1050549).
- smp, cpumask: Use non-atomic cpumask_{set,clear}_cpu()
  (bsc#1050549).
- smp: Avoid sending needless IPI in smp_call_function_many()
  (bsc#1050549).
- commit 46ecda3
* Mon Sep  4 2017 msuchanek@suse.de
- powerpc/xive: Fix section __init warning (fate#322438).
- commit fe47c32
* Mon Sep  4 2017 msuchanek@suse.de
- powerpc/xive: improve debugging macros (fate#322438).
- powerpc/xive: add XIVE Exploitation Mode to CAS (fate#322438).
- powerpc/xive: introduce H_INT_ESB hcall (fate#322438).
- powerpc/xive: add the HW IRQ number under xive_irq_data
  (fate#322438).
- powerpc/xive: introduce xive_esb_write() (fate#322438).
- commit daa41de
* Mon Sep  4 2017 msuchanek@suse.de
- powerpc/xive: rename xive_poke_esb() in xive_esb_read()
  (fate#322438).
- powerpc/xive: guest exploitation of the XIVE interrupt
  controller (fate#322438).
- powerpc/xive: introduce a common routine xive_queue_page_alloc()
  (fate#322438).
- powerpc/xmon: Exclude all of xmon from ftrace (fate#322438).
- commit 71dd0bb
* Mon Sep  4 2017 bpoirier@suse.com
- Refresh patch order in networking section
- commit 2da2414
* Mon Sep  4 2017 msuchanek@suse.de
- powerpc/xive: Fix the size of the cpumask used in
  xive_find_target_in_mask() (fate#322438).
- commit 956ce91
* Mon Sep  4 2017 tbogendoerfer@suse.de
- sch_sfq: fix null pointer dereference on init failure
  (bsc#1056787).
- sch_hfsc: fix null pointer deref and double free on init failure
  (bsc#1056787).
- net: sched: don't do tcf_chain_flush from tcf_chain_destroy
  (bsc#1056787).
- net: sched: fix use after free when tcf_chain_destroy is called
  multiple times (bsc#1056787).
- udp: make function udp_skb_dtor_locked static (bsc#1056787).
- commit a5094e3
* Mon Sep  4 2017 tbogendoerfer@suse.de
- nfp: double free on error in probe (bsc#1055968).
- nfp: remove incorrect mask check for vlan matching
  (bsc#1055968).
- nfp: fix supported key layers calculation (bsc#1055968).
- nfp: fix unchecked flow dissector use (bsc#1055968).
- nfp: avoid buffer leak when representor is missing
  (bsc#1055968).
- nfp: make sure representors are destroyed before their lower
  netdev (bsc#1055968).
- nfp: don't hold PF lock while enabling SR-IOV (bsc#1055968).
- commit 6f53b58
* Mon Sep  4 2017 tbogendoerfer@suse.de
- net: Define SCM_TIMESTAMPING_PKTINFO on all architectures
  (bsc#1056787).
- commit 502bfad
* Mon Sep  4 2017 tbogendoerfer@suse.de
- Update config files.
- commit 3eb3872
* Mon Sep  4 2017 tbogendoerfer@suse.de
- nfp: do not update MTU from BH in flower app (bsc#1055968).
- nfp: Initialize RX and TX ring 64-bit stats seqcounts
  (bsc#1055968).
- nfp: freeing the wrong variable (bsc#1055968).
- nfp: flower: add missing clean up call to avoid memory leaks
  (bsc#1055968).
- nfp: default to chained metadata prepend format (bsc#1055968).
- nfp: remove legacy MAC address lookup (bsc#1055968).
- nfp: improve order of interfaces in breakout mode (bsc#1055968).
- nfp: add control message passing capabilities to flower offloads
  (bsc#1055968).
- nfp: add a stats handler for flower offloads (bsc#1055968).
- nfp: add metadata to each flow offload (bsc#1055968).
- nfp: add basic action capabilities to flower offloads
  (bsc#1055968).
- nfp: extend flower matching capabilities (bsc#1055968).
- nfp: extend flower add flow offload (bsc#1055968).
- nfp: provide infrastructure for offloading flower based TC
  filters (bsc#1055968).
- nfp: add phys_switch_id support (bsc#1055968).
- nfp: flower: add Kconfig for flower app (bsc#1055968).
- nfp: allocate a private workqueue for driver work (bsc#1055968).
- nfp: reorder SR-IOV config and nfp_app SR-IOV callbacks
  (bsc#1055968).
- nfp: handle SR-IOV already enabled when driver is probing
  (bsc#1055968).
- nfp: wire get_phys_port_name on representors (bsc#1055968).
- nfp: allow converting representor's netdev into nfp_port
  (bsc#1055968).
- nfp: move representors' struct net_device_ops to shared code
  (bsc#1055968).
- nfp: make the representor get stats app-independent
  (bsc#1055968).
- nfp: spawn nfp_ports for PF and VF ports (bsc#1055968).
- nfp: add nfp_app cleanup callback and make flower use it
  (bsc#1055968).
- nfp: remove unused nfp_cpp_area_check_range() (bsc#1055968).
- nfp: add helper for mapping runtime symbols (bsc#1055968).
- nfp: move area mapping helper into nfpcore (bsc#1055968).
- nfp: explicitly check if application FW is loaded (bsc#1055968).
- nfp: add VF and PF representors to flower app (bsc#1055968).
- nfp: add flower app (bsc#1055968).
- nfp: add support for control messages for flower app
  (bsc#1055968).
- nfp: add support for tx/rx with metadata portid (bsc#1055968).
- nfp: provide nfp_port to of nfp_net_get_mac_addr()
  (bsc#1055968).
- nfp: app callbacks for SRIOV (bsc#1055968).
- nfp: add stats and xmit helpers for representors (bsc#1055968).
- nfp: general representor implementation (bsc#1055968).
- nfp: map mac_stats and vf_cfg BARs (bsc#1055968).
- nfp: move physical port init into a helper (bsc#1055968).
- nfp: devlink add support for getting eswitch mode (bsc#1055968).
- nfp: xdp: report if program is offloaded (bsc#1055968).
- nfp: bpf: add support for XDP_FLAGS_HW_MODE (bsc#1055968).
- nfp: bpf: release the reference on offloaded programs
  (bsc#1055968).
- nfp: bpf: don't offload XDP programs in DRV_MODE (bsc#1055968).
- nfp: xdp: move driver XDP setup into a separate function
  (bsc#1055968).
- nfp: add VLAN filtering support (bsc#1055968).
- bpf: nfp: Report bpf_prog ID during XDP_QUERY_PROG
  (bsc#1055968).
- nfp: report application FW build name in ethtool -i
  (bsc#1055968).
- nfp: keep MIP object around (bsc#1055968).
- nfp: remove automatic caching of HWInfo (bsc#1055968).
- nfp: remove automatic caching of RTsym table (bsc#1055968).
- nfp: make sure to cancel port refresh on the error path
  (bsc#1055968).
- commit 2a7c54a
* Mon Sep  4 2017 tbogendoerfer@suse.de
- net: sched: fix p_filter_chain check in tcf_chain_flush
  (bsc#1056787).
- net_sched: reset pointers to tcf blocks in classful qdiscs'
  destructors (bsc#1056787).
- net/sched/hfsc: allocate tcf block for hfsc root class
  (bsc#1056787).
- commit b26c3ec
* Mon Sep  4 2017 tbogendoerfer@suse.de
- net: switchdev: add SET_SWITCHDEV_OPS helper (bsc#1056787).
- net: store port/representator id in metadata_dst (bsc#1056787).
- xdp: add reporting of offload mode (bsc#1056787).
- xdp: add HW offload mode flag for installing programs
  (bsc#1056787).
- xdp: pass XDP flags into install handlers (bsc#1056787).
- net: Add IFLA_XDP_PROG_ID (bsc#1056787).
- bpf: Introduce bpf_prog ID (bsc#1056787).
- bpf: teach verifier to track stack depth (bsc#1056787).
- commit 5b751d3
* Mon Sep  4 2017 tbogendoerfer@suse.de
- networking: add and use skb_put_u8() (bsc#1056787).
- networking: make skb_push & __skb_push return void pointers
  (bsc#1056787).
- networking: make skb_pull & friends return void pointers
  (bsc#1056787).
- networking: make skb_put & friends return void pointers
  (bsc#1056787).
- networking: introduce and use skb_put_data() (bsc#1056787).
- networking: convert many more places to skb_put_zero()
  (bsc#1056787).
- net: sched: act_tunnel_key: make UDP checksum configurable
  (bsc#1056787).
- net: sched: act_tunnel_key: request UDP checksum by default
  (bsc#1056787).
- skbuff: make skb_put_zero() return void (bsc#1056787).
- net: use skb_unref() in napi_consume_skb() (bsc#1056787).
- bpf: permits narrower load from bpf program context fields
  (bsc#1056787).
- skbuff/mac80211: introduce and use skb_put_zero() (bsc#1056787).
- mac80211: mesh: support sending wide bandwidth CSA
  (bsc#1056787).
- net: factor out a helper to decrement the skb refcount
  (bsc#1056787).
- bpf: add bpf_set_hash helper for tc progs (bsc#1056787).
- bpf: remove cg_skb_func_proto and use sk_filter_func_proto
  directly (bsc#1056787).
- skbuff: only inherit relevant tx_flags (bsc#1056787).
- net: qrtr: Inform open sockets about new controller
  (bsc#1056787).
- net: qrtr: Broadcast DEL_CLIENT message when endpoint is closed
  (bsc#1056787).
- net: qrtr: Inject BYE on remote termination (bsc#1056787).
- net: qrtr: Refactor packet allocation (bsc#1056787).
- net: propagate tc filter chain index down the ndo_setup_tc call
  (bsc#1056787).
- net: sched: introduce a TRAP control action (bsc#1056787).
- net: sched: select cls when cls_act is enabled (bsc#1056787).
- neigh: Really delete an arp/neigh entry on "ip neigh delete"
  or "arp -d" (bsc#1056787).
- net/sched: cls_flower: add support for matching on ip tos and
  ttl (bsc#1056787).
- net/flow_dissector: add support for dissection of misc ip
  header fields (bsc#1056787).
- rtnetlink: use the new rtnl_get_event() interface (bsc#1056787).
- rtnl: Add support for netdev event to link messages
  (bsc#1056787).
- net_sched: only create filter chains for new filters/actions
  (bsc#1056787).
- net: sched: cls_api: make reclassify return all the way back
  to the original tp (bsc#1056787).
- net/sched: flower: add support for matching on tcp flags
  (bsc#1056787).
- net: flow_dissector: add support for dissection of tcp flags
  (bsc#1056787).
- net/sched: fix filter flushing (bsc#1056787).
- net/sched: properly assign RCU pointer in
  tcf_chain_tp_insert/remove (bsc#1056787).
- net: allow simultaneous SW and HW transmit timestamping
  (bsc#1056787).
- net: add new control message for incoming HW-timestamped packets
  (bsc#1056787).
- net: add function to retrieve original skb device using NAPI ID
  (bsc#1056787).
- net: ethernet: update drivers to handle HWTSTAMP_FILTER_NTP_ALL
  (bsc#1056787).
- net: define receive timestamp filter for NTP (bsc#1056787).
- sk_buff.h: improve description of CHECKSUM_{COMPLETE,
  UNNECESSARY} (bsc#1056787).
- net: more accurate checksumming in validate_xmit_skb()
  (bsc#1056787).
- net: use skb->csum_not_inet to identify packets needing crc32c
  (bsc#1056787).
- sk_buff: remove support for csum_bad in sk_buff (bsc#1056787).
- net: introduce skb_crc32c_csum_help (bsc#1056787).
- skbuff: add stub to help computing crc32c on SCTP packets
  (bsc#1056787).
- net: fix __skb_try_recv_from_queue to return the old behavior
  (bsc#1056787).
- net: make struct net_device::tx_queue_len unsigned int
  (bsc#1056787).
- sch_dsmark: Fix uninitialized variable warning (bsc#1056787).
- net: sched: add termination action to allow goto chain
  (bsc#1056787).
- net: sched: push tp down to action init (bsc#1056787).
- net: sched: introduce multichain support for filters
  (bsc#1056787).
- net: sched: push chain dump to a separate function
  (bsc#1056787).
- net: sched: introduce helpers to work with filter chains
  (bsc#1056787).
- net: sched: move TC_H_MAJ macro call into tcf_auto_prio
  (bsc#1056787).
- net: sched: replace nprio by a bool to make the function more
  readable (bsc#1056787).
- net: sched: rename tcf_destroy_chain helper (bsc#1056787).
- net: sched: introduce tcf block infractructure (bsc#1056787).
- net: sched: move tc_classify function to cls_api.c
  (bsc#1056787).
- tcp: internal implementation for pacing (bsc#1056787).
- udp: keep the sk_receive_queue held when splicing (bsc#1056787).
- udp: use a separate rx queue for packet reception (bsc#1056787).
- net/sock: factor out dequeue/peek with offset code
  (bsc#1056787).
- net: fix some identation issues at kernel-doc markups
  (bsc#1056787).
- net: skbuff.h: properly escape a macro name on kernel-doc
  (bsc#1056787).
- commit 7232e8e
* Mon Sep  4 2017 bp@suse.de
- x86/mm: Fix SME encryption stack ptr handling (fate#322123).
- commit aea6d23
* Mon Sep  4 2017 bp@suse.de
- acpi, x86/mm: Remove encryption mask from ACPI page protection
  type (fate#322123).
- commit 4d393f7
* Mon Sep  4 2017 bp@suse.de
- x86/mm, kexec: Fix memory corruption with SME on successive
  kexecs (fate#322123).
- commit 261ee7e
* Mon Sep  4 2017 bp@suse.de
- x86/boot: Fix memremap() related build failure (fate#322123).
- commit 04d48c7
* Mon Sep  4 2017 bp@suse.de
- x86/boot/64/clang: Use fixup_pointer() to access
  'next_early_pgt' (fate#322123).
  Subsequently pulled in by git-fixes.
- commit db95bac
* Mon Sep  4 2017 bp@suse.de
- x86/mm: Add support to make use of Secure Memory Encryption
  (fate#322123).
- commit 1ede395
* Mon Sep  4 2017 bp@suse.de
- compiler-gcc.h: Introduce __nostackprotector function attribute
  (fate#322123).
- commit 9b71e69
* Mon Sep  4 2017 bp@suse.de
- x86/boot: Add early cmdline parsing for options with arguments
  (fate#322123).
- commit f880532
* Mon Sep  4 2017 bp@suse.de
- x86/mm: Add support to encrypt the kernel in-place
  (fate#322123).
- commit 7fb1d36
* Mon Sep  4 2017 bp@suse.de
- x86/mm: Create native_make_p4d() for PGTABLE_LEVELS <= 4
  (fate#322123).
- commit 519d43f
* Mon Sep  4 2017 bp@suse.de
- x86/mm: Use proper encryption attributes with /dev/mem
  (fate#322123).
- commit 7e40dec
* Mon Sep  4 2017 bp@suse.de
- xen/x86: Remove SME feature in PV guests (fate#322123).
- commit b2b2f82
* Mon Sep  4 2017 bp@suse.de
- x86/mm, kexec: Allow kexec to be used with SME (fate#322123).
- commit c5ac3b2
* Mon Sep  4 2017 bp@suse.de
- kvm/x86/svm: Support Secure Memory Encryption within KVM
  (fate#322123).
- commit ded3057
* Mon Sep  4 2017 bp@suse.de
- x86, drm, fbdev: Do not specify encrypted memory for video
  mappings (fate#322123).
- commit 3926698
* Mon Sep  4 2017 bp@suse.de
- x86/boot/realmode: Check for memory encryption on the APs
  (fate#322123).
- commit a907124
* Mon Sep  4 2017 bp@suse.de
- iommu/amd: Allow the AMD IOMMU to work with memory encryption
  (fate#322123).
- Refresh
  patches.drivers/0012-iommu-amd-suppress-io_page_faults-in-kdump-kernel.
- Refresh
  patches.drivers/0019-iommu-amd-remove-amd_iommu_disabled-check-from-amd_iommu_detect.
- commit 06efcc5
* Mon Sep  4 2017 tbogendoerfer@suse.de
- Patch will be redone with commits for bsc#1056787
  Delete
  patches.suse/msft-hv-1363-networking-introduce-and-use-skb_put_data.patch.
- commit de2f49a
* Mon Sep  4 2017 bp@suse.de
- x86/cpu/AMD: Make the microcode level available earlier in
  the boot (fate#322123).
- commit 45da941
* Mon Sep  4 2017 bp@suse.de
- swiotlb: Add warnings for use of bounce buffers with SME
  (fate#322123).
- commit 4b6c991
* Mon Sep  4 2017 bp@suse.de
- x86, swiotlb: Add memory encryption support (fate#322123).
- commit 0dc9b8d
* Mon Sep  4 2017 bp@suse.de
- x86/realmode: Decrypt trampoline area if memory encryption is
  active (fate#322123).
- commit 70f1f35
* Mon Sep  4 2017 bp@suse.de
- x86/mm: Add support for changing the memory encryption attribute
  (fate#322123).
- commit 5eb9aa3
* Mon Sep  4 2017 bp@suse.de
- x86/mm: Add support to access persistent memory in the clear
  (fate#322123).
- commit 2521a3c
* Mon Sep  4 2017 bp@suse.de
- x86/boot: Use memremap() to map the MPF and MPC data
  (fate#322123).
- commit 40f02a4
* Mon Sep  4 2017 bp@suse.de
- x86/mm: Add support to access boot related data in the clear
  (fate#322123).
- commit e966ee6
* Mon Sep  4 2017 bp@suse.de
- x86/efi: Update EFI pagetable creation to work with SME
  (fate#322123).
- commit ce57435
* Mon Sep  4 2017 bp@suse.de
- efi: Update efi_mem_type() to return an error rather than 0
  (fate#322123).
- commit 91147ec
* Mon Sep  4 2017 bp@suse.de
- efi: Add an EFI table address match function (fate#322123).
- commit 473de56
* Mon Sep  4 2017 bp@suse.de
- x86/boot/e820: Add support to determine the E820 type of an
  address (fate#322123).
- commit a831c04
* Mon Sep  4 2017 bp@suse.de
- x86/mm: Insure that boot memory areas are mapped properly
  (fate#322123).
- commit 7075d9d
* Mon Sep  4 2017 bp@suse.de
- x86/mm: Add support for early encryption/decryption of memory
  (fate#322123).
- commit c49e594
* Mon Sep  4 2017 bp@suse.de
- x86/mm: Extend early_memremap() support with additional attrs
  (fate#322123).
- commit bffaaa4
* Mon Sep  4 2017 bp@suse.de
- x86/mm: Add SME support for read_cr3_pa() (fate#322123).
- commit 8a90820
* Mon Sep  4 2017 tbogendoerfer@suse.de
- nfp: advertise support for NFD ABI 0.5 (bsc#1055968).
- nfp: create control vNICs and wire up rx/tx (bsc#1055968).
- nfp: allow non-equal distribution of IRQs (bsc#1055968).
- nfp: slice the netdev spawning function (bsc#1055968).
- nfp: don't clutter init code passing fw_ver around
  (bsc#1055968).
- nfp: map all queue controllers at once (bsc#1055968).
- nfp: make vNIC ctrl memory mapping function reusable
  (bsc#1055968).
- nfp: add control vNIC datapath (bsc#1055968).
- nfp: prepare config and enable for working without netdevs
  (bsc#1055968).
- nfp: allow allocation and initialization of netdev-less vNICs
  (bsc#1055968).
- nfp: make sure debug accesses don't depend on netdevs
  (bsc#1055968).
- nfp: prepare print macros for use without netdev (bsc#1055968).
- nfp: move nfp_net_vecs_init() (bsc#1055968).
- nfp: reuse ring free code on close (bsc#1055968).
- nfp: split out the allocation part of open (bsc#1055968).
- nfp: reorder open and close functions (bsc#1055968).
- nfp: fix memory leak on FW load error (bsc#1055968).
- nfp: move basic eBPF stats to app-specific code (bsc#1055968).
- nfp: move bpf offload code to the BPF app (bsc#1055968).
- nfp: move eBPF offload files to BPF app directory (bsc#1055968).
- nfp: report app name in ethtool -i (bsc#1055968).
- nfp: move port init to apps (bsc#1055968).
- nfp: turn reading PCIe RTsym parameters into a helper
  (bsc#1055968).
- nfp: add missing fall through statements (bsc#1055968).
- sched: add helper for updating statistics on all actions
  (bsc#1055968).
- nfp: don't keep count for free buffers delayed kick
  (bsc#1055968).
- nfp: don't add ring size to index calculations (bsc#1055968).
- nfp: fix print format for ring pointers in ring dumps
  (bsc#1055968).
- nfp: don't wait for resources indefinitely (bsc#1055968).
- nfp: add hwmon support (bsc#1055968).
- nfp: support variable NSP response lengths (bsc#1055968).
- nfp: shorten CPP core probe logs (bsc#1055968).
- nfp: support long reads and writes with the cpp helpers
  (bsc#1055968).
- nfp: only try to get to PCIe ctrl memory if BARs are wide enough
  (bsc#1055968).
- nfp: don't set aux pointers if ioremap failed (bsc#1055968).
- nfp: set driver VF limit (bsc#1055968).
- nfp: add set_mac_address support while the interface is up
  (bsc#1055968).
- nfp: add MAY_USE_DEVLINK dependency (bsc#1055968).
- nfp: support port splitting via devlink (bsc#1055968).
- nfp: calculate total port lanes for split (bsc#1055968).
- nfp: register ports as devlink ports (bsc#1055968).
- nfp: add helper for cleaning up vNICs (bsc#1055968).
- nfp: add devlink support (bsc#1055968).
- nfp: move mutex init out of net code (bsc#1055968).
- nfp: refresh port state before reporting autonegotiation
  (bsc#1055968).
- nfp: mark port state as stale if update failed (bsc#1055968).
- nfp: mark port state as stale after reconfig (bsc#1055968).
- nfp: provide linking on port structures (bsc#1055968).
- nfp: move refresh tracking into the port structure
  (bsc#1055968).
- nfp: update port state in place (bsc#1055968).
- nfp: introduce nfp_port (bsc#1055968).
- nfp: disallow mixing vNICs with and without NSP port entry
  (bsc#1055968).
- nfp: introduce very minimal nfp_app (bsc#1055968).
- nfp: add nfp_net_pf_free_vnic() function (bsc#1055968).
- nfp: rename netdev/port to vNIC (bsc#1055968).
- nfp: make nfp_net alloc/init/cleanup/free not depend on netdevs
  (bsc#1055968).
- nfp: add nfp_cppcore_pcie_unit() helper (bsc#1055968).
- nfp: eliminate an if statement in calculation of completed
  frames (bsc#1055968).
- nfp: add a helper for wrapping descriptor index (bsc#1055968).
- nfp: complete the XDP TX ring only when it's full (bsc#1055968).
- nfp: add CHECKSUM_COMPLETE support (bsc#1055968).
- nfp: version independent support for chained RSS metadata
  (bsc#1055968).
- nfp: don't assume RSS and IRQ moderation are always enabled
  (bsc#1055968).
- nfp: support LSO2 capability (bsc#1055968).
- nfp: rename l4_offset in struct nfp_net_tx_desc to lso_hdrlen
  (bsc#1055968).
- nfp: don't enable TSO on the device when disabled (bsc#1055968).
- commit c02b1d9
* Mon Sep  4 2017 bp@suse.de
- x86/mm: Provide general kernel support for memory encryption
  (fate#322123).
- commit 0bc99cf
* Mon Sep  4 2017 bp@suse.de
- x86/mm: Simplify pd_page() macros (fate#322123).
- commit 35ace63
* Mon Sep  4 2017 bp@suse.de
- x86/mm: Add support to enable SME in early boot processing
  (fate#322123).
- commit 9508f8a
* Mon Sep  4 2017 bp@suse.de
- x86/mm: Remove phys_to_virt() usage in ioremap() (fate#322123).
- commit 371b1fb
* Mon Sep  4 2017 bp@suse.de
- x86/mm: Add Secure Memory Encryption (SME) support
  (fate#322123).
  Update config files with new options.
- commit 1f3aaaf
* Mon Sep  4 2017 bp@suse.de
- x86/cpu/AMD: Handle SME reduction in physical address size
  (fate#322123).
- commit 88d989f
* Mon Sep  4 2017 bp@suse.de
- x86/cpu/AMD: Add the Secure Memory Encryption CPU feature
  (fate#322123).
- commit 4e8af2a
* Mon Sep  4 2017 bp@suse.de
- x86, mpparse, x86/acpi, x86/PCI, x86/dmi, SFI: Use memremap()
  for RAM mappings (fate#322123).
- commit fd1bdfe
* Mon Sep  4 2017 bp@suse.de
- x86/mm/pat: Set write-protect cache mode for full PAT support
  (fate#322123).
- commit 9b2584b
* Mon Sep  4 2017 bp@suse.de
- x86/cpu/AMD: Document AMD Secure Memory Encryption (SME)
  (fate#322123).
- commit 112bbc1
* Mon Sep  4 2017 bp@suse.de
- x86/boot/64: Put __startup_64() into .head.text (fate#322123).
- commit cb63948
* Mon Sep  4 2017 bp@suse.de
- x86/boot/64: Add support of additional page table level during
  early boot (fate#322123).
- commit c69bf2f
* Mon Sep  4 2017 bp@suse.de
- x86/boot/64: Rename init_level4_pgt and early_level4_pgt
  (fate#322123).
- commit d75bf42
* Mon Sep  4 2017 bp@suse.de
- x86/ftrace: Exclude functions in head64.c from function-tracing
  (fate#322123).
- commit 6d229da
* Mon Sep  4 2017 tbogendoerfer@suse.de
- Sorted patches in network section
- commit e2cc8e7
* Mon Sep  4 2017 bp@suse.de
- x86/boot/64: Rewrite startup_64() in C (fate#322123).
- commit 935bc66
* Mon Sep  4 2017 bp@suse.de
- x86/mm: Split read_cr3() into read_cr3_pa() and __read_cr3()
  (fate#322123).
- commit c5d71a2
* Mon Sep  4 2017 lhenriques@suse.com
- ceph: fix readpage from fscache (bsc#1057015).
- commit c9e96e6
* Fri Sep  1 2017 dbueso@suse.de
- powerpc: use spin loop primitives in some functions (bsc#1056912).
- commit dfd3f3e
* Fri Sep  1 2017 dbueso@suse.de
- spin loop primitives for busy waiting (bsc#1056912).
- commit cda1f6a
* Fri Sep  1 2017 lduncan@suse.com
- scsi: libcxgbi: add check for valid cxgbi_task_data
  (bsc#1046541).
- scsi: cxgb4i: assign rxqs in round robin mode (bsc#1046541).
- commit 3064c71
* Fri Sep  1 2017 jroedel@suse.de
- iommu/vt-d: Helper function to query if a pasid has any active
  users (fate#322864).
- commit 01214f9
* Fri Sep  1 2017 oneukum@suse.com
- Update config files. (FATE#322631)
- commit 90aeb55
* Fri Sep  1 2017 yousaf.kaukab@suse.com
- ixgbe: Use new PCI_DEV_FLAGS_NO_RELAXED_ORDERING flag
  (bsc#1056419).
- Revert commit 1a8b6d76dc5b ("net:add one common
  config...") (bsc#1056419).
- net/cxgb4vf: Use new PCI_DEV_FLAGS_NO_RELAXED_ORDERING flag
  (bsc#1056419).
- net/cxgb4: Use new PCI_DEV_FLAGS_NO_RELAXED_ORDERING flag
  (bsc#1056419).
- commit ce6396a
* Fri Sep  1 2017 bp@suse.de
- supported.conf: Add Goldmont-specific EDAC driver (fate#322662)
- commit eff24c3
* Fri Sep  1 2017 neilb@suse.com
- NFSv4: Fix double frees in nfs4_test_session_trunk()
  (git-fixes).
- xprtrdma: Don't defer MR recovery if ro_map fails (git-fixes).
- xprtrdma: Fix FRWR invalidation error recovery (git-fixes).
- xprtrdma: Fix client lock-up after application signal fires
  (git-fixes).
- xprtrdma: Rename rpcrdma_req::rl_free (git-fixes).
- xprtrdma: Pass only the list of registered MRs to ro_unmap_sync
  (git-fixes).
- xprtrdma: Pre-mark remotely invalidated MRs (git-fixes).
- xprtrdma: On invalidation failure, remove MWs from rl_registered
  (git-fixes).
- commit 7d59497
* Fri Sep  1 2017 mgalbraith@suse.de
- Per IBM request, drop drop IBM specific patches from SLE15 (bnc#1012582)
- Delete patches.suse/sched-disable-FAIR_SLEEPERS-for-S390.patch.
- Delete patches.suse/sched-reinstate-FAIR_SLEEPERS-feature.patch.
- Delete patches.suse/sched-reinstate-sched_compat_yield.patch.
- commit 3ee70fe
* Thu Aug 31 2017 tiwai@suse.de
- rt2800: fix TX_PIN_CFG setting for non MT7620 chips
  (bsc#1055826).
- commit d79ffeb
* Thu Aug 31 2017 oneukum@suse.com
- pinctrl: intel: Add Intel Cannon Lake PCH-H pin controller
  support (FATE#321195).
- spi: pxa2xx: Add support for Intel Cannonlake (FATE#321195).
- pinctrl: intel: Add Intel Cannon Lake PCH pin controller support
  (FATE#321195).
- pinctrl: intel: Make it possible to specify mode per pin in
  a group (FATE#321195).
- pinctrl: intel: Add support for variable size pad groups
  (FATE#321195).
- mmc: sdhci-pci: Add support for Intel CNP (FATE#321195).
- mmc: sdhci-pci: Use macros in pci_ids definition (FATE#321195).
- scsi: ufs: flush eh_work when eh_work scheduled (FATE#321195).
- commit 16f0485
* Thu Aug 31 2017 oneukum@suse.com
- scsi: ufshcd-pci: Add Intel CNL support (FATE#321195).
- scsi: ufshcd-pci: Fix PM config (FATE#321195).
- scsi: ufs: Tidy clocks list head usage (FATE#321195).
- commit f7ba845
* Thu Aug 31 2017 yousaf.kaukab@suse.com
- PCI: Allow PCI express root ports to find themselves
  (bsc#1056419).
- PCI: fix oops when try to find Root Port for a PCI device
  (bsc#1056419).
- PCI: Disable Relaxed Ordering Attributes for AMD A1100
  (bsc#1056419).
- PCI: Disable Relaxed Ordering for some Intel processors
  (bsc#1056419).
- PCI: Disable PCIe Relaxed Ordering if unsupported (bsc#1056419).
- commit 7e5ee6f
* Thu Aug 31 2017 jthumshirn@suse.de
- scsi: qla2xxx: Fix an integer overflow in sysfs code
  (bsc#1056588, CVE-2017-14051).
- commit a9495c3
* Thu Aug 31 2017 jthumshirn@suse.de
- scsi: qla2xxx: Fix an integer overflow in sysfs code
  (bsc#1056588, CVE-2017-14051).
- commit 4fafb75
* Thu Aug 31 2017 oneukum@suse.com
- supported.conf: the old style UCSI for non-x86
- commit ed3ca0b
* Thu Aug 31 2017 jslaby@suse.cz
- blacklist.conf: add one objtool patch
- commit 6f1e31d
* Thu Aug 31 2017 tiwai@suse.de
- supported.conf: Reduce supported sound modules (bsc#1056612,FATE#323981)
- commit a185749
* Thu Aug 31 2017 msuchanek@suse.de
- scsi: cxlflash: Fix vlun resize failure in the shrink path
  (fate#322239).
- scsi: cxlflash: Avoid double mutex unlock (fate#322239).
- scsi: cxlflash: Remove unnecessary existence check
  (fate#322239).
- scsi: cxlflash: Fix an error handling path in
  'cxlflash_disk_attach()' (fate#322239).
- scsi: cxlflash: return -EFAULT if copy_from_user() fails
  (fate#322239).
- commit e126787
* Thu Aug 31 2017 msuchanek@suse.de
- scsi: cxlflash: Update debug prints in reset handlers
  (fate#322239).
- scsi: cxlflash: Update send_tmf() parameters (fate#322239).
- scsi: cxlflash: Avoid double free of character device
  (fate#322239).
- scsi: cxlflash: Update TMF command processing (fate#322239).
- scsi: cxlflash: Remove zeroing of private command data
  (fate#322239).
- scsi: cxlflash: Support WS16 unmap (fate#322239).
- commit 438c2e8
* Thu Aug 31 2017 msuchanek@suse.de
- scsi: cxlflash: Support AFU debug (fate#322239).
- scsi: cxlflash: Support LUN provisioning (fate#322239).
- scsi: cxlflash: Refactor AFU capability checking (fate#322239).
- scsi: cxlflash: Introduce host ioctl support (fate#322239).
- scsi: cxlflash: Separate AFU internal command handling from
  AFU sync specifics (fate#322239).
- commit e1c2471
* Thu Aug 31 2017 msuchanek@suse.de
- scsi: cxlflash: Create character device to provide host
  management interface (fate#322239).
- scsi: cxlflash: Add scsi command abort handler (fate#322239).
- scsi: cxlflash: Flush pending commands in cleanup path
  (fate#322239).
- scsi: cxlflash: Track pending scsi commands in each hardware
  queue (fate#322239).
- scsi: cxlflash: Handle AFU sync failures (fate#322239).
- commit aec8db3
* Thu Aug 31 2017 msuchanek@suse.de
- scsi: cxlflash: Schedule asynchronous reset of the host
  (fate#322239).
- scsi: cxlflash: Reset hardware queue context via specified
  register (fate#322239).
- scsi: cxlflash: Update cxlflash_afu_sync() to return errno
  (fate#322239).
- scsi: cxlflash: Combine the send queue locks (fate#322239).
- commit b877eca
* Thu Aug 31 2017 oneukum@suse.com
- supported.conf: add full ucsi support (FATE#322665, FATE#322666)
- commit 893e6d9
* Thu Aug 31 2017 bp@suse.de
- RAS/CEC: Disable CEC (bsc#1056592).
- commit cb2beb8
* Wed Aug 30 2017 mgorman@suse.de
- Fix up over-eager 'wait_queue_t' renaming (bnc#971975 VM
  performance -- page waitqueue).
- commit 92ad9c7
* Wed Aug 30 2017 jslaby@suse.cz
- Linux 4.12.10 (bnc#1012628 bnc#1014351 bnc#1048935 bsc#1020657
  bsc#1050582).
- Delete
  patches.drivers/ALSA-hda-Add-stereo-mic-quirk-for-Lenovo-G50-70-17aa.
- Delete
  patches.fixes/Bluetooth-hidp-fix-possible-might-sleep-error-in-hid.patch.
- Delete
  patches.fixes/Input-ALPS-Fix-Alps-Touchpad-two-finger-scroll-does-.
- Delete
  patches.fixes/netfilter-expect-fix-crash-when-putting-uninited-exp.patch.
- commit 030062c
* Wed Aug 30 2017 mgorman@suse.de
- sched/wait: Introduce wakeup boomark in wake_up_page_bit
  (bnc#971975 VM performance -- page waitqueue).
- sched/wait: Break up long wake list walk (bnc#971975 VM
  performance -- page waitqueue).
- page waitqueue: always add new entries at the end (bnc#971975
  VM performance -- page waitqueue).
- sched/wait: Clean up some documentation warnings (bnc#971975
  VM performance -- page waitqueue).
- sched/wait: Disambiguate wq_entry->task_list and
  wq_head->task_list naming (bnc#971975 VM performance --
  page waitqueue).
- sched/wait: Split out the wait_bit*() APIs from <linux/wait.h>
  into <linux/wait_bit.h> (bnc#971975 VM performance -- page
  waitqueue).
- sched/wait: Re-adjust macro line continuation backslashes in
  <linux/wait.h> (bnc#971975 VM performance -- page waitqueue).
- sched/wait: Improve the bit-wait API parameter names in
  the API function prototypes (bnc#971975 VM performance --
  page waitqueue).
- sched/wait: Standardize wait_bit_queue naming (bnc#971975 VM
  performance -- page waitqueue).
- sched/wait: Standardize 'struct wait_bit_queue' wait-queue
  entry field name (bnc#971975 VM performance -- page waitqueue).
- sched/wait: Standardize internal naming of wait-queue heads
  (bnc#971975 VM performance -- page waitqueue).
- sched/wait: Standardize internal naming of wait-queue entries
  (bnc#971975 VM performance -- page waitqueue).
- commit 59134c0
* Wed Aug 30 2017 mgorman@suse.de
- sched/wait: Rename wait_queue_t => wait_queue_entry_t
  (bnc#971975 VM performance -- page waitqueue).
- Refresh
  patches.fixes/Bluetooth-hidp-fix-possible-might-sleep-error-in-hid.patch.
- commit 60bfe92
* Wed Aug 30 2017 jthumshirn@suse.de
- scsi: qla2xxx: Update driver version to 10.00.00.01-k
  (FATE#322910).
- scsi: qla2xxx: Do not call abort handler function during chip
  reset (FATE#322910).
- scsi: qla2xxx: Ability to process multiple SGEs in Command
  SGL for CT passthrough commands (FATE#322910).
- scsi: qla2xxx: Skip zero queue count entry during FW dump
  capture (FATE#322910).
- scsi: qla2xxx: Recheck session state after RSCN (FATE#322910).
- scsi: qla2xxx: Increase ql2xmaxqdepth to 64 (FATE#322910).
- scsi: qla2xxx: Enable Async TMF processing (FATE#322910).
- scsi: qla2xxx: Cleanup NPIV host in target mode during config
  teardown (FATE#322910).
- scsi: qla2xxx: Add LR distance support from nvram bit
  (FATE#322910).
- scsi: qla2xxx: Add support for minimum link speed (FATE#322910).
- scsi: qla2xxx: Remove potential macro parameter side-effect
  in ql_dump_regs() (FATE#322910).
- scsi: qla2xxx: Print correct mailbox registers in failed summary
  (FATE#322910).
- scsi: qla2xxx: Fix task mgmt handling for NPIV (FATE#322910).
- scsi: qla2xxx: Allow SNS fabric login to be retried
  (FATE#322910).
- scsi: qla2xxx: Add timeout ability to wait_for_sess_deletion()
  (FATE#322910).
- scsi: qla2xxx: Move logging default mask to execute once only
  (FATE#322910).
- scsi: qla2xxx: Use sp->free instead of hard coded call
  (FATE#322910).
- scsi: qla2xxx: Prevent sp->free null/uninitialized pointer
  dereference (FATE#322910).
- scsi: qla2xxx: Add ability to autodetect SFP type (FATE#322910).
- scsi: qla2xxx: Use fabric name for Get Port Speed command
  (FATE#322910).
- scsi: qla2xxx: Change ha->wq max_active value to default
  (FATE#322910).
- scsi: qla2xxx: Remove extra register read (FATE#322910).
- scsi: qla2xxx: Fix NPIV host enable after chip reset
  (FATE#322910).
- scsi: qla2xxx: Use BIT_6 to acquire FAWWPN from switch
  (FATE#322910).
- scsi: qla2xxx: Fix system panic due to pointer access problem
  (FATE#322910).
- scsi: qla2xxx: Fix WWPN/WWNN in debug message (FATE#322910).
- scsi: qla2xxx: Add command completion for error path
  (FATE#322910).
- scsi: qla2xxx: Update fw_started flags at qpair creation
  (FATE#322910).
- scsi: qla2xxx: Fix target multiqueue configuration
  (FATE#322910).
- scsi: qla2xxx: Correction to vha->vref_count timeout
  (FATE#322910).
- scsi: qla2xxx: fix spelling mistake of variable
  sfp_additonal_info (FATE#322910).
- scsi: qla2xxx: use dma_mapping_error to check map errors
  (FATE#322910).
- scsi: qla2xxx: Fix remoteport disconnect for FC-NVMe
  (FATE#322910).
- scsi: qla2xxx: Simpify unregistration of FC-NVMe local/remote
  ports (FATE#322910).
- scsi: qla2xxx: Added change to enable ZIO for FC-NVMe devices
  (FATE#322910).
- scsi: qla2xxx: Move function prototype to correct header
  (FATE#322910).
- scsi: qla2xxx: Cleanup FC-NVMe code (FATE#322910).
- scsi: qla2xxx: Off by one in qlt_ctio_to_cmd() (FATE#322910).
- t10-pi: Move opencoded contants to common header (FATE#322910).
- qla2xxx: Fix NVMe entry_type for iocb packet on BE system
  (FATE#322910).
- scsi: qla2xxx: avoid unused-function warning (FATE#322910).
- scsi: qla2xxx: fix a bunch of typos and spelling mistakes
  (FATE#322910).
- scsi: qla2xxx: Protect access to qpair members with
  qpair->qp_lock (FATE#322910).
- scsi: qla2xxx: Update Driver version to 10.00.00.00-k
  (FATE#322910).
- scsi: qla2xxx: Use FC-NVMe FC4 type for FDMI registration
  (FATE#322910).
- scsi: qla2xxx: Send FC4 type NVMe to the management server
  (FATE#322910).
- scsi: qla2xxx: Add FC-NVMe F/W initialization and transport
  registration (FATE#322910).
- scsi: qla2xxx: Add FC-NVMe command handling (FATE#322910).
- scsi: qla2xxx: Add FC-NVMe port discovery and PRLI handling
  (FATE#322910).
- scsi: qla2xxx: Update driver version to 9.01.00.00-k
  (FATE#322910).
- scsi: qla2xxx: Include Exchange offload/Extended Login into
  FW dump (FATE#322910).
- scsi: qla2xxx: Move target stat counters from vha to qpair
  (FATE#322910).
- scsi: qla2xxx: Remove datasegs_per_cmd and datasegs_per_cont
  field (FATE#322910).
- scsi: qla2xxx: Remove unused tgt_enable_64bit_addr flag
  (FATE#322910).
- scsi: qla2xxx: Add debug logging routine for qpair
  (FATE#322910).
- scsi: qla2xxx: Add function call to qpair for door bell
  (FATE#322910).
- scsi: qla2xxx: use shadow register for ISP27XX (FATE#322910).
- scsi: qla2xxx: move fields from qla_hw_data to qla_qpair
  (FATE#322910).
- scsi: qla2xxx: Add fw_started flags to qpair (FATE#322910).
- scsi: qla2xxx: Add debug knob for user control workload
  (FATE#322910).
- scsi: qla2xxx: Fix mailbox failure while deleting Queue pairs
  (FATE#322910).
- scsi: qla2xxx: Enable Target Multi Queue (FATE#322910).
- scsi: qla2xxx: Preparation for Target MQ (FATE#322910).
- scsi: qla2xxx: Combine Active command arrays (FATE#322910).
- scsi: qla2xxx: don't include <generated/utsrelease.h>
  (FATE#322910).
- scsi: qla2xxx: Fix compile warning (FATE#322910).
- scsi: qla2xxx: remove redundant null check on tgt (FATE#322910).
- scsi: qla2xxx: remove writeq/readq function definitions
  (FATE#322910).
- scsi: qla2xxx: Remove extra register read (FATE#322910).
- scsi: qla2xxx: Remove unused irq_cmd_count field (FATE#322910).
- scsi: qla2xxx: Accelerate SCSI BUSY status generation in target
  mode (FATE#322910).
- scsi: qla2xxx: Remove redundant wait when target is stopped
  (FATE#322910).
- scsi: qla2xxx: Add ql2xiniexchg parameter (FATE#322910).
- scsi: qla2xxx: Turn on FW option for exchange check
  (FATE#322910).
- scsi: qla2xxx: Cleanup debug message IDs (FATE#322910).
- scsi: qla2xxx: Fix name server relogin (FATE#322910).
- scsi: qla2xxx: Convert 32-bit LUN usage to 64-bit (FATE#322910).
- scsi: qla2xxx: Use flag PFLG_DISCONNECTED (FATE#322910).
- scsi: tcm_qla2xxx: Do not allow aborted cmd to advance
  (FATE#322910).
- scsi: qla2xxx: Fix path recovery (FATE#322910).
- scsi: qla2xxx: Retain loop test for fwdump length exceeding
  buffer length (FATE#322910).
- scsi: qla2xxx: Replace usage of spin_lock with spin_lock_irqsave
  (FATE#322910).
- scsi: qla2xxx: Remove an unused structure member (FATE#322910).
- commit e1bfb61
* Wed Aug 30 2017 msuchanek@suse.de
- genirq/cpuhotplug: Do not migrated shutdown irqs (bsc#1054935).
- commit 075835d
* Wed Aug 30 2017 msuchanek@suse.de
- genirq/cpuhotplug: Reorder check logic (bsc#1054935).
- commit 1367886
* Wed Aug 30 2017 msuchanek@suse.de
- genirq/cpuhotplug: Dont claim success on error (bsc#1054935).
- commit 4f8cdfc
* Wed Aug 30 2017 oneukum@suse.com
- USB: add usbfs ioctl to retrieve the connection speed
  (FATE#321327).
- xhci: remove endpoint ring cache (FATE#321327, FATE#322665,
  FATE#322666).
- xhci: refactor transfer event errors and completion codes
  (FATE#321327, FATE#322665, FATE#322666).
- xhci: Add support for endpoint soft reset (FATE#321327).
- xhci: support calling cleanup_halted_endpoint with soft retry
  (bFATE#321327).
- xhci: handle transfer events without TRB pointer (FATE#321327).
- xhci: cleanup virtual endoint structure, remove stopped_stream
  (FATE#321327).
- xhci: cleanup finish_td() skip option (FATE#321327).
- usb: typec: Add support for UCSI interface (FATE#322665,
  FATE#322666).
- usb: typec: ucsi: Add ACPI driver (FATE#322665, FATE#322666).
- usb: typec: include linux/device.h in ucsi.h (FATE#322665,
  FATE#322666).
- usb: hcd: constify attribute_group structures (FATE#321327).
- xhci: rename temp and temp1 variables (FATE#321327).
- usb: Increase root hub reset signaling time to prevent retry
  (FATE#321327).
- xhci: rework bus_resume and check ports are suspended before
  resuming them (FATE#321327).
- usb: make device_type const (FATE#321327).
- USB: core: constify vm_operations_struct (FATE#321327).
- usb: xhci: Support enabling of compliance mode for xhci 1.1
  (FATE#321327).
- usb: misc: lvstest: add entry to place port in compliance mode
  (FATE#321327).
- Update config files.
- commit 7e26cc6
* Wed Aug 30 2017 oneukum@suse.com
- usb: typec: Add a sysfs node to manage port type (FATE#322665,
  FATE#322666).
- usb: typec: update partner power delivery support with opmode
  (FATE#322665, FATE#322666).
- xhci: remove unused stopped_td pointer (FATE#321327).
- xhci: Add stream id to xhci_dequeue_state structure
  (FATE#321327).
- xhci: Find out where an endpoint or stream stopped from its
  context (FATE#321327).
- xhci: Add helper to get hardware dequeue pointer for stopped
  rings (FATE#321327).
- usb: typec: Don't prevent using constant typec_mode_desc
  initializers (FATE#322665, FATE#322666).
- commit 80163a3
* Wed Aug 30 2017 mbenes@suse.cz
- Add live patching section to series.conf for future backports
  (fate#323487)
- commit 428055c
* Wed Aug 30 2017 mbenes@suse.cz
- Drop kGraft (fate#323487)
  Upstream live patching infrastructure is going to be used in SLE15
- Delete patches.suse/kgr-0002-livepatch-add-infrastructure.patch.
- Delete
  patches.suse/kgr-0003-livepatch-kgr_in_progress-for-all-threads.patch.
- Delete
  patches.suse/kgr-0004-ftrace-Make-ftrace_is_dead-available-globally.patch.
- Delete patches.suse/kgr-0005-initial-code.patch.
- Delete patches.suse/kgr-0006-add-testing-kgraft-patch.patch.
- Delete patches.suse/kgr-0007-add-Documentation.patch.
- Delete
  patches.suse/kgr-0008-mark-task_safe-in-some-kthreads.patch.
- Delete patches.suse/kgr-0009-kthreads-support.patch.
- Delete patches.suse/kgr-0010-handle-irqs.patch.
- Delete patches.suse/kgr-0011-allow-stacking-of-patches.patch.
- Delete
  patches.suse/kgr-0012-handle-patched-modules-that-are-being-removed.patch.
- Delete
  patches.suse/kgr-0013-try-to-apply-skipped-patches-when-a-module-is-lo.patch.
- Delete patches.suse/kgr-0014-allow-for-forced-module-load.patch.
- Delete patches.suse/kgr-0015-allow-replace_all.patch.
- Delete
  patches.suse/kgr-0016-support-for-forcing-success-of-patching-process.patch.
- Delete
  patches.suse/kgr-0017-correct-error-handling-of-the-first-patching-sta.patch.
- Delete
  patches.suse/kgr-0018-send-a-fake-signal-to-all-blocking-tasks.patch.
- Delete
  patches.suse/kgr-0019-mark-task_safe-in-non-upstream-kthreads.patch.
- Delete
  patches.suse/kgr-0020-kmemleak-really-mark-the-kthread-safe-after-a.patch.
- Delete
  patches.suse/kgr-0021-fix-reversion-of-a-patch-already-reverted-by-a-r.patch.
- Delete
  patches.suse/kgr-0022-add-objname-to-kgr_patch_fun-struct.patch.
- Delete patches.suse/kgr-0023-remove-abort_if_missing-flag.patch.
- Delete
  patches.suse/kgr-0024-do-not-return-and-print-an-error-only-if-the-obj.patch.
- Delete
  patches.suse/kgr-0025-fix-subtle-race-with-kgr_module_init-going-notif.patch.
- Delete
  patches.suse/kgr-0026-fix-an-asymmetric-dealing-with-delayed-module-lo.patch.
- Delete
  patches.suse/kgr-0027-call-kgr_init_ftrace_ops-only-for-loaded-objects.patch.
- Delete
  patches.suse/kgr-0028-change-to-kallsyms_on_each_symbol-iterator.patch.
- Delete
  patches.suse/kgr-0029-add-sympos-as-disambiguator-field-to-kgr_patch_f.patch.
- Delete patches.suse/kgr-0030-add-sympos-to-sysfs.patch.
- Delete
  patches.suse/kgr-0031-add-sympos-and-objname-to-error-and-debug-messag.patch.
- Delete patches.suse/kgr-0032-taint-with-TAINT_LIVEPATCH.patch.
- Delete
  patches.suse/kgr-0033-define-pr_fmt-and-modify-all-pr_-messages.patch.
- Delete
  patches.suse/kgr-0034-kgraft-bcache-Do-not-block-livepatching-in-the-write.patch.
- Delete
  patches.suse/kgr-0035-kgraft-gfs2-Do-not-block-livepatching-in-the-log-dae.patch.
- Delete
  patches.suse/kgr-0036-kgraft-xen-Do-not-block-livepatching-in-the-XEN-blki.patch.
- Delete
  patches.suse/kgr-0037-ignore-zombie-tasks-during-the-patching.patch.
- Delete
  patches.suse/kgr-0038-kgraft-xen-Do-not-block-kGraft-in-xenbus-kthread.patch.
- Delete
  patches.suse/kgr-0039-kgraft-iscsi-target-Do-not-block-kGraft-in-iscsi_np-.patch.
- Delete
  patches.suse/kgr-0040-remove-all-arch-specific-kgraft-header-files.patch.
- Delete
  patches.suse/kgr-0041-make-a-taint-flag-module-specific.patch.
- Delete
  patches.suse/kgr-0042-locking-semaphore-Add-down_interruptible_timeout.patch.
- Delete
  patches.suse/kgr-0043-kgr-Mark-eeh_event_handler-kthread-safe-using-a-time.patch.
- Delete
  patches.suse/kgr-0102-kgr-mark-kernel-unsupported-upon-patch-revert.patch.
- Delete patches.suse/printk-mark_kgr_task_safe.patch.
- commit dde7e1c
* Wed Aug 30 2017 aaptel@suse.com
- CIFS: Fix maximum SMB2 header size (bsc#1056185).
- commit d54f5d7
* Tue Aug 29 2017 tiwai@suse.de
- Refresh patches.suse/iwlwifi-expose-default-fallback-ucode-api.
  The latest firmware matches for iwl7xxx/3168 series, so dropped the changes.
- commit 1447668
* Tue Aug 29 2017 yousaf.kaukab@suse.com
- arm64: update config file for RAS support
- commit 4812033
* Tue Aug 29 2017 yousaf.kaukab@suse.com
- ras: mark stub functions as 'inline' (fate#323583).
- ACPI: APEI: Enable APEI multiple GHES source to share a single
  external IRQ (fate#323583).
- acpi: apei: check for pending errors when probing GHES entries
  (fate#323583).
- arm/arm64: KVM: add guest SEA support (fate#323583).
- trace, ras: add ARM processor error trace event (fate#323583).
- ras: acpi / apei: generate trace event for unrecognized CPER
  section (fate#323583).
- efi: print unrecognized CPER section (fate#323583).
- acpi: apei: panic OS with fatal error status block
  (fate#323583).
- acpi: apei: handle SEA notification type for ARMv8
  (fate#323583).
- arm64: exception: handle Synchronous External Abort
  (fate#323583).
- efi: parse ARM processor error (fate#323583).
- cper: add timestamp print to CPER status printing (fate#323583).
- ras: acpi/apei: cper: add support for generic data v3 structure
  (fate#323583).
- acpi: apei: read ack upon ghes record consumption (fate#323583).
- ACPI / APEI: Switch to use new generic UUID API (fate#323583).
- uuid: fix incorrect uuid_equal conversion in test_uuid_test
  (fate#323583).
- fs: switch ->s_uuid to uuid_t (fate#323583).
- ima/policy: switch to use uuid_t (fate#323583).
- block: remove blk_part_pack_uuid (fate#323583).
- xfs: use the common helper uuid_is_null() (fate#323583).
- xfs: remove uuid_getnodeuniq and xfs_uu_t (fate#323583).
- S390/sysinfo: use uuid_is_null instead of opencoding it
  (fate#323583).
- uuid: hoist uuid_is_null() helper from libnvdimm (fate#323583).
- uuid: hoist helpers uuid_equal() and uuid_copy() from xfs
  (fate#323583).
- uuid: don't export guid_index and uuid_index (fate#323583).
- uuid: rename uuid types (fate#323583).
- uuid: remove uuid_be defintions from the uapi header
  (fate#323583).
- nfsd: namespace-prefix uuid_parse (fate#323583).
- md: namespace private helper names (fate#323583).
- xfs: use uuid_be to implement the uuid_t type (fate#323583).
- xfs: use uuid_copy() helper to abstract uuid_t (fate#323583).
- uuid,afs: move struct uuid_v1 back into afs (fate#323583).
- commit ccd5a8a
* Tue Aug 29 2017 oneukum@suse.com
- i2c: i801: Add support for Intel Cannon Lake (FATE#321195).
- mfd: intel-lpss: Add Intel Cannonlake PCI IDs (FATE#321195).
- HID: intel-ish-hid: Enable Cannon Lake ish driver (FATE#321195).
- commit fe6deda
* Mon Aug 28 2017 mgorman@suse.de
- Avoid page waitqueue race leaving possible page locker waiting
  (bnc#971975 VM performance -- page waitqueue).
- commit fc6592a
* Mon Aug 28 2017 tonyj@suse.de
- powerpc/perf: Fix usage of nest_imc_refc (FATE#322448,
  bsc#1054914).
- powerpc/perf/imc: Fix nest events on muti socket system
  (FATE#322448, bsc#1054914).
- powerpc/perf: Fix double unlock in imc_common_cpuhp_mem_free()
  (FATE#322448, bsc#1054914).
- powerpc/perf: Add thread IMC PMU support (FATE#322448,
  bsc#1054914).
- powerpc/perf: Add core IMC PMU support (FATE#322448,
  bsc#1054914).
- powerpc/perf: Add nest IMC PMU support (FATE#322448,
  bsc#1054914).
- perf vendor events powerpc: Update POWER9 events (FATE#322450,
  bsc#1052213).
- perf vendor events powerpc: remove suffix in mapfile
  (FATE#322450, bsc#1052213).
- commit 3b5ba34
* Mon Aug 28 2017 jroedel@suse.de
- KVM: x86: block guest protection keys unless the host has them
  enabled (bsc#1055935).
- KVM, pkeys: do not use PKRU value in vcpu->arch.guest_fpu.state
  (bsc#1055935).
- KVM: x86: simplify handling of PKRU (bsc#1055935).
- commit da19195
* Mon Aug 28 2017 dbueso@suse.de
- ptr_ring: use kmalloc_array() (bsc#1055945).
- commit f6d643d
* Mon Aug 28 2017 dbueso@suse.de
- blacklist.conf: add more entries (uml, rhashtable tests)
- commit 398a701
* Mon Aug 28 2017 tiwai@suse.de
- rpm/kernel-binary.spec.in: Update drm-kmp obsolete for SLE12-SP3/Leap-42.3
- commit 161c705
* Mon Aug 28 2017 mgorman@suse.de
- Minor page waitqueue cleanups (bnc#971975 VM performance --
  page waitqueue).
- commit 98a2529
* Mon Aug 28 2017 tbogendoerfer@suse.de
- Drop old qed patches, which will be refreshed while doing backports
- Delete
  patches.drivers/qed-sp3-0216-qed-bump-drivers-to-version-8.10.10.63.patch.
- Delete
  patches.drivers/qed-sp3-0264-qed-Enable-RoCE-parser-searching-on-fp-init.patch.
- Delete
  patches.drivers/qed-sp3-0265-qed-Correct-order-of-wwnn-and-wwpn.patch.
- Delete
  patches.drivers/qed-sp3-0266-qed-Share-additional-information-with-qedf.patch.
- Delete
  patches.drivers/qed-sp3-0267-qed-Support-NVM-image-reading-API.patch.
- Delete
  patches.drivers/qed-sp3-0268-qed-Add-support-for-changing-iSCSI-mac.patch.
- Delete
  patches.drivers/qed-sp3-0269-qedi-Add-support-for-offload-iSCSI-Boot.patch.
- commit 8c6203d
* Mon Aug 28 2017 mhocko@suse.cz
- mm, memory_hotplug: do not back off draining pcp free pages
  from kworker context (bnc#1049591).
- commit e362ef6
* Mon Aug 28 2017 tiwai@suse.de
- drm/i915: Disable tv output on i9x5gm (bsc#1055490).
- commit 425d710
* Mon Aug 28 2017 mgorman@suse.de
- mm: consider the number in local CPUs when reading NUMA stats
  (VM Performance, bnc#959436).
- mm: update NUMA counter threshold size (VM Performance,
  bnc#959436).
- mm: change the call sites of numa statistics items (VM
  Performance, bnc#959436).
- commit 451bfd6
* Mon Aug 28 2017 tiwai@suse.de
- Refresh patch tags of patches.fixes/Input-ALPS-Fix-Alps-Touchpad-two-finger-scroll-does-
- commit df5244b
* Mon Aug 28 2017 tiwai@suse.de
- rpm/kernel-docs.spec.in: Disable PDF build again
  ... due to the breakage with the recent TeXLive 2017.
  Also add the missing dependency on texlive-varwidth.
- commit 9f682b5
* Fri Aug 25 2017 hare@suse.de
- S/390: enable CONFIG_KMSG_IDS (bsc#1053718)
- commit a6e1a82
* Fri Aug 25 2017 hare@suse.de
- Drop obsolete S/390 patches (bsc#1053718)
- Delete
  patches.arch/s390-sles12sp2-00-02-s390-dasd-add-query-host-access-to-volume-support.patch.
- Delete
  patches.arch/s390-sles12sp2-00-03-s390-pci-add-report_error-attribute-01.patch.
- Delete
  patches.arch/s390-sles12sp2-00-03-s390-pci-add-report_error-attribute-02.patch.
- Delete
  patches.arch/s390-sles12sp2-00-03-s390-pci-add-report_error-attribute-03.patch.
- Delete
  patches.arch/s390-sles12sp2-00-03-s390-pci-add-report_error-attribute-04.patch.
- Delete
  patches.arch/s390-sles12sp2-00-04-s390-pci-fmb-enhancements-03.patch.
- Delete
  patches.arch/s390-sles12sp2-10-05-kmsg-add-descriptions.patch.
- Delete patches.arch/s390-sles12sp3-00-04-kmsg.patch.
- Delete patches.arch/s390-sles12sp3-00-07-kmsg.patch.
- Delete patches.arch/s390-sles12sp3-00-08-kmsg.patch.
- commit a1f2fe2
* Fri Aug 25 2017 hare@suse.de
- s390: Kernel message catalog (bnc#1053718, LTC#157660).
- Refresh patches.suse/0001-x86-unwind-Add-the-ORC-unwinder.patch.
- Delete patches.arch/kmsg-fix-parameter-limitations.
- Delete patches.arch/s390-message-catalog.diff.
- commit 5df3fc3
* Fri Aug 25 2017 mmarek@suse.com
- rpm/config.sh: Update KOTD build targets
  Build the internal packages against SLE15 and add s390x to the OBS
  builds.
- commit 88cc604
* Fri Aug 25 2017 tbogendoerfer@suse.de
- cxgb4: Fix tids count for ipv6 offload connection (bsc#1046540
  fate#322930).
- cxgb4: implement ndo_set_vf_rate() (bsc#1046540 fate#322930).
- cxgb4: fix incorrect cim_la output for T6 (bsc#1046540
  fate#322930).
- cxgb4: FW upgrade fixes (bsc#1046540 fate#322930).
- cxgb4: add new T5 pci device id (bsc#1046540 fate#322930).
- cxgb4 : retrieve port information from firmware (bsc#1046540
  fate#322930).
- cxgb4: add new T5 pci device id (bsc#1046540 fate#322930).
- commit 407692b
* Fri Aug 25 2017 hare@suse.de
- Drop patches.suse/scsi-netlink-ml (bsc#1055689)
- commit 8e3c10c
* Fri Aug 25 2017 mmarek@suse.com
- supported.conf: Fix malformed entry for n5pf
- commit 22e41e9
* Fri Aug 25 2017 jslaby@suse.cz
- Linux 4.12.9 (bnc#1012628 bsc#1052580 bnc#1049599).
- Delete
  patches.drivers/ALSA-usb-audio-Apply-sample-rate-quirk-to-Sennheiser.
- Delete patches.fixes/debug-fix-WARN_ON_ONCE-for-modules.patch.
- Update config files.
- commit f2ab6ba
* Thu Aug 24 2017 lduncan@suse.com
- lib: test_rhashtable: Fix KASAN warning (bsc#1055359).
- lib: test_rhashtable: fix for large entry counts (bsc#1055359).
- commit 28437b2
* Thu Aug 24 2017 jack@suse.cz
- supported.conf: Remove logfs (does not exist anymore), add orangefs as
  unsupported
- commit 1afee12
* Thu Aug 24 2017 mhocko@suse.cz
- kernel/watchdog: Prevent false positives with turbo modes
  (bnc#1055313).
- Update config files.
- commit 75b22a6
* Thu Aug 24 2017 vbabka@suse.cz
- cma: fix calculation of aligned offset (VM Functionality,
  bsc#1055314).
- commit 8914932
* Wed Aug 23 2017 msuchanek@suse.de
- powerpc/powernv/idle: Disable LOSE_FULL_CONTEXT states when
  stop-api fails (bsc#1055121).
- commit cf34929
* Wed Aug 23 2017 msuchanek@suse.de
- powerpc/powernv: Simplify lazy IRQ handling in CPU offline
  (bsc#1055121).
- commit 25e5ffb
* Wed Aug 23 2017 msuchanek@suse.de
- powerpc/64s/idle: Move soft interrupt mask logic into C code
  (bsc#1055121).
  - fix paste error in previous patch name
- commit 56abbca
* Wed Aug 23 2017 mhocko@suse.cz
- mm, oom: fix potential data corruption when oom_reaper races
  with writer (bnc#1055311).
- mm: fix double mmap_sem unlock on MMF_UNSTABLE enforced SIGBUS
  (bnc#1055311).
- commit 8afe3e4
* Wed Aug 23 2017 msuchanek@suse.de
- rtc: opal: Handle disabled TPO in opal_get_tpo_time()
  (bsc#1055122).
- commit 2cf6a2b
* Wed Aug 23 2017 msuchanek@suse.de
- rtc: interface: Validate alarm-time before handling rollover
  (bsc#1055122).
- commit 61f40d3
* Wed Aug 23 2017 jroedel@suse.de
- x86/cpufeature, kvm/svm: Rename (shorten) the new "virtualized
  VMSAVE/VMLOAD" CPUID flag (fate#323405).
- KVM: SVM: Enable Virtual VMLOAD VMSAVE feature (fate#323405).
- KVM: SVM: Add Virtual VMLOAD VMSAVE feature definition
  (fate#323405).
- KVM: SVM: Rename lbr_ctl field in the vmcb control area
  (fate#323405).
- KVM: SVM: Prepare for new bit definition in lbr_ctl
  (fate#323405).
- commit fda2890
* Wed Aug 23 2017 msuchanek@suse.de
- powerpc/powernv/pci: Add support for PHB4 diagnostics
  (bsc#1055120).
- commit 8b6d16d
* Wed Aug 23 2017 msuchanek@suse.de
- powerpc/powernv/pci: Dynamically allocate PHB diag data
  (bsc#1055120).
- commit d796605
* Wed Aug 23 2017 msuchanek@suse.de
- powerpc/powernv/pci: Reduce spam when dumping PEST
  (bsc#1055120).
- commit a228946
* Wed Aug 23 2017 msuchanek@suse.de
- powerpc/powernv: Add support to clear sensor groups data
  (bsc#1055115).
- commit ca4565c
* Wed Aug 23 2017 msuchanek@suse.de
- powerpc/powernv: Add support to set power-shifting-ratio
  (bsc#1055115).
- commit 73968cc
* Wed Aug 23 2017 msuchanek@suse.de
- powerpc/powernv: Add support for powercap framework
  (bsc#1055115).
- commit 934753a
* Wed Aug 23 2017 msuchanek@suse.de
- hwmon: (ibmpowernv) Add current(A) sensor (bsc#1055115).
- commit f4b3bf5
* Wed Aug 23 2017 msuchanek@suse.de
- hwmon: (ibmpowernv) introduce a legacy_compatibles array
  (bsc#1055115).
- commit 9e071c1
* Wed Aug 23 2017 msuchanek@suse.de
- hwmon: (ibmpowernv) Add highest/lowest attributes to sensors
  (bsc#1055115).
- commit ea5ab64
* Wed Aug 23 2017 msuchanek@suse.de
- powerpc/powernv: Enable PCI peer-to-peer (bsc#1055120).
- commit a6a5452
* Wed Aug 23 2017 msuchanek@suse.de
- powerpc/powernv: Detect and create IMC device (bsc1054914,
  fate#322448).
- commit 7df86cd
* Wed Aug 23 2017 msuchanek@suse.de
- powerpc/powernv: Add IMC OPAL APIs (bsc1054914, fate#322448).
- commit d35ae16
* Wed Aug 23 2017 mhocko@suse.cz
- blacklist.conf: blacklist 1ee1c3f5b5cf
  CONFIG_DEBUG_VM is disabled in all our kernel flavors
- commit 2802e86
* Wed Aug 23 2017 msuchanek@suse.de
- powerpc/powernv/idle: Correctly initialize core_idle_state_ptr
  (bsc#1055121).
- powerpc/powernv/idle: Decouple Timebase restore & Per-core
  SPRs restore (bsc#1055121).
- powerpc/powernv/idle: Restore LPCR on wakeup from deep-stop
  (bsc#1055121).
- powerpc/powernv/idle: Restore SPRs for deep idle states via
  stop API (bsc#1055121).
- powerpc/powernv/idle: Use Requested Level for restoring state
  on P9 DD1 (bsc#1055121).
- commit 9ac205d
* Wed Aug 23 2017 msuchanek@suse.de
- cpuidle-powernv: Allow Deep stop states that don't stop time
  (bsc#1055121).
- powerpc/64s/idle: Branch to handler with virtual mode offset
  (bsc#1055121).
- commit a2551db
* Wed Aug 23 2017 msuchanek@suse.de
- powerpc/mm/radix: Avoid flushing the PWC on every
  flush_tlb_range (bsc#1055186, fate#323286).
- commit 37f137e
* Wed Aug 23 2017 msuchanek@suse.de
- powerpc/mm/radix: Improve TLB/PWC flushes (bsc#1055186,
  fate#323286).
- commit 7c388fb
* Wed Aug 23 2017 msuchanek@suse.de
- powerpc/mm/radix: Improve _tlbiel_pid to be usable for PWC
  flushes (bsc#1055186, fate#323286).
- commit c4233df
* Wed Aug 23 2017 msuchanek@suse.de
- powerpc/mm/radix: Refactor radix__mark_rodata_ro() (bsc#1055186,
  fate#323286).
- commit b3b09ac
* Wed Aug 23 2017 msuchanek@suse.de
- powerpc/mm/radix: Synchronize updates to the process table
  (bsc#1055186, fate#323286).
- commit d78f2e1
* Wed Aug 23 2017 msuchanek@suse.de
- powerpc/mm/radix: Implement STRICT_RWX/mark_rodata_ro() for
  Radix (bsc#1055186, fate#323286).
- commit 8abecba
* Wed Aug 23 2017 msuchanek@suse.de
- powerpc/mm/hash: Implement mark_rodata_ro() for hash
  (bsc#1055186, fate#323286).
- commit 80a9929
* Wed Aug 23 2017 msuchanek@suse.de
- powerpc/64s: Leave interrupts hard enabled in context switch
  for radix (bsc#1055186, fate#323286).
- commit 749d27e
* Wed Aug 23 2017 msuchanek@suse.de
- powerpc/powernv: Fix boot on Power8 bare metal due to
  opal_configure_cores() (bsc#1055117, fate#323286).
- commit 396c5c1
* Wed Aug 23 2017 msuchanek@suse.de
- powerpc/powernv: Tell OPAL about our MMU mode on POWER9
  (bsc#1055117, fate#323286).
- commit bc75dc8
* Wed Aug 23 2017 msuchanek@suse.de
- powerpc/mm: Fix pmd/pte_devmap() on non-leaf entries
  (bsc#1055117, fate#323286).
- commit 457e49f
* Wed Aug 23 2017 msuchanek@suse.de
- powerpc/mm: Add devmap support for ppc64 (bsc#1055117,
  fate#323286).
- commit beadf59
* Wed Aug 23 2017 msuchanek@suse.de
- powerpc/mm/radix: Workaround prefetch issue with KVM
  (bsc#1055117, fate#323286).
- commit 34d0082
* Wed Aug 23 2017 msuchanek@suse.de
- powerpc/mm: Trace tlbie(l) instructions (bsc#1055117,
  fate#323286).
- commit f6cd9ad
* Wed Aug 23 2017 tiwai@suse.de
- ALSA: hda - Add stereo mic quirk for Lenovo G50-70 (17aa:3978)
  (bsc#1020657).
- commit d300598
* Wed Aug 23 2017 jslaby@suse.cz
- Bluetooth: hidp: fix possible might sleep error in
  hidp_session_thread (bnc#1014351).
- commit fa3a4f0
* Tue Aug 22 2017 tiwai@suse.de
- ALSA: ice1712: Add support for STAudio ADCIII (bsc#1048934).
- commit 53a20a8
* Tue Aug 22 2017 tiwai@suse.de
- ALSA: hda - Implement mic-mute LED mode enum (bsc#1055013).
- commit b870486
* Tue Aug 22 2017 msuchanek@suse.de
- cxl: Export library to support IBM XSL (bsc#1055014,
  fate#322239).
  Update config files.
- commit 06766f5
* Tue Aug 22 2017 msuchanek@suse.de
- mm/hugetlb: clean up ARCH_HAS_GIGANTIC_PAGE (bsc#1055014,
  fate#322239).
- commit ecf0169
* Tue Aug 22 2017 msuchanek@suse.de
- powerpc/mm/hugetlb: add support for 1G huge pages (bsc#1055014,
  fate#322239).
  Update config files.
- commit 619d9b1
* Tue Aug 22 2017 tiwai@suse.de
- supported.conf: Add Intel HDMI LPE audio to be supported
- commit 7218d85
* Tue Aug 22 2017 bp@suse.de
- supported.conf: Remove microcode loader
  It is not a module anymore.
- commit 6997200
* Tue Aug 22 2017 mhocko@suse.cz
- supported.conf: make z3fold.ko officially unsupported
  We do not have anybody inhouse to be familiar with the code and there
  was no explicit fate to enable it either. Make it available in the
  kernel-extra though.
- commit 5bd98fe
* Mon Aug 21 2017 pmladek@suse.com
- Update TAINT_FLAGS_COUNT for the added taint flags
  This fixes the port for 4.12.
  Refresh patches.suse/supported-flag.
- commit 22a9dcd
* Fri Aug 18 2017 msuchanek@suse.de
- Do not ship firmware (bsc#1054239).
  Pull firmware from kernel-firmware instead.
- commit 0b0b5c9
* Fri Aug 18 2017 tbogendoerfer@suse.de
- supported.conf: mark sfc-falcon as unsupported (fate#323467, bsc#1039860)
- commit 6eb197e
* Fri Aug 18 2017 yousaf.kaukab@suse.com
- tty: pl011: fix initialization order of QDF2400 E44
  (fate#323912).
- commit 1f108a8
* Fri Aug 18 2017 neilb@suse.com
- Delete patches.suse/0017-NFS-nfs4_lookup_revalidate-need-to-report-STALE-inod.patch.
  This has been fixed a different way upstream
- commit 535dc30
* Thu Aug 17 2017 jeffm@suse.com
- supported.conf: clear mistaken external support flag for cifs.ko (bsc#1053802).
- commit a5b6524
* Thu Aug 17 2017 neilb@suse.com
- Refresh patches.fixes/0001-MD-fix-sleep-in-atomic.patch.
- Refresh
  patches.fixes/0001-NFSv4-don-t-let-hanging-mounts-block-other-mounts.patch.
- Refresh
  patches.fixes/0001-loop-Add-PF_LESS_THROTTLE-to-block-loop-device-threa.patch.
- Refresh
  patches.fixes/0001-md-use-a-separate-bio_set-for-synchronous-IO.patch.
- Refresh patches.fixes/d-lookup-fairness.fix.
- Refresh patches.fixes/dm-snap-avoid-deadlock.patch.
- Refresh patches.fixes/nfs4_close.fix.
- Refresh
  patches.suse/0017-NFS-nfs4_lookup_revalidate-need-to-report-STALE-inod.patch.
- Refresh patches.suse/blk-timeout-no-round.
- Delete
  patches.fixes/0001-NFS-don-t-try-to-cross-a-mountpount-when-there-isn-t.patch.
- Delete
  patches.fixes/0001-Revert-SUNRPC-xs_sock_mark_closed-does-not-need-to-t.patch.
- Delete
  patches.fixes/0001-md-handle-read-only-member-devices-better.patch.
- Delete patches.fixes/cifs-optional-treename-prefix.
- Delete patches.fixes/nfs_flush_incompatible.fix.
- Delete patches.fixes/ptrace-in-namespace-perm-check.fix.
- Delete patches.suse/nfs-no-share-transport.
- Delete patches.suse/nfs-no-share-transport-nfsv4.
  Review patches carried forward from SLE12.
  Some not needed, some not wanted, some perserved and refreshed.
- commit 30682b5
* Thu Aug 17 2017 jslaby@suse.cz
- Linux 4.12.8 (bnc#1012628).
- commit 4d7933a
* Thu Aug 17 2017 neilb@suse.com
- SUNRPC: Mask XIDs to prevent replay cache collision
  (fate#322786).
- NFS: Allow multiple connections to NFSv3 and NFSv4.0 servers
  (fate#322786).
- NFS: Display the "nconnect" mount option if it is set
  (fate#322786).
- pNFS: Allow multiple connections to the DS (fate#322786).
- NFSv4: Allow multiple connections to NFSv4.x (x>0) servers
  (fate#322786).
- NFS: Add a mount option to specify number of TCP connections
  to use (fate#322786).
- SUNRPC: Allow creation of RPC clients with multiple connections
  (fate#322786).
- commit e56b097
* Wed Aug 16 2017 tonyj@suse.de
- powerpc/perf/hv-24x7: Aggregate result elements on POWER9 SMT8
  (FATE#323438).
- powerpc/perf/hv-24x7: Support v2 of the hypervisor API
  (FATE#323438).
- powerpc/perf/hv-24x7: Minor improvements (FATE#323438).
- powerpc/perf/hv-24x7: Fix return value of hcalls (FATE#323438).
- powerpc-perf/hx-24x7: Don't log failed hcall twice
  (FATE#323438).
- powerpc/perf/hv-24x7: Properly iterate through results
  (FATE#323438).
- powerpc/perf/hv-24x7: Fix off-by-one error in request_buffer
  check (FATE#323438).
- powerpc/perf/hv-24x7: Fix passing of catalog version number
  (FATE#323438).
- commit 56353ab
* Wed Aug 16 2017 jeffm@suse.com
- supported.conf: mark reiserfs unsupported (FATE#323394).
  ReiserFS is not supported in SLE15.  ReiserFS file systems must be
  transferred or converted before installing.
- commit 5f3f041
* Wed Aug 16 2017 msuchanek@suse.de
- powerpc/mm/hash64: Make vmalloc 56T on hash (bsc#1048914,
  bsc#1054026).
- commit cbc95bf
* Wed Aug 16 2017 msuchanek@suse.de
- powerpc/mm/slb: Move comment next to the code it's referring to
  (bsc#1048914, bsc#1054026).
- commit a120516
* Wed Aug 16 2017 msuchanek@suse.de
- powerpc/mm/book3s64: Make KERN_IO_START a variable (bsc#1048914,
  bsc#1054026).
- commit 7eb1dbb
* Wed Aug 16 2017 tiwai@suse.de
- blacklist.conf: add blacklist entries for drm
- commit 369eed2
* Wed Aug 16 2017 tiwai@suse.de
- drm/i915: Remove assertion from raw __i915_vma_unpin()
  (bsc#1051510).
- drm/i915: Fix out-of-bounds array access in bdw_load_gamma_lut
  (bsc#1051510).
- drm/i915: Unbreak gpu reset vs. modeset locking (bsc#1051510).
- drm/i915: fix backlight invert for non-zero minimum brightness
  (bsc#1051510).
- drm/i915: Fix an error checking test (bsc#1051510).
- drm/msm/hdmi: Use bitwise operators when building register
  values (bsc#1051510).
- drm/imx: fix typo in ipu_plane_formats[] (bsc#1051510).
- drm/bridge: tc358767: fix probe without attached output node
  (bsc#1051510).
- drm/msm/dsi: Calculate link clock rates with updated dsi->lanes
  (bsc#1051510).
- drm: omapdrm: Take GEM object reference when exporting dmabuf
  (bsc#1051510).
- drm/rockchip: fix Kconfig dependencies (bsc#1051510).
- drm/amdkfd: NULL dereference involving create_process()
  (bsc#1051510).
- drm/mediatek: separate color module to fixup error memory
  reallocation (bsc#1051510).
- commit 54d6c62
* Wed Aug 16 2017 oneukum@suse.com
- supported.conf: overzealous destruction of PCMCIA
- commit 1d32c31
* Wed Aug 16 2017 oneukum@suse.com
- supported.conf: added Cavium Nitrox (FATE#323034)
- commit c54e3ea
* Wed Aug 16 2017 msuchanek@suse.de
- s390: export symbols for crash-kmp (bsc#1053915).
- commit dd8539a
* Wed Aug 16 2017 oneukum@suse.com
- Update config files.
  Cavium crypto accelerators
  (FATE#323034, FATE#323051)
- commit 546670e
* Tue Aug 15 2017 tonyj@suse.de
- perf vendor events: Add POWER9 PVRs to mapfile (FATE#322450,
  bsc#1050145).
- perf vendor events: Add POWER9 PMU events (FATE#322450,
  bsc#1050145).
- perf pmu-events: Support additional POWER8+ PVR in mapfile
  (FATE#322450, bsc#1050145 (dependent patch)).
- commit 5191db3
* Tue Aug 15 2017 bpoirier@suse.com
- Refresh patch order in networking section
- commit 5beeea5
* Tue Aug 15 2017 mgorman@suse.de
- Revert "mm: numa: defer TLB flush for THP migration as long
  as possible" (mprotect/madvise theoretical races (bnc#1053919)).
- mm: fix KSM data corruption (mprotect/madvise theoretical races
  (bnc#1053919)).
- mm: fix MADV_[FREE|DONTNEED] TLB flush miss problem
  (mprotect/madvise theoretical races (bnc#1053919)).
- mm: make tlb_flush_pending global (mprotect/madvise theoretical
  races (bnc#1053919)).
- mm: refactor TLB gathering API (mprotect/madvise theoretical
  races (bnc#1053919)).
- mm: migrate: fix barriers around tlb_flush_pending
  (mprotect/madvise theoretical races (bnc#1053919)).
- mm: migrate: prevent racy access to tlb_flush_pending
  (mprotect/madvise theoretical races (bnc#1053919)).
- commit e34ab01
* Tue Aug 15 2017 dbueso@suse.de
- mm, hugetlb: schedule when potentially allocating many hugepages (bsc#971975).
- commit 56cb576
* Tue Aug 15 2017 dbueso@suse.de
- sched/deadline: Zero out positive runtime after throttling
  constrained tasks (bsc#978907).
- sched/core: Allow __sched_setscheduler() in interrupts when
  PI is not used (bsc#978907).
- commit 472d759
* Tue Aug 15 2017 jeffm@suse.com
- Remove legacy overlayfs compatibility layer (FATE#323754).
- commit 276905f
* Tue Aug 15 2017 oneukum@suse.com
- ACPI / PM: Ignore spurious SCI wakeups from suspend-to-idle
  (FATE#323777).
- ACPI / PM: Run wakeup notify handlers synchronously
  (FATE#323777).
- commit 925f2b6
* Tue Aug 15 2017 yousaf.kaukab@suse.com
- i2c: xgene-slimpro: include linux/io.h for memremap
  (bsc#1053633).
- i2c: xgene-slimpro: Add ACPI support by using PCC mailbox
  (bsc#1053633).
- i2c: xgene-slimpro: Use a single function to send command
  message (bsc#1053633).
- ACPI / irq: Fix return code of acpi_gsi_to_irq() (bsc#1053627).
- commit d7a9a50
* Tue Aug 15 2017 hare@suse.de
- Delete
  patches.fixes/dm-raid-Do-not-call-BUG-in-__rdev_sectors.patch.
- Delete patches.fixes/md-fix-a-null-dereference.patch.
- commit 88d2447
* Tue Aug 15 2017 hare@suse.de
- Delete
  patches.drivers/blk-mq-map-all-HWQ-also-in-hyperthreaded-system.patch.
- commit 4b25e5c
* Tue Aug 15 2017 hare@suse.de
- Delete patches.suse/loop-fix-regression-with-op_is_write.patch.
- commit aadbd32
* Tue Aug 15 2017 hare@suse.de
- Re-enable 'patches.fixes/dm-multipath-Improve-logging.patch'
- commit 7c6e565
* Tue Aug 15 2017 hare@suse.de
- Delete
  patches.fixes/dm-mpath-fix-potential-for-dropping-queue_if_no_path.patch.
- commit a103f04
* Tue Aug 15 2017 hare@suse.de
- Delete patches.fixes/watchdog-hpwdt-add-support-for-iLO5.patch.
- commit e86c31d
* Tue Aug 15 2017 hare@suse.de
- Delete
  patches.drivers/target-fixup-error-message-in-target_tg_pt_gp_alua_a.patch.
- Delete
  patches.drivers/target-fixup-error-message-in-target_tg_pt_gp_tg_pt_.patch.
- commit b9fb445
* Tue Aug 15 2017 hare@suse.de
- megaraid_sas: Fallback to older scanning if no disks are found
  (bnc#870440).
- megaraid_sas: boot hangs while LD is offline (bnc#698102).
- Delete
  patches.suse/megaraid_sas-Fallback-to-older-scanning-if-not-disks.patch.
- Delete
  patches.suse/megaraid_sas-boot-hangs-while-LD-is-offline.patch.
- commit 168240e
* Tue Aug 15 2017 hare@suse.de
- Re-enable 'patches.suse/fcoe-reduce-max_sectors'
- commit 0e279a1
* Tue Aug 15 2017 hare@suse.de
- scsi: fnic: changing queue command to return result
  DID_IMM_RETRY when rport is init (bsc#1035920).
- commit 6c8597b
* Tue Aug 15 2017 hare@suse.de
- Delete
  patches.drivers/0005-scsi-fnic-Correcting-rport-check-location-in-fnic_qu.patch.
- commit 243f663
* Tue Aug 15 2017 hare@suse.de
- Delete
  patches.drivers/mpt3sas-Ensure-the-connector_name-string-is-NUL-term.patch.
- commit 5836852
* Tue Aug 15 2017 hare@suse.de
- Delete patches.fixes/scsi-dh-queuedata-accessors.
- commit 475dab3
* Tue Aug 15 2017 hare@suse.de
- Reshuffle 'patches.drivers/scsi_transport_fc-return-EBUSY-for-deleted-vport.patch'
- commit 2ed0ed3
* Tue Aug 15 2017 hare@suse.de
- Delete
  patches.fixes/block-don-t-check-request-size-in-blk_cloned_rq_chec.patch.
- commit c81e3a2
* Tue Aug 15 2017 hare@suse.de
- Delete patches.suse/dm-mpath-detach-existing-hardware-handler.
- commit 5762cda
* Tue Aug 15 2017 hare@suse.de
- Delete patches.suse/no-partition-scan (FATE#323406)
- commit 5056c39
* Tue Aug 15 2017 hare@suse.de
- Refresh patches.suse/dm-mpath-accept-failed-paths.
- commit a98933b
* Tue Aug 15 2017 hare@suse.de
- Delete patches.suse/dm-mpath-no-partitions-feature (FATE#323406)
- commit ef1cd4c
* Tue Aug 15 2017 tiwai@suse.de
- ALSA: usb-audio: Apply sample rate quirk to Sennheiser headset
  (bsc#1052580).
- commit a8251af
* Mon Aug 14 2017 msuchanek@suse.de
- genirq: Handle NOAUTOEN interrupt setup proper (fate#322438).
- commit 9650b8d
* Mon Aug 14 2017 msuchanek@suse.de
- powerpc/xive: Fix section mismatch warnings (fate#322438).
- powerpc/xive: Ensure active irqd when setting affinity
  (fate#322438).
- powerpc/xive: Silence message about VP block allocation
  (fate#322438).
- KVM: PPC: Book3S HV: Don't sleep if XIVE interrupt pending on
  POWER9 (fate#322438).
- commit 2b1c5d2
* Mon Aug 14 2017 msuchanek@suse.de
- KVM: PPC: Book3S HV: Don't let VCPU sleep if it has a doorbell
  pending (fate#322438).
- commit f863b85
* Mon Aug 14 2017 mwilck@suse.com
- hpsa/smartpqi: metadata and series.conf update
- moved hpsa patches upwards in series.conf
- hpsa/smartpqi "limit transfer length" patches accepted upstream
- Refresh
  patches.drivers/0001-scsi-hpsa-limit-transfer-length-to-1MB.patch.
- Refresh
  patches.fixes/0001-smartpqi-limit-transfer-length-to-1MB.patch.
- commit c0d744c
* Mon Aug 14 2017 tiwai@suse.de
- ALSA: fm801: Initialize chip after IRQ handler is registered
  (bsc#1051510).
- iwlwifi: mvm: quietly accept non-sta assoc response frames
  (bsc#1051510).
- iwlwifi: mvm: fix deduplication start logic (bsc#1051510).
- iwlwifi: fix TX tracing for non-linear SKBs (bsc#1051510).
- iwlwifi: mvm: change sta_id to u8 (bsc#1051510).
- iwlwifi: mvm: handle IBSS probe_queue in a few missing places
  (bsc#1051510).
- iwlwifi: mvm: remove DQA non-STA client mode special case
  (bsc#1051510).
- iwlwifi: mvm: don't mess the SNAP header in TSO for non-QoS
  packets (bsc#1051510).
- iwlwifi: mvm: fix a NULL pointer dereference of error in
  recovery (bsc#1051510).
- iwlwifi: fix tracing when tx only is enabled (bsc#1051510).
- iwlwifi: mvm: quietly accept non-sta disassoc frames
  (bsc#1051510).
- iwlwifi: mvm: don't send fetch the TID from a non-QoS packet
  in TSO (bsc#1051510).
- iwlwifi: mvm: fix mac80211 queue tracking (bsc#1051510).
- iwlwifi: missing error code in iwl_trans_pcie_alloc()
  (bsc#1051510).
- commit d7ab615
* Sun Aug 13 2017 jslaby@suse.cz
- Linux 4.12.7 (bnc#1012628).
- commit 7dae241
* Sun Aug 13 2017 jslaby@suse.cz
- Refresh
  patches.fixes/netfilter-expect-fix-crash-when-putting-uninited-exp.patch.
  Update upstream status.
- commit cdb9f49
* Sat Aug 12 2017 jslaby@suse.cz
- Linux 4.12.6 (CVE-2017-7542 CVE-2017-8831 bnc#1012628
  bsc#1037994 bsc#1049882).
- Delete
  patches.fixes/ipv6-avoid-overflow-of-offset-in-ip6_find_1stfragopt.patch.
- Delete
  patches.fixes/media-saa7164-fix-double-fetch-PCIe-access-condition.
- commit 29b7412
* Fri Aug 11 2017 dbueso@suse.de
- sched/wait: Remove the lockless swait_active() check in swake_up*() (bsc#1050549).
- commit 5f6d96e
* Fri Aug 11 2017 dbueso@suse.de
- ipc/sem: play nicer with large nsops allocations (bsc#1050323).
- ipc/sem: drop sem_checkid helper (bsc#1050323).
- locking/osq_lock: Fix osq_lock queue corruption (bsc#1050549).
- commit 458731e
* Fri Aug 11 2017 dbueso@suse.de
- update configs
- commit 2295f30
* Thu Aug 10 2017 dbueso@suse.de
- block/cfq: cache rightmost rb_node (bsc#1052639).
- mem/memcg: cache rightmost node (bsc#1052639).
- fs/epoll: use faster rb_first_cached() (bsc#1052639).
- procfs: use faster rb_first_cached() (bsc#1052639).
- lib/interval-tree: correct comment wrt generic flavor
  (bsc#1052639).
- block/cfq: replace cfq_rb_root leftmost caching (bsc#1052639).
- locking/rtmutex: replace top-waiter and pi_waiters leftmost
  caching (bsc#1052639).
- sched/deadline: replace earliest dl and rq leftmost caching
  (bsc#1052639).
- rbtree: add some additional comments for rebalancing cases
  (bsc#1052639).
- rbtree: optimize root-check during rebalancing loop
  (bsc#1052639).
- rbtree: cache leftmost node internally (bsc#1052639).
- lib/interval_tree_test.c: allow full tree search (bsc#1052639).
- lib/interval_tree_test.c: allow users to limit scope of endpoint
  (bsc#1052639).
- lib/interval_tree_test.c: make test options module parameters
  (bsc#1052639).
- lib/interval_tree_test.c: allow the module to be compiled-in
  (bsc#1052639).
- commit 1f8bb6f
* Thu Aug 10 2017 dbueso@suse.de
- bitmap: use memcmp optimisation in more situations
  (bsc#1050549).
- include/linux/bitmap.h: turn bitmap_set and bitmap_clear into
  memset when possible (bsc#1050549).
- commit 1f0d3c0
* Thu Aug 10 2017 dbueso@suse.de
- kcmp: fs/epoll: wrap kcmp code with CONFIG_CHECKPOINT_RESTORE
  (bsc#1052639).
- kcmp: add KCMP_EPOLL_TFD mode to compare epoll target files
  (bsc#1052639).
- procfs: fdinfo: extend information about epoll target files
  (bsc#1052639).
- fs, epoll: short circuit fetching events if thread has been
  killed (bsc#1052639).
- commit 935d249
* Thu Aug 10 2017 dbueso@suse.de
- locking/rtmutex: Don't initialize lockdep when not required
  (bsc#1050549).
- rt_mutex: Add lockdep annotations (bsc#1050549).
- sched/cfs: Make util/load_avg more stable (bnc#978907).
- commit 1933697
* Thu Aug 10 2017 msuchanek@suse.de
- rpm/modules.fips include module list from dracut (bsc#1074984, FATE#323247).
- commit bfa538f
* Thu Aug 10 2017 ohering@suse.de
- Delete stale patches.suse/suse-hv-storvsc-sg_tablesize.patch.
- commit df0c558
* Thu Aug 10 2017 ohering@suse.de
- hv: print extra debug in kvp_on_msg in error paths
  (bnc#1039153).
- netvsc: make sure and unregister datapath (fate#323887,
  bsc#1052899).
- netvsc: fix rtnl deadlock on unregister of vf (fate#323887,
  bsc#1052442).
- netvsc: transparent VF management (fate#323887, bsc#1051979).
- hyperv: netvsc: Neaten netvsc_send_pkt by using a temporary
  (fate#323887).
- netvsc: signal host if receive ring is emptied (fate#323887).
- netvsc: fix error unwind on device setup failure (fate#323887).
- netvsc: optimize receive completions (fate#323887).
- netvsc: remove unnecessary indirection of page_buffer
  (fate#323887).
- netvsc: don't print pointer value in error message
  (fate#323887).
- netvsc: fix warnings reported by lockdep (fate#323887).
- netvsc: fix return value for set_channels (fate#323887).
- Revert "netvsc: optimize calculation of number of slots"
  (fate#323887).
- netvsc: remove no longer used max_num_rss queues (fate#323887).
- netvsc: include rtnetlink.h (fate#323887).
- netvsc: fix netvsc_set_channels (fate#323887).
- netvsc: prefetch the first incoming ring element (fate#323887).
- netvsc: Remove redundant use of ipv6_hdr() (fate#323887).
- netvsc: remove bogus rtnl_unlock (fate#323887).
- netvsc: fix ptr_ret.cocci warnings (fate#323887).
- netvsc: add rtnl annotations in rndis (fate#323887).
- netvsc: save pointer to parent netvsc_device in channel table
  (fate#323887).
- netvsc: need rcu_derefence when accessing internal device info
  (fate#323887).
- netvsc: use ERR_PTR to avoid dereference issues (fate#323887).
- netvsc: change logic for change mtu and set_queues
  (fate#323887).
- netvsc: change order of steps in setting queues (fate#323887).
- netvsc: add some rtnl_dereference annotations (fate#323887).
- netvsc: force link update after MTU change (fate#323887).
- PCI: hv: Use vPCI protocol version 1.2 (fate#323887).
- PCI: hv: Add vPCI version protocol negotiation (fate#323887).
- PCI: hv: Temporary own CPU-number-to-vCPU-number infra
  (fate#323887).
- PCI: hv: Use page allocation for hbus structure (fate#323887).
- PCI: hv: Fix comment formatting and use proper integer fields
  (fate#323887).
- scsi: storvsc: use default I/O timeout handler for FC devices
  (fate#323887).
- hv_netvsc: Fix the carrier state error when data path is off
  (fate#323887).
- hv_netvsc: Remove unnecessary var link_state from struct
  netvsc_device_info (fate#323887).
- x86/hyperv: Read TSC frequency from a synthetic MSR
  (fate#323887).
- x86/hyperv: Check frequency MSRs presence according to the
  specification (fate#323887).
- networking: introduce and use skb_put_data() (fate#323887).
- scsi: storvsc: remove unnecessary channel inbound lock
  (fate#323887).
- scsi: storvsc: use in place iterator function (fate#323887).
- netvsc: fold in get_outbound_net_device (fate#323887).
- netvsc: pass net_device to netvsc_init_buf and
  netvsc_connect_vsp (fate#323887).
- netvsc: mark error cases as unlikely (fate#323887).
- netvsc: use typed pointer for internal state (fate#323887).
- netvsc: use hv_get_bytes_to_read (fate#323887).
- netvsc: optimize calculation of number of slots (fate#323887).
- tools: hv: set hotplug for VF on Suse (fate#323887).
- tools: hv: set allow-hotplug for VF on Ubuntu (fate#323887).
- netvsc: Add #include's for csum_* function declarations
  (fate#323887).
- vmbus: Reuse uuid_le_to_bin() helper (fate#323887).
- drivers: hv: vmbus: Increase the time between retries in
  vmbus_post_msg() (fate#323887).
- hv_utils: fix TimeSync work on pre-TimeSync-v4 hosts
  (fate#323887).
- hv_utils: drop .getcrosststamp() support from PTP driver
  (fate#323887).
- Drivers: hv: vmbus: Get the current time from the current
  clocksource (fate#323887).
- HV: properly delay KVP packets when negotiation is in progress
  (fate#323887).
- Drivers: hv: vmbus: Fix rescind handling (fate#323887).
- Drivers: hv: util: Make hv_poll_channel() a little more
  efficient (fate#323887).
- Drivers: hv: vmbus: Fix error code returned by vmbus_post_msg()
  (fate#323887).
- tools: hv: properly handle long paths (fate#323887).
- Tools: hv: vss: Thaw the filesystem and continue if freeze
  call has timed out (fate#323887).
- tools: hv: Add clean up for included files in Ubuntu net config
  (fate#323887).
- commit 5791482
* Thu Aug 10 2017 msuchanek@suse.de
- powerpc: Only do ERAT invalidate on radix context switch on
  P9 DD1 (bsc#1053131).
- commit b476432
* Thu Aug 10 2017 oneukum@suse.com
- crypto: cavium - make several functions static (FATE#323051,
  FATE#323034).
- crypto: cavium/nitrox - dma_mapping_error() returns bool
  (FATE#323034).
- crypto: cavium - fix spelling mistake "Revsion" -> "Revision"
  (FATE#323034).
- crypto: cavium - Add more algorithms (FATE#323034, FATE#323051).
- commit 7a50f51
* Thu Aug 10 2017 oneukum@suse.com
- crypto: cavium - Remove the individual encrypt/decrypt function
  for each algorithm (FATE#323051, FATE#323034).
- crypto: cavium - Downgrade the annoying misc interrupt print
  from dev_err to dev_dbg (FATE#323034, FATE#323051).
- crypto: cavium - Register the CNN55XX supported crypto
  algorithms (FATE#323034).
- crypto: cavium - Add debugfs support in CNN55XX driver
  (FATE#323034).
- crypto: cavium - Add support for CNN55XX adapters (FATE#323051).
- commit 2b3984f
* Thu Aug 10 2017 brogers@suse.com
- Delete patches.suse/x86-kvm-increase-guest-vcpu-support-count-to-240.patch.
  Obsolete, as it is already in upstream kernel.
  Also reassign a patch to jslaby which was mislabeled as mine.
- commit 62ea3d9
* Wed Aug  9 2017 bpoirier@suse.com
- Refresh patch order in networking section
  Some patches were added out of order.
- commit 314b1ee
* Wed Aug  9 2017 tbogendoerfer@suse.de
- Dropped already present patch
  patches.drivers/ibft-expose-ibft-acpi-header-via-sysfs.patch
- commit ca0f923
* Wed Aug  9 2017 tbogendoerfer@suse.de
- enabled/moved
  patches.suse/module-Inform-user-when-loading-externally-supported.patch
  patches.drivers/i40evf-fix-merge-error-in-older-patch.patch
  Refresh
  patches.drivers/i40evf-fix-merge-error-in-older-patch.patch.
- commit bd094a0
* Wed Aug  9 2017 jbeulich@suse.com
- Delete patches.fixes/xsa216.patch (went into 4.12).
- commit 05e7511
* Wed Aug  9 2017 jgross@suse.com
- re-enable Xen pvusb frontend patches
- commit 6cb7475
* Wed Aug  9 2017 msuchanek@suse.de
- kdump: protect vmcoreinfo data under the crash memory
  (bsc#1051137).
- commit 8c0423d
* Wed Aug  9 2017 msuchanek@suse.de
- kexec: move vmcoreinfo out of the kernel's .bss section
  (bsc#1051137).
- commit b72922b
* Wed Aug  9 2017 msuchanek@suse.de
- powerpc/fadump: use the correct VMCOREINFO_NOTE_SIZE for phdr
  (bsc#1051137).
- commit 30c6dec
* Wed Aug  9 2017 msuchanek@suse.de
- powerpc/fadump: Set an upper limit for boot memory size
  (bsc#1051137).
- commit 68223be
* Wed Aug  9 2017 msuchanek@suse.de
- powerpc/fadump: Update comment about offset where fadump is
  reserved (bsc#1051137).
- commit eb88722
* Wed Aug  9 2017 msuchanek@suse.de
- Refresh fadump patches metadata and change to upstream order.
- commit a85ebb8
* Wed Aug  9 2017 ohering@suse.de
- Delete stale patches.fixes/scsi-ibmvscsi-module_alias.patch.
- Delete stale patches.suse/suse-ppc64-branding.
- commit 6b6f95c
* Wed Aug  9 2017 tiwai@suse.de
- [media] saa7164: fix double fetch PCIe access condition
  (CVE-2017-8831 bsc#1037994).
- commit 4d38c27
* Wed Aug  9 2017 dbueso@suse.de
- x86/tsc: Fold set_cyc2ns_scale() into caller (bsc#1052904).
- commit d94e9ff
* Wed Aug  9 2017 dbueso@suse.de
- bitmap: optimise bitmap_set and bitmap_clear of a single bit
  (bsc#1050549).
- lib/test_bitmap.c: add optimisation tests (bsc#1050549).
- commit a98aaca
* Wed Aug  9 2017 dbueso@suse.de
- cpuidle: Fix idle time tracking (bsc#1052904).
- x86/tsc: Call check_system_tsc_reliable() before
  unsynchronized_tsc() (bsc#1052904).
- sched/clock: Fix early boot preempt assumption in
  __set_sched_clock_stable() (bsc#1052904).
- sched/clock: Print a warning recommending 'tsc=unstable'
  (bsc#1052904).
- sched/clock: Use late_initcall() instead of sched_init_smp()
  (bsc#1052904).
- sched/clock: Remove watchdog touching (bsc#1052904).
- sched/clock: Remove unused argument to
  sched_clock_idle_wakeup_event() (bsc#1052904).
- x86/tsc: Provide 'tsc=unstable' boot parameter (bsc#1052904).
- x86/tsc: Feed refined TSC calibration into sched_clock()
  (bsc#1052904).
- x86/tsc: Fix sched_clock() sync (bsc#1052904).
- x86/tsc, sched/clock, clocksource: Use clocksource watchdog
  to provide stable sync points (bsc#1052904).
- x86/tsc: Remodel cyc2ns to use seqcount_latch() (bsc#1052904).
- sched/clock: Initialize all per-CPU state before switching
  (back) to unstable (bsc#1052904).
- commit 521cce8
* Wed Aug  9 2017 dbueso@suse.de
- ipc: add missing container_of()s for randstruct (bsc#1050323).
- kernel/locking: Fix compile error with qrwlock.c (bsc#1050549).
- commit 62276d3
* Tue Aug  8 2017 msuchanek@suse.de
- ibmvnic: Report rx buffer return codes as netdev_dbg
  (bsc#1052794).
- commit 3bd6034
* Tue Aug  8 2017 msuchanek@suse.de
- ibmvnic: Check for transport event on driver resume
  (bsc#1051556, bsc#1052709).
- commit fefc352
* Tue Aug  8 2017 msuchanek@suse.de
- ibmvnic: Initialize SCRQ's during login renegotiation
  (bsc#1052223).
- commit 9454da2
* Tue Aug  8 2017 jack@suse.cz
- ext4: Don't clear SGID when inheriting ACLs (bsc#1052766).
- ext4: preserve i_mode if __ext4_set_acl() fails (bsc#1052766).
- commit 0e8e28d
* Mon Aug  7 2017 jroedel@suse.de
- iommu/amd: Fix schedule-while-atomic BUG in initialization code
  (bsc1052533).
- iommu/amd: Enable ga_log_intr when enabling guest_mode
  (bsc1052533).
- commit 645d9f3
* Mon Aug  7 2017 jslaby@suse.cz
- Linux 4.12.5 (bnc#1012628 bsc#1049483 bsc#1049599).
- Delete patches.fixes/dentry-name-snapshots.patch.
- Delete
  patches.suse/0001-md-remove-idx-from-struct-resync_pages.patch.
- commit e6109ef
* Fri Aug  4 2017 ohering@suse.de
- Remove merged hyperv patches that lacked an upstream tag
- commit a39c1e7
* Fri Aug  4 2017 tiwai@suse.de
- rpm/kernel-docs.spec.in: Disable PDF build again.
  4.12.x still seems having some issues.  Temporarily disabled again.
- commit 472526a
* Fri Aug  4 2017 tiwai@suse.de
- ALSA: hda/realtek - There is no loopback mixer in the
  ALC234/274/294 (bsc#1052235).
- ALSA: hda/realtek - Fix typo of pincfg for Dell quirk
  (bsc#1052235).
- ALSA: hda/realtek - Support Dell headset mode for ALC3271
  (bsc#1052235).
- ALSA: hda/realtek - No loopback on ALC225/ALC295 codec
  (bsc#1052235).
- ALSA: hda/realtek - Update headset mode for ALC225
  (bsc#1052235).
- ALSA: hda/realtek - Update headset mode for ALC298
  (bsc#1052235).
- ALSA: hda/realtek - Support headset mode for
  ALC234/ALC274/ALC294 (bsc#1052235).
- ALSA: hda/realtek - Add default procedure for suspend and
  resume state (bsc#1052235).
- ALSA: hda/realtek - Add ALC256 HP depop function (bsc#1052235).
- ALSA: hda/realtek - New codec device ID for ALC1220
  (bsc#1052235).
- ALSA: hda/realtek - New codecs support for ALC215/ALC285/ALC289
  (bsc#1052235).
- ALSA: hda/realtek - Remove ALC285 device ID (bsc#1052235).
- commit 876d653
* Fri Aug  4 2017 tiwai@suse.de
- Re-enable xmlto for 4.12 build
  Otherwise the doc-build complains and aborts.
- commit de2cf2a
* Thu Aug  3 2017 jkosina@suse.cz
- supported.conf: add Intel ISH support (FATE#322842)
- commit 129f345
* Wed Aug  2 2017 jroedel@suse.de
- kvm: nVMX: Fix nested_vmx_check_msr_bitmap_controls
  (bsc#1051478).
- commit 56b5cb8
* Wed Aug  2 2017 jroedel@suse.de
- blacklist.conf: Blacklist c133c7615751 ('x86/nmi: Fix timeout test in test_nmi_ipi()')
  Fixes just a test-case.
- commit a4200a2
* Wed Aug  2 2017 jroedel@suse.de
- PCI / PM: Fix native PME handling during system suspend/resume
  (bsc#1051478).
- PCI: Enable ECRC only if device supports it (bsc#1051478).
- PCI: dwc: dra7xx: Use RW1C for IRQSTATUS_MSI and IRQSTATUS_MAIN
  (bsc#1051478).
- PCI: Correct PCI_STD_RESOURCE_END usage (bsc#1051478).
- commit 9891a80
* Wed Aug  2 2017 jkosina@suse.cz
- series.conf: patches.suse/sched-optimize-latency-defaults.patch has been
  enabled by Mel Gorman already, drop the one with mgalbraith guard
- commit 75879d1
* Wed Aug  2 2017 tiwai@suse.de
- rpm/kernel-docs.spec.in: Fix package list and enable building PDFs
  Finally it works!  Added some missing pieces (ImageMagick, some texlive
  subpkgs) in addition to use explicitly python3-Sphinx stuff.
- commit c117a0c
* Wed Aug  2 2017 yousaf.kaukab@suse.com
- Delete
  patches.drivers/0002-iommu-arm-smmu-Plumb-in-new-ACPI-identifiers.patch.
  6dbeea7da557 iommu/arm-smmu: Plumb in new ACPI identifiers in v4.12.4
- commit 39ce84a
* Wed Aug  2 2017 mbrugger@suse.com
- Refresh
  patches.arch/arm64-drivers-char-kmem-disable-on-arm64.patch.
- Delete patches.arch/0001-arm64-Define-Cortex-A73-MIDR.patch.
- Delete
  patches.arch/0001-arm64-arch_timer-Add-infrastructure-for-multiple-err.patch.
- Delete
  patches.arch/0002-arm64-arch_timer-Add-erratum-handler-for-globally-de.patch.
- Delete
  patches.arch/0002-arm64-cpu_errata-Allow-an-erratum-to-be-match-for-al.patch.
- Delete
  patches.arch/0003-arm64-arch_timer-Add-erratum-handler-for-CPU-specifi.patch.
- Delete
  patches.arch/0004-arm64-arch_timer-Move-arch_timer_reg_read-write-arou.patch.
- Delete
  patches.arch/0005-arm64-arch_timer-Get-rid-of-erratum_workaround_set_s.patch.
- Delete
  patches.arch/0006-arm64-arch_timer-Rework-the-set_next_event-workaroun.patch.
- Delete
  patches.arch/0007-arm64-arch_timer-Make-workaround-methods-optional.patch.
- Delete
  patches.arch/0008-arm64-arch_timer-Allows-a-CPU-specific-erratum-to-on.patch.
- Delete
  patches.arch/0009-arm64-arch_timer-Move-clocksource_counter-and-co-aro.patch.
- Delete
  patches.arch/0010-arm64-arch_timer-Enable-CNTVCT_EL0-trap-if-workaroun.patch.
- Delete
  patches.arch/0011-arm64-arch_timer-Workaround-for-Cortex-A73-erratum-8.patch.
- Delete
  patches.arch/0012-arm64-arch_timer-Allow-erratum-matching-with-ACPI-OE.patch.
- Delete
  patches.arch/0013-arm64-arch_timer-Add-HISILICON_ERRATUM_161010101-ACP.patch.
- Delete
  patches.arch/arm64-0001-iommu-arm-smmu-Invalidate-TLBs-properly.patch.
- Delete
  patches.arch/arm64-1-6-Documentation-arm64-pmu-Add-Broadcom-Vulcan-PMU-binding.patch.
- Delete
  patches.arch/arm64-2-6-arm64-dts-Add-Broadcom-Vulcan-PMU-in-dts.patch.
- Delete
  patches.arch/arm64-3-4-perf-xgene-Add-APM-X-Gene-SoC-Performance-Monitoring-Unit-driver.patch.
- Delete
  patches.arch/arm64-3-6-arm64-perf-Changed-events-naming-as-per-ARM-ARM.patch.
- Delete
  patches.arch/arm64-4-6-arm64-perf-Define-complete-ARMv8-recommended-implementation-defined-events.patch.
- Delete
  patches.arch/arm64-5-6-arm64-perf-Filter-common-events-based-on-PMCEIDn_EL0.patch.
- Delete
  patches.arch/arm64-6-6-arm64-perf-Add-Broadcom-Vulcan-PMU-support.patch.
- Delete
  patches.arch/arm64-Documentation-gpio-Update-description-for-X-Gene-standby-GPIO-controller-DTS-binding.patch.
- Delete
  patches.arch/arm64-dts-Update-X-Gene-standby-GPIO-controller-DTS-entries.patch.
- Delete patches.arch/arm64-fix-includes-for-smp.patch.
- Delete
  patches.arch/arm64-gpio-xgene-Enable-X-Gene-standby-GPIO-as-interrupt-controller.patch.
- Delete
  patches.arch/arm64-irqdomain-Export-irq_domain_free_irqs_common.patch.
- Delete
  patches.arch/arm64-pci-numa-adding-helper-functions-as-requiered.patch.
- Delete
  patches.arch/arm64-thd-0002-pci-Add-is_pcierc-element-to-struct-pci_bus.patch.
- Delete
  patches.arch/arm64-thd-gicv3-its-increase-FOREC_MAX_ZONEORDER-for-Cav.patch.
- Delete
  patches.arch/crypto-arm64-crc32-detect-crc32-support-in-assembler.patch.
- Delete patches.arch/x86-boot-rename-reserve_bios_regions.patch.
- Delete
  patches.drivers/0001-clk-mvebu-mark-root-clocks-in-AP806-CP110-system-con.patch.
- commit 36915c9
* Wed Aug  2 2017 yousaf.kaukab@suse.com
- arm64: iommu/arm-smmu-v3: Increase CMDQ drain timeout value (bsc#1035479).
- Delete
  patches.drivers/0005-iommu-arm-smmu-v3-Increase-SMMU-CMD-queue-poll-timeo.patch.
  Switch to solution accepted upstream.
- commit 591ddbd
* Wed Aug  2 2017 hare@suse.de
- Drop obsolete SCSI patches
- Delete
  patches.drivers/cciss-set-cciss_allow_hpsa-per-default.patch.
- Delete
  patches.fixes/scsi-Do-not-use-synchronous-ALUA-submission-for-NetA.patch.
- Delete
  patches.fixes/scsi-Retry-failfast-commands-after-EH.patch.
- commit 714a4bc
* Wed Aug  2 2017 hare@suse.de
- st: fix blk_get_queue usage (bnc#834808).
- commit ea540b7
* Wed Aug  2 2017 hare@suse.de
- Update loop patches to upstream submission
- loop: Remove unused 'bdev' argument from loop_set_capacity
  (bsc#931634, FATE#319010).
- loop: fix error handling regression (bsc#931634, FATE#319010).
- loop: support 4k physical blocksize (bsc#931634, FATE#319010).
- Refresh patches.suse/loop-Compability-for-older-releases.patch.
- Delete patches.suse/loop-Add-lo_logical_blocksize.patch.
- Delete
  patches.suse/loop-Enable-correct-physical-blocksize.patch.
- Delete
  patches.suse/loop-Pass-logical-blocksize-in-lo_init-0-ioctl-field.patch.
- Delete
  patches.suse/loop-Remove-unused-bdev-argument-from-loop_set_capac.patch.
- commit 3d19f6c
* Wed Aug  2 2017 hare@suse.de
- Drop obsolete lpfc patches
- Delete
  patches.drivers/0428-lpfc-Add-nvme-initiator-devloss-support.patch.
- Delete
  patches.drivers/0429-lpfc-Fix-transition-nvme-i-rport-handling-to-nport-o.patch.
- Delete
  patches.drivers/0430-lpfc-Fix-nvme-port-role-handling-in-sysfs-and-debugf.patch.
- Delete
  patches.drivers/0431-lpfc-Add-changes-to-assist-in-NVMET-debugging.patch.
- Delete
  patches.drivers/0432-lpfc-Fix-Lun-Priority-level-shown-as-NA.patch.
- Delete
  patches.drivers/0433-lpfc-Fix-nvmet-node-ref-count-handling.patch.
- Delete
  patches.drivers/0434-lpfc-Fix-Port-going-offline-after-multiple-resets.patch.
- Delete
  patches.drivers/0435-lpfc-Fix-counters-so-outstandng-NVME-IO-count-is-acc.patch.
- Delete
  patches.drivers/0436-lpfc-Fix-return-value-of-board_mode-store-routine-in.patch.
- Delete
  patches.drivers/0437-lpfc-Fix-crash-on-powering-off-BFS-VM-with-passthrou.patch.
- Delete
  patches.drivers/0438-lpfc-Fix-System-panic-after-loading-the-driver.patch.
- Delete
  patches.drivers/0439-lpfc-Null-pointer-dereference-when-log_verbose-is-se.patch.
- Delete
  patches.drivers/0440-lpfc-Fix-PRLI-retry-handling-when-target-rejects-it.patch.
- Delete
  patches.drivers/0441-lpfc-Fix-vports-not-logging-into-target.patch.
- Delete
  patches.drivers/0442-lpfc-update-to-revision-to-11.4.0.0.patch.
- Delete
  patches.drivers/0443-lpfc-tie-lpfc-dev_loss_tmo-dynamic-changes-to-transp.patch.
- commit b536d39
* Wed Aug  2 2017 yousaf.kaukab@suse.com
- Refresh patches.drivers/0004-iommu-arm-smmu-v3-Add-workaround-for-Cavium-ThunderX.patch.
- commit a112130
* Wed Aug  2 2017 yousaf.kaukab@suse.com
- Refresh patches.drivers/0003-iommu-arm-smmu-v3-Add-workaround-for-Cavium-ThunderX.patch.
- commit 1f0b409
* Wed Aug  2 2017 yousaf.kaukab@suse.com
- Refresh patches.drivers/0002-ACPI-IORT-Fixup-SMMUv3-resource-size-for-Cavium-Thun.patch.
- commit ec446ff
* Wed Aug  2 2017 yousaf.kaukab@suse.com
- ACPICA: IORT: Update SMMU models for revision C (bsc#1036060).
- commit a283c6f
* Wed Aug  2 2017 yousaf.kaukab@suse.com
- Delete patches.drivers/0013-PCI-ACPI-Add-ThunderX-pass2.x-2nd-node-MCFG-quirk.patch.
  cd183740480f PCI/ACPI: Add ThunderX pass2.x 2nd node MCFG quirk in v4.12
- commit 8af3b43
* Wed Aug  2 2017 yousaf.kaukab@suse.com
- Delete patches.drivers/0012-PCI-ACPI-Tidy-up-MCFG-quirk-whitespace.patch.
  ced414a14f70 PCI/ACPI: Tidy up MCFG quirk whitespace in v4.12
- commit b8dfc46
* Wed Aug  2 2017 yousaf.kaukab@suse.com
- Delete patches.drivers/0017-MAINTAINERS-Add-entry-for-Cavium-MMC-driver.patch.
  25fc84650373 MAINTAINERS: Add entry for Cavium MMC driver in v4.12
- commit 58bf6f3
* Wed Aug  2 2017 yousaf.kaukab@suse.com
- Delete patches.drivers/0016-mmc-cavium-Support-DDR-mode-for-eMMC-devices.patch.
  4ce944074e5e mmc: cavium: Support DDR mode for eMMC devices in v4.12
- commit 7ead2d8
* Wed Aug  2 2017 yousaf.kaukab@suse.com
- Delete patches.drivers/0015-mmc-cavium-Add-scatter-gather-DMA-support.patch.
  cd76e5c565e8 mmc: cavium: Add scatter-gather DMA support in v4.12
- commit 4c792e1
* Wed Aug  2 2017 yousaf.kaukab@suse.com
- Delete patches.drivers/0014-mmc-cavium-Add-MMC-PCI-driver-for-ThunderX-SOCs.patch.
  166bac38c3c5 mmc: cavium: Add MMC PCI driver for ThunderX SOCs in v4.12
- commit 018a1e3
* Wed Aug  2 2017 yousaf.kaukab@suse.com
- Delete patches.drivers/0013-mmc-cavium-Add-core-MMC-driver-for-Cavium-SOCs.patch.
  ba3869ff32e4 mmc: cavium: Add core MMC driver for Cavium SOCs in v4.12
- commit 947dfdf
* Wed Aug  2 2017 yousaf.kaukab@suse.com
- Delete patches.drivers/0012-dt-bindings-mmc-Add-Cavium-SOCs-MMC-bindings.patch.
  dc5aee3f9f45 dt-bindings: mmc: Add Cavium SOCs MMC bindings in v4.12
- commit b4b7a95
* Wed Aug  2 2017 mgalbraith@suse.de
- Refresh patches.fixes/sched-Fix-up-proc-sched_debug-to-print-only-runnable-tasks-again.patch.
- Refresh patches.suse/sched-optimize-latency-defaults.patch.
- Refresh patches.suse/sched-reinstate-FAIR_SLEEPERS-feature.patch.
- Refresh patches.suse/sched-reinstate-sched_compat_yield.patch.
- Delete patches.suse/sched-domain-flags-proc-handler.patch.
- Delete patches.suse/sched-provide-nortsched-boot-option.patch.
- Delete patches.suse/sched-provide-rtkthreads-rtworkqueues-boot-options.patch.
- commit 823b493
* Wed Aug  2 2017 mgorman@suse.de
- sched,numa: scale scan period with tasks in group and
  shared/private (Automatic NUMA Balancing (fate#315482)).
- commit cccc123
* Wed Aug  2 2017 mgorman@suse.de
- numa,sched: slow down scan rate if shared faults dominate
  (Automatic NUMA Balancing (fate#315482)).
- commit bd6ebee
* Wed Aug  2 2017 mgorman@suse.de
- Refresh patches.suse/sched-optimize-latency-defaults.patch.
- commit 3a3fa45
* Tue Aug  1 2017 rgoldwyn@suse.com
- Apparmor for FATE#323500 (namespace, ptrace etc.)
  The networking patches are applied after the upstream patches
  because they are not upstreamed. It was simpler to change
  the networking patches later because of the changes in core(LSM)
  in the upstream patches.
- securityfs: add the ability to support symlinks (FATE#323500).
- apparmorfs: Combine two function calls into one in
  aa_fs_seq_raw_abi_show() (FATE#323500).
- doc: ReSTify apparmor.txt (FATE#323500).
- apparmorfs: Use seq_putc() (FATE#323500).
- apparmor: Fix error cod in __aa_fs_profile_mkdir()
  (FATE#323500).
- security/apparmor: Use POSIX-compatible "printf '%%s'"
  (FATE#323500).
- apparmor: move file context into file.h (FATE#323500).
- apparmor: make internal lib fn skipn_spaces available to the
  rest of apparmor (FATE#323500).
- apparmor: allow profiles to provide info to disconnected paths
  (FATE#323500).
- apparmor: Move path lookup to using preallocated buffers
  (FATE#323500).
- apparmor: move to per loaddata files, instead of replicating
  in profiles (FATE#323500).
- apparmor: use macro template to simplify profile seq_files
  (FATE#323500).
- apparmor: use macro template to simplify namespace seq_files
  (FATE#323500).
- apparmor: add custom apparmorfs that will be used by policy
  namespace files (FATE#323500).
- apparmor: rename apparmor file fns and data to indicate use
  (FATE#323500).
- apparmor: allow specifying an already created dir to create
  ns entries in (FATE#323500).
- apparmor: convert from securityfs to apparmorfs for policy ns
  files (FATE#323500).
- apparmor: move permissions into their own file to be more
  easily shared (FATE#323500).
- apparmor: rework perm mapping to a slightly broader set
  (FATE#323500).
- apparmor: provide finer control over policy management
  (FATE#323500).
- apparmor: add policy revision file interface (FATE#323500).
- apparmor: add mkdir/rmdir interface to manage policy namespaces
  (FATE#323500).
- apparmor: add label data availability to the feature set
  (FATE#323500).
- apparmor: speed up transactional queries (FATE#323500).
- apparmor: add fn to test if profile supports a given mediation
  class (FATE#323500).
- apparmor: add gerneric permissions struct and support fns
  (FATE#323500).
- apparmor: switch from file_perms to aa_perms (FATE#323500).
- apparmor: add profile permission query ability (FATE#323500).
- apparmor: provide information about path buffer size at boot
  (FATE#323500).
- apparmor: cleanup __find_child( (FATE#323500).
- apparmor: add namespace lookup fns() (FATE#323500).
- apparmor: fix policy load/remove semantics (FATE#323500).
- apparmor: fix apparmor_query data (FATE#323500).
- apparmor: fix display of ns name (FATE#323500).
- apparmor: move bprm_committing_creds/committed_creds to lsm.c
  (FATE#323500).
- apparmor: convert to profile block critical sections
  (FATE#323500).
- apparmor: share profile name on replacement (FATE#323500).
- apparmor: refactor updating profiles to the newest parent
  (FATE#323500).
- apparmor: cleanup remove unused and not fully implemented
  profile rename (FATE#323500).
- apparmor: convert aa_change_XXX bool parameters to flags
  (FATE#323500).
- apparmor: cleanup rename XXX_file_context() to XXX_file_ctx()
  (FATE#323500).
- apparmor: revalidate files during exec (FATE#323500).
- apparmor: add the base fns() for domain labels (FATE#323500).
- apparmor: switch from profiles to using labels on contexts
  (FATE#323500).
- apparmor: switch getprocattr to using label_print fns(
  (FATE#323500).
- apparmor: update query interface to support label queries
  (FATE#323500).
- apparmor: move capability checks to using labels (FATE#323500).
- apparmor: move resource checks to using labels (FATE#323500).
- apparmor: add cross check permission helper macros
  (FATE#323500).
- apparmor: move ptrace checks to using labels (FATE#323500).
- apparmor: allow ptrace checks to be finer grained than just
  capability (FATE#323500).
- apparmor: move aa_file_perm() to use labels (FATE#323500).
- apparmor: update aa_audit_file() to use labels (FATE#323500).
- apparmor: refactor path name lookup and permission checks
  around labels (FATE#323500).
- apparmor: move path_link mediation to using labels
  (FATE#323500).
- apparmor: rework file permission to cache file access in
  file->ctx (FATE#323500).
- apparmor: mediate files when they are received (FATE#323500).
- apparmor: support v7 transition format compatible with
  label_parse (FATE#323500).
- apparmor: move exec domain mediation to using labels
  (FATE#323500).
- apparmor: move change_hat mediation to using labels
  (FATE#323500).
- apparmor: move change_profile mediation to using labels
  (FATE#323500).
- apparmor: add domain label stacking info to apparmorfs
  (FATE#323500).
- apparmor: add stacked domain labels interface (FATE#323500).
- apparmor: export that basic profile namespaces are supported
  (FATE#323500).
- apparmor: put back designators in struct initialisers
  (FATE#323500).
- Refresh
  patches.apparmor/apparmor-basic-networking-rules-4.11-rc1.patch.
- Refresh patches.apparmor/apparmor-basic-networking-rules.patch.
- Refresh
  patches.apparmor/apparmor-fix-quieting-of-audit-messages-for-network-mediation.patch.
- commit e310a9d
* Tue Aug  1 2017 yousaf.kaukab@suse.com
- Delete patches.drivers/0071-mmc-dw_mmc-improve-dw_mci_reset-a-bit.patch.
  bc2dcc1a2a5e mmc: dw_mmc: improve dw_mci_reset a bit in v4.12
- commit 847a0dd
* Tue Aug  1 2017 yousaf.kaukab@suse.com
- Delete patches.drivers/0070-mmc-dw_mmc-move-mci_send_cmd-forward-to-avoid-declar.patch.
  4dba18defb4c mmc: dw_mmc: move mci_send_cmd forward to avoid declaration in v4.12
- commit edcfef2
* Tue Aug  1 2017 yousaf.kaukab@suse.com
- Delete patches.drivers/0069-mmc-dw_mmc-remove-declaration-of-dw_mci_card_busy.patch.
  132b3b6aa618 mmc: dw_mmc: remove declaration of dw_mci_card_busy in v4.12
- commit 346a64d
* Tue Aug  1 2017 yousaf.kaukab@suse.com
- Delete patches.drivers/0068-mmc-dw_mmc-move-dw_mci_get_cd-forward-to-avoid-decla.patch.
  671fa142fc03 mmc: dw_mmc: move dw_mci_get_cd forward to avoid declaration in v4.12
- commit e7920fa
* Tue Aug  1 2017 yousaf.kaukab@suse.com
- Delete patches.drivers/0067-mmc-dw_mmc-move-dw_mci_ctrl_reset-forward-to-avoid-d.patch.
  8e6db1f65510 mmc: dw_mmc: move dw_mci_ctrl_reset forward to avoid declaration in v4.12
- commit 72c131b
* Tue Aug  1 2017 yousaf.kaukab@suse.com
- Delete patches.drivers/0066-mmc-dw_mmc-move-dw_mci_reset-forward-to-avoid-declar.patch.
  8e6db1f65510 mmc: dw_mmc: move dw_mci_ctrl_reset forward to avoid declaration in v4.12
- commit e993d40
* Tue Aug  1 2017 yousaf.kaukab@suse.com
- Delete patches.drivers/0065-mmc-dw_mmc-improve-the-timeout-polling-code.patch.
  b6d2d81c5c2d mmc: dw_mmc: improve the timeout polling code in v4.12
- commit 1d3f660
* Tue Aug  1 2017 yousaf.kaukab@suse.com
- Delete patches.arch/0010-arm64-Add-CNTFRQ_EL0-trap-handler.patch.
  9842119a238b arm64: Add CNTFRQ_EL0 trap handler in v4.12
- commit 32e4ad4
* Tue Aug  1 2017 yousaf.kaukab@suse.com
- Delete patches.arch/0008-arm64-add-ESR_ELx_SYS64_ISS_SYS_OP_MASK-define.patch.
  116c81f427ff arm64: Work around systems with mismatched cache line sizes in v4.9
- commit 02dfdaa
* Tue Aug  1 2017 hare@suse.de
- Drop cciss driver (FATE#323833)
- Update config files.
- supported.conf:
- commit cac232d
* Tue Aug  1 2017 yousaf.kaukab@suse.com
- Delete patches.arch/0003-arm64-cpu_errata-Add-capability-to-advertise-Cortex-.patch.
  eeb1efbcb83c arm64: cpu_errata: Add capability to advertise Cortex-A73 erratum 858921 in v4.12
- commit 22fb6fa
* Tue Aug  1 2017 yousaf.kaukab@suse.com
- Delete patches.arch/0001-irqdomain-add-empty-irq_domain_check_msi_remap.patch.
  b3e228473e6c irqdomain: Add empty irq_domain_check_msi_remap in v4.12
- commit ba2255e
* Tue Aug  1 2017 jthumshirn@suse.de
- Delete
  patches.drivers/0444-nvme_fc-fix-confused-queue-size-handling.patch.
- Delete
  patches.drivers/0445-nvme_fc-on-lldd-transport-io-error-terminate-associa.patch.
- Delete
  patches.drivers/0446-lpfc-Fix-defects-reported-by-Coverity-Scan.patch.
- Delete patches.drivers/0447-lpfc-Add-auto-EQ-delay-logic.patch.
- Delete
  patches.drivers/0448-lpfc-fix-irq_affinity-relative-to-older-irq-interfaces.patch.
- Delete
  patches.drivers/0451-scatterlist-add-sg_zero_buffer-helper.patch.
- Delete
  patches.drivers/0452-nvmet-use-NVME_IDENTIFY_DATA_SIZE.patch.
- Delete
  patches.drivers/0453-nvme-introduce-NVMe-Namespace-Identification-Descrip.patch.
- Delete
  patches.drivers/0454-nvme-rename-uuid-to-nguid-in-nvme_ns.patch.
- Delete
  patches.drivers/0455-nvme-get-list-of-namespace-descriptors.patch.
- Delete
  patches.drivers/0456-nvme-provide-UUID-value-to-userspace.patch.
- Delete
  patches.drivers/0457-nvmet-implement-namespace-identify-descriptor-list.patch.
- Delete
  patches.drivers/0458-nvmet-add-uuid-field-to-nvme_ns-and-populate-via-con.patch.
- Delete
  patches.drivers/0459-nvmet-allow-overriding-the-NVMe-VS-via-configfs.patch.
- Delete
  patches.drivers/0460-nvme-add-fields-into-identify-controller-data-struct.patch.
- Delete
  patches.drivers/0461-Fix-system-panic-when-express-lane-enabled.patch.
- Delete
  patches.drivers/0462-Vport-creation-is-failing-with-Link-Down-error.patch.
- Delete
  patches.drivers/0463-Reduce-time-spent-in-IRQ-for-received-NVME-commands.patch.
- Delete
  patches.drivers/0464-Fix-SLI3-drivers-attempting-NVME-ELS-commands.patch.
- Delete
  patches.drivers/0465-Fix-crash-after-firmware-flash-when-IO-is-running.patch.
- Delete
  patches.drivers/0466-Fix-crash-doing-IO-with-resets.patch.
- Delete
  patches.drivers/0467-Fix-crash-in-lpfc_sli_ringtxcmpl_put-when-nvmet-gets.patch.
- Delete
  patches.drivers/0468-Driver-responds-LS_RJT-to-Beacon-Off-ELS.patch.
- Delete
  patches.drivers/0469-lpfc-update-to-revision-to-11.4.0.1.patch.
- Delete
  patches.drivers/0469-nvme_fc-Fix-crash-when-nvme-controller-connection-fa.patch.
- Delete
  patches.drivers/0470-nvmet_fc-fix-crashes-on-bad-opcodes.patch.
- Delete
  patches.drivers/0471-nvme_fc-Fix-hard-lockup-in-nvme-host-transport-on-co.patch.
- Delete
  patches.drivers/0473-nvme_fc-fix-double-calls-to-nvme_cleanup_cmd.patch.
- Delete
  patches.drivers/0474-nvme_fc-fix-error-recovery-on-link-down.patch.
- Delete
  patches.drivers/0475-lpfc-Fix-nvme-io-stoppage-after-link-bounce.patch.
- Delete
  patches.drivers/0476-lpfc-fix-refcount-error-on-node-list.patch.
- Delete
  patches.drivers/nvme-submit-nvme_admin_activate_fw-to-admin-queue.patch.
- commit 0d0b596
* Tue Aug  1 2017 yousaf.kaukab@suse.com
- Refresh patches.drivers/0001-ARM64-PCI-Set-root-bus-NUMA-node-on-ACPI-systems.patch.
- commit bb1bc41
* Tue Aug  1 2017 yousaf.kaukab@suse.com
- Delete patches.drivers/0008-drivers-net-xgene-fix-build-after-change_mtu-functio.patch.
  Not required for kernel v4.12
- commit 7a10760
* Tue Aug  1 2017 agraf@suse.de
- Clean up upstreamed patches list. Annotate the remaining ones
  with their current status.
- Delete patches.arch/arm-exynos-dwmmc-modalias.patch.
- Delete patches.arch/arm-xen-fixup.patch.
- Delete
  patches.arch/arm64-Allow-for-different-DMA-and-CPU-bus-offsets.patch.
- Delete
  patches.arch/arm64-PCI-xilinx-nwl-Add-support-for-Xilinx-NWL-PCIe-Host-.patch.
- Delete
  patches.arch/arm64-Relocate-screen_info.lfb_base-on-PCI-BAR-alloc.patch.
- Delete
  patches.arch/arm64-bcm2837-0070-ARM-bcm2835-Add-VC4-to-the-device-tree.patch.
- Delete
  patches.arch/arm64-bcm2837-0071-drm-vc4-Add-DPI-driver.patch.
- Delete
  patches.arch/arm64-bcm2837-0073-irqchip-bcm2836-Drop-smp_set_ops-on-arm64-builds.patch.
- Delete
  patches.arch/arm64-bcm2837-0074-irqchip-bcm2836-Fix-compiler-warning-on-64-bit-build.patch.
- Delete
  patches.arch/arm64-bcm2837-0075-irqchip-bcm2836-Use-a-more-generic-memory-barrier-ca.patch.
- Delete
  patches.arch/arm64-bcm2837-0076-clk-bcm2835-Fix-compiler-warnings-on-64-bit-builds.patch.
- Delete
  patches.arch/arm64-bcm2837-0078-ARM-bcm2835-Add-devicetree-for-the-Raspberry-Pi-3.patch.
- Delete
  patches.arch/arm64-bcm2837-0079-drm-vc4-Fix-NULL-deref-in-HDMI-init-error-path.patch.
- Delete
  patches.arch/arm64-bcm2837-0081-don-t-force-serial-pins-to-uart0.patch.
- Delete
  patches.arch/arm64-bcm2837-0088-arm64-Add-platform-selection-for-BCM2835.patch.
- Delete
  patches.arch/arm64-bcm2837-0103-ARM-bcm2835-dt-Add-the-ethernet-to-the-device-trees.patch.
- Delete
  patches.arch/arm64-bcm2837-0104-ARM-bcm2837-dt-Add-the-ethernet-to-the-device-trees.patch.
- Delete
  patches.arch/arm64-bcm2837-0106-rtc-efi-Fail-probing-if-RTC-reads-don-t-work.patch.
- Delete
  patches.arch/arm64-bcm2837-0112-clk-bcm2835-Mark-the-VPU-clock-as-critical.patch.
- Delete
  patches.arch/arm64-bcm2837-0113-clk-bcm2835-Mark-GPIO-clocks-enabled-at-boot-as-crit.patch.
- Delete
  patches.arch/arm64-bcm2837-0114-clk-bcm2835-Skip-PLLC-clocks-when-deciding-on-a-new-.patch.
- Delete
  patches.arch/arm64-bcm2837-0115-clk-bcm2835-Mark-the-CM-SDRAM-clock-s-parent-as-crit.patch.
- Delete
  patches.arch/arm64-bcm2837-0195-bcm2835-Add-Raspberry-Pi-thermal-sensor-to-the-device-tree.patch.
- Delete
  patches.arch/arm64-bcm2837-0197-thermal-Add-Raspberry-Pi-BCM2835-thermal-driver.patch.
- Delete
  patches.arch/arm64-ls1043-0101-fsl-fman-Convert-to-long.patch.
- Delete
  patches.arch/arm64-ls1043-0129-phy-Add-an-mdio_device-structure.patch.
- Delete
  patches.arch/arm64-ls1043-0130-arm64-Export-arch_setup_dma_ops.patch.
- Delete
  patches.arch/arm64-ls1043-0215-caam-Declare-PER_CPU-variable-outside-function-scope.patch.
- Delete
  patches.arch/arm64-ls1043-0221-caam-Use-old-attrs-interface.patch.
- Delete
  patches.arch/ppc64le-ile-0001-powerpc-Add-global-exports-for-all-interrupt-vectors.patch.
- Delete
  patches.arch/ppc64le-ile-0002-powerpc-Add-relocation-code-for-fixups.patch.
- Delete
  patches.arch/ppc64le-ile-0003-powerpc-Add-hack-to-make-ppc64le-work-on-hosts-witho.patch.
- Delete
  patches.arch/ppc64le-ile-0004-powerpc-Don-t-return-to-BE-mode-when-we-are-already-.patch.
- commit ab1a7d7
* Tue Aug  1 2017 nborisov@suse.com
- series.conf: Remove commented out line
  While pushing my for-next to SLE15 i got the following warning:
  remote: Warning: multiple uses in /tmp/githook.T8ujQR04YV/series.conf:
  patches.suse/btrfs-8888-add-allow_unsupported-module-parameter.patch
  This was due to aforementioned patch being disabled during the transition of the
  branch. In the meantime JeffM has already triaged/enabled the patch. So let's
  remove the extra line
- commit 19d3938
* Mon Jul 31 2017 mgorman@suse.de
- Remove patches for review that must be reimplemented from scratch if still required
- commit abf83a9
* Mon Jul 31 2017 tiwai@suse.de
- mwifiex: do not update MCS set from hostapd (bsc#1051510).
- iwlwifi: pcie: reconfigure MSI-X HW on resume (bsc#1051510).
- iwlwifi: pcie: fix command completion name debug (bsc#1051510).
- iwlwifi: pcie: fix TVQM queue ID range check (bsc#1051510).
- iwlwifi: mvm: unconditionally stop device after init
  (bsc#1051510).
- iwlwifi: mvm: reset the fw_dump_desc pointer after ASSERT
  (bsc#1051510).
- drm/tegra: dc: Avoid reset asserts on Tegra20 (bsc#1051510).
- drm/panel: add backlight dependency for sitronix-st7789v
  (bsc#1051510).
- drm/panel: S6E3HA2 needs backlight code (bsc#1051510).
- drm/nouveau: use proper prototype in nouveau_pmops_runtime()
  definition (bsc#1051510).
- drm/nouveau/disp/nv50-: bump max chans to 21 (bsc#1051510).
- drm/i915: Fix scaler init during CRTC HW state readout
  (bsc#1051510).
- drm: exynos: mark pm functions as __maybe_unused (bsc#1051510).
- drm/doc: Fix missing @ctx documentation (bsc#1051510).
- commit d5522f6
* Mon Jul 31 2017 nborisov@suse.com
- Btrfs: incremental send, fix invalid path for link  commands
  (bsc#1051479).
- Btrfs: incremental send, fix invalid path for unlink  commands
  (bsc#1051479).
- Btrfs: send, fix invalid path after renaming and linking  file
  (bsc#1051479).
- commit 86ebf6c
* Mon Jul 31 2017 jgross@suse.com
- Move XEN patches to dedicated section
- commit aef3ab9
* Mon Jul 31 2017 jgross@suse.com
- Rebased patches.fixes/xen-allocate-page-for-shared-info-page-from-low-mem.patch to 4.12
- commit 221ffe0
* Mon Jul 31 2017 jgross@suse.com
- Rebased patches.fixes/xen-balloon-don-t-online-new-memory-initially.patch to 4.12
- commit 4009e51
* Mon Jul 31 2017 jgross@suse.com
- Rebased patches.fixes/xen-mce-dont-issue-error-message.patch to 4.12
- commit d5fc01c
* Mon Jul 31 2017 jgross@suse.com
- Rebased patches.fixes/xen-add-sysfs-node-for-guest-type.patch to 4.12
- commit 90f8a3b
* Mon Jul 31 2017 jgross@suse.com
- Removed patches.fixes/xen-use-machine-addresses-in-vmcoreinfo-when-pv.patch,
  already contained in upstream 4.12
- commit b385b8c
* Mon Jul 31 2017 rgoldwyn@suse.com
- Refresh
  patches.fixes/0002-fs-fcntl-f_setown-avoid-undefined-behaviour.patch.
  Correct the patch according to SLE15 (as opposed to SLE12SP2) because
  patches.fixes/0001-fs-fcntl-f_setown-allow-returning-error.patch
  changed the function prototype.
- commit ca46fac
* Sun Jul 30 2017 mgorman@suse.de
- Remove comment about patches merged via -stable
- commit 0cb4556
* Fri Jul 28 2017 hare@suse.de
- Drop obsolete patches and update patch description
- Refresh
  patches.drivers/scsi_transport_fc-return-EBUSY-for-deleted-vport.patch.
- Delete
  patches.drivers/libfc-do-not-flood-console-with-messages-libfc-queue.patch.
- Delete
  patches.drivers/scsi_transport_fc-do-not-call-queue_work-under-lock.patch.
- Delete
  patches.drivers/scsi_transport_fc-fixup-race-condition-in-fc_rport_f.patch.
- commit 4ca214c
* Fri Jul 28 2017 glin@suse.com
- bpf: fix mixed signed/unsigned derived min/max value bounds
  (bsc#1050081).
- commit c6eeed6
* Fri Jul 28 2017 jslaby@suse.cz
- Update config files.
  Fix vanillas after the orc update.
- commit 2a27bf2
* Fri Jul 28 2017 jslaby@suse.cz
- Linux 4.12.4 (bnc#1012628).
- commit f2e2c0a
* Thu Jul 27 2017 mgorman@suse.de
- Review and document sched-Further-improve-spurious-CPU_IDLE-active-migrations.patch
- commit 36d9aef
* Thu Jul 27 2017 rgoldwyn@suse.com
- btrfs: nowait aio: Correct assignment of pos (FATE#321994).
- btrfs: nowait aio support (FATE#321994).
- xfs: nowait aio support (FATE#321994).
- ext4: nowait aio support (FATE#321994).
- block: return on congested block device (FATE#321994).
- fs: Introduce IOMAP_NOWAIT (FATE#321994).
- fs: return if direct I/O will trigger writeback (FATE#321994).
- fs: Introduce RWF_NOWAIT and FMODE_AIO_NOWAIT (FATE#321994).
- fs: Use RWF_* flags for AIO operations (FATE#321994).
- fs: Introduce filemap_range_has_page() (FATE#321994).
- fs: Separate out kiocb flags setup based on RWF_* flags
  (FATE#321994).
- commit d1dfe7b
* Thu Jul 27 2017 bpoirier@suse.com
- supported.conf: Update network drivers
- commit 49a23df
* Thu Jul 27 2017 mkubecek@suse.cz
- ipv6: avoid overflow of offset in ip6_find_1stfragopt
  (CVE-2017-7542 bsc#1049882).
- commit 00c5961
* Thu Jul 27 2017 mgorman@suse.de
- Enable sched-ratelimit-nohz.patch
- commit f691847
* Thu Jul 27 2017 jthumshirn@suse.de
- Delete
  patches.drivers/0043-lightnvm-fix-warning-ret-may-be-used-uninitialized.patch.
- commit e2eabec
* Thu Jul 27 2017 jthumshirn@suse.de
- Re-enable patches.drivers/scsi-bnx2i-missing-error-code-in-bnx2i_ep_connect
- commit 90b3cea
* Thu Jul 27 2017 mgorman@suse.de
- exports from rcu_idle_exit() and rcu_idle_enter() (bnc#978907
  Scheduler performance -- idle).
- rcu_idle_enter() rely on callers disabling irqs (bnc#978907
  Scheduler performance -- idle).
- commit d4e79a7
* Thu Jul 27 2017 jslaby@suse.cz
- Refresh
  patches.suse/0001-md-remove-idx-from-struct-resync_pages.patch.
- commit b11fd5b
* Thu Jul 27 2017 jslaby@suse.cz
- objtool: Fix sibling call detection logic (bnc#1018348).
- x86/kconfig: Make it easier to switch to the new ORC unwinder
  (bnc#1018348).
- x86/kconfig: Consolidate unwinders into multiple choice
  selection (bnc#1018348).
- Refresh
- Refresh patches.suse/0001-x86-unwind-Add-the-ORC-unwinder.patch.
- Refresh
  patches.suse/0002-dwarf-do-not-throw-away-unwind-info.patch.
- Refresh
  patches.suse/0002-objtool-x86-Add-several-functions-and-files-to-the-o.patch.
- Refresh
  patches.suse/0002-x86-entry-64-Initialize-the-top-of-the-IRQ-stack-bef.patch.
- Refresh
  patches.suse/0002-x86-kconfig-Make-it-easier-to-switch-to-the-new-ORC-.patch.
- Refresh
  patches.suse/0003-objtool-Implement-stack-validation-2.0.patch.
- Refresh
  patches.suse/0003-x86-kconfig-Consolidate-unwinders-into-multiple-choi.patch.
- Refresh
  patches.suse/0007-x86-entry-64-Add-unwind-hint-annotations.patch.
- Refresh
  patches.suse/0008-x86-asm-Add-unwind-hint-annotations-to-sync_core.patch.
- Update config files.
  Update to version from -tip. ORC is in -tip completely. So make sure
  we use the upstream version.
- commit 34dd0f5
* Thu Jul 27 2017 bpoirier@suse.com
- net: ena: update ena driver to version 1.2.0 (bsc#1047121).
- net: ena: update driver's rx drop statistics (bsc#1047121).
- net: ena: use lower_32_bits()/upper_32_bits() to split dma
  address (bsc#1047121).
- net: ena: separate skb allocation to dedicated function
  (bsc#1047121).
- net: ena: use napi_schedule_irqoff when possible (bsc#1047121).
- net: ena: allow the driver to work with small number of msix
  vectors (bsc#1047121).
- net: ena: add support for out of order rx buffers refill
  (bsc#1047121).
- net: ena: add reset reason for each device FLR (bsc#1047121).
- net: ena: change sizeof() argument to be the type pointer
  (bsc#1047121).
- net: ena: add hardware hints capability to the driver
  (bsc#1047121).
- net: ena: change return value for unsupported features
  unsupported return value (bsc#1047121).
- commit 025123f
* Thu Jul 27 2017 enadolski@suse.com
- btrfs: remove outdated version of backrefs rbtree patch set
  These patches are superceded by the version that was submitted
  to upstream. This commit removes the outdated files and their
  corresponding entries in series.conf.
- Delete
  patches.suse/btrfs-add-a-node-counter-to-each-of-the-rbtrees.
- Delete
  patches.suse/btrfs-add-cond_resched-calls-when-resolving-backrefs.
- Delete
  patches.suse/btrfs-allow-backref-search-checks-for-shared-extents.
- Delete
  patches.suse/btrfs-backref-add-tracepoints-for-prelim_ref-insertion-and-merging.
- Delete
  patches.suse/btrfs-backref-add-unode_aux_to_inode_list-helper.
- Delete patches.suse/btrfs-backref-cleanup-_-namespace-abuse.
- Delete patches.suse/btrfs-backref-constify-some-arguments.
- Delete
  patches.suse/btrfs-btrfs_check_shared-should-manage-its-own-transaction.
- Delete
  patches.suse/btrfs-clean-up-extraneous-computations-in-add_delayed_refs.
- Delete patches.suse/btrfs-constify-tracepoint-arguments.
- Delete
  patches.suse/btrfs-convert-prelimary-reference-tracking-to-use-rbtrees.
- Delete
  patches.suse/btrfs-remove-ref_tree-implementation-from-backref-c.
- Delete patches.suse/btrfs-struct-funcs-constify-readers.
- commit 7a9c5fb
* Thu Jul 27 2017 enadolski@suse.com
- btrfs: clean up extraneous computations in add_delayed_refs
  (bsc#974590 bsc#1030061 bsc#1022914 bsc#1017461).
- btrfs: allow backref search checks for shared extents
  (bsc#974590 bsc#1030061 bsc#1022914 bsc#1017461).
- btrfs: add cond_resched() calls when resolving backrefs
  (bsc#974590 bsc#1030061 bsc#1022914 bsc#1017461).
- btrfs: backref, add tracepoints for prelim_ref insertion and
  merging (bsc#974590 bsc#1030061 bsc#1022914 bsc#1017461).
- btrfs: add a node counter to each of the rbtrees (bsc#974590
  bsc#1030061 bsc#1022914 bsc#1017461).
- btrfs: convert prelimary reference tracking to use rbtrees
  (bsc#974590 bsc#1030061 bsc#1022914 bsc#1017461).
- btrfs: remove ref_tree implementation from backref.c (bsc#974590
  bsc#1030061 bsc#1022914 bsc#1017461).
- btrfs: btrfs_check_shared should manage its own transaction
  (bsc#974590 bsc#1030061 bsc#1022914 bsc#1017461).
- btrfs: backref, cleanup __ namespace abuse (bsc#974590
  bsc#1030061 bsc#1022914 bsc#1017461).
- btrfs: backref, add unode_aux_to_inode_list helper (bsc#974590
  bsc#1030061 bsc#1022914 bsc#1017461).
- btrfs: backref, constify some arguments (bsc#974590 bsc#1030061
  bsc#1022914 bsc#1017461).
- btrfs: constify tracepoint arguments (bsc#974590 bsc#1030061
  bsc#1022914 bsc#1017461).
- btrfs: struct-funcs, constify readers (bsc#974590 bsc#1030061
  bsc#1022914 bsc#1017461).
- commit 68ccc54
* Wed Jul 26 2017 mcgrof@suse.com
- mm: kmemleak: treat vm_struct as alternative reference to
  vmalloc'ed objects (bsc#1027456).
- mm: kmemleak: factor object reference updating out of
  scan_block() (bsc#1027456).
- mm: kmemleak: slightly reduce the size of some structures on
  64-bit architectures (bsc#1027456).
- commit bc42ba6
* Wed Jul 26 2017 mcgrof@suse.com
- Refresh
  patches.suse/0001-mm-kmemleak-slightly-reduce-the-size-of-some-structu.patch.
- Refresh
  patches.suse/0002-mm-kmemleak-factor-object-reference-updating-out-of-.patch.
- Refresh
  patches.suse/0003-mm-kmemleak-treat-vm_struct-as-alternative-reference.patch.
- commit f7ebe40
* Wed Jul 26 2017 mcgrof@suse.com
- Refresh
  patches.suse/0001-mm-kmemleak-slightly-reduce-the-size-of-some-structu.patch.
- Refresh
  patches.suse/0002-mm-kmemleak-factor-object-reference-updating-out-of-.patch.
- Refresh
  patches.suse/0003-mm-kmemleak-treat-vm_struct-as-alternative-reference.patch.
- commit eb41516
* Wed Jul 26 2017 mgorman@suse.de
- audit: Reduce overhead using a coarse clock (bnc#1050724).
- commit e3464f2
* Wed Jul 26 2017 mgorman@suse.de
- Remove architecture heading that is no longer supported
- commit e5e149e
* Wed Jul 26 2017 mgorman@suse.de
- rcu: Use RCU_NOCB_WAKE rather than RCU_NOGP_WAKE (bnc#978907
  Scheduler performance -- idle).
- doc: Take tail recursion into account in RCU requirements
  (bnc#978907 Scheduler performance -- idle).
- srcu: Document auto-expediting requirement (bnc#978907 Scheduler
  performance -- idle).
- rcu: Remove obsolete reference to synchronize_kernel()
  (bnc#978907 Scheduler performance -- idle).
- srcu: Eliminate possibility of destructive counter overflow
  (bnc#978907 Scheduler performance -- idle).
- rcu: Prevent rcu_barrier() from starting needless grace periods
  (bnc#978907 Scheduler performance -- idle).
- commit 7f11b71
* Wed Jul 26 2017 mkubecek@suse.cz
- ipv6: avoid overflow of offset in ip6_find_1stfragopt
  (CVE-2017-7542 bsc#1049882).
- commit 399d4a0
* Wed Jul 26 2017 mkubecek@suse.cz
- bpf/verifier: fix min/max handling in BPF_SUB (bsc#1050081).
- bpf: fix mixed signed/unsigned derived min/max value bounds
  (bsc#1050081).
- commit f90c358
* Wed Jul 26 2017 mkubecek@suse.cz
- supported.conf: mark nf_log_bridge as supported
  This was the only netfilter module not marked as supported. There is no
  apparent reason except that nobody marked it when the functionality was
  separated into its own module.
- commit c5e825b
* Wed Jul 26 2017 mkubecek@suse.cz
- supported.conf: mark nftables related modules as supported (fate#323407)
- commit 0fbfb00
* Wed Jul 26 2017 tiwai@suse.de
- Input: ALPS - Fix Alps Touchpad two finger scroll does not
  work on right side (bsc#1050582).
- commit 93ed5e8
* Wed Jul 26 2017 tiwai@suse.de
- Delete patches.drivers/0088-dma-buf-sync_file-Add-back-the-u64_to_user_ptr-macro.patch
  It's a stop-gap fix in SLE12-SP3 for 4.9 dmabuf API.
- commit 678704a
* Wed Jul 26 2017 tiwai@suse.de
- Delete patches.drivers/vgaarb-Add-more-context-to-error-messages.patch
  It's no longer needed as we AMD binary-only stuff is dead.
- commit 78dd994
* Wed Jul 26 2017 dbueso@suse.de
- configs: update defaults for REFCOUNT_FULL
  Such that it is always disabled, with the exception
  of x86-64 debug.
- commit ddb821a
* Wed Jul 26 2017 dbueso@suse.de
- mm: update callers to use HASH_ZERO flag (bsc#971975).
- mm: zero hash tables in allocator (bsc#971975).
- locking/qspinlock: Explicitly include asm/prefetch.h
  (bsc#1050549).
- locking/rtmutex: Remove unnecessary priority adjustment
  (bsc#1050549).
- locking/refcount: Create unchecked atomic_t implementation
  (bsc#1050549).
- commit ca0d066
* Tue Jul 25 2017 jeffm@suse.com
- Refresh patches.suse/squashfs-3.4.patch.
  Restore fixes from:
  patches.suse/squashfs3-properly-handle-dir_emit-failures.patch.
- commit 03d0582
* Tue Jul 25 2017 jthumshirn@suse.de
- Forward port v4.13-rc qedf patches from SLE12-SP3
- commit 4512e77
* Tue Jul 25 2017 fvogt@suse.com
- Reassign some bcm283x patches
  patches.arch/arm64-bcm2837-0195-bcm2835-Add-Raspberry-Pi-thermal-sensor-to-the-device-tree.patch
  and patches.arch/arm64-bcm2837-0197-thermal-Add-Raspberry-Pi-BCM2835-thermal-driver.patch
  are now upstream, but due to a bug in Kconfig not enabled in arm64 builds. Needs a proper fix
  with proper testing which I currently can't do.
- commit d6fe1c5
* Tue Jul 25 2017 mgorman@suse.de
- Enable hpsa patch that avoids bypassing the controller cache
- commit 1c4e9ea
* Tue Jul 25 2017 jthumshirn@suse.de
- Update v4.13-rc2 bnxt_re patches
- commit 41b7731
* Tue Jul 25 2017 oneukum@suse.com
- Update config files.
  Kill the ancient PCMCIA/CardBus . (bsc#323267)
- commit 6b5ad53
* Tue Jul 25 2017 msuchanek@suse.de
- blacklist 2400fd822f46 powerpc/asm: Mark cr0 as clobbered in mftb()
- commit 0f1ad8b
* Mon Jul 24 2017 dbueso@suse.de
- ipc/util.h: update documentation for ipc_getref() and
  ipc_putref() (bsc#1050323).
- ipc/sem: drop __sem_free() (bsc#1050323).
- ipc/msg: remove special msg_alloc/free (bsc#1050323).
- ipc/shm: remove special shm_alloc/free (bsc#1050323).
- ipc: move atomic_set() to where it is needed (bsc#1050323).
- ipc/msg.c: avoid ipc_rcu_putref for failed ipc_addid()
  (bsc#1050323).
- ipc/shm.c: avoid ipc_rcu_putref for failed ipc_addid()
  (bsc#1050323).
- ipc/sem.c: avoid ipc_rcu_putref for failed ipc_addid()
  (bsc#1050323).
- ipc/util: drop ipc_rcu_alloc() (bsc#1050323).
- ipc/msg: avoid ipc_rcu_alloc() (bsc#1050323).
- ipc/shm: avoid ipc_rcu_alloc() (bsc#1050323).
- ipc/sem: avoid ipc_rcu_alloc() (bsc#1050323).
- ipc/util: drop ipc_rcu_free() (bsc#1050323).
- ipc/msg: do not use ipc_rcu_free() (bsc#1050323).
- ipc/shm: do not use ipc_rcu_free() (bsc#1050323).
- ipc/sem: do not use ipc_rcu_free() (bsc#1050323).
- ipc: drop non-RCU allocation (bsc#1050323).
- include/linux/sem.h: correctly document sem_ctime (bsc#1050323).
- ipc: merge ipc_rcu and kern_ipc_perm (bsc#1050323).
- ipc/sem.c: remove sem_base, embed struct sem (bsc#1050323).
- fs: remove call_fsync helper function (bsc#1050323).
- mqueue: move compat syscalls to native ones (bsc#1050323).
- commit c68517a
* Mon Jul 24 2017 tiwai@suse.de
- Apply the upstreamed (submitted) DRM patches, drop a couple of them
  (bnc#746883,bnc#895608,bnc#871134,bnc#893040,bnc#806990).
  patches.drivers/drm-radeon-limit-bpp-for-low-vram.patch
  patches.drivers/drm-ast-Actually-load-DP501-firmware-when-required.patch
  patches.drivers/drm-ast-Add-an-crtc_disable-callback-to-the-crtc-helper-funcs.patch
  patches.drivers/drm-ast-Fix-memleak-in-error-path-in-ast_bo_create.patch
  patches.drivers/drm-ast-Free-container-instead-of-member-in-ast_user_framebuffer_destroy.patch
  patches.drivers/drm-ast-Simplify-function-ast_bo_unpin.patch
  patches.drivers/drm-mgag200-Add-additional-limits-for-certain-G200-variants.patch
  patches.drivers/drm-mgag200-Add-command-line-option-to-specify-preferred-depth.patch
  patches.drivers/drm-mgag200-Add-doublescan-and-interlace-support.patch
  patches.drivers/drm-mgag200-Add-mode-validation-debugging-code.patch
  patches.drivers/drm-mgag200-Add-support-for-MATROX-PCI-device-IDs-0x520-and-0x521.patch
  patches.drivers/drm-mgag200-Cleanup-cursor-BOs-properly.patch
  patches.drivers/drm-mgag200-Consolidate-depth-bpp-handling.patch
  patches.drivers/drm-mgag200-Don-t-use-crtc_-parameters-for-validation.patch
  patches.drivers/drm-mgag200-Fix-memleak-in-error-path-in-mgag200_bo_create.patch
  patches.drivers/drm-mgag200-Free-container-instead-of-member-in-mga_user_framebuffer_destroy.patch
  patches.drivers/drm-mgag200-Implement-basic-PM-support
  patches.drivers/drm-mgag200-Initialize-data-needed-to-map-fbdev-memory.patch
  patches.drivers/drm-mgag200-Simplify-function-mgag200_ttm_placement.patch
  Dropped:
  patches.drivers/drm-cirrus-Add-missing-drm_connector_unregister.patch
  patches.drivers/drm-mgag200-Add-missing-drm_connector_unregister.patch
- commit b11e49b
* Mon Jul 24 2017 mgorman@suse.de
- writeback: rework wb_[dec|inc]_stat family of functions
  (bnc#971975 VM performance -- statistics).
- percpu_counter: Rename __percpu_counter_add to
  percpu_counter_add_batch (bnc#971975 VM performance --
  statistics).
- commit 960acce
* Mon Jul 24 2017 mgorman@suse.de
- kernel/fork.c: virtually mapped stacks: do not disable
  interrupts (bnc#978907 Scheduler performance -- fork).
- commit e0d9b89
* Mon Jul 24 2017 mgorman@suse.de
- sched/fair: Fix load_balance() affinity redo path (bnc#978907
  Scheduler performance -- load balancer).
- sched/cputime: Accumulate vtime on top of nsec clocksource
  (bnc#978907 Scheduler performance -- nohz_full, accounting).
- sched/cputime: Move the vtime task fields to their own struct
  (bnc#978907 Scheduler performance -- nohz_full, accounting).
- sched/cputime: Rename vtime fields (bnc#978907 Scheduler
  performance -- nohz_full, accounting).
- sched/cputime: Always set tsk->vtime_snap_whence after
  accounting vtime (bnc#978907 Scheduler performance -- nohz_full,
  accounting).
- vtime, sched/cputime: Remove vtime_account_user() (bnc#978907
  Scheduler performance -- nohz_full, accounting).
- commit 835d782
* Mon Jul 24 2017 mgorman@suse.de
- sched/topology: Rename sched_group_cpus() (bnc#978907 Scheduler
  performance -- topology).
- sched/topology: Rename sched_group_mask() (bnc#978907 Scheduler
  performance -- topology).
- sched/topology: Simplify sched_group_mask() usage (bnc#978907
  Scheduler performance -- topology).
- sched/topology: Rewrite get_group() (bnc#978907 Scheduler
  performance -- topology).
- sched/topology: Add a few comments (bnc#978907 Scheduler
  performance -- topology).
- sched/topology: Fix overlapping sched_group_capacity (bnc#978907
  Scheduler performance -- topology).
- sched/topology: Add sched_group_capacity debugging (bnc#978907
  Scheduler performance -- topology).
- sched/topology: Small cleanup (bnc#978907 Scheduler performance
  - - topology).
- sched/topology: Remove FORCE_SD_OVERLAP (bnc#978907 Scheduler
  performance -- topology).
- sched/topology: Move comment about asymmetric node setups
  (bnc#978907 Scheduler performance -- topology).
- sched/topology: Verify the first group matches the child domain
  (bnc#978907 Scheduler performance -- topology).
- sched/debug: Print the scheduler topology group mask (bnc#978907
  Scheduler performance -- topology).
- sched/topology: Simplify build_overlap_sched_groups()
  (bnc#978907 Scheduler performance -- topology).
- sched/topology: Refactor function build_overlap_sched_groups()
  (bnc#978907 Scheduler performance -- topology).
- commit bccf165
* Mon Jul 24 2017 mkubecek@suse.cz
- supported.conf: update core networking
  Add missing modules, drop those not built anymore.
- commit 017c4e5
* Mon Jul 24 2017 msuchanek@suse.de
- powerpc/fadump: Add a warning when 'fadump_reserve_mem='
  is used (bsc#1049231).
- commit f59fefd
* Mon Jul 24 2017 msuchanek@suse.de
- s390/crash: Remove unused KEXEC_NOTE_BYTES (bsc#1049706).
- commit f3e8437
* Mon Jul 24 2017 mkubecek@suse.cz
- Refresh and enable
  patches.drivers/i40e-add-private-flag-to-control-source-pruning.patch.
- commit d3ea4f6
* Mon Jul 24 2017 mkubecek@suse.cz
- Delete patches.suse/AF_MAX.patch.
  This patch reserved space for adding AF_HYPERV and AF_SMC constants as
  implementations of both families were not upstreamed at the moment of
  SLE12-SP2 kABI freeze. AF_SMC was accepted in the meantime (which turned
  out to be a bad thing, BtW), AF_HYPERV submission was rejected in July 2016
  and no attempt to resubmit it was made since.
  In other words, there doesn't seem to be any reason to keep the patch, it
  can be reintroduced later (in updated form) if there is a need.
- commit 4e036bb
* Mon Jul 24 2017 mkubecek@suse.cz
- Update upstream reference:
  patches.fixes/usb-early-Remove-trace_printk-callers-in-xhci-dbc.patch.
- commit 0162ee3
* Mon Jul 24 2017 mhocko@suse.cz
- blacklist.conf: blacklist 5d6dec6fba38 (we do not have any users)
- commit 7131165
* Mon Jul 24 2017 mhocko@suse.cz
- blacklist.conf: 3bc1630774bc (compilation fix for config which we do not
  care)
- commit e1ee65a
* Mon Jul 24 2017 mhocko@suse.cz
- blacklist.conf: 38cb266ad1a2 (trivial doc formatting)
- commit 4fa3930
* Sat Jul 22 2017 bpoirier@suse.com
- Sort network patch section and rename accordingly
- commit 8588a81
* Sat Jul 22 2017 bpoirier@suse.com
- Refresh
  patches.drivers/e1000e-Don-t-return-uninitialized-stats.patch.
  It was a local commit id.
- commit 4c5c3f9
* Fri Jul 21 2017 colyli@suse.de
- md: remove 'idx' from 'struct resync_pages' (bsc#1049599).
- commit 515f14e
* Fri Jul 21 2017 lhenriques@suse.com
- Patch has been merged into 4.12
  Delete
  patches.fixes/ceph-check-i_nlink-while-converting-a-file-handle-to-dentry.patch.
- commit d60ca32
* Fri Jul 21 2017 tbogendoerfer@suse.de
- enabled and moved patches present in SLE12-SP3 and still needed in SLE15
- commit 597b029
* Fri Jul 21 2017 duwe@suse.de
- Be prepared to enable ARM64 live patching during SLE15 lifetime
  (FATE#322421).
- Delete
  patches.arch/powerpc-add-kernel-parameter-iommu_alloc_quiet.patch.
  DMA_ATTR_NO_WARN is now incorporated.
- Delete patches.fixes/fix-stop-machine.
  Proper mainline fix is now in.
- Remove FIPS patches:
- Delete patches.suse/allow-cmac_3des_ede-for-FIPS-140-2.
- Delete patches.suse/allow-cmac_aes-for-FIPS-140-2.
- Delete patches.suse/disallow-ansi_cprng-for-FIPS-140-2.
- Delete patches.suse/fips-remove-hmac-crc32-add-nullcipher-hack.
- commit cd28b1d
* Fri Jul 21 2017 jroedel@suse.de
- x86/acpi: Prevent out of bound access caused by broken ACPI
  tables (CVE-2017-11473 bsc#1049603).
- commit cc7b51e
* Fri Jul 21 2017 oneukum@suse.com
- Update config files.
  Remove WUSB (FATE#323423)
- commit 2257fee
* Fri Jul 21 2017 oneukum@suse.com
- supported.conf:
  remove support for IRDA (FATE#323263)
- commit bdaf793
* Fri Jul 21 2017 oneukum@suse.com
- supported.conf:
  removed support for ISDN (FATE#323266)
- commit 4265d36
* Fri Jul 21 2017 oneukum@suse.com
- Update config files.
  Exterminate ISDN (FATE#323266)
- commit f13b205
* Fri Jul 21 2017 oneukum@suse.com
- Update config files.
  Exterminate IRDA (FATE#323263)
- commit ef690e1
* Fri Jul 21 2017 jslaby@suse.cz
- Linux 4.12.3 (CVE-2017-7541 bnc#1012628 bsc#1049645).
- Refresh patches.suse/pstore-backend-autoaction.
- Delete
  patches.fixes/brcmfmac-fix-possible-buffer-overflow-in-brcmf_cfg80.
- commit 409edbf
* Fri Jul 21 2017 jthumshirn@suse.de
- Delete
  patches.drivers/0051-Missing-bio_put-following-submit_bio_wait.patch.
- Delete
  patches.drivers/0127-scsi-lpfc-Fix-crash-on-PCI-hotplug-remove-path.patch.
- Delete patches.drivers/0426-nvmet_fc-fix-list-corruption.patch.
- Delete
  patches.drivers/0427-nvmet_fc-cap-amount-of-work-allowed-in-workqueue.patch.
  Delete superseded patches and re-attribute PM patch to Joey
- commit 492279e
* Fri Jul 21 2017 mcgrof@suse.com
- Delete
  patches.fixes/xfs-fix-buffer-overflow-dm_get_dirattrs.patch.
- Delete
  patches.fixes/xfs_dmapi-fix-the-debug-compilation-of-xfs_dmapi.patch.
- commit 2f7c909
* Fri Jul 21 2017 mcgrof@suse.com
- Refresh
  patches.drivers/0001-module-warn-if-module-init-probe-takes-long.patch.
- commit c47c847
* Thu Jul 20 2017 jack@suse.cz
- dentry name snapshots (bsc#1049483).
- commit 76ea0ca
* Thu Jul 20 2017 mwilck@suse.com
- Delete
  patches.drivers/ipmi_si-create-hardware-independent-softdep-for-ipmi.patch.
  upstream now.
- commit c4eb19d
* Thu Jul 20 2017 mwilck@suse.com
- Refresh
  patches.drivers/0001-hpsa-update-identify-physical-device-structure.patch.
- Refresh
  patches.drivers/0002-hpsa-do-not-get-enclosure-info-for-external-devices.patch.
- Refresh patches.drivers/0003-hpsa-update-reset-handler.patch.
- Refresh patches.drivers/0004-hpsa-do-not-reset-enclosures.patch.
- Refresh
  patches.drivers/0005-hpsa-rescan-later-if-reset-in-progress.patch.
- Refresh
  patches.drivers/0006-hpsa-correct-resets-on-retried-commands.patch.
- Refresh patches.drivers/0007-hpsa-cleanup-reset-handler.patch.
- Refresh
  patches.drivers/0008-hpsa-correct-queue-depth-for-externals.patch.
- Refresh
  patches.drivers/0009-hpsa-separate-monitor-events-from-rescan-worker.patch.
- Refresh
  patches.drivers/0010-hpsa-send-ioaccel-requests-with-0-length-down-raid-path.patch.
- Update patches.drivers/0011-hpsa-remove-abort-handler.patch
  (bsc#1022600 fate#321928 bsc#1016119).
- Refresh patches.drivers/0012-hpsa-bump-driver-version.patch.
- Delete
  patches.drivers/hpsa-fallback-to-use-legacy-REPORT-PHYS-command.patch.
- Delete
  patches.drivers/hpsa-use-correct-DID_NO_CONNECT-hostbyte.patch.
- commit 3a174f7
* Thu Jul 20 2017 nborisov@suse.com
- Add Omar's total_bytes_pinned patches from upstream and delete old backports
- Btrfs: always account pinned bytes when dropping a tree block
  ref (bsc#1040182).
- Btrfs: make add_pinned_bytes() take an s64 num_bytes instead
  of u64 (bsc#1040182).
- Btrfs: make BUG_ON() in add_pinned_bytes() an ASSERT()
  (bsc#1040182).
- Btrfs: return old and new total ref mods when adding delayed
  refs (bsc#1040182).
- Btrfs: rework delayed ref total_bytes_pinned accounting
  (bsc#1040182).
- Btrfs: update total_bytes_pinned when pinning down extents
  (bsc#1040182).
- Delete
  patches.suse/0001-Btrfs-make-add_pinned_bytes-take-an-s64-num_bytes-in.patch.
- Delete
  patches.suse/0002-Btrfs-make-BUG_ON-in-add_pinned_bytes-an-ASSERT.patch.
- Delete
  patches.suse/0003-Btrfs-update-total_bytes_pinned-when-pinning-down-ex.patch.
- Delete
  patches.suse/0004-Btrfs-always-account-pinned-bytes-when-dropping-a-tr.patch.
- Delete
  patches.suse/0005-Btrfs-return-old-and-new-total-ref-mods-when-adding-.patch.
- Delete
  patches.suse/0006-Btrfs-rework-delayed-ref-total_bytes_pinned-accounti.patch.
- Delete
  patches.suse/0007-Btrfs-warn-if-total_bytes_pinned-is-non-zero-on-unmo.patch.
- commit 97e177b
* Thu Jul 20 2017 tbogendoerfer@suse.de
- Patch is already part of 4.12.
  Delete
  patches.drivers/cxgb4-0157-cxgb4-notify-uP-to-route-ctrlq-compl-to-rdma-rspq.patch.
- commit c3e3c5d
* Thu Jul 20 2017 jeffm@suse.com
- btrfs: fix lockup in find_free_extent with read-only block
  groups (bsc#1046682).
- commit fa3b074
* Thu Jul 20 2017 jslaby@suse.cz
- debug: fix WARN_ON_ONCE() for modules (bnc#1049599).
- commit b1e9bab
* Thu Jul 20 2017 mhocko@suse.cz
- patches.fixes/mm-mmap.c-do-not-blow-on-PROT_NONE-MAP_FIXED-holes-i.patch
  forward port
- commit e188cbc
* Thu Jul 20 2017 tbogendoerfer@suse.de
- Deleted outdated patches.
- Delete
  patches.drivers/staging-rdma-0001-Commit-507f6afa3ab6-struct-ib_class_port_info-this-c.patch.
- Delete
  patches.drivers/staging-rdma-0002-Fix-changed-get_user_pages-arguments.patch.
- Delete
  patches.drivers/staging-rdma-0003-Adapt-staging-rdma-drivers-to-IB-core-Let-create_ah.patch.
- commit 357b909
* Thu Jul 20 2017 tiwai@suse.de
- brcmfmac: fix possible buffer overflow in
  brcmf_cfg80211_mgmt_tx() (CVE-2017-7541,bsc#1049645).
- commit 9f05680
* Thu Jul 20 2017 mhocko@suse.cz
- series.conf - move some MM patches to the proper section
- commit d78e77f
* Wed Jul 19 2017 mmarek@suse.cz
- rpm/kernel-binary.spec.in: find-debuginfo.sh should not touch build-id
  This needs rpm-4.14+ (bsc#964063).
- commit f622d60
* Wed Jul 19 2017 lduncan@suse.com
- Removing gaurded patch from SLE12 not needed.
- commit 0d62b5e
* Wed Jul 19 2017 jack@suse.cz
- ext4: avoid unnecessary stalls in ext4_evict_inode()
  (bsc#1049486).
- commit 47dc213
* Wed Jul 19 2017 mmarek@suse.cz
- Reassign some of the to be reviewed patches
- commit 7431a6f
* Wed Jul 19 2017 oneukum@suse.com
- Refresh
  patches.suse/0003-kabi-Add-placeholders-to-a-couple-of-important-struc.patch.
  Taking all the kABI placeholders, as teh rational for them has not changed.
- commit 72e50ae
* Wed Jul 19 2017 mfleming@suse.de
- Delete
  patches.suse/sched-Add-missing-update_rq_clock-call-in-set_user_n.patch:
  Merged as 2fb8d36787affe26f3536c3d8ec094995a48037d in v4.11-rc1.
- commit f2bba64
* Wed Jul 19 2017 mfleming@suse.de
- Delete
  patches.suse/sched-Add-missing-update_rq_clock-call-for-task_hot.patch:
  Merged as 3bed5e2166a5e433bf62162f3cd3c5174d335934 as v4.11-rc1.
- commit 23e5248
* Wed Jul 19 2017 mfleming@suse.de
- Delete
  patches.suse/sched-Add-missing-update_rq_clock-in-detach_task_cfs.patch:
  Merged as 80f5c1b84baa8180c3c27b7e227429712cd967b6 in v4.11-rc1.
- commit 85dec32
* Wed Jul 19 2017 mfleming@suse.de
- Delete
  patches.suse/sched-Add-missing-update_rq_clock-in-post_init_entit.patch:
  Merged as 4126bad6717336abe5d666440ae15555563ca53f in v4.11-rc1.
- commit d31a75d
* Wed Jul 19 2017 mmarek@suse.cz
- Delete patches.suse/split-package, the specfile does not use this anymore
- commit f265fd3
* Wed Jul 19 2017 jkosina@suse.cz
- supported.conf: import supported.conf from SLE12-SP3 and add missing entries
- commit 22aaf02
* Wed Jul 19 2017 jthumshirn@suse.de
- Renumber SmartPQI patches, as we're restarting from 1 now
- commit 9737cb7
* Wed Jul 19 2017 jthumshirn@suse.de
- Refresh
  patches.drivers/0041-scsi-smartpqi-correct-aio-error-path.patch.
- Refresh
  patches.drivers/0048-scsi-smartpqi-make-ioaccel-references-consistent.patch.
- Delete patches.drivers/0001-scsi-fcoe-convert-to-kworker.patch.
- commit 2cee378
* Wed Jul 19 2017 oneukum@suse.com
- Delete
  patches.drivers/0001-USB-add-descriptors-from-USB-Power-Delivery-spec.patch.
- Delete
  patches.drivers/0001-cdc-acm-added-sanity-checking-for-probe.patch.
- Delete patches.drivers/0001-gspca-correct-speed-testing.patch.
- Delete
  patches.drivers/0002-USB-PD-define-specific-requests.patch.
- Delete patches.drivers/0002-uvc-correct-speed-testing.patch.
- Delete
  patches.drivers/0003-USB-PD-additional-feature-selectors.patch.
- Delete
  patches.suse/0001-usb-quirk-to-stop-runtime-PM-for-Intel-7260.patch.
- commit 2b88672
* Wed Jul 19 2017 jroedel@suse.de
- iommu/amd: Free already flushed ring-buffer entries before
  full-check (bsc#1045709).
- iommu/amd: Remove amd_iommu_disabled check from
  amd_iommu_detect() (bsc#1045715 bsc#1043261).
- iommu/amd: Free IOMMU resources when disabled on command line
  (bsc#1045715 bsc#1043261).
- iommu/amd: Set global pointers to NULL after freeing them
  (bsc#1045715 bsc#1043261).
- iommu/amd: Check for error states first in iommu_go_to_state()
  (bsc#1045715 bsc#1043261).
- iommu/amd: Add new init-state IOMMU_CMDLINE_DISABLED
  (bsc#1045715 bsc#1043261).
- iommu/amd: Rename free_on_init_error() (bsc#1045715
  bsc#1043261).
- iommu/amd: Disable IOMMUs at boot if they are enabled
  (bsc#1045715 bsc#1043261).
- iommu/amd: Suppress IO_PAGE_FAULTs in kdump kernel (bsc#1045715
  bsc#1043261).
- iommu/amd: Remove queue_release() function (bsc#1045709).
- iommu/amd: Add per-domain timer to flush per-cpu queues
  (bsc#1045709).
- iommu/amd: Add flush counters to struct dma_ops_domain
  (bsc#1045709).
- iommu/amd: Add locking to per-domain flush-queue (bsc#1045709).
- iommu/amd: Make use of the per-domain flush queue (bsc#1045709).
- iommu/amd: Add per-domain flush-queue data structures
  (bsc#1045709).
- iommu/amd: Rip out old queue flushing code (bsc#1045709).
- iommu/amd: Reduce delay waiting for command buffer space
  (bsc#1045709).
- iommu/amd: Reduce amount of MMIO when submitting commands
  (bsc#1045709).
- iommu/amd: Constify irq_domain_ops (bsc#1045709).
- iommu/amd: Ratelimit io-page-faults per device (bsc#1045709).
- commit f012b19
* Wed Jul 19 2017 hare@suse.de
- Delete upstreamed patches
- Delete
  patches.drivers/0097-NVMe-Only-release-requested-regions.patch.
- Delete
  patches.drivers/0385-nvme-fc-correct-port-role-bits.patch.
- Delete
  patches.drivers/0386-nvme-fc-require-target-or-discovery-role-for-fc-nvme.patch.
- Delete
  patches.drivers/0387-nvme-fc-stop-queues-on-error-detection.patch.
- Delete
  patches.drivers/0388-nvmet-fc-remove-target-cpu-scheduling-flag.patch.
- Delete
  patches.drivers/0389-nvmet-release-the-sq-ref-on-rdma-read-errors.patch.
- Delete
  patches.drivers/0390-nvme_fc-get-rid-of-local-reconnect_delay.patch.
- Delete patches.drivers/0391-nvme_fc-Support-ctrl_loss_tmo.patch.
- Delete
  patches.drivers/0392-nvme_fc-replace-ioabort-msleep-loop-with-completion.patch.
- Delete
  patches.drivers/0393-nvme_fc-revise-comment-on-teardown.patch.
- Delete
  patches.drivers/0394-nvme_fc-set-logging-level-on-resets-deletes.patch.
- Delete patches.drivers/0395-nvmet_fc-Reduce-work_q-count.patch.
- Delete
  patches.drivers/0396-nvmet_fc-Add-queue-create-and-delete-callbacks-in-LL.patch.
- Delete
  patches.drivers/0397-nvme_fc-remove-extra-controller-reference-taken-on-r.patch.
- Delete
  patches.drivers/0398-nvme_fcloop-fix-port-deletes-and-callbacks.patch.
- Delete
  patches.drivers/0399-nvme_fc-correct-nvme-status-set-on-abort.patch.
- Delete
  patches.drivers/0400-nvme_fc-create-fc-class-and-transport-device.patch.
- Delete
  patches.drivers/0401-nvme_fc-add-uevent-for-auto-connect.patch.
- Delete
  patches.drivers/0402-nvme-core-allow-controller-RESETTING-to-RECONNECTING.patch.
- Delete
  patches.drivers/0403-nvme_fc-change-ctlr-state-assignments-during-reset-r.patch.
- Delete
  patches.drivers/0404-nvme_fc-add-a-dev_loss_tmo-field-to-the-remoteport.patch.
- Delete
  patches.drivers/0405-nvme_fc-add-dev_loss_tmo-to-controller.patch.
- Delete
  patches.drivers/0406-nvme_fc-check-connectivity-before-initiating-reconne.patch.
- Delete
  patches.drivers/0407-nvme_fc-change-failure-code-on-remoteport-connectivi.patch.
- Delete
  patches.drivers/0408-nvme_fc-move-remote-port-get-put-free-location.patch.
- Delete
  patches.drivers/0409-nvme_fc-add-dev_loss_tmo-timeout-and-remoteport-resu.patch.
- Delete
  patches.drivers/lpfc-Revert-patch-lpfc-Delete-unnecessary-checks-bef.patch.
- Delete
  patches.drivers/lpfc-driver-update-for-SLES12-SP2-11.1.0.1.patch.
- Delete
  patches.fixes/fc-add-missing-ELS-explanation-values.patch.
- Delete patches.fixes/fc_rport-PRLI-fixes.patch.
- Delete
  patches.fixes/fc_rport-Return-LS_RJT_BUSY-for-PRLI-in-status-PLOGI.patch.
- Delete
  patches.fixes/fcoe-Add-FIP-responder-on-the-real-network-device.patch.
- Delete patches.fixes/fcoe-FIP-debugging.patch.
- Delete patches.fixes/fcoe-Use-kfree_skb-instead-of-kfree.patch.
- Delete
  patches.fixes/fcoe-correct-sending-FIP-VLAN-packets-on-VLAN-0.patch.
- Delete
  patches.fixes/fcoe-filter-out-frames-from-invalid-vlans.patch.
- Delete
  patches.fixes/fcoe-inhibit-writing-invalid-values-into-the-enabled.patch.
- Delete
  patches.fixes/fcoe-make-R_A_TOV-and-E_D_TOV-configurable.patch.
- Delete patches.fixes/fcoe-set-default-TC-priority.patch.
- Delete
  patches.fixes/fcoe_ctlr-fix-potential-deadlock-when-re-adding-port.patch.
- Delete patches.fixes/libfc-Clarify-ramp-down-messages.patch.
- Delete
  patches.fixes/libfc-Correctly-set-E_D_TOV-and-R_A_TOV-values-in-RT.patch.
- Delete patches.fixes/libfc-Debug-PRLI-failures.patch.
- Delete
  patches.fixes/libfc-Do-not-attempt-to-login-if-the-port-is-already.patch.
- Delete
  patches.fixes/libfc-Do-not-drop-down-to-FLOGI-for-fc_rport_login.patch.
- Delete
  patches.fixes/libfc-Do-not-drop-out-of-order-frames.patch.
- Delete
  patches.fixes/libfc-Do-not-take-rdata-rp_mutex-when-processing-a-F.patch.
- Delete
  patches.fixes/libfc-Fix-PRLI-response-handling-yet-again.patch.
- Delete patches.fixes/libfc-Fixup-disc_mutex-handling.patch.
- Delete
  patches.fixes/libfc-Fixup-fixup-disc_mutex-handling.patch.
- Delete patches.fixes/libfc-Implement-RTV-responder.patch.
- Delete
  patches.fixes/libfc-Issue-PRLI-after-a-PRLO-has-been-received.patch.
- Delete patches.fixes/libfc-Revisit-kref-handling.patch.
- Delete
  patches.fixes/libfc-Send-LS_RJT-responses-on-frame-allocation-fail.patch.
- Delete
  patches.fixes/libfc-Update-rport-reference-counting.patch.
- Delete
  patches.fixes/libfc-additional-debugging-in-fc_rport.patch.
- Delete patches.fixes/libfc-additional-debugging-messages.patch.
- Delete
  patches.fixes/libfc-do-not-overwrite-DID_TIME_OUT-status.patch.
- Delete
  patches.fixes/libfc-do-not-send-ABTS-when-resetting-exchanges.patch.
- Delete
  patches.fixes/libfc-don-t-advance-state-machine-for-incoming-FLOGI.patch.
- Delete
  patches.fixes/libfc-don-t-fail-sequence-abort-for-completed-exchan.patch.
- Delete
  patches.fixes/libfc-fc_fcp-wait-for-E_D_TOV-when-out-of-order-sequ.patch.
- Delete patches.fixes/libfc-fixup-RTV-handling.patch.
- Delete patches.fixes/libfc-fixup-locking-of-ptp_setup.patch.
- Delete patches.fixes/libfc-frame-alloc-failure-messages.patch.
- Delete patches.fixes/libfc-quarantine-timed-out-xids.patch.
- Delete
  patches.fixes/libfc-reset-exchange-manager-during-LOGO-handling.patch.
- Delete patches.fixes/libfc-reset-timeout-on-queue-full.patch.
- Delete
  patches.fixes/libfc-safeguard-against-invalid-exchange-index.patch.
- Delete patches.fixes/libfc-sanitize-E_D_TOV-setting.patch.
- Delete patches.fixes/libfc-send-LOGO-for-PLOGI-failure.patch.
- Delete
  patches.fixes/libfc-spurious-I-O-error-under-high-load.patch.
- Delete
  patches.fixes/libfc-use-configured-e_d_tov-for-remote-port-state-r.patch.
- Delete
  patches.fixes/libfc-use-configured-lport-R_A_TOV-when-sending-exch.patch.
- Delete
  patches.fixes/libfc-use-error-code-for-fc_rport_error.patch.
- Delete patches.fixes/scsi-Fix-RCU-handling-for-VPD-pages.patch.
- Delete
  patches.fixes/scsi-vpd-pages-are-mandatory-for-SPC-2.patch.
- Delete
  patches.fixes/scsi_dh_alua-Do-not-modify-the-interval-value-for-re.patch.
- Delete
  patches.fixes/scsi_dh_alua-Do-not-retry-for-unmapped-device.patch.
- Delete
  patches.fixes/scsi_dh_alua-Retry-RTPG-on-SCSI-host_bytes-values.patch.
- Delete
  patches.fixes/scsi_dh_alua-do-not-call-BUG_ON-when-updating-port-g.patch.
- Delete
  patches.fixes/scsi_transport_sas-add-scsi_target_id-sysfs-attribut.patch.
- commit 292a8cf
* Wed Jul 19 2017 tbogendoerfer@suse.de
- Update Patch-mainline tags.
- Refresh
  patches.drivers/cxgb4-0151-cxgb4-reduce-resource-allocation-in-kdump-kernel.patch.
- Refresh
  patches.drivers/cxgb4-0152-cxgb4-Fix-netdev_features-flag.patch.
- Refresh
  patches.drivers/cxgb4-0153-cxgb4-keep-carrier-off-before-registering-netdev.patch.
- Refresh
  patches.drivers/cxgb4-0157-cxgb4-notify-uP-to-route-ctrlq-compl-to-rdma-rspq.patch.
- Refresh
  patches.drivers/qed-sp3-0264-qed-Enable-RoCE-parser-searching-on-fp-init.patch.
- Refresh
  patches.drivers/qed-sp3-0265-qed-Correct-order-of-wwnn-and-wwpn.patch.
- Refresh
  patches.drivers/qed-sp3-0266-qed-Share-additional-information-with-qedf.patch.
- Refresh
  patches.drivers/qed-sp3-0267-qed-Support-NVM-image-reading-API.patch.
- Refresh
  patches.drivers/qed-sp3-0268-qed-Add-support-for-changing-iSCSI-mac.patch.
- Refresh
  patches.drivers/xgene-sp3-0001-phy-Add-helper-function-to-check-phy-interface-mode.patch.
- Refresh
  patches.drivers/xgene-sp3-0011-drivers-net-xgene-Protect-indirect-MAC-access.patch.
- Refresh
  patches.drivers/xgene-sp3-0012-drivers-net-phy-xgene-Add-lock-to-protect-mac-access.patch.
- Refresh
  patches.drivers/xgene-sp3-0013-drivers-net-xgene-Use-rgmii-mdio-mac-access.patch.
- Refresh
  patches.drivers/xgene-sp3-0014-drivers-net-xgene-Remove-redundant-local-stats.patch.
- Refresh
  patches.drivers/xgene-sp3-0015-drivers-net-xgene-Refactor-statistics-error-parsing-.patch.
- Refresh
  patches.drivers/xgene-sp3-0016-drivers-net-xgene-Remove-unused-macros.patch.
- Refresh
  patches.drivers/xgene-sp3-0017-drivers-net-xgene-Extend-ethtool-statistics.patch.
- Refresh
  patches.drivers/xgene-sp3-0018-drivers-net-xgene-Add-rx_overrun-tx_underrun-statist.patch.
- Refresh
  patches.drivers/xgene-sp3-0019-drivers-net-xgene-Workaround-for-HW-errata-10GE_4.patch.
- Refresh
  patches.drivers/xgene-sp3-0020-drivers-net-xgene-Add-frame-recovered-statistics-cou.patch.
- Refresh
  patches.drivers/xgene-sp3-0021-drivers-net-xgene-Workaround-for-HW-errata-10GE_10-E.patch.
- Refresh
  patches.drivers/xgene-sp3-0022-drivers-net-xgene-Fix-redundant-prefetch-buffer-clea.patch.
- Refresh
  patches.drivers/xgene-sp3-0023-xgene-Check-all-RGMII-phy-mode-variants.patch.
- commit b012c38
* Wed Jul 19 2017 jroedel@suse.de
- Delete
  patches.drivers/0001-iommu-amd-ratelimit-io-page-faults-per-device.
- Delete
  patches.drivers/0001-iommu-amd-suppress-io_page_faults-in-kdump-kernel.
- Delete patches.drivers/0002-iommu-amd-constify-irq_domain_ops.
- Delete
  patches.drivers/0002-iommu-amd-disable-iommus-at-boot-if-they-are-enabled.
- Delete
  patches.drivers/0003-iommu-amd-reduce-amount-of-mmio-when-submitting-commands.
- Delete patches.drivers/0003-iommu-amd-rename-free_on_init_error.
- Delete
  patches.drivers/0004-iommu-amd-add-new-init-state-iommu_cmdline_disabled.
- Delete
  patches.drivers/0004-iommu-amd-reduce-delay-waiting-for-command-buffer-space.
- Delete
  patches.drivers/0005-iommu-amd-check-for-error-states-first-in-iommu_go_to_state.
- Delete
  patches.drivers/0005-iommu-amd-rip-out-old-queue-flushing-code.
- Delete
  patches.drivers/0006-iommu-amd-add-per-domain-flush-queue-data-structures.
- Delete
  patches.drivers/0006-iommu-amd-set-global-pointers-to-null-after-freeing-them.
- Delete
  patches.drivers/0007-iommu-amd-free-iommu-resources-when-disabled-on-command-line.
- Delete
  patches.drivers/0007-iommu-amd-make-use-of-the-per-domain-flush-queue.
- Delete
  patches.drivers/0008-iommu-amd-add-locking-to-per-domain-flush-queue.
- Delete
  patches.drivers/0008-iommu-amd-remove-amd_iommu_disabled-check-from-amd_iommu_detect.
- Delete
  patches.drivers/0009-iommu-amd-add-flush-counters-to-struct-dma_ops_domain.
- Delete
  patches.drivers/0010-iommu-amd-add-per-domain-timer-to-flush-per-cpu-queues.
- Delete
  patches.drivers/0011-iommu-amd-remove-queue_release-function.
- Delete
  patches.drivers/0012-iommu-amd-free-already-flushed-ring-buffer-entries-before-full-check.
- commit abd2aa7
* Wed Jul 19 2017 jbohac@suse.cz
- Drop bridge-remove-br_netfilter-warning.patch
  patches.suse/bridge-remove-br_netfilter-warning.patch was intended for
  SLE12-SPx only. For SLE15 we want to follow the upstream behaviour of bridge /
  br_netfilter.
- commit d00a8a0
* Wed Jul 19 2017 jthumshirn@suse.de
- series.conf: Delete already upstreamed patches.
- commit d8c5404
* Wed Jul 19 2017 jroedel@suse.de
- Re-assign patches.suse/0009-PM-hibernate-Reserve-hibernation-key-and-erase-footp.patch
- commit 1d767fc
* Wed Jul 19 2017 gqjiang@suse.com
- Delete
  patches.suse/0004-md-cluster-use-sync-way-to-handle-METADATA_UPDATED-m.patch.
- Delete
  patches.suse/0005-md-move-bitmap_destroy-to-the-beginning-of-__md_stop.patch.
- Delete
  patches.suse/0006-md-cluster-add-CHANGE_CAPACITY-message-type.patch.
- Delete
  patches.suse/0007-md-cluster-introduce-cluster_check_sync_size.patch.
- Delete
  patches.suse/0008-md-cluster-add-the-support-for-resize.patch.
- commit ef41919
* Tue Jul 18 2017 mhocko@suse.cz
- Added patches.fixes/0001-mm-memory_hotplug-simplify-empty-node-mask-handling-.patch
  Added patches.fixes/0002-hugetlb-memory_hotplug-prefer-to-use-reserved-pages-.patch
  Added patches.fixes/0003-mm-unify-new_node_page-and-alloc_migrate_target.patch.
  forward ported
- commit d5e8bf8
* Tue Jul 18 2017 mhocko@suse.cz
- patches.suse/0001-mm-memory_hotplug-support-movable_node-for-hotplugab.patch
  forward port
- commit 3426276
* Tue Jul 18 2017 mhocko@suse.cz
- Update
  patches.suse/0004-mm-memory_hotplug-get-rid-of-is_zone_device_section.patch
  (bnc#1027153, bnc#1030659, bnc#1047595, fate#323634).
- Delete
  patches.fixes/004-mm-memory_hotplug-get-rid-of-is_zone_device_section-fix.patch.
- commit 9b458ae
* Tue Jul 18 2017 mhocko@suse.cz
- mm: remove return value from init_currently_empty_zone
  (bnc#1027153, bnc#1030659, fate#323634).
- mm, memory_hotplug: consider offline memblocks removable
  (bnc#1027153, bnc#1030659, fate#323634).
- mm: consider zone which is not fully populated to have holes
  (bnc#1027153, bnc#1030659, fate#323634).
- mm, compaction: skip over holes in __reset_isolation_suitable
  (bnc#1027153, bnc#1030659, fate#323634).
- mm: __first_valid_page skip over offline pages (bnc#1027153,
  bnc#1030659, fate#323634).
- mm, vmstat: skip reporting offline pages in pagetypeinfo
  (bnc#1027153, bnc#1030659, fate#323634).
- mm, memory_hotplug: do not associate hotadded memory to
  zones until online (bnc#1027153, bnc#1030659, bnc#1047506,
  fate#323634).
- mm, memory_hotplug: fix MMOP_ONLINE_KEEP behavior (bnc#1027153,
  bnc#1030659, fate#323634).
- mm, memory_hotplug: do not assume ZONE_NORMAL is default kernel
  zone (bnc#1027153, bnc#1030659, fate#323634).
- mm, memory_hotplug: replace for_device by want_memblock in
  arch_add_memory (bnc#1027153, bnc#1030659, fate#323634).
- mm, memory_hotplug: fix the section mismatch warning
  (bnc#1027153, bnc#1030659, fate#323634).
- mm, memory_hotplug: remove unused cruft after memory hotplug
  rework (bnc#1027153, bnc#1030659, fate#323634).
- Update
  patches.suse/0002-mm-memory_hotplug-use-node-instead-of-zone-in-can_on.patch
  (bnc#1027153, bnc#1030659, fate#323634).
- Update
  patches.suse/0003-mm-drop-page_initialized-check-from-get_nid_for_pfn.patch
  (bnc#1027153, bnc#1030659, fate#323634).
- Update
  patches.suse/0004-mm-memory_hotplug-get-rid-of-is_zone_device_section.patch
  (bnc#1027153, bnc#1030659, fate#323634).
- mm, memory_hotplug: split up register_one_node() (bnc#1027153,
  bnc#1030659, fate#323634).
- Delete
  patches.fixes/0001-mm-memory_hotplug-fix-MMOP_ONLINE_KEEP-behavior.patch.
- Delete
  patches.fixes/0002-mm-memory_hotplug-do-not-assume-ZONE_NORMAL-is-defau.patch.
- Delete
  patches.fixes/include-linux-mmzone.h-simplify-zone_intersects.patch.
- Delete
  patches.suse/0006-mm-memory_hotplug-do-not-associate-hotadded-memory-t.patch.
- Delete
  patches.suse/0008-mm-memory_hotplug-fix-the-section-mismatch-warning.patch.
- Delete
  patches.suse/0009-mm-memory_hotplug-remove-unused-cruft-after-memory-h.patch.
- Delete
  patches.suse/mm-memory_hotplug-consider-offline-memblocks-removable.patch.
  Replace the SLE12-SP2 based implementation by the upstream commits. Take
  the whole series but in principle there are no large changes between the
  two.
- commit 5fdd3c7
* Tue Jul 18 2017 bpoirier@suse.com
- Move all networking patches in one section
  Driver and core changes are intertwined upstream. Trying to separate them
  leads to an unbisectable series.
- commit dc0dd37
* Tue Jul 18 2017 bpoirier@suse.com
- Delete
  patches.drivers/qed-bump-driver-versions-to-8.7.1.62.patch.
  Specific to SLE12SP2 backport, see bsc#966318 comment 16
- Delete
  patches.fixes/scsi-bfa-Increase-requested-firmware-version-to-3.2..patch.
  Upstream as
  2d1148f0f450 scsi: bfa: Increase requested firmware version to 3.2.5.1 (v4.10-rc4)
- commit 31b4006
* Tue Jul 18 2017 tiwai@suse.de
- Adjust guard prefix in series.conf, no functional change
- commit f09e36f
* Tue Jul 18 2017 tiwai@suse.de
- Enable patches.fixes/iio-hid-sensor-fix-return-of-EINVAL-on-invalid-value
  It's a trivial fix from 4.13-rc1 and still valid.
- commit 4daf55f
* Tue Jul 18 2017 tiwai@suse.de
- Enable patches.drivers/kernel-Export-mm_access.patch.
  This patch is still required for supporting AMD ROCm.
- commit d9a4c03
* Tue Jul 18 2017 mhocko@suse.cz
- Delete patches.fixes/mm-do-not-loop-on-GFP_REPEAT-when-no-reclaim-progress.patch.
  fixed as a part of 0a0337e0d1d134465778a16f5cbea95086e8e9e0 (4.7)
- commit a38fe09
* Tue Jul 18 2017 tiwai@suse.de
- Delete patches.drivers/drm-Print-EDID-errors-less-obviously.patch
  This change is no longer needed with the recent upstream code.
- commit 30a521d
* Tue Jul 18 2017 mhocko@suse.cz
- patches.suse/mm-inform-about-enabling-mirrored-memory.patch
  enable because the concern with the mirrored memory still holds
- commit b059f43
* Tue Jul 18 2017 mhocko@suse.cz
- Delete patches.fixes/powerpc-implement-arch_reserved_kernel_pages.patch.
  merged 1e76609cc1646c5222feefe86a3433a79be4fb73 (4.9)
- commit cbafebe
* Tue Jul 18 2017 mhocko@suse.cz
- Delete patches.fixes/mm-memblock-expose-total-reserved-memory.patch.
  merged as 8907de5dc6e9d5925cf3b0a698cc3a4272fda073 (4.9)
- commit 7eb2ba2
* Tue Jul 18 2017 mhocko@suse.cz
- Delete patches.fixes/mm-introduce-arch_reserved_kernel_pages.patch.
  merged as f6f34b4387d9e18304451a131b35d7c4f27a0b5a (4.9)
- commit c8145c8
* Tue Jul 18 2017 mhocko@suse.cz
- patches.suse/mm-Warn-users-of-node-memory-hot-remove-if-the-memory-ratio-is-a-high-risk.patch
  enable the patch as we want to have an idea that somebody overuses
  movable memory.
- commit 490b154
* Tue Jul 18 2017 mgorman@suse.de
- Delete
  patches.suse/mm-fadvise-avoid-expensive-remote-LRU-cache-draining-after-FADV_DONTNEED.patch.
- Delete patches.suse/mm-fix-remote-numa-hits-statistics.patch.
- Delete patches.suse/mm-get-rid-of-__GFP_OTHER_NODE.patch.
- Delete
  patches.suse/mm-mmzone.c-swap-likely-to-unlikely-as-code-logic-is-different-for-next_zones_zonelist.patch.
- Delete
  patches.suse/mm-mprotect.c-don-t-touch-single-threaded-PTEs-which-are-on-the-right-node.patch.
- Delete patches.suse/sched-debug-always-show-nr_migrations.patch.
- Delete
  patches.suse/thp-fix-MADV_DONTNEED-vs.-numa-balancing-race.patch.
- Delete
  patches.suse/thp-reduce-indentation-level-in-change_huge_pmd.patch.
- commit 165d34d
* Tue Jul 18 2017 mhocko@suse.cz
- Refresh patches.suse/memcg-deprecate-memory.force_empty-knob.patch.
  forward ported. We still want to catch users who might depend on the
  knob
- commit a082540
* Tue Jul 18 2017 mhocko@suse.cz
- Delete patches.suse/memcg-introduce-low-limit-for-cgroupv1.patch.
  cgroup v2 is no longer in devel mode since
  34a9304a96d6351c2d35dcdc9293258378fc0bd8 (4.5)
- commit 3ed04d3
* Tue Jul 18 2017 nborisov@suse.com
- Disable CONFIG_XFS_RT (fate#321934)
- commit fede9b2
* Tue Jul 18 2017 jack@suse.cz
- Enable patches.fixes/fs-speedup-clean-bdev-aliases.patch: The issue has
  not been sorted out upstream yet.
- commit f565355
* Tue Jul 18 2017 jack@suse.cz
- Delete patches.fixes/md-Make-flush-bios-explicitely-sync.patch: Merged
  as commit 5a8948f8a32ba56c17b3fb75d318ac98157f3ba5 to 4.12-rc4.
- commit 064de7f
* Tue Jul 18 2017 jack@suse.cz
- Delete
  patches.fixes/btrfs-Make-flush-bios-explicitely-sync.patch: Merged as
  commit 8d91012528b3c95c159e6b6779e367421df9cbb5 to 4.12-rc5.
- commit 199953b
* Tue Jul 18 2017 jack@suse.cz
- Delete
  patches.fixes/reiserfs-Make-flush-bios-explicitely-sync.patch: Merged as
  commit d8747d642ec4ce96adf17ae35652a5e4015cfe02 to 4.12-rc4.
- commit 74f0ec4
* Tue Jul 18 2017 jack@suse.cz
- Delete
  patches.fixes/gfs2-Make-flush-bios-explicitely-sync.patch: Merged as
  0f0b9b63e14fc3f66e4d342df016c9b071c5abed to 4.12-rc4.
- commit 5260255
* Tue Jul 18 2017 mhocko@suse.cz
- Delete patches.suse/proc-show-MADV_FREE-pages-info-in-smaps.patch.
  merged as cf8496ea8020792ea32d0fbec0c140d8de93011a (4.12)
- commit 622d942
* Tue Jul 18 2017 jack@suse.cz
- Delete
  patches.fixes/x86-mm-fix-gup_pte_range-vs-DAX-mappings.patch: Merged as
  commit ef947b2529f918d9606533eb9c32b187ed6a5ede to 4.11-rc2
- commit 8edaf40
* Tue Jul 18 2017 mhocko@suse.cz
- Delete patches.suse/mm-enable-MADV_FREE-for-swapless-system.patch.
  merged as 93e06c7a645343d222c9a838834a51042eebbbf7 (4.12)
- commit f290c11
* Tue Jul 18 2017 msuchanek@suse.de
- Refresh ibmvnic patch metadata
  Also rename patches to 3 digit scheme.
- commit 1de7e2b
* Tue Jul 18 2017 mhocko@suse.cz
- Delete patches.suse/mm-reclaim-MADV_FREE-pages.patch.
  merged as 802a3a92ad7ac0b9be9df229dee530a1f0a8039b (4.12)
- commit 0086a29
* Tue Jul 18 2017 mhocko@suse.cz
- Delete patches.suse/mm-move-MADV_FREE-pages-into-LRU_INACTIVE_FILE-list.patch.
  merged as f7ad2a6cb9f7c4040004bedee84a70a9b985583e (4.12)
- commit 0d6a174
* Tue Jul 18 2017 jack@suse.cz
- Printk patches will be handled by Petr Mladek.
- commit 7aa5f41
* Tue Jul 18 2017 mhocko@suse.cz
- Delete patches.suse/mm-dont-assume-anonymous-pages-have-SwapBacked-flag.patch.
  merged as d44d363f65780f2ac2ec672164555af54896d40d (4.12)
- commit 66d14fb
* Tue Jul 18 2017 mhocko@suse.cz
- Delete patches.suse/mm-delete-unnecessary-TTU_-flags.patch
  merged as a128ca71fb29ed4444b80f38a0148b468826e19b (4.12)
- commit aa5cda3
* Tue Jul 18 2017 mhocko@suse.cz
- Refresh patches.fixes/mm-make-PR_SET_THP_DISABLE-immediately-active.patch
  forward-port
- commit 35db809
* Tue Jul 18 2017 jack@suse.cz
- Delete patches.suse/cgroup-Export-cgroup_is_descendant.patch: Commit
  b11cfb5807e30 in 4.5-rc1 made this obsolete.
- commit 229d877
* Tue Jul 18 2017 jack@suse.cz
- Delete
  patches.suse/xfs-silence-warnings-in-xfs-vm-releasepage.patch: Merged as
  commit 0a417b8dc1f10 to 4.10-rc4
- commit e4fddb8
* Tue Jul 18 2017 jack@suse.cz
- Delete patches.suse/kabi-Add-placeholder-to-vm_fault.patch: kABI
  placeholder not needed anymore since DAX patches are already in
  4.12.
- commit 7c85cca
* Tue Jul 18 2017 mhocko@suse.cz
- Delete patches.fixes/mm-fix-classzone_idx-underflow-in-shrink_zones.patch.
  obsolete by b2e18757f2c9
- commit 054b718
* Tue Jul 18 2017 mhocko@suse.cz
- Delete patches.suse/x86-mm-sched-make-lazy-TLB-mode-even-lazier-kabi.patch
  we do not need kabi workaround anymore
- commit a1b7ca1
* Tue Jul 18 2017 mhocko@suse.cz
- Refresh patches.fixes/mm-adaptive-hash-table-scaling.patch to the
  upstream version
- Delete patches.fixes/mm-adaptive-hash-table-scaling-fix.patch.
- Delete patches.fixes/mm-drop-HASH_ADAPT.patch.
  those were follow up fixes for the patch taken from the mmotm tree
- commit e8e2fc2
* Tue Jul 18 2017 jeffm@suse.com
- Refresh
  patches.suse/btrfs-8888-add-allow_unsupported-module-parameter.patch.
- commit dcc0c57
* Tue Jul 18 2017 jeffm@suse.com
- Refresh patches.suse/squashfs-3.4.patch.
- Delete
  patches.suse/squashfs3-properly-handle-dir_emit-failures.patch.
- commit d3a07b1
* Tue Jul 18 2017 nborisov@suse.com
- Refresh
  patches.suse/0001-Btrfs-skip-commit-transaction-if-we-don-t-have-enoug.patch.
- commit e762284
* Tue Jul 18 2017 msuchanek@suse.de
- Enable POWER patches from 4.13
- commit b709393
* Tue Jul 18 2017 msuchanek@suse.de
- Enable ibmvnic patches.
- commit 759126f
* Tue Jul 18 2017 jeffm@suse.com
- Refresh patches.suse/xfs-unsupported-features.patch.
- commit 02d7e1f
* Tue Jul 18 2017 jroedel@suse.de
- Delete patches.suse/x86-mm-sched-make-lazy-TLB-mode-even-lazier-kabi.patch.
- commit 178d687
* Tue Jul 18 2017 jeffm@suse.com
- Refresh patches.suse/ext4-unsupported-features.patch.
- commit 70b7452
* Tue Jul 18 2017 jeffm@suse.com
- Delete patches.suse/8250-sysrq-ctrl_o.patch.
  The SLE15 merge re-added this patch.  It was removed in:
  05568ac53a9 (Delete POWER4 specific patches.suse/8250-sysrq-ctrl_o.patch.)
- commit cf3419b
* Tue Jul 18 2017 jeffm@suse.com
- Refresh patches.suse/unsupported-features.patch.
- commit 658708b
* Tue Jul 18 2017 jeffm@suse.com
- Delete patches.rpmify/lustre-lloop-dont-change-logical-size.
  This patch was incomplete and LUSTRE_FS=n in any case.
- commit 0ba6419
* Tue Jul 18 2017 jeffm@suse.com
- Remove DMAPI patches (fate#320591).
- Delete
  patches.fixes/xfs-fix-buffer-overflow-dm_get_dirattrs.patch.
- Delete
  patches.fixes/xfs_dmapi-fix-the-debug-compilation-of-xfs_dmapi.patch.
- Delete patches.suse/dmapi-Make-NFSD-DMAPI-aware.patch.
- Delete patches.suse/dmapi-source.patch.
- Delete patches.suse/dmapi-support-for-xfs.patch.
- commit a1b6653
* Tue Jul 18 2017 jslaby@suse.cz
- series: turn away from some patches
  Once upon a time, I only touched those. Turn away from them now.
- commit 3b9f2a5
* Tue Jul 18 2017 jslaby@suse.cz
- Refresh
  patches.suse/0001-x86-entry-64-Refactor-IRQ-stacks-and-make-them-NMI-s.patch.
- Refresh
  patches.suse/0002-x86-entry-64-Initialize-the-top-of-the-IRQ-stack-bef.patch.
- Refresh
  patches.suse/0003-x86-dumpstack-fix-occasionally-missing-registers.patch.
- Refresh
  patches.suse/0004-x86-dumpstack-fix-interrupt-and-exception-stack-boun.patch.
- Refresh
  patches.suse/0005-objtool-add-ORC-unwind-table-generation.patch.
- Refresh
  patches.suse/0006-objtool-x86-add-facility-for-asm-code-to-provide-unw.patch.
- Refresh
  patches.suse/0007-x86-entry-64-add-unwind-hint-annotations.patch.
- Refresh
  patches.suse/0008-x86-asm-add-unwind-hint-annotations-to-sync_core.patch.
  Update upstream information.
- commit 8db850a
* Tue Jul 18 2017 msuchanek@suse.de
- Delete fadump patches which are in 4.12 and enable the rest.
- commit 53bf06b
* Tue Jul 18 2017 msuchanek@suse.de
- Refresh fadump patch metadata
- Refresh patches.arch/ia64-remove-multiple-definitions-of-append-elf.patch.
- Refresh patches.arch/move-crashkernel-and-vmcore-related-code-under-config_crash_dump.patch.
- Refresh patches.arch/powerpc-fadump-remove-dependency-with-kexec.patch.
- Refresh patches.arch/powerpc-fadump-reuse-crashkernel-parameter-to-reserve-memory.patch.
- Refresh patches.arch/powerpc-fadump-update-fadump-kernel-documentation.patch.
- commit 12d1968
* Tue Jul 18 2017 jkosina@suse.cz
- series.conf: manually fixup some of the missess of the automatic
  guard generation
- series.conf: move IOMMU AMD to Joerg
- commit 0900ac0
* Tue Jul 18 2017 msuchanek@suse.de
- Delete patches.arch/ACPICA-Update-TPM2-ACPI-table.patch.
  in 4.12
- commit 8224558
* Tue Jul 18 2017 jkosina@suse.cz
- series.conf: move intel_pstate-Increase-hold-off-time-before-samples-are-scaled.patch
  over to Mel as requested
- commit 8bc2621
* Tue Jul 18 2017 jkosina@suse.cz
- series.conf: make the forward-porting patch guards per-login (scripted)
- commit d3987bc
* Tue Jul 18 2017 msuchanek@suse.de
- Refresh metadata on recent powerpc patches.
- Refresh patches.arch/powerpc-Fix-proc-cpuinfo-revision-for-POWER9-DD2.patch.
- Refresh patches.arch/powerpc-perf-0026-Fix-branch-event-code-for-power9.patch.
- commit 54227b1
* Tue Jul 18 2017 msuchanek@suse.de
- Remove post-4.12 tpm patches.
  Should get these from stable updates.
- commit b857f37
* Tue Jul 18 2017 mmarek@suse.com
- Refresh and trim ppc64le and x86_64 debug configs
- commit 2f8eb87
* Tue Jul 18 2017 tiwai@suse.de
- Refresh and apply patches.drivers/b43-Add-missing-MODULE_FIRMWARE.
- commit 6878788
* Tue Jul 18 2017 tiwai@suse.de
- Delete patches.fixes/drm-i915-Fix-S4-resume-breakage.
  The workaround wasn't merged to upstream, and it seems becoming
  superfluous with the recent i915 driver, so let's drop this one.
- commit f5a35ab
* Tue Jul 18 2017 tiwai@suse.de
- Delete upstreamed or SLE12-specific patches
- commit c0b786f
* Tue Jul 18 2017 tiwai@suse.de
- rpm/kernel-docs.spec.in: Drop unnecessary xmlto for 4.13+
- commit e47dc84
* Tue Jul 18 2017 tiwai@suse.de
- rpm/kernel-docs.spec.in: Correct kernel-docs package summary/description
- commit 697b763
* Tue Jul 18 2017 tiwai@suse.de
- rpm/kernel-docs.spec.in: refresh dependencies for PDF build (bsc#1048129)
  But it still doesn't work with Tex Live 2017, thus disabled yet.
  Also add texlive-anyfontsize for HTML math handling.
- commit ead44a1
* Tue Jul 18 2017 jkosina@suse.cz
- Update config files: temporarily disable module signature verification (bsc#1049122)
- commit 59b1abb
* Tue Jul 18 2017 jslaby@suse.cz
- Delete
  patches.suse/kgr-0001-s390-livepatch-reorganize-TIF-bits.patch.
  This was in upstream as 30d64f1904d44a7e52a93d711d57aabbac2efd72.
- commit 2b93b5d
* Tue Jul 18 2017 jslaby@suse.cz
- Delete
  patches.arch/stack-unwind-cfi_ignore-takes-more-arguments.
- Delete patches.arch/x86_64-unwind-annotations.
- Delete
  patches.suse/revert-x86-remove-warning-and-warning_symbol-from-struct-stacktrace_ops.
- Delete patches.suse/stack-unwind.patch.
  Kill the old stack unwinding crap.
- commit 8eb0aae
* Tue Jul 18 2017 jslaby@suse.cz
- Delete patches.rpmify/drm-i915-disable-KASAN-for-handlers.patch.
  It was never accepted, is under discussion. But we disabled
  CONFIG_DRM_I915_WERROR in commit 5fc7b327348b, so we are safe anyway.
- commit 09fc05f
* Tue Jul 18 2017 jslaby@suse.cz
- Delete patches.rpmify/get_builtin_firmware-gcc-7.patch.
  This was never accepted. Instead this seems to be fixed in gcc.
- commit c486b10
* Mon Jul 17 2017 jeffm@suse.com
- Delete patches.drivers/ppc64-adb.
  This hardware was discontinued in 2006 and the patch was never accepted
  upstream.
- commit 38f5b34
* Mon Jul 17 2017 jeffm@suse.com
- Delete patches.arch/ppc-prom-nodisplay.patch.
  We no longer support 32-bit ppc and this hardware only existed with a
  32-bit CPU.
- commit 44570ac
* Mon Jul 17 2017 jeffm@suse.com
- Delete patches.arch/ppc-pegasos-console-autodetection.patch.
  We no longer support 32-bit ppc and this hardware only existed with a
  32-bit CPU.
- commit 9a9213c
* Mon Jul 17 2017 jeffm@suse.com
- Delete patches.suse/ppc-powerbook-usb-fn-key-default.patch.
  We no longer support 32-bit ppc and there were no 64-bit powerbooks.
- commit 550dc2e
* Mon Jul 17 2017 jkosina@suse.cz
- README.BRANCH: update branch information
- commit 895cf17
* Mon Jul 17 2017 jkosina@suse.cz
- Create SLE15 branch
- Branch off from stable
- Import all the patches from SLE12 codestream with unclear
  upstream status and mark them with 'needs_review' guard at
  the end of series.conf
- Initial import/merge configs from SLE12 codestream; needs verification
  to make sure no SLE12-enabled options are lost
- Patches which were left intact (conflict as they were in both
  branches):
  patches.suse/supported-flag
  patches.suse/genksyms-add-override-flag.diff
  patches.suse/vfs-add-super_operations-get_inode_dev
  patches.suse/suse-hv-guest-os-id.patch
  patches.suse/btrfs-fs-super.c-add-new-super-block-devices-super_block_d.patch
  patches.suse/btrfs-btrfs-use-the-new-VFS-super_block_dev.patch
  patches.drivers/pstore_disable_efi_backend_by_default.patch
  patches.suse/pstore-backend-autoaction
  patches.fixes/scsi-ibmvscsi-module_alias.patch
  patches.fixes/drm-i915-Fix-S4-resume-breakage
  patches.suse/iwlwifi-expose-default-fallback-ucode-api
  patches.suse/crasher.patch
  patches.suse/ftrace-x86-xen-use-kernel-identity-mapping-only-when.patch
- config.conf replaced from SLE12 codebase
- drop 'needs_review'-marked variants of patches which are already present and
  do apply cleanly from -stable branch already.
-  patches.arch/acpi_thermal_passive_blacklist.patch: update with version from
  stable branch to fix build.
- update README.BRANCH
- commit 2028ed7
* Mon Jul 17 2017 msuchanek@suse.de
- Refresh metadata of fadump patches
- Refresh patches.arch/powerpc-fadump-add-reschedule-point-while-releasing-memory.patch.
- Refresh patches.arch/powerpc-fadump-avoid-duplicates-in-crash-memory-ranges.patch.
- Refresh patches.arch/powerpc-fadump-avoid-holes-in-boot-memory-area-when-fadump-is-registered.patch.
- Refresh patches.arch/powerpc-fadump-provide-a-helpful-error-message.patch.
- commit 6f71027
* Mon Jul 17 2017 msuchanek@suse.de
- Refresh TPM and CXL patch metadata.
- Refresh patches.arch/ACPICA-Update-TPM2-ACPI-table.patch.
- Refresh patches.arch/cxl-Unlock-on-error-in-probe.patch.
- commit f1e3eba
* Mon Jul 17 2017 jslaby@suse.cz
- netfilter: expect: fix crash when putting uninited expectation
  (bnc#1048935).
- Delete
  patches.fixes/netfilter-nf_ct_expect-fix-expect-removal.patch.
  Replace by upstream fix (from a subsys repo).
- commit abad31d
* Mon Jul 17 2017 jslaby@suse.cz
- netfilter: nf_ct_expect: fix expect removal (bnc#1048935).
- commit 28fe876
* Mon Jul 17 2017 mmarek@suse.cz
- Drop multiversion(kernel) from the KMP template (fate#323189)
- commit 71504d8
* Sat Jul 15 2017 jslaby@suse.cz
- Linux 4.12.2 (bnc#1012628).
- commit 1b6adc0
* Wed Jul 12 2017 jslaby@suse.cz
- Linux 4.12.1 (bnc#1012628).
- commit 77712d8
* Tue Jul 11 2017 tiwai@suse.de
- rpm/kernel-docs.spec.in: Fix and cleanup for 4.13 doc build (bsc#1048129)
  The whole DocBook stuff has been deleted.  The PDF build still non-working
  thus the sub-packaging disabled so far.
- commit 8e7de10
* Mon Jul 10 2017 jslaby@suse.cz
- fs/fcntl: f_setown, avoid undefined behaviour (bnc#1006180).
- fs/fcntl: f_setown, allow returning error (bnc#1006180).
- commit c67ada2
* Mon Jul 10 2017 jslaby@suse.cz
- x86/entry/64: Refactor IRQ stacks and make them NMI-safe
  (bnc#1018348).
- x86/entry/64: Initialize the top of the IRQ stack before
  switching stacks (bnc#1018348).
- x86/dumpstack: fix occasionally missing registers (bnc#1018348).
- x86/dumpstack: fix interrupt and exception stack boundary checks
  (bnc#1018348).
  Update ORC to v3.
- commit dca9bfc
* Mon Jul 10 2017 jslaby@suse.cz
- Refresh
  patches.suse/0001-objtool-Move-checking-code-to-check.c.patch.
- Refresh
  patches.suse/0002-objtool-x86-Add-several-functions-and-files-to-the-o.patch.
- Refresh
  patches.suse/0003-objtool-Implement-stack-validation-2.0.patch.
- Refresh
  patches.suse/0004-objtool-Silence-warnings-for-functions-which-use-IRE.patch.
  Update upstream status.
- commit f413050
* Mon Jul 10 2017 jslaby@suse.cz
- rpm/kernel-docs.spec.in: temporary fix for 4.12 and later
  There is a little DocBook in 4.12 and none in 4.13. So remove creating
  the link.
- commit 1d6ee3e
* Tue Jul  4 2017 jslaby@suse.cz
- Refresh
  patches.fixes/tty-handle-the-case-where-we-cannot-restore-a-line-d.patch.
  Update upstream status.
- commit 50443d0
* Tue Jul  4 2017 jslaby@suse.cz
- Update to 4.12-final.
- commit f35ee68
* Mon Jul  3 2017 jslaby@suse.cz
- objtool: Silence warnings for functions which use IRET
  (bnc#1018348).
- Update config files.
- Refresh
  patches.suse/0002-dwarf-do-not-throw-away-unwind-info.patch.
  Push the new version of unDWARF unwinder which is now called Orc. The
  first 4 patches were accepted to the -tip tree, so they are marked
  appropriatelly.
- commit 48ca048
* Thu Jun 29 2017 jslaby@suse.cz
- Linux 4.11.8 (bnc#1012628).
- commit 42bd7a0
* Tue Jun 27 2017 tiwai@suse.de
- config/x86_64: Align 8250 serial configs for many ports (bsc#1024449)
- commit 7a8608e
* Mon Jun 26 2017 jeffm@suse.com
- Update to 4.12-rc7.
- commit aec31ef
* Mon Jun 26 2017 jslaby@suse.cz
- tty: Fix ldisc crash on reopened tty (bnc#1043488).
- commit 53c91b6
* Sun Jun 25 2017 afaerber@suse.de
- config: ARM: Consistently enable SPI_GPIO
  Bit-banging is needed when a SoC doesn't support native SPI or when such
  drivers are missing. SPI_GPIO was enabled for armv6hl and armv7hl default,
  but missing for armv7hl lpae and arm64. Set CONFIG_SPI_GPIO=m consistently.
- commit 8750062
* Sat Jun 24 2017 jslaby@suse.cz
- Linux 4.11.7 (bnc#1012628).
- commit ddd09a5
* Fri Jun 23 2017 jslaby@suse.cz
- drm/nouveau/gpio: enable interrupts on cards with 32 gpio lines
  (bnc#1045105).
- commit d61c66b
* Thu Jun 22 2017 jeffm@suse.com
- reiserfs: don't preallocate blocks for extended attributes
  (bsc#990682).
- commit ffd9401
* Thu Jun 22 2017 jeffm@suse.com
- reiserfs: don't preallocate blocks for extended attributes
  (bsc#990682).
- commit a4e55c0
* Thu Jun 22 2017 jeffm@suse.com
- reiserfs: Protect dquot_writeback_dquots() by s_umount semaphore
  (bsc#1037795).
- reiserfs: Make cancel_old_flush() reliable (bsc#1037795).
- commit 5e3bb37
* Thu Jun 22 2017 jeffm@suse.com
- config: VGACON_SOFT_SCROLLBACK_SIZE=128 (FATE#307471).
  This doubles the scrollback buffer on VGA consoles with only a little
  bit of memory cost.
- commit b8a18f3
* Thu Jun 22 2017 jslaby@suse.cz
- x86/unwind: add undwarf unwinder (bnc#1018348).
- Refresh
  patches.suse/0001-objtool-move-checking-code-to-check.c.patch.
- Refresh patches.suse/0003-objtool-stack-validation-2.0.patch.
- Refresh
  patches.suse/0004-objtool-add-undwarf-debuginfo-generation.patch.
- Delete
  patches.suse/0008-extable-rename-sortextable-script-to-sorttable.patch.
- Delete
  patches.suse/0009-extable-add-undwarf-table-sorting-ability-to-sorttab.patch.
- Delete patches.suse/0010-x86-unwind-add-undwarf-unwinder.patch.
  Refresh the UNDWARF unwinder according to usptream reviews. And add
  few fixes fro DRAP sequences again and handle more exceptions.
- commit 31d141e
* Tue Jun 20 2017 jeffm@suse.com
- btrfs: serialize subvolume mounts with potentially mismatching
  rw flags (bsc#951844 bsc#1024015).
- commit 638ee5d
* Tue Jun 20 2017 jjolly@suse.de
- Update config files.
- config.conf: Added s390x zfcpdump kernel
- commit 9bfc6ab
* Tue Jun 20 2017 jjolly@suse.de
- Update config files.
- config.conf: Added s390x zfcpdump kernel
- commit 5162e6c
* Tue Jun 20 2017 jeffm@suse.com
- Update to 4.12-rc6.
- commit 4d2b302
* Tue Jun 20 2017 jeffm@suse.com
- btrfs: add cond_resched to btrfs_qgroup_trace_leaf_items
  (bsc#1028286 bsc#1017461 bsc#1036171).
- commit 7d41685
* Tue Jun 20 2017 mmarek@suse.com
- Only set CONFIG_GCC_PLUGINS=y in kernel-syzkaller (boo#1043591)
- commit 1fffb22
* Tue Jun 20 2017 mmarek@suse.com
- Only set CONFIG_GCC_PLUGINS=y in kernel-syzkaller (boo#1043591)
- commit fe00c55
* Tue Jun 20 2017 mmarek@suse.com
- rpm/kernel-binary.spec.in: Only kernel-syzkaller needs gcc-devel
  (boo#1043591).
- commit d7ff041
* Mon Jun 19 2017 mcgrof@suse.com
- mm: kmemleak: treat vm_struct as alternative reference to vmalloc'ed objects (bsc#1027456).
- mm: kmemleak: factor object reference updating out of scan_block() (bsc#1027456).
- mm: kmemleak: slightly reduce the size of some structures on 64-bit architectures (bsc#1027456).
- commit 880dbd7
* Sat Jun 17 2017 jslaby@suse.cz
- Linux 4.11.6 (bnc#1012628).
- commit e566a4a
* Thu Jun 15 2017 mmarek@suse.com
- kabi.pl: Consider GPL vs. non-GPL exports (fate#322999)
- commit 8bde754
* Wed Jun 14 2017 jslaby@suse.cz
- Linux 4.11.5 (CVE-2017-1000380 bnc#1012628 bsc#1040041
  bsc#1044125 CVE-2017-7346 bsc#1031796).
- Delete
  patches.fixes/ALSA-timer-Fix-missing-queue-indices-reset-at-SNDRV_.
- Delete patches.fixes/ALSA-timer-Fix-race-between-read-and-ioctl.
- Delete
  patches.fixes/drm-vmwgfx-limit-the-number-of-mip-levels-in-vmw_gb_.patch.
- Delete
  patches.fixes/ptrace-Properly-initialize-ptracer_cred-on-fork.
- commit 8ffa6bb
* Tue Jun 13 2017 tiwai@suse.de
- ALSA: timer: Fix missing queue indices reset at
  SNDRV_TIMER_IOCTL_SELECT (CVE-2017-1000380,bsc#1044125).
- ALSA: timer: Fix race between read and ioctl
  (CVE-2017-1000380,bsc#1044125).
- commit 94096d3
* Tue Jun 13 2017 mmarek@suse.com
- rpm/kernel-module-subpackage: Generate proper supplements in the template
  ... instead of relying on find-provides.ksyms to do it (bsc#981083).
- commit b1fe840
* Mon Jun 12 2017 jeffm@suse.com
- Update to 4.12-rc5.
- Eliminated 1 patch.
- commit 270295f
* Mon Jun 12 2017 mmarek@suse.com
- rpm/kernel-source.spec.in: Do not list deleted depdendency helpers
  (bsc#981083).
- commit 9306efe
* Fri Jun  9 2017 mmarek@suse.com
- Define dependencies of in-kernel KMPs statically
  This allows us to use rpm's internal dependency generator (bsc#981083).
- commit 88d6128
* Fri Jun  9 2017 mmarek@suse.com
- rpm/find-provides: Delete, as /boot/vmlinux-* is no longer in -devel
- commit 4df55cc
* Fri Jun  9 2017 mmarek@suse.com
- rpm/package-descriptions: Import SLE12-SP3 KMP descriptions
- commit ff51a7c
* Wed Jun  7 2017 jslaby@suse.cz
- Linux 4.11.4 (CVE-2017-8890 CVE-2017-9074 CVE-2017-9075
  CVE-2017-9076 CVE-2017-9077 CVE-2017-9211 CVE-2017-9242
  bnc#1012628 bsc#1038544 bsc#1039882 bsc#1039883 bsc#1039885
  bsc#1040069 bsc#1040389 bsc#1041431).
- Delete
  patches.fixes/crypto-skcipher-Add-missing-API-setkey-checks.
- Delete
  patches.fixes/dccp-tcp-do-not-inherit-mc_list-from-parent.patch.
- Delete
  patches.fixes/ipv6-Check-ip6_find_1stfragopt-return-value-properly.patch.
- Delete
  patches.fixes/ipv6-Prevent-overrun-when-parsing-v6-header-options.patch.
- Delete
  patches.fixes/ipv6-dccp-do-not-inherit-ipv6_mc_list-from-parent.patch.
- Delete
  patches.fixes/ipv6-fix-out-of-bound-writes-in-__ip6_append_data.patch.
- Delete
  patches.fixes/sctp-do-not-inherit-ipv6_-mc-ac-fl-_list-from-parent.patch.
- commit cba98ee
* Wed Jun  7 2017 mkubecek@suse.cz
- Update upstream reference:
  patches.fixes/virtio_net-lower-limit-on-buffer-size.patch.
- commit 922d3e3
* Tue Jun  6 2017 jslaby@suse.cz
- tty: handle the case where we cannot restore a line discipline
  (bnc#1042878).
- commit 9273e2f
* Tue Jun  6 2017 mkubecek@suse.cz
- usb/early: Remove trace_printk() callers in xhci-dbc
  (bsc#1042295).
- commit 52a1432
* Tue Jun  6 2017 mkubecek@suse.cz
- virtio_net: lower limit on buffer size (bsc#1042717).
- commit a3aa4ed
* Tue Jun  6 2017 jslaby@suse.cz
- Update config files.
  Disable CONFIG_DRM_I915_WERROR, i.e. -Werror in i915. It causes build
  failures in -syzkaller flavor due to a bit oversized frames:
  drivers/gpu/drm/i915/intel_dpll_mgr.c:1548:1: error: the frame size of 2240 bytes is larger than 2048 bytes
- commit 5fc7b32
* Tue Jun  6 2017 mkubecek@suse.cz
- series.conf: better section label (networking core)
- commit 05ee05a
* Tue Jun  6 2017 mkubecek@suse.cz
- ipv6: fix out of bound writes in __ip6_append_data()
  (CVE-2017-9242 bsc#1041431).
- commit 26cd5c8
* Mon Jun  5 2017 pjakobsson@suse.de
- drm/vmwgfx: limit the number of mip levels in
  vmw_gb_surface_define_ioctl() (CVE-2017-7346 bsc#1031796).
- commit dfa88a5
* Mon Jun  5 2017 msuchanek@suse.de
- rpm/kernel-binary.spec: remove superfluous flags
  This should make build logs more readable and people adding more flags
  should have easier time finding a place to add them in the spec file.
- commit 13e40fa
* Mon Jun  5 2017 jslaby@suse.cz
- Update
  patches.fixes/0001-SUNRPC-Refactor-svc_set_num_threads.patch
  (bsc#1039674 CVE-2017-9059).
- Update
  patches.fixes/0002-NFSv4-Fix-callback-server-shutdown.patch
  (bsc#1039674 CVE-2017-9059).
  Fix References tags.
- commit bf7afe3
* Mon Jun  5 2017 jslaby@suse.cz
- Refresh
  patches.suse/0002-objtool-x86-add-several-functions-and-files-to-the-o.patch.
- Refresh patches.suse/0003-objtool-stack-validation-2.0.patch.
- Refresh
  patches.suse/0004-objtool-add-undwarf-debuginfo-generation.patch.
- Refresh
  patches.suse/0005-objtool-x86-add-facility-for-asm-code-to-provide-CFI.patch.
  Handle more DRAP sequences correctly.
- commit 0a00faf
* Mon Jun  5 2017 msuchanek@suse.de
- kernel-binary.spec: Propagate MAKE_ARGS to %%build (bsc#1012422)
- commit 6171b7a
* Mon Jun  5 2017 jeffm@suse.com
- Update to 4.12-rc4.
- Eliminated 1 patch.
- commit f198de4
* Fri Jun  2 2017 afaerber@suse.de
- rpm/dtb.spec.in.in: Fix new include path
  Commit 89de3db69113d58cdab14d2c777de6080eac49dc ("rpm/dtb.spec.in.in:
  Update include path for dt-bindings") introduced an additional include
  path for 4.12. The commit message had it correct, but the spec file
  template lacked a path component, breaking the aarch64 build while
  succeeding on armv7hl. Fix that.
- commit 36b7480
* Fri Jun  2 2017 mmarek@suse.com
- rpm/kernel-source.spec.in: Drop patches.{trace,xen}.tar.bz2
  These are empty in current branches.
- commit 742f1d0
* Wed May 31 2017 afaerber@suse.de
- rpm/dtb.spec.in.in: Update include path for dt-bindings
  Kernels before 4.12 had arch/{arm,arm64}/boot/dts/include/ directories
  with a symlink to include/dt-bindings/.
  In 4.12 those include/ directories were dropped.
  Therefore use include/ directly.
  Additionally some cross-architecture .dtsi reuse was introduced, which
  requires scripts/dtc/include-prefixes/ that didn't exist on older kernels.
- commit 89de3db
* Wed May 31 2017 jslaby@suse.cz
- objtool: move checking code to check.c (bnc#1018348).
- objtool, x86: add several functions and files to the objtool
  whitelist (bnc#1018348).
- objtool: stack validation 2.0 (bnc#1018348).
- objtool: add undwarf debuginfo generation (bnc#1018348).
- objtool, x86: add facility for asm code to provide CFI hints
  (bnc#1018348).
- x86/entry: add CFI hint undwarf annotations (bnc#1018348).
- x86/asm: add CFI hint annotations to sync_core() (bnc#1018348).
- extable: rename 'sortextable' script to 'sorttable'
  (bnc#1018348).
- extable: add undwarf table sorting ability to sorttable script
  (bnc#1018348).
- x86/unwind: add undwarf unwinder (bnc#1018348).
- Delete patches.arch/x86_64-unwind-annotations.
- Update config files.
  Switch from DWARF to unDWARF. This is the way upstream wants us to go.
  We can drop patches.arch/x86_64-unwind-annotations now as it is
  superseded by the patchset:
  1) Objtool generates info for assembly now.
  2) Manual annotations are put to places where objtool gets lost.
  This version is RFC submitted upstream.
  DWARF unwinder is not dropped on the floor yet, just commented out.
  Let's see how this works out and drop it then. So far both
  task-context and the interrupt-context traces look good (TM).
  unDWARF is supported only on x86_64 so far.
- commit ac3e118
* Tue May 30 2017 bpoirier@suse.com
- Refresh
  patches.drivers/e1000e-Don-t-return-uninitialized-stats.patch.
  Update link.
- commit fe56f0b
* Tue May 30 2017 bpoirier@suse.com
- Refresh
  patches.drivers/e1000e-Don-t-return-uninitialized-stats.patch.
  Fix incorrect tag.
- commit 7bbd095
* Tue May 30 2017 afaerber@suse.de
- config: armv7hl: Update to v4.12-rc3
- commit 8cfaade
* Tue May 30 2017 afaerber@suse.de
- config: armv6hl: Update to v4.12-rc3
- commit f8dbef0
* Tue May 30 2017 afaerber@suse.de
- config: arm64: Update to v4.12-rc3
  Harmonize the display drivers while at it.
- commit 305b5bb
* Mon May 29 2017 mkubecek@suse.cz
- drm/i915: Fix new -Wint-in-bool-context gcc compiler warning.
- commit d41a006
* Mon May 29 2017 mkubecek@suse.cz
- Update to 4.12-rc3.
- Eliminated 1 patch.
- commit 383e7eb
* Mon May 29 2017 neilb@suse.com
- NFSv4: Fix callback server shutdown (bsc#1039675,
  CVS#2017-9059).
- SUNRPC: Refactor svc_set_num_threads() (bsc#1039675,
  CVS#2017-9059).
- commit 596757c
* Fri May 26 2017 afaerber@suse.de
- config: arm64: Make PINCTRL_SINGLE built-in
  This fixes serial console on the HiKey board (bsc#1040492).
  (cherry picked from commit 02f57029be80cfec078617f5dbb4022ea5931ac3)
- config: arm64: Make PINCTRL_SINGLE built-in
  This fixes serial console on the HiKey board (bsc#1040492).
- commit 36186ce
* Fri May 26 2017 mkubecek@suse.cz
- Update to 4.12-rc2
- Eliminated 32 patches.
- ARM configs need updating.
- OSS (sound) support marked broken
- Config changes:
  - Kernel hacking:
  - EARLY_PRINTK_USB_XDBC=y
  - Block:
  - BFQ_GROUP_IOSCHED=y
  - BLK_DEV_THROTTLING_LOW=n (experimental)
  - DM_INTEGRITY=m
  - IOSCHED_BFQ=y
  - MQ_IOSCHED_KYBER=y
  - Filesystems:
  - UBIFS_FS_SECURITY=y
  - Networking:
  - NET_9P_XEN=m
  - NET_SCH_DEFAULT=n (for custom builds)
  - Network drivers:
  - BT_HCIUART_NOKIA=m
  - CAN_HI311X=m
  - CAN_MCBA_USB=m
  - CAN_PEAK_PCIEFD=m
  - CAN_VXCAN=m
  - DWC_XLGMAC=m
  - DWC_XLGMAC_PCI=m
  - IEEE802154_CA8210=m
  - IEEE802154_CA8210_DEBUGFS=n
  - MDIO_DEVICE=m
  - MLX5_CORE_IPOIB=y
  - NET_VENDOR_SYNOPSYS=y
  - RTL8723BS=m
  - TIGON3_HWMON=y
  - VSOCKMON=m
  - DRM:
  - BACKLIGHT_ARCXCNN=m
  - DM_INTEGRITY=m
  - DRM_FBDEV_OVERALLOC=100 (default)
  - DRM_I915_DEBUG_VBLANK_EVADE=n (driver debugging)
  - DRM_I915_LOW_LEVEL_TRACEPOINTS=n (driver debugging)
  - DRM_I915_SELFTEST=n (driver debugging)
  - Sound:
  - SND_FIREFACE=m
  - SND_FIREWIRE_MOTU=m
  - SND_I2S_HI6210_I2S=m
  - SND_SOC_ADAU1761_I2C=n
  - SND_SOC_ADAU1761_SPI=n
  - SND_SOC_CS35L35=m
  - SND_SOC_DA7213=m
  - SND_SOC_DIO2125=n
  - SND_SOC_ES7134=n
  - SND_SOC_INTEL_BYT_CHT_DA7213_MACH=m
  - SND_SOC_INTEL_BYT_CHT_NOCODEC_MACH=m
  - SND_SOC_MAX98927=n
  - SND_SOC_NAU8824=m
  - PCI:
  - PCI_ENDPOINT=y
  - PCI_ENDPOINT_CONFIGFS=n
  - PCI_ENDPOINT_TEST=m
  - PCI_EPF_TEST=m
  - PCI_SW_SWITCHTEC=m
  - USB:
  - TYPEC_FUSB302=m
  - TYPEC_TCPCI=m
  - TYPEC_TCPM=m
  - TYPEC_WCOVE=m
  - USB_PCI=y
  - NVM:
  - NVM_PBLK=m
  - Power supply:
  - BATTERY_AXP20X=m
  - CHARGER_AXP20X=m
  - Multimedia:
  - CEC_PLATFORM_DRIVERS=y
  - IR_SIR=m (renamed LIRC_SIR)
  - MEDIA_CEC_RC=y
  - USB_RAINSHADOW_CEC=m
  - VIDEO_OV2640=m (renamed SOC_CAMERA_OV2640)
  - Input:
  - JOYSTICK_PSXPAD_SPI=m
  - JOYSTICK_PSXPAD_SPI_FF=y
  - MOUSE_PS2_SYNAPTICS_SMBUS=y
  - TOUCHSCREEN_TSC2007_IIO=y
  - Hardware monitoring:
  - SENSORS_ASPEED=m
  - DAX:
  - DAX=y
  - EDAC:
  - EDAC_GHES=n (causes problems, ask bpetkov)
  - Crypto:
  - SYSTEM_BLACKLIST_KEYRING=n
  - HID:
  - HID_ACCUTOUCH=m
  - HID_NTI=m
  - HID_SENSOR_HUMIDITY=m
  - HID_SENSOR_TEMP=m
  - Industrial I/O
  - AXP20X_ADC=m
  - LTC2497=n
  - LTC2632=n
  - MAX1118=n
  - MAX30102=m
  - MAX9611=n
  - SRF04=m
  - VL6180=m
  - Thermal:
  - THERMAL_EMERGENCY_POWEROFF_DELAY_MS=0
  - I2C:
  - I2C_MUX_LTC4306=m
  - IB:
  - INFINIBAND_OPA_VNIC=m
  - Staging:
  - LNET_XPRT_IB=m
  - Xen:
  - XEN_PV=y
  - x86:
  - DELL_WMI_LED=m (renamed LEDS_DELL_NETBOOKS)
  - INTEL_CHT_INT33FE=m
  - X86_MCELOG_LEGACY=y
  - Misc:
  - ALTERA_PR_IP_CORE=m
  - CHARLCD=m
  - FPGA_MGR_XILINX_SPI=m
  - HD44780=m
  - INTEL_SOC_PMIC_BXTWC=m
  - MFD_TI_LMU=m
  - MMC_SDHCI_XENON=m
  - RAS_CEC=y
  - RESET_IMX7=n
  - W1_SLAVE_DS2438=m
  - XPOWER_PMIC_OPREGION=y
  - ppc64le:
  - ARCH_MMAP_RND_BITS=14
  - ARCH_MMAP_RND_COMPAT_BITS=7
  - CRYPTO_CRCT10DIF_VPMSUM=n
  - CRYPTO_DEV_CCREE=n
  - DA9062_THERMAL=n
  - DRM_LVDS_ENCODER=n
  - DRM_MEGACHIPS_STDPXXXX_GE_B850V3_FW=n
  - DRM_RCAR_DW_HDMI=n
  - FA_DUMP=n
  - FPGA_MGR_ICE40_SPI=n
  - GPIO_FTGPIO010=n
  - KPROBES_ON_FTRACE=y
  - LEDS_LP3952=n
  - PPC_DT_CPU_FTRS=n
  - PPC_XIVE_NATIVE=y
  - THREAD_SHIFT=14
  - XILINX_PR_DECOUPLER=n
  - s390x:
  - ARCH_RANDOM=y
  - ATA=n
  - DEFERRED_STRUCT_PAGE_INIT=n
  - MAX_PHYSMEM_BITS=46
  - S390_CCW_IOMMU=n
- commit a8e0ac1
* Thu May 25 2017 jslaby@suse.cz
- Linux 4.11.3 (CVE-2017-7487 bnc#1012628 bsc#1038879).
- Delete
  patches.fixes/ipx-call-ipxitf_put-in-ioctl-error-path.patch.
- commit 7262353
* Thu May 25 2017 tiwai@suse.de
- Refresh patches.fixes/ptrace-Properly-initialize-ptracer_cred-on-fork.
  Update patch-mainline and git-commit tags.
- commit 2182e18
* Wed May 24 2017 mkubecek@suse.cz
- ipv6/dccp: do not inherit ipv6_mc_list from parent
  (CVE-2017-9076 CVE-2017-9077 bsc#1039885 bsc#1040069).
- commit fcae12e
* Wed May 24 2017 mkubecek@suse.cz
- sctp: do not inherit ipv6_{mc|ac|fl}_list from parent
  (CVE-2017-9075 bsc#1039883).
- commit 9f0e1bf
* Wed May 24 2017 mkubecek@suse.cz
- ipv6: Check ip6_find_1stfragopt() return value properly
  (CVE-2017-9074 bsc#1039882).
- ipv6: Prevent overrun when parsing v6 header options
  (CVE-2017-9074 bsc#1039882).
- commit 1862833
* Wed May 24 2017 mkubecek@suse.cz
- ipx: call ipxitf_put() in ioctl error path (CVE-2017-7487
  bsc#1038879).
- commit 01283ea
* Wed May 24 2017 mkubecek@suse.cz
- dccp/tcp: do not inherit mc_list from parent (CVE-2017-8890
  bsc#1038544).
- commit cedfd44
* Tue May 23 2017 tiwai@suse.de
- crypto: skcipher - Add missing API setkey checks
  (bsc#1040389,CVE-2017-9211).
- commit a536fda
* Tue May 23 2017 tiwai@suse.de
- ptrace: Properly initialize ptracer_cred on fork (bsc#1040041).
- commit d5c0513
* Sat May 20 2017 jslaby@suse.cz
- Linux 4.11.2 (bnc#1012628).
- commit 03903d8
* Fri May 19 2017 tiwai@suse.de
- Update config files: set HD-audio power save as default (boo#1039995).
- commit ba31213
* Fri May 19 2017 jdelvare@suse.de
- Revert "drm/amdgpu: update tile table for oland/hainan"
  (boo#1027378, boo#1039806).
- commit 455115d
* Mon May 15 2017 jslaby@suse.cz
- Linux 4.11.1 (bnc#1012628 bnc#1038615).
- Delete
  patches.fixes/refcount-change-EXPORT_SYMBOL-markings.patch.
- commit c31e8e6
* Fri May 12 2017 jthumshirn@suse.de
- IB/rxe: Don't clamp residual length to mtu (boo#1030941).
- commit 89c1e48
* Thu May 11 2017 jslaby@suse.cz
- refcount: change EXPORT_SYMBOL markings (bnc#1038615).
- commit 8acb5bf
* Wed May 10 2017 jeffm@suse.com
- config: disable XFS_RT
- commit 98d6a9a
* Mon May  8 2017 jdelvare@suse.de
- config: armv6hl: Disable KEYBOARD_TM2_TOUCHKEY
  The Samsung TM2 board is based on an Exynos SoC, which the armv6
  kernel does not support.
- commit 38e6377
* Sat May  6 2017 stefan.bruens@rwth-aachen.de
- config: arm64: Enable MEDIA_CONTROLLER API
  Option is already set on armv7hl/armv6hl.
- commit efe309e
* Sat May  6 2017 stefan.bruens@rwth-aachen.de
- config: arm64: Enable SND_SOC and codecs
  Config mimics armv7hl, save any differences due to less SoCs supported
  by arm64.
  [AF: Rebased onto v4.12-rc3]
- commit 214bcc6
* Thu May  4 2017 bpoirier@suse.com
- e1000e: Don't return uninitialized stats (bug#1034635).
- commit 836a5a5
* Thu May  4 2017 bpoirier@suse.com
- e1000e: Don't return uninitialized stats (bug#1034635).
- commit 07b59a7
* Wed May  3 2017 msuchanek@suse.de
- kernel-binary.spec Remove superfluous [].
- commit 0bf8e9f
* Tue May  2 2017 msuchanek@suse.de
- Use make --output-sync feature when available (bsc#1012422).
  The mesages in make output can interleave making it impossible to
  extract warnings reliably. Since version 4 GNU Make supports
  - -output-sync flag that prints output of each sub-command atomically
  preventing this issue. Detect the flag and use it if available.
  SLE11 has make 3.81 so it is required to include make 4 in the kernel
  OBS projects to take advantege of this.
- commit 8c2f46d
* Tue May  2 2017 tiwai@suse.de
- Set CONFIG_CRYPTO_MD5=y for a better diagnoise at S4 resume (bsc#1031893).
- commit 0ecb407
* Mon May  1 2017 jeffm@suse.com
- Update to 4.11-final.
- commit adde629
* Fri Apr 28 2017 mkubecek@suse.cz
- supported.conf: move ipvs modules from cluster-network-kmp to kernel packages (fate#323221)
- commit 3b2c2cd
* Fri Apr 28 2017 jdelvare@suse.de
- Update x86 config files: disable SILEAD_DMI
  The silead_dmi "driver" is in an horrible shape. The design is pretty
  bad and the implementation is poor, to stay polite. I wish such code
  would not make it into the upstream kernel in the first place. I
  don't want it to run on any openSUSE system until it is fixed.
- commit ec41301
* Thu Apr 27 2017 jslaby@suse.cz
- Linux 4.10.13 (bnc#1012628).
- commit e5d11ce
* Wed Apr 26 2017 tiwai@suse.de
- platform/x86: dell-laptop: Add keyboard backlight timeout AC
  settings (bsc#1013561).
- commit 7aedba7
* Wed Apr 26 2017 mkubecek@suse.cz
- macsec: avoid heap overflow in skb_to_sgvec (CVE-2017-7477
  bsc#1035823).
- commit 461b1f0
* Tue Apr 25 2017 mmarek@suse.com
- rpm/kernel-binary.spec.in: Do not split KMPs for openSUSE (fate#319339)
- commit a259f75
* Tue Apr 25 2017 mmarek@suse.com
- rpm/dtb.spec.in.in: Do not depend on kernel-source (bsc#1034066)
  Apply the patches during build, just like kernel-binary.spec.in does.
- commit 4e37db7
* Mon Apr 24 2017 jeffm@suse.com
- Update to 4.11-rc8.
- commit 20b036c
* Mon Apr 24 2017 tiwai@suse.de
- Disable CONFIG_POWER_SUPPLY_DEBUG in debug kernels (bsc#1031500).
- commit 11b3f7c
* Mon Apr 24 2017 tiwai@suse.de
- Disable CONFIG_POWER_SUPPLY_DEBUG in debug kernels (bsc#1031500).
- commit d90dab6
* Mon Apr 24 2017 mkubecek@suse.cz
- supported.conf: sync core networking with SLE12-SP3
- commit e3b9ed8
* Fri Apr 21 2017 jslaby@suse.cz
- Linux 4.10.12 (bnc#1012628 bsc#1031935 bsc#1032285).
- Delete
  patches.fixes/drm-fb-helper-Allow-var-x-yres-_virtual-fb-width-hei.
- Delete
  patches.fixes/drm-nouveau-kms-nv50-fix-double-dma_fence_put-when-d.
- commit 3043bd9
* Thu Apr 20 2017 tiwai@suse.de
- Input: soc_button_array - properly map usage 0x07/0xe3 to
  KEY_LEFTMETA (boo#1019337,boo#1034642).
- Input: soc_button_array - add support for ACPI 6.0 Generic
  Button Device (boo#1019337,boo#1034642).
- Input: soc_button_array - get rid of MAX_NBUTTONS
  (boo#1019337,boo#1034642).
- Input: soc_button_array - Propagate error from gpiod_count()
  (boo#1019337,boo#1034642).
- Input: soc_button_array - use NULL for GPIO connection ID
  (boo#1019337,boo#1034642).
- commit 5e4b2c2
* Thu Apr 20 2017 tiwai@suse.de
- Input: axp20x-pek - do not register input device on some systems
  (bsc#1035040,boo#1019337).
- Input: axp20x_pek - add axp20x_pek_probe_input_device helper
  (bsc#1035040,boo#1019337).
- Input: axp20x-pek - use our own device for errors
  (bsc#1035040,boo#1019337).
- commit 9642058
* Thu Apr 20 2017 tiwai@suse.de
- i2c: designware-baytrail: fix potential null pointer dereference
  on dev (boo#1026458,bsc#1011913).
- i2c: designware: Get selected speed mode sda-hold-time via ACPI
  (boo#1026458,bsc#1011913).
- i2c: designware: Disable pm for PMIC i2c-bus even if there is
  no _SEM method (boo#1026458,bsc#1011913).
- i2c: designware: Never suspend i2c-busses used for accessing
  the system PMIC (boo#1026458,bsc#1011913).
- i2c-designware: increase timeout of semaphore transfer
  (boo#1026458,bsc#1011913).
- drm/i915: Listen for PMIC bus access notifications
  (boo#1026458,bsc#1011913).
- drm/i915: Add intel_uncore_suspend / resume functions
  (boo#1026458,bsc#1011913).
- i2c: designware-baytrail: Call pmic_bus_access_notifier_chain
  (boo#1026458,bsc#1011913).
- i2c: designware-baytrail: Acquire P-Unit access on bus acquire
  (boo#1026458,bsc#1011913).
- i2c: designware-baytrail: Add support for cherrytrail
  (boo#1026458,bsc#1011913).
- i2c: designware-baytrail: Fix race when resetting the semaphore
  (boo#1026458,bsc#1011913).
- i2c: designware-baytrail: Disallow the CPU to enter C6 or C7
  while holding the punit semaphore (boo#1026458,bsc#1011913).
- i2c: designware-baytrail: Only check iosf_mbi_available()
  for shared hosts (boo#1026458,bsc#1011913).
- i2c: designware-baytrail: Pass dw_i2c_dev into helper functions
  (boo#1026458,bsc#1011913).
- i2c: designware: Rename accessor_flags to flags
  (boo#1026458,bsc#1011913).
- x86/platform/intel/iosf_mbi: Add a PMIC bus access notifier
  (boo#1026458,bsc#1011913).
- x86/platform/intel/iosf_mbi: Add a mutex for P-Unit access
  (boo#1026458,bsc#1011913).
- commit 72f33ac
* Thu Apr 20 2017 tiwai@suse.de
- HID: asus: change mapping from KEY_WLAN to KEY_RFKILL
  (bsc#1026458).
- HID: asus: ignore declared dummy usages (bsc#1026458).
- HID: asus: fix and generalize ambiguous preprocessor macros
  (bsc#1026458).
- HID: asus: support Republic of Gamers special keys
  (bsc#1026458).
- HID: asus: drop dependency on I2C_HID (bsc#1026458).
- commit b794289
* Thu Apr 20 2017 tiwai@suse.de
- Enable CONFIG_INTEL_SOC_PMIC and CONFIG_PMIC_OPREGION (boo#1035040).
  Some of these configs are built-in only, unfortunately, and consequently
  it requires CONFIG_MFD_CORE=y, too.
- commit a2ce90f
* Thu Apr 20 2017 tiwai@suse.de
- Enable configs for AXP I2C stuff on Cherrytail devices (boo#1035040).
- commit 636bfd4
* Thu Apr 20 2017 tiwai@suse.de
- Enable CONFIG_INPUT_SOC_BUTTON_ARRAY for x86 (boo#1034642).
- commit a7fc032
* Wed Apr 19 2017 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Do not sign modules if CONFIG_MODULE_SIG=n (bsc#1035053)
- commit 50db9ef
* Wed Apr 19 2017 jeffm@suse.com
- Update to 4.11-rc7.
- commit 6e80a14
* Wed Apr 19 2017 afaerber@suse.de
- config: arm64: Enable SUN8I_H3_CCU for Allwinner H5
- commit 967bdfb
* Tue Apr 18 2017 tiwai@suse.de
- Enable CONFIG_KXCJK1013 for Cherrytrail devices (boo#1034809).
- commit 9add148
* Tue Apr 18 2017 jslaby@suse.cz
- Linux 4.10.11 (CVE-2017-7308 bnc#1012628 bsc#1031579).
- Delete
  patches.fixes/net-packet-fix-overflow-in-check-for-priv-area-size.patch.
- commit bd70196
* Thu Apr 13 2017 afaerber@suse.de
- config: ARM: Make SERIAL_DEV_BUS built-in
- Makes available SERIAL_DEV_CTRL_TTYPORT
- commit 2cea027
* Thu Apr 13 2017 afaerber@suse.de
- rpm/dtb.spec.in.in: Enable overlay support for Tumbleweed and Leap 42.3
- Generate __symbols__ node to allow resolution of labels in overlays
- commit c94e646
* Wed Apr 12 2017 jslaby@suse.cz
- Linux 4.10.10 (CVE-2017-7261 CVE-2017-7294 bnc#1012628
  boo#1031052 boo#1031440).
- Delete
  patches.drivers/drm-vmwgfx-NULL-pointer-dereference-in-vmw_surface_define_ioctl.patch.
- Delete
  patches.drivers/drm-vmwgfx-fix-integer-overflow-in-vmw_surface_define_ioctl.patch.
- commit a78ebd0
* Tue Apr 11 2017 tiwai@suse.de
- drm/nouveau/kms/nv50: fix double dma_fence_put() when destroying
  plane state (bsc#1032285).
- commit 739eada
* Mon Apr 10 2017 jeffm@suse.com
- Update to 4.11-rc6.
- Eliminated 2 patches.
- commit 5a51416
* Sun Apr  9 2017 afaerber@suse.de
- config: armv7hl: Enable i.MX 7 ADC
- commit 5e1975a
* Sat Apr  8 2017 afaerber@suse.de
- config: armv7hl: Update for 4.11-rc5
- commit 4559861
* Sat Apr  8 2017 afaerber@suse.de
- config: armv6hl: Update to 4.11-rc5
- commit 9a48325
* Sat Apr  8 2017 jslaby@suse.cz
- Linux 4.10.9 (CVE-2017-7187 bnc#1012628 bsc#1030213).
- Delete
  patches.fixes/scsi-sg-check-length-passed-to-sg_next_cmd_len.patch.
- commit 195f937
* Fri Apr  7 2017 mmarek@suse.com
- Sync i386/debug with i386/pae
  CONFIG_HWMON=y
  CONFIG_LGUEST_GUEST=y
  CONFIG_PATA_LEGACY=n
  CONFIG_USB_OHCI_HCD_SSB=y
- commit 067b87b
* Fri Apr  7 2017 mmarek@suse.com
- Disable CONFIG_ISA in i386/debug to sync with pae.
- commit 9433586
* Fri Apr  7 2017 mmarek@suse.com
- Use fragment configs for debug and i386/default.
- commit 32643f4
* Fri Apr  7 2017 stefan.bruens@rwth-aachen.de
- config: ARM: Enable TI INA2xx current/voltage sensors
  [AF: Disable hwmon driver; enable for armv6hl and armv7hl lpae, too]
- commit 08a83e7
* Thu Apr  6 2017 rgoldwyn@suse.com
- btrfs: qgroups: Retry after commit on getting EDQUOT
  (bsc#1019614).
- commit 05ecabb
* Mon Apr  3 2017 mstaudt@suse.de
- drm/vmwgfx: fix integer overflow in vmw_surface_define_ioctl()
  (boo#1031440 CVE-2017-7294).
- drm/vmwgfx: NULL pointer dereference in
  vmw_surface_define_ioctl() (boo#1031052 CVE-2017-7261).
- drm/vmwgfx: fix integer overflow in vmw_surface_define_ioctl()
  (boo#1031440 CVE-2017-7294).
- drm/vmwgfx: NULL pointer dereference in
  vmw_surface_define_ioctl() (boo#1031052 CVE-2017-7261).
- commit eb4ae7d
* Mon Apr  3 2017 jeffm@suse.com
- Update to 4.11-rc5.
- Eliminated 1 patch.
- commit a0b8e6b
* Mon Apr  3 2017 jthumshirn@suse.de
- scsi: sg: check length passed to SG_NEXT_CMD_LEN (bsc#1030213,
  CVE-2017-7187).
- commit 64f4c97
* Mon Apr  3 2017 jthumshirn@suse.de
- scsi: sg: check length passed to SG_NEXT_CMD_LEN (bsc#1030213,
  CVE-2017-7187).
- commit 4dc7b4d
* Fri Mar 31 2017 mkubecek@suse.cz
- Update patches.kernel.org/patch-4.10.7-8 references (add CVE-2017-7184 bsc#1030573).
- commit ea9dcd4
* Fri Mar 31 2017 mkubecek@suse.cz
- tcp: mark skbs with SCM_TIMESTAMPING_OPT_STATS (CVE-2017-7277
  bsc#1031265).
- tcp: fix SCM_TIMESTAMPING_OPT_STATS for normal skbs
  (CVE-2017-7277 bsc#1031265).
- commit 37681e8
* Fri Mar 31 2017 mkubecek@suse.cz
- net/packet: fix overflow in check for tp_reserve (CVE-2017-7308
  bsc#1031579).
- net/packet: fix overflow in check for tp_frame_nr (CVE-2017-7308
  bsc#1031579).
- net/packet: fix overflow in check for priv area size
  (CVE-2017-7308 bsc#1031579).
- commit fbe9fc9
* Fri Mar 31 2017 tiwai@suse.de
- drm/fb-helper: Allow var->x/yres(_virtual) < fb->width/height
  again (bsc#1031935).
- commit 62e9602
* Fri Mar 31 2017 mkubecek@suse.cz
- ping: implement proper locking (bsc#1031003).
- commit 3ea493f
* Fri Mar 31 2017 jslaby@suse.cz
- Linux 4.10.8 (bnc#1012628).
- commit fd89662
* Fri Mar 31 2017 lpechacek@suse.com
- doc/README.SUSE: update links to KMP manual
- commit 9ab365a
* Thu Mar 30 2017 jslaby@suse.cz
- drm/i915: disable KASAN for handlers (bnc#1025903).
- commit 28152f5
* Thu Mar 30 2017 jslaby@suse.cz
- Linux 4.10.7 (bnc#1007962 bnc#1012628 bsc#1013576 bsc#1028489
  bsc#1000619).
- Delete patches.drivers/drm-reference-count-event-completion.
- Delete patches.drivers/fbcon-Fix-vc-attr-at-deinit.
- Delete
  patches.fixes/crypto-algif_hash-avoid-zero-sized-array.patch.
- Delete
  patches.fixes/genetlink-fix-counting-regression-on-ctrl_dumpfamily.patch.
- commit 24e2bda
* Wed Mar 29 2017 jslaby@suse.cz
- linkage: new macros for assembler symbols (dwarf).
- dwarf: do not throw away unwind info (dwarf).
  Update to another snapshot. The code is readable and mostly clean now.
- commit e0611e0
* Mon Mar 27 2017 jeffm@suse.com
- Update to 4.11-rc4.
- commit 491b77c
* Sun Mar 26 2017 jslaby@suse.cz
- Linux 4.10.6 (bnc#1012628 bnc#1025903).
- Delete
  patches.rpmify/give-up-on-gcc-ilog2-constant-optimizations.patch.
- commit e326586
* Fri Mar 24 2017 mkubecek@suse.cz
- genetlink: fix counting regression on ctrl_dumpfamily()
  (bsc#1028489).
- commit 5182272
* Thu Mar 23 2017 tbogendoerfer@suse.de
- Rename global variable "unsupported" to "suse_unsupported" to avoid a clash
  with upstream code (commit 578b46b9383c) needed  for backport of cxgb4
  driver (FATE#321658 bsc#1005778)
- Refresh patches.suse/supported-flag.
- commit 8457d74
* Wed Mar 22 2017 tiwai@suse.de
- Refresh patches.suse/iwlwifi-expose-default-fallback-ucode-api.
  Some ucode's are upgraded to 27 recently.
- commit 2b9b66a
* Wed Mar 22 2017 jslaby@suse.cz
- Linux 4.10.5 (CVE-2017-6353 bnc#1012628 bsc#1027066
  bsc#1027798).
- Delete patches.fixes/bonding-use-ETH_MAX_MTU-as-max-mtu.patch.
- Delete
  patches.fixes/sctp-deny-peeloff-operation-on-asocs-with-threads-sl.patch.
- Delete patches.fixes/team-use-ETH_MAX_MTU-as-max-mtu.patch.
- Update config files.
- commit f3fbfc6
* Mon Mar 20 2017 afaerber@suse.de
- config: arm64: Update to 4.11-rc3
- commit 416ea28
* Mon Mar 20 2017 jeffm@suse.com
- Update to 4.11-rc3.
- Config changes:
  - LPFC_NVME_INITIATOR=y
  - LPFC_NVME_TARGET=y
- commit 5799355
* Mon Mar 20 2017 jslaby@suse.cz
- give up on gcc ilog2() constant optimizations (bnc#1025903).
- commit c2678b7
* Sat Mar 18 2017 jslaby@suse.cz
- Linux 4.10.4 (bnc#1012628 bsc#1025903).
- Delete
  patches.fixes/drm-i915-gvt-Fix-superfluous-newline-in-GVT_DISPLAY_.
- commit e2ef894
* Fri Mar 17 2017 mkubecek@suse.cz
- team: use ETH_MAX_MTU as max mtu (bsc#1027798).
- openvswitch: Set internal device max mtu to ETH_MAX_MTU
  (bsc#1027798).
- commit 338f856
* Wed Mar 15 2017 jslaby@suse.cz
- Linux 4.10.3 (CVE-2017-2636 bnc#1012628 bnc#1027565
  boo#1027378).
- Delete
  patches.fixes/drm-amdgpu-revert-update-tile-table-for-oland-hainan.patch.
- Delete
  patches.fixes/tty-n_hdlc-get-rid-of-racy-n_hdlc.tbuf.patch.
- commit 0c9f8e4
* Tue Mar 14 2017 mmarek@suse.com
- rpm/apply-patches: Fix failure if there are no vanilla patches
  The grep command returns 1 if there are no patches and we are using
  pipefail.
- commit 6dc70de
* Mon Mar 13 2017 mkubecek@suse.cz
- config: enable IPv6 multicast routing (bsc#1010755)
  While the reasoning in bugzilla is rather weak (basically just failing
  automated test checking for the feature, without any real user actually
  asking for it), I see little reason to have multicast routing enabled
  for IPv4 and disabled for IPv6.
- commit bedef39
* Mon Mar 13 2017 jeffm@suse.com
- Update to 4.11-rc2.
- Eliminated 2 patches.
- Config changes:
  - UPROBE_EVENT=y -> UPROBE_EVENTS=y
  - KPROBE_EVENT=y -> KPROBE_EVENTS=y
- commit ad81cf3
* Sun Mar 12 2017 jslaby@suse.cz
- Linux 4.10.2 (bnc#1012628).
- commit bfb2d22
* Fri Mar 10 2017 msuchanek@suse.de
- powerpc: Blacklist GCC 5.4 6.1 and 6.2 (boo#1028895).
- commit 3f366f7
* Thu Mar  9 2017 jslaby@suse.cz
- tty: n_hdlc: get rid of racy n_hdlc.tbuf (bnc#1027565
  CVE-2017-2636).
- commit c829304
* Tue Mar  7 2017 jdelvare@suse.de
- Revert "drm/amdgpu: update tile table for oland/hainan"
  (boo#1027378).
- commit f764d42
* Mon Mar  6 2017 jeffm@suse.com
- Update to 4.11-rc1.
- Eliminated 3 patches.
- ARM configs need updating.
- Important for developers, DEBUG_RODATA was renamed to STRICT_KERNEL_RWX
- Config changes:
  - Generic:
  - PRINTK_SAFE_LOG_BUF_SHIFT=13
  - renamed from NMI_LOG_BUF_SHIFT, uses the same value
  - CGROUP_RDMA=y
  - MAGIC_SYSRQ_SERIAL=y
  - WW_MUTEX_SELFTEST=n
  - TEST_SORT=n
  - TEST_PARMAN=n
  - STATIC_USERMODEHELPER=n (needs distro support first)
  - SECURITY_APPARMOR_DEBUG=n
  - CRYPTO_AES_TIm
  - SERIAL_DEV_BUS=m
  - GCC:
  - GCC_PLUGIN_STRUCTLEAK=n
  - Block/Storage:
  - BLK_DEBUG_FS=y
  - BLK_SED_OPAL=y
  - MQ_IOSCHED_DEADLINE=y
  - VIRTIO_BLK_SCSI=n (default, use virtio-scsi)
  - Network:
  - SMC=m
  - INET_ESP_OFFLOAD=m
  - INET6_ESP_OFFLOAD=m
  - NFT_SET_BITMAP=m
  - NET_ACT_SAMPLE=m
  - PSAMPLE=m
  - NET_IFE=m
  - QEDF=m
  - IPVTAP=m
  - NFP=m
  - NFP_DEBUG=n (performance)
  - i386/x86_64:
  - SPI_INTEL_SPI_PLATFORM=m
  - XEN_PVH=y
  - PC104=y
  - x86_64:
  - AQTION=m
  - INTEL_TURBO_MAX_3=y
  - DVB:
  - DVB_USB_ZD1301=m
  - VIDEO_IVTV_DEPRECATED_IOCTLS=n (default)
  - DRM:
  - DRM_DEBUG_MM_SELFTEST=n (default)
  - DRM_I915_SW_FENCE_DEBUG_OBJECTS=n
  - DRM_TINYDRM=m
  - TINYDRM_MI0283QT=n
  - Console:
  - VGACON_SOFT_SCROLLBACK_PERSISTENT_ENABLE_BY_DEFAULT=y (old behavior)
  - USB:
  - USB_SERIAL_UPD78F0730=m
  - USB_HUB_USB251XB=m
  - IB:
  - INFINIBAND_BNXT_RE=m (except on s390x)
  - x86:
  - SILEAD_DMI=y
  - SND_X86=m
  - HDMI_LPE_AUDIO=m
  - EXTCON_INTEL_INT3496=m
  - ppc64/ppc64le:
  - FSI=m
  - IIO ADC/DAC/Sensors:
  - HX711=n
  - MAX11100=n
  - TI_ADS7950=n
  - TI_TLC4541=n
  - MPU3050_I2C=n
  - IIO_ST_LSM6DSX=n
  - M3605=n
  - MAX5481=n
  - SRF08=n
  - TMP007=n
  - PHY:
  - PHY_QCOM_USB_HS=m (ARM-only?)
  - PHY_QCOM_USB_HSIC=m (ARM-only?)
  - Misc:
  - LEDS_BRIGHTNESS_HW_CHANGED=y
  - TOUCHSCREEN_ZET6223=m
  - SERIAL_8250_EXAR=y
  - PTP_1588_CLOCK_KVM=m
  - PWRSEQ_SD8787=m
  - PINCTRL_GEMINILAKE=m
  - GPIO_EXAR=m
  - GPIO_PCI_IDIO_16=m
  - W1_SLAVE_DS2405=m
  - CHARGER_SBS=m
  - SENSORS_STTS751=m
  - SOFT_WATCHDOG_PRETIMEOUT=y
  - NIC7018=m
  - IR_SPI=m
  - EEPROM_IDT_89HPESX=m
  - ARM:
  - KEYBOARD_TM2_TOUCHKEY=n (exynos)
  - PINCTRL_TI_IODELAY=n
  - CHARGER_DETECTOR_MAX14656=n
  - COMMON_CLK_VC5=n
  - MFD_CPCAP=n
  - SND_SOC_ES8328_I2C=n
  - SND_SOC_ES8328_SPI=n
  - SND_SOC_NAU8540=n
  - COMMON_CLK_VC5=n
  - SOC_ZTE=n
- commit 9086470
* Mon Mar  6 2017 msuchanek@suse.de
- kernel-binary.spec.in: Add g++ dependency.
  [   44s] ../scripts/gcc-plugin.sh: line 19: g++: command not found
- commit 59857ea
* Mon Mar  6 2017 mkubecek@suse.cz
- bonding: use ETH_MAX_MTU as max mtu (bsc#1027798).
- commit 2f8350b
* Thu Mar  2 2017 mkubecek@suse.cz
- Update patches.kernel.org/patch-4.10.1 references (add CVE-2017-6347 bsc#1027179).
- commit 8c10701
* Thu Mar  2 2017 mkubecek@suse.cz
- sctp: deny peeloff operation on asocs with threads sleeping
  on it (CVE-2017-6353 bsc#1027066).
- commit 8fb16bc
* Mon Feb 27 2017 jslaby@suse.cz
- crypto: algif_hash - avoid zero-sized array (bnc#1007962).
- commit 2f945d3
* Sun Feb 26 2017 jslaby@suse.cz
- Linux 4.10.1 (bnc#1012628).
- commit 1ecd5af
* Tue Feb 21 2017 tiwai@suse.de
- drm/i915/gvt: Fix superfluous newline in GVT_DISPLAY_READY
  env var (bsc#1025903).
- commit cac9478
* Mon Feb 20 2017 jeffm@suse.com
- Update to 4.10-final.
- commit 12a7a6d
* Sat Feb 18 2017 jslaby@suse.cz
- Linux 4.9.11 (CVE-2017-5897 CVE-2017-5970 CVE-2017-5986
  bnc#1012628 bsc#1023762 bsc#1024938 bsc#1025235).
- Delete patches.fixes/ip6_gre-fix-ip6gre_err-invalid-reads.patch.
- Delete
  patches.fixes/ipv4-keep-skb-dst-around-in-presence-of-IP-options.patch.
- Delete
  patches.fixes/sctp-avoid-BUG_ON-on-sctp_wait_for_sndbuf.patch.
- commit cf9c670
* Thu Feb 16 2017 jeffm@suse.com
- btrfs: use the new VFS super_block_dev (bnc#865869).
- commit f064a41
* Thu Feb 16 2017 jeffm@suse.com
- fs/super.c: add new super block sub devices super_block_dev
  (bnc#865869).
- commit 47c7d30
* Thu Feb 16 2017 mkubecek@suse.cz
- sctp: avoid BUG_ON on sctp_wait_for_sndbuf (CVE-2017-5986
  bsc#1025235).
- commit ffeeef5
* Wed Feb 15 2017 jslaby@suse.cz
- Linux 4.9.10 (bnc#1012628 bsc#1018100).
- Delete
  patches.suse/btrfs-fix-btrfs_compat_ioctl-failures-on-non-compat-ioctls.
- commit 59c7cc2
* Tue Feb 14 2017 mkubecek@suse.cz
- ipv4: keep skb->dst around in presence of IP options
  (CVE-2017-5970 bsc#1024938).
- commit fff3f63
* Mon Feb 13 2017 jeffm@suse.com
- Update to 4.10-rc8.
- Eliminated 1 patch.
- commit e195904
* Fri Feb 10 2017 jslaby@suse.cz
- Refresh patches.suse/DWARF-EH-frame-based-stack-unwinding.patch.
  Refactoring of the code. It is readable, understandable and a heap
  faster. More to come later.
- commit 0a72883
* Thu Feb  9 2017 jslaby@suse.cz
- Linux 4.9.9 (bnc#1012628 bsc#1021921 bsc#1022181).
- Delete
  patches.drivers/drm-i915-execlists-Reset-RING-registers-upon-resume.
- Delete
  patches.fixes/PCI-ASPM-Handle-PCI-to-PCIe-bridges-as-roots-of-PCIe.
- commit 6c5120c
* Thu Feb  9 2017 mkubecek@suse.cz
- ip6_gre: fix ip6gre_err() invalid reads (CVE-2017-5897
  bsc#1023762).
- commit e1a455d
* Tue Feb  7 2017 afaerber@suse.de
- config: armv6hl: Enable RASPBERRYPI_POWER
- commit 7c28efb
* Tue Feb  7 2017 tiwai@suse.de
- iwlwifi: Expose the default fallback ucode API to module info
  (boo#1021082, boo#1023884).
- commit 12d02bb
* Tue Feb  7 2017 afaerber@suse.de
- config: Make VIRTIO_CONSOLE built-in
- commit 2f30d33
* Tue Feb  7 2017 jeffm@suse.com
- btrfs: fix btrfs_compat_ioctl failures on non-compat ioctls
  (bsc#1018100).
- commit b456c83
* Tue Feb  7 2017 jeffm@suse.com
- btrfs: fix btrfs_compat_ioctl failures on non-compat ioctls
  (bsc#1018100).
- commit d9294c3
* Mon Feb  6 2017 jeffm@suse.com
- Update to 4.10-rc7.
- Eliminated 1 patch.
- commit bbf896d
* Sat Feb  4 2017 jslaby@suse.cz
- Linux 4.9.8 (bnc#1012628).
- commit af90696
* Fri Feb  3 2017 jkosina@suse.cz
- Refresh
  patches.fixes/x86-efi-Always-map-the-first-physical-page-into-the-EFI-pagetables.patch:
  update references
- commit 4e3d085
* Thu Feb  2 2017 jslaby@suse.cz
- Update config files.
- Refresh patches.suse/DWARF-EH-frame-based-stack-unwinding.patch.
- fix for save_stack_trace (lockdep et al.)
- depends on !KASAN (too slow)
- commit 7c0ba48
* Thu Feb  2 2017 jslaby@suse.cz
- Update config files.
- Refresh patches.suse/DWARF-EH-frame-based-stack-unwinding.patch.
- fix for save_stack_trace (lockdep et al.)
- depends on !KASAN (too slow)
- commit 2e68dd0
* Wed Feb  1 2017 jslaby@suse.cz
- Linux 4.9.7 (bnc#1012628 bnc#1022792 bsc#1018358).
- Delete
  patches.drivers/drm-Fix-broken-VT-switch-with-video-1366x768-option.
- Delete patches.fixes/userns-Make-ucounts-lock-irq-safe.patch.
- commit 1680560
* Tue Jan 31 2017 jslaby@suse.cz
- userns: Make ucounts lock irq-safe (bnc#1022792).
- commit 4a049e6
* Tue Jan 31 2017 jslaby@suse.cz
- Refresh patches.suse/DWARF-EH-frame-based-stack-unwinding.patch.
  Fix build failures for good.
- commit b1105aa
* Tue Jan 31 2017 jslaby@suse.cz
- Update config files.
- Refresh patches.suse/DWARF-EH-frame-based-stack-unwinding.patch.
- Refresh patches.suse/stack-unwind-disable-kasan.patch.
  Update dwarf unwinder. It fixes a build failure when disabled and
  moves files around.
- commit db55b7b
* Tue Jan 31 2017 jslaby@suse.cz
- Update config files.
- Refresh patches.suse/DWARF-EH-frame-based-stack-unwinding.patch.
- Refresh patches.suse/stack-unwind-disable-kasan.patch.
  Update dwarf unwinder. It fixes a build failure when disabled and
  moves files around.
- commit 18f6269
* Tue Jan 31 2017 jslaby@suse.cz
- Update config files.
  Re-disable CONFIG_STACK_UNWIND in syzkaller. It was disabled until
  4.9-rc1 because the stack unwinder and KASAN do not play well
  together. In 4.9-rc1 we disabled DWARF stack unwinder completely due
  to upstream stack unwindining rewrite. I ported the unwinder recently,
  but forgot to disable it in the syzkaller flavor. Do it now.
- commit 22e78d3
* Mon Jan 30 2017 jeffm@suse.com
- Update to 4.10-rc6.
- Eliminated 1 patch.
- commit 85b893c
* Mon Jan 30 2017 tiwai@suse.de
- PCI/ASPM: Handle PCI-to-PCIe bridges as roots of PCIe
  hierarchies (bsc#1022181).
- commit 29fd208
* Mon Jan 30 2017 jkosina@suse.cz
- [tip:efi/urgent] x86/efi: Always map the first physical page
  into the EFI pagetables.
- commit 33e3495
* Fri Jan 27 2017 tiwai@suse.de
- drm: reference count event->completion (bsc#1013576).
- commit c67d673
* Thu Jan 26 2017 jslaby@suse.cz
- Linux 4.9.6 (bnc#1012628).
- commit d1207ac
* Wed Jan 25 2017 tiwai@suse.de
- drm/i915/execlists: Reset RING registers upon resume
  (bsc#1021921).
- commit 7b0a59a
* Mon Jan 23 2017 tiwai@suse.de
- [media] uvcvideo: uvc_scan_fallback() for webcams with broken
  chain (bsc#1021474).
- commit 9bb1a8a
* Mon Jan 23 2017 jeffm@suse.com
- Update to 4.10-rc5.
- commit 7dca981
* Mon Jan 23 2017 dsterba@suse.com
- rpm/kernel-binary.spec.in: gcc plugins needs gcc-devel
  The build fails with missing bversion.h header.
- commit 95b4403
* Fri Jan 20 2017 mmarek@suse.com
- rpm/kernel-binary.spec.in: scripts/gcc-plugin.sh needs gcc-c++
- commit d577958
* Fri Jan 20 2017 jslaby@suse.cz
- Linux 4.9.5 (bnc#1003623 bnc#1012628).
- Delete
  patches.fixes/revert-tty-serial-8250-add-CON_CONSDEV-to-flags.patch.
- commit 699d1c6
* Wed Jan 18 2017 jslaby@suse.cz
- Update config files (bnc#1011884).
  Kill FRAME_POINTER. Thanks to the stack traces generation rewrite in
  4.9 & DWARF unwinding port, frame pointers are no longer needed for
  stack traces. We can shoot them down now. I am going to implement
  generation of DWARF info for assembly rather soon.
  If issues occur, please revert this and let me know.
- commit 911f899
* Tue Jan 17 2017 mmarek@suse.com
- rpm/kernel-binary.spec.in: Fix installation of /etc/uefi/certs (bsc#1019594)
- commit c6c6a91
* Mon Jan 16 2017 jslaby@suse.cz
- Refresh
  patches.fixes/revert-tty-serial-8250-add-CON_CONSDEV-to-flags.patch.
  Update upstream status.
- commit d26480f
* Mon Jan 16 2017 jslaby@suse.cz
- Update config files.
- Refresh patches.suse/stack-unwind-disable-kasan.patch.
- Delete
  patches.suse/revert-x86-remove-warning-and-warning_symbol-from-struct-stacktrace_ops.
  Update and enable the DWARF unwinder.
- commit d7228f4
* Mon Jan 16 2017 jeffm@suse.com
- Update to 3.10-rc4.
- commit 4f824f1
* Mon Jan 16 2017 jeffm@suse.com
- Delete
  patches.suse/revert-btrfs-fix-lockdep-warning-on-deadlock-against-an-inode-s-log-mutex.patch.
- Delete
  patches.suse/revert-btrfs-improve-performance-on-fsync-against-new-inode-after-rename-unlink.patch.
- commit a282581
* Sun Jan 15 2017 jslaby@suse.cz
- Linux 4.9.4 (bnc#1012628).
- commit ddcc4a0
* Sun Jan 15 2017 agraf@suse.de
- Enable CMA DMA on AArch64 (boo#1020021)
- commit 26c1d96
* Fri Jan 13 2017 jeffm@suse.com
- reiserfs: fix race in prealloc discard (bsc#987576).
- commit 5e5739e
* Fri Jan 13 2017 jeffm@suse.com
- reiserfs: fix race in prealloc discard (bsc#987576).
- commit 0467a6d
* Fri Jan 13 2017 tiwai@suse.de
- rpm/kernel-docs.spec.in: Fix building docs
- Fix html and pdf creation in Documetation/media/*
- Add graphviz to buildreq for image conversion
- Fix file list to remove REPORTING-BUGS
- commit a6d2693
* Fri Jan 13 2017 jeffm@suse.com
- config: RING_BUFFER_BENCHMARK=m on s390x (bsc#1019860).
  Commit 0b422208 should have done this but set it =y instead.
- commit 6cd2532
* Thu Jan 12 2017 tiwai@suse.de
- drm: Fix broken VT switch with video=1366x768 option
  (bsc#1018358).
- commit 1ed7879
* Thu Jan 12 2017 jslaby@suse.cz
- Linux 4.9.3 (bnc#1012628 bsc#1000433).
- Delete
  patches.drivers/drm-radeon-Always-store-CRTC-relative-radeon_crtc-cu.
- commit 7204b59
* Wed Jan 11 2017 jeffm@suse.com
- Delete
  patches.suse/btrfs-fix-extent-tree-corruption-due-to-relocation.patch.
  The issue being investigated with resolved with upstream commit
  054570a1dc94 (Btrfs: fix relocation incorrectly dropping data references).
- commit ed9b04a
* Wed Jan 11 2017 jslaby@suse.cz
- Refresh patches.suse/DWARF-EH-frame-based-stack-unwinding.patch.
- Delete patches.suse/unwind-use-thread_return-on-i386.
  Fix a warning and unwinding of blocked tasks. thread_return fix not
  needed anymore.
- commit abd21b1
* Mon Jan  9 2017 jeffm@suse.com
- unwind: use thread_return on i386
  This fixes a build failure.  I don't have an i386 environment set up for
  testing.
- commit f1c24bb
* Mon Jan  9 2017 jeffm@suse.com
- config/vanilla: re-add CONFIG_SCHED_OMIT_FRAME_POINTER=y
  Re-enabling the stack unwind patches means that we need this defined
  on vanilla flavors on i386 and x86_64.
- commit 0482a34
* Mon Jan  9 2017 jeffm@suse.com
- Update to 4.10-rc3.
- Config changes:
  - armv7hl/default:
  - HZ_FIXED=0, HZ_200=y (restriction removed upstream)
- commit ff90e91
* Mon Jan  9 2017 jslaby@suse.cz
- Linux 4.9.2 (bnc#1012628 bsc#1000433).
- Refresh
  patches.drivers/drm-radeon-Always-store-CRTC-relative-radeon_crtc-cu.
- Delete
  patches.drivers/drm-radeon-Also-call-cursor_move_locked-when-the-cur.
- Delete
  patches.drivers/drm-radeon-Hide-the-HW-cursor-while-it-s-out-of-boun.
- commit 2d3c294
* Fri Jan  6 2017 jslaby@suse.cz
- Refresh patches.suse/stack-unwind-disable-kasan.patch.
- Delete
  patches.suse/revert-x86-remove-warning-and-warning_symbol-from-struct-stacktrace_ops.
- Update config files.
  Port the DWARF unwinder to 4.9+.
- commit 17aa5c3
* Fri Jan  6 2017 afaerber@suse.de
- rpm: Add arm64 dtb-zte subpackage
  4.9 added arch/arm64/boot/dts/zte/.
- commit 23a79e3
* Fri Jan  6 2017 jslaby@suse.cz
- Linux 4.9.1 (bnc#1012628 bnc#1016101 bsc#1010690).
- Delete
  patches.fixes/ASoC-intel-Fix-crash-at-suspend-resume-without-card.
- Delete
  patches.rpmify/kbuild-provide-include-asm-asm-prototypes.h-for-x86.patch.
- commit da02006
* Fri Jan  6 2017 afaerber@suse.de
- rpm: Add arm64 dtb-allwinner subpackage
  4.10 added arch/arm64/boot/dts/allwinner/.
- commit 81535fa
* Thu Jan  5 2017 mmarek@suse.cz
- rpm/kernel-obs-build.spec.in: Fix typo
- commit 45e1765
* Thu Jan  5 2017 mmarek@suse.com
- Enable kernel-obs-{build,qa} also in the vanilla branches
- commit 022e5fb
* Thu Jan  5 2017 mmarek@suse.com
- rpm/dtb.spec.in.in: Fix for kernel-source-vanilla (bsc#1011920)
- commit 4de517c
* Thu Jan  5 2017 mmarek@suse.com
- rpm/mkspec: Do not build dtbs for kernel-source-rt (bsc#1011920)
- commit f3a9899
* Thu Jan  5 2017 mmarek@suse.com
- rpm/dtb.spec.in.in: Use kernel-source-vanilla in vanilla branches (bsc#1011920)
- commit 44cf2d6
* Thu Jan  5 2017 tiwai@suse.de
- fbcon: Fix vc attr at deinit (bsc#1000619).
- commit e989b9d
* Mon Jan  2 2017 jeffm@suse.com
- Update to 4.10-rc2.
- Eliminated 1 patch.
- commit 870a2f2
* Mon Jan  2 2017 afaerber@suse.de
- config: armv7hl: Update to v4.10-rc1
- commit 3dd6d79
* Mon Jan  2 2017 afaerber@suse.de
- config: armv6hl: Update to v4.10-rc1
- commit 1856e58
* Mon Jan  2 2017 afaerber@suse.de
- config: arm64: Update to 4.10-rc1
- commit 544f60a
* Mon Jan  2 2017 jslaby@suse.cz
- drm: Use u64 for intermediate dotclock calculations
  (bnc#1006472).
- commit 1af4b0f
* Mon Jan  2 2017 jslaby@suse.cz
- x86/kbuild: enable modversions for symbols exported from asm
  (bnc#1016101).
  Replace by the upstream version.
- commit 772efd7
* Thu Dec 29 2016 jeffm@suse.com
- Update to 4.10-rc1.
- Eliminated 6 patches.
- ARM configs need updating.
- Config changes:
  - General:
  - CONSOLE_LOGLEVEL_DEFAULT=7 (default)
  - BUG_ON_DATA_CORRUPTION=y
  - REMOTEPROC=m
  - CGROUP_BPF=y
  - STM_SOURCE_FTRACE=m
  - Block:
  - BLK_DEV_ZONED=y
  - BLK_WBT=y
  - BLK_WBT_SQ=n (default)
  - BLK_WBT_MQ=y (default)
  - x86:
  - INTEL_RDT_A=y
  - SCHED_MC_PRIO=y
  - Net:
  - INET_RAW_DIAG=m
  - IPV6_SEG6_LWTUNNEL=y
  - IPV6_SEG6_INLINE=n
  - IPV6_SEG6_HMAC=y
  - NF_LOG_NETDEV=m
  - NF_CT_PROTO_DCCP=y
  - NF_CT_PROTO_SCTP=y
  - NF_CT_PROTO_UDPLITE=y
  - NFT_RT=m
  - NFT_OBJREF=m
  - IP_SET_HASH_IPMAC=m
  - NF_SOCKET_IPV4=m
  - NFT_FIB_IPV4=m
  - NF_SOCKET_IPV6=m
  - NFT_FIB_IPV6=m
  - NFT_FIB_INET=m
  - LWTUNNEL_BPF=y
  - AMD_XGBE=m
  - AMD_XGBE_DCB=y
  - BNXT_DCB=y
  - MLXSW_CORE_THERMAL=y
  - MLXSW_I2C=m
  - MLXSW_SWITCHIB=m
  - MLXSW_MINIMAL=m
  - SFC_FALCON=m
  - SFC_FALCON_MTD=y
  - LED_TRIGGER_PHY=y
  - Debugging:
  - TEST_ASYNC_DRIVER_PROBE=n
  - DMA_FENCE_TRACE=n
  - DVB_DEMUX_SECTION_LOSS_LOG=n
  - SW_SYNC=n
  - MTD:
  - MTD_NAND_OXNAS=n
  - NVME:
  - NVME_FC=m
  - NVME_TARGET_FC=m
  - NVME_TARGET_FCLOOP=m
  - DM_DEBUG_BLOCK_MANAGER_LOCKING=n
  - iSCSI:
  - QEDI=m
  - ARM:
  - MESON_GXL_PHY
  - PINCTRL_SX150X
  - DRM_SIL_SII8620
  - DRM_TI_TFP410
  - DRM_HISI_HIBMC
  - DRM_MXSFB
  - SND_SOC_MSM8916_WCD_ANALOG
  - SND_SOC_MSM8916_WCD_DIGITAL
  - LEDS_NIC78BX
  - RTC_DRV_R7301
  - COMMON_CLK_MT2701
  - COMMON_CLK_MT2701_MMSYS
  - COMMON_CLK_MT2701_IMGSYS
  - COMMON_CLK_MT2701_VDECSYS
  - COMMON_CLK_MT2701_HIFSYS
  - COMMON_CLK_MT2701_ETHSYS
  - COMMON_CLK_MT2701_BDPSYS
  - LIQUIDIO_VF
  - SENSORS_XGENE
  - ALTERA_MBOX
  - ARM_SCPI_PROTOCOL
  - IIO_CROS_EC_SENSORS_CORE
  - Sound:
  - SND_SOC_CS35L34=m
  - SND_SOC_CS42L42=m
  - Wifi:
  - WIRELESS_WDS=n (deprecated)
  - Misc drivers:
  - RMI4_SMB=m
  - RMI4_F03=y
  - RMI4_F34=y
  - SCR24X=m
  - I2C_MUX_MLXCPLD=m
  - SENSORS_TC654=m
  - SENSORS_TMP108=m
  - MEDIA_CEC_SUPPORT=y
  - IR_SERIAL=m
  - IR_SERIAL_TRANSMITTER=y
  - DRM_I915_ALPHA_SUPPORT=n
  - DRM_I915_CAPTURE_ERROR=y
  - DRM_I915_COMPRESS_ERROR=y
  - DRM_I2C_ADV7511_AUDIO=y
  - HID_MAYFLASH=m
  - HID_UDRAW_PS3=m
  - USB_SERIAL_F8153X=m
  - MMC_SDHCI_CADENCE=m
  - LEDS_USER=m
  - INFINIBAND_VMWARE_PVRDMA=m
  - HT16K33=m
  - UIO_HV_GENERIC=m
  - VFIO_MDEV=m
  - VFIO_MDEV_DEVICE=m
  - SURFACE3_WMI=m
  - SURFACE_3_BUTTON=m
  - MLX_CPLD_PLATFORM=m
  - CRYPTO_DEV_VIRTIO=m
  - I2C_MLXCPLD=m
  - Misc chip drivers:
  - DA280=n
  - DA311=n
  - DMARD10=n
  - AD7766=n
  - ENVELOPE_DETECTOR=n
  - 104_QUAD_8=n
  - DPOT_DAC=n
  - HTS221=n
  - LMP91000=n
  - ABP060MG=n
  - FPGA_BRIDGE=m
  - FPGA_REGION=m
  - GPU:
  - DRM_I915_GVT_KVMGT=m
  - File systems:
  - OVERLAY_FS_REDIRECT_DIR=n (not backward compatible)
  - UBIFS_FS_ENCRYPTION=y
  - ppc64:
  - CC_STACKPROTECTOR_REGULAR=y
  - USE_THIN_ARCHIVES=n
  - KEXEC_FILE=y
  - RELOCATABLE_TEST=n
  - MOVABLE_NODE=y
  - TCG_TIS=m
  - PPC_PTDUMP=n
  - CRYPTO_CRC32C_VPMSUM=m
  - s390x:
  - IRQ_DOMAIN_DEBUG=n
  - BATMAN_ADV_BATMAN_V=y (consistent with other flavors)
  - I2C options, mostly =n -- enable as needed
- commit c901e2e
* Wed Dec 28 2016 tiwai@suse.de
- rpm/kernel-binary.spec.in: Obsolete ftsteutates KMP (boo#997172)
- commit 34c1867
* Tue Dec 20 2016 xxxxxmichl@googlemail.com
- added De0-Nanos-SoC board support (and others based on Altera SOC).
- commit 3299f4a
* Mon Dec 19 2016 jdelvare@suse.de
- config: Disable GPIO_TS4900 in most kernels
  The gpio-ts4900 driver is only useful on i.MX6 boards, and only one
  of our kernels supports them.
- commit 92e9ad3
* Fri Dec 16 2016 jslaby@suse.cz
- kbuild: provide include/asm/asm-prototypes.h for x86 (bnc#1016101).
- commit 74d2b9b
* Thu Dec 15 2016 jslaby@suse.cz
- ipc: msg, make msgrcv work with LONG_MIN (bnc#1005918).
- commit 1583bd5
* Wed Dec 14 2016 jeffm@suse.com
- Fix incorrect 'Reference' tag.
- commit fd5379c
* Mon Dec 12 2016 jeffm@suse.com
- Update to 4.9-final.
- Eliminated 1 patch.
- commit f49341d
* Mon Dec 12 2016 jslaby@suse.cz
- Linux 4.8.14 (CVE-2016-9576 bnc#1012628 bsc#1013604
  CVE-2016-8655 bsc#1012754).
- Delete
  patches.fixes/don-t-feed-anything-but-regular-iovec-s-to-blk_rq_map_user_iov.patch.
- Delete
  patches.fixes/packet-fix-race-condition-in-packet_set_ring.patch.
- commit ab53e9a
* Fri Dec  9 2016 jthumshirn@suse.de
- Don't feed anything but regular iovec's to blk_rq_map_user_iov
  (CVE-2016-9576 bsc#1013604).
- commit 7730184
* Fri Dec  9 2016 jthumshirn@suse.de
- Don't feed anything but regular iovec's to blk_rq_map_user_iov
  (CVE-2016-9576 bsc#1013604).
- commit f66af51
* Fri Dec  9 2016 jslaby@suse.cz
- Linux 4.8.13 (bnc#1012628 boo#1008745 bsc#1010970).
- Delete
  patches.fixes/0001-libfc-fix-seconds_since_last_reset-miscalculation.patch.
- Delete patches.fixes/kasan-update-kasan_global-for-gcc-7.patch.
- Delete
  patches.fixes/zram-Fix-unbalanced-idr-management-at-hot-removal.
- commit 725988c
* Mon Dec  5 2016 jeffm@suse.com
- Update to 4.9-rc8.
- Eliminated 1 patch.
- MODVERSIONS is enabled again.
- commit 59795cb
* Mon Dec  5 2016 jslaby@suse.cz
- kasan: update kasan_global for gcc 7 (syzkaller).
- commit 18bb86c
* Mon Dec  5 2016 jslaby@suse.cz
- kasan: support use-after-scope detection (syzkaller).
- commit 5e37e6b
* Fri Dec  2 2016 jslaby@suse.cz
- Linux 4.8.12 (CVE-2016-7913 bnc#1012628 bsc#1010478
  bsc#1000287).
- Delete
  patches.apparmor/apparmor-fix-change_hat-not-finding-hat-after-policy-replacement.patch.
- Delete patches.fixes/xc2028-Fix-use-after-free-bug-properly.
- commit f8adb5a
* Fri Dec  2 2016 mkubecek@suse.cz
- packet: fix race condition in packet_set_ring (CVE-2016-8655
  bsc#1012754).
- commit 3d7ef11
* Thu Dec  1 2016 jslaby@suse.cz
- drm/i915: Mark CPU cache as dirty when used for rendering
  (bnc#931300).
- commit 04f28df
* Wed Nov 30 2016 jeffm@suse.com
- Update to 4.9-rc7.
- Eliminated 3 patches.
- MODVERSIONS (temporarily) depends on BROKEN (because it is).  This will
  need to be re-enabled when it is fixed or KMPs won't work.
- commit 3fd3ec0
* Wed Nov 30 2016 afaerber@suse.de
- config: arm64: Enable TCG_INFINEON
- commit bcfa9f0
* Tue Nov 29 2016 msuchanek@suse.de
- Add power key support for PMIcs which are already included in the configs
  (boo#1012477).
  Arm64 already has these so no need to patch it.
- commit b8f3026
* Tue Nov 29 2016 mmarek@suse.cz
- rpm/kernel-spec-macros: Fix the check if there is no rebuild counter (bsc#1012060)
- commit 6f16f5f
* Mon Nov 28 2016 mmarek@suse.com
- rpm/kernel-binary.spec.in: Export a make-stderr.log file (bsc#1012422)
- commit f738229
* Sun Nov 27 2016 tiwai@suse.de
- Fix bug reference in
  patches.fixes/Revert-ACPI-Execute-_PTS-before-system-reboot
  (bsc#1012220).
- commit f8ae998
* Sat Nov 26 2016 jslaby@suse.cz
- Linux 4.8.11 (: :).
- commit 8e531aa
* Fri Nov 25 2016 tiwai@suse.de
- ASoC: intel: Fix crash at suspend/resume without card
  registration (bsc#1010690).
- commit ab10cc8
* Fri Nov 25 2016 tiwai@suse.de
- Revert "ACPI: Execute _PTS before system reboot" (bsc#101220).
- commit a8caaa4
* Fri Nov 25 2016 mmarek@suse.com
- rpm/dtb.spec.in.in: Adjust the formatting to osc's liking (bsc#1011920)
- commit cdcab93
* Fri Nov 25 2016 tiwai@suse.de
- xc2028: Fix use-after-free bug properly (CVE-2016-7913
  bsc#1010478).
- commit dcfac88
* Thu Nov 24 2016 msuchanek@suse.de
- Enable Intel i810 audio driver used in OpenQA VMs (boo#1012575).
- commit 19ce2a6
* Thu Nov 24 2016 mkubecek@suse.cz
- Update patches.kernel.org/patch-4.8.7-8 references (add CVE-2016-9555 bsc#1011685).
- commit d81bac1
* Thu Nov 24 2016 mmarek@suse.com
- rpm/kernel-spec-macros: Ignore too high rebuild counter (bsc#1012060)
- commit 4ba30ba
* Wed Nov 23 2016 mmarek@suse.com
- rpm/mkspec-dtb: Print progress like mkspec does (bsc#1011920)
- commit 327c01e
* Wed Nov 23 2016 mmarek@suse.com
- Drop dtb-source.spec and move the sources to kernel-source (bsc#1011920)
- commit 3a67f58
* Wed Nov 23 2016 mmarek@suse.com
- Preprocess the dtb spec template with the kernel mkspec script
  This sets up the kernel version and release macros (bsc#1011920).
- commit 814c4ec
* Wed Nov 23 2016 mmarek@suse.com
- rpm/mkspec-dtb: Do not run the osc specfile formatter (bsc#1011920)
  It may produce varying output depending on the installed osc version.
- commit 2673925
* Wed Nov 23 2016 mmarek@suse.com
- rpm/mkspec-dtb: Stop copying the dtb .changes files (bsc#1011920)
  We are using the kernel changelog now.
- commit c7605f2
* Wed Nov 23 2016 mmarek@suse.com
- rename dtb's pre_checkin.pl to mkspec-dtb (bsc#1011920)
- commit 9e33f22
* Wed Nov 23 2016 mmarek@suse.com
- Import dtb-source specfiles into kernel-source (bsc#1011920)
- commit 7975919
* Mon Nov 21 2016 mmarek@suse.cz
- Drop kernel-obs-qa-xen unconditionally (bsc#1010040)
  The IBS cannot build it, even if there is a xen-capable
  kernel-obs-build.
- commit f4797cb
* Mon Nov 21 2016 jeffm@suse.com
- Update to 4.9-rc6.
- commit 5f5c2ad
* Mon Nov 21 2016 tiwai@suse.de
- zram: Fix unbalanced idr management at hot removal
  (bsc#1010970).
- commit d1ec066
* Mon Nov 21 2016 jslaby@suse.cz
- Linux 4.8.10 (: :).
- commit 86386e1
* Sat Nov 19 2016 jslaby@suse.cz
- Linux 4.8.9 (: :).
- commit be1f097
* Tue Nov 15 2016 mmarek@suse.com
- rpm/kernel-binary.spec.in: Only build -base and -extra with CONFIG_MODULES (bsc#1000118)
- commit 4bd9ec7
* Tue Nov 15 2016 mmarek@suse.com
- rpm/kernel-binary.spec.in: Do not create KMPs with CONFIG_MODULES=n
- commit 1cf9838
* Tue Nov 15 2016 mmarek@suse.com
- Reformat spec files according to the format_spec_file osc helper
- commit a3cd251
* Tue Nov 15 2016 mmarek@suse.com
- Update the copyright header in spec files
- commit 50b5bef
* Tue Nov 15 2016 jslaby@suse.cz
- Linux 4.8.8 (CVE-2016-7039 bsc#1001486).
- Delete patches.fixes/net-add-recursion-limit-to-GRO.patch.
- commit 7b7d4ed
* Mon Nov 14 2016 jeffm@suse.com
- Update to 4.9-rc5.
- commit 22cecc1
* Mon Nov 14 2016 jslaby@suse.cz
- rpm/constraints.in: increase disk for kernel-syzkaller
  The kernel-syzkaller build now consumes around 30G. This causes
  headache in factory where the package rebuilds over and over. Require
  35G disk size to successfully build the flavor.
- commit 970a25c
* Sat Nov 12 2016 tiwai@suse.de
- Update config files: disable ASoC Intel BXT drivers
  They are still premature, and it enables snd-soc-skl automatically
  that interferes with the legacy HD-audio driver.  Keep them disabled
  until the issues are solved in upstream.
- commit 9e0babb
* Fri Nov 11 2016 jeffm@suse.com
- Disabled kmsg patches for s390.
  It needs updating to deal with printk headers.
- commit 2740f7f
* Thu Nov 10 2016 jslaby@suse.cz
- Linux 4.8.7 (CVE-2016-7042 bnc#1006417 bnc#1008880 boo#1006825
  bsc#1004517 bsc#1007653 boo#1003298 bsc#1007615).
- Delete
  patches.drivers/0001-usbhid-add-ATEN-CS962-to-list-of-quirky-devices.patch.
- Delete
  patches.fixes/0001-KEYS-Fix-short-sprintf-buffer-in-proc-keys-show-func.patch.
- Delete patches.fixes/ALSA-seq-Fix-time-account-regression.
- Delete
  patches.fixes/btrfs-fix-races-on-root_log_ctx-lists.patch.
- Delete
  patches.fixes/drm-fb-helper-Dont-call-dirty-callback-for-untouched-clips.
- Delete
  patches.fixes/drm-i915-gen9-fix-DDB-partitioning-for-multi-screen-.patch.
- Delete
  patches.fixes/x86-smpboot-Init-apic-mapping-before-usage.patch.
- commit c8f02a2
* Tue Nov  8 2016 jthumshirn@suse.de
- libfc: fix seconds_since_last_reset miscalculation (boo#1008745).
- commit da23b4a
* Mon Nov  7 2016 jslaby@suse.cz
- drm/i915/gen9: fix DDB partitioning for multi-screen cases
  (bnc#1008880).
- commit 4a45dd3
* Sun Nov  6 2016 jeffm@suse.com
- Update to 4.9-rc4.
- Eliminated 2 patches.
- commit fccf41c
* Thu Nov  3 2016 oneukum@suse.com
- usbhid: add ATEN CS962 to list of quirky devices (bsc#1007615).
- commit f452d0b
* Thu Nov  3 2016 jlee@suse.com
- KEYS: Fix short sprintf buffer in /proc/keys show function
  (bsc#1004517, CVE-2016-7042).
- commit 9d6b45c
* Wed Nov  2 2016 afaerber@suse.de
- config: arm64/armv7hl: Disable QCOM_WCNSS_PIL for now
  Avoids a depmod error/abort:
  depmod: ERROR: Cycle detected: qcom_wcnss_iris -> qcom_wcnss -> qcom_wcnss_iris
- commit 7183962
* Tue Nov  1 2016 mkubecek@suse.cz
- Update patches.fixes/net-add-recursion-limit-to-GRO.patch mainline reference.
- commit 3d61b80
* Tue Nov  1 2016 mkubecek@suse.cz
- Update patches.fixes/net-add-recursion-limit-to-GRO.patch mainline reference.
- commit dce3a53
* Mon Oct 31 2016 jslaby@suse.cz
- x86/smpboot: Init apic mapping before usage (bnc#1006417).
- commit 7d70b08
* Mon Oct 31 2016 jslaby@suse.cz
- Linux 4.8.6 (: :).
- commit dbb68be
* Sun Oct 30 2016 jeffm@suse.com
- Update to 4.9-rc3.
- Eliminated 2 patches.
- commit b005706
* Sat Oct 29 2016 jeffm@suse.com
- btrfs: fix races on root_log_ctx lists (bsc#1007653).
- commit c710f61
* Sat Oct 29 2016 jeffm@suse.com
- btrfs: fix races on root_log_ctx lists (bsc#1007653).
- commit 1e904fd
* Fri Oct 28 2016 jslaby@suse.cz
- Linux 4.8.5 (: :).
- commit 9148e7c
* Thu Oct 27 2016 tiwai@suse.de
- drm/radeon: Hide the HW cursor while it's out of bounds
  (bsc#1000433).
- drm/radeon: Also call cursor_move_locked when the cursor size
  changes (bsc#1000433).
- drm/radeon: Always store CRTC relative radeon_crtc->cursor_x/y
  values (bsc#1000433).
- drm/radeon: Hide the HW cursor while it's out of bounds
  (bsc#1000433).
- drm/radeon: Also call cursor_move_locked when the cursor size
  changes (bsc#1000433).
- drm/radeon: Always store CRTC relative radeon_crtc->cursor_x/y
  values (bsc#1000433).
- commit 30e023d
* Tue Oct 25 2016 tiwai@suse.de
- ALSA: seq: Fix time account regression (boo#1006825).
- commit 9168b92
* Tue Oct 25 2016 tiwai@suse.de
- drm/fb-helper: Don't call dirty callback for untouched clips
  (boo#1003298).
- commit 092ed80
* Mon Oct 24 2016 jeffm@suse.com
- Update to 4.9-rc2.
- commit ac4ccc9
* Sat Oct 22 2016 jslaby@suse.cz
- Linux 4.8.4 (CVE-2016-7425 bnc#1003623 bsc#999932).
- Delete
  patches.fixes/drm-virtio-reinstate-drm_virtio_set_busid.patch.
- Delete
  patches.fixes/scsi-arcmsr-buffer-overflow-in-arcmsr_iop_message_xfer.patch.
- commit 402d8c1
* Fri Oct 21 2016 afaerber@suse.de
- config: armv7hl: Update to v4.9-rc1
- commit 11efe27
* Thu Oct 20 2016 afaerber@suse.de
- config: arm64: Update to v4.9-rc1
- commit 4e38383
* Thu Oct 20 2016 jslaby@suse.cz
- Update patches.kernel.org/patch-4.8.2-3 (bnc#1004418
  CVE-2016-5195).
- commit 94eb9fb
* Thu Oct 20 2016 jslaby@suse.cz
- Linux 4.8.3 (: :).
- commit db38c1f
* Wed Oct 19 2016 afaerber@suse.de
- config: armv6hl: Update to v4.9-rc1
- commit 46b5233
* Tue Oct 18 2016 jslaby@suse.cz
- Revert "tty: serial: 8250: add CON_CONSDEV to flags"
  (bnc#1003623).
- commit 967aac9
* Tue Oct 18 2016 fdmanana@suse.com
- Btrfs: fix extent tree corruption due to relocation
  (bsc#990384).
- commit 8930e43
* Mon Oct 17 2016 jeffm@suse.com
- config: restore vanilla configs
  I accidentally appended the new config options to the vanilla configs.
  This patch restores them.
- commit 55c3dd5
* Mon Oct 17 2016 jeffm@suse.com
- Update to 4.9-rc1.
- Eliminated 14 patches.
- ARM configs need updating.
- Config changes:
  - General:
  - VMAP_STACK=y (where supported)
  - GCC plugins:
  - GCC_PLUGIN_LATENT_ENTROPY=n (fork/irq overhead)
  - CPUFREQ:
  - CPU_FREQ_GOV_SCHEDUTIL=y
  - x86:
  - MLX_PLATFORM=m
  - INTEL_ISH_HID=m
  - SND_SOC_INTEL_BDW_RT5677_MACH=m
  - SERIAL_8250_LPSS=y (i386)
  - PCI:
  - PCIE_PTM=y
  - Networking:
  - TCP_CONG_BBR=m
  - NFT_NUMGEN=m
  - NFT_SET_RBTREE=m
  - NFT_SET_HASH=m
  - NFT_QUOTA=m
  - NET_ACT_SKBMOD=m
  - NET_ACT_TUNNEL_KEY=m
  - NET_IFE_SKBTCINDEX=m
  - BATMAN_ADV_DEBUGFS=y
  - BT_HCIUART_MRVL=y
  - AF_RXRPC_IPV6=y
  - AF_RXRPC_INJECT_LOSS=n
  - ENA_ETHERNET=m
  - MICROSEMI_PHY=m
  - CRYPTO_DEV_CHELSIO=m
  - INFINIBAND_QEDR=m
  - GPIO:
  - INPUT_GPIO_DECODER=m
  - GPIO_MOCKUP=m
  - GPIO_GPIO_MM=m
  - GPIO_TS4900=m
  - DRM:
  - DRM_AMDGPU_SI=y
  - DRM_PANEL_JDI_LT070ME05000=n
  - DRM_DUMB_VGA_DAC=m
  - DRM_LEGACY (this may impact users with older hardware)
  - Sound:
  - SND_SOC_NAU88C10=m
  - SND_SIMPLE_SCU_CARD=m
  - USB:
  - USB_LEDS_TRIGGER_USBPORT=m
  - USBIP_VHCI_HC_PORTS=8 (default)
  - USBIP_VHCI_NR_HCS=1 (default)
  - USB_HSIC_USB4604=m
  - Other:
  - LEDS_IS31FL319X=m
  - RTC_DRV_DS1307_CENTURY=y
  - WDAT_WDT=m
  - WATCHDOG_PRETIMEOUT_GOV_PANIC=m
  - WATCHDOG_PRETIMEOUT_GOV_NOOP=y
  - VIDEO_TW5864=m
  - CONFIG_LEDS_MLXCPLD=m
  - SCSI_SMARTPQI=m
  - TOUCHSCREEN_EKTF2127=m
  - syzkaller config:
  - UBSAN_NULL=y
- commit 059949b
* Mon Oct 17 2016 jeffm@suse.com
- config: disable NET_DSA on non-ARM
- commit 17e3f19
* Mon Oct 17 2016 jslaby@suse.cz
- drm: virtio: reinstate drm_virtio_set_busid() (bnc#1003623).
- commit 7574477
* Sun Oct 16 2016 jslaby@suse.cz
- Linux 4.8.2 (: :).
- commit b46d583
* Sun Oct 16 2016 afaerber@suse.de
- config: armv7hl: Enable MMC_SDHCI_IPROC for lpae (boo#1005019)
  Needed for Raspberry Pi 2, and default flavor already has it.
- commit 81ca578
* Fri Oct 14 2016 jslaby@suse.cz
- time: Avoid undefined behaviour in ktime_add_safe() (syzkaller
  testing).
- commit 28732f2
* Fri Oct 14 2016 jslaby@suse.cz
- fix get_builtin_firmware compilation with gcc 7 (bnc#1004626).
- commit c8f15f0
* Tue Oct 11 2016 mwilck@suse.de
- Input: ALPS - set DualPoint flag for 74 03 28 devices
  (bsc#987703).
- Input: ALPS - allow touchsticks to report pressure (bsc#987703).
- Input: ALPS - handle 0-pressure 1F events (bsc#987703).
- Input: ALPS - add touchstick support for SS5 hardware
  (bsc#987703).
- Input: ALPS - set DualPoint flag for 74 03 28 devices
  (bsc#987703).
- Input: ALPS - allow touchsticks to report pressure (bsc#987703).
- Input: ALPS - handle 0-pressure 1F events (bsc#987703).
- Input: ALPS - add touchstick support for SS5 hardware
  (bsc#987703).
- commit 5e4310e
* Mon Oct 10 2016 mkubecek@suse.cz
- net: add recursion limit to GRO (CVE-2016-7039 bsc#1001486).
- commit c6408a6
* Fri Oct  7 2016 jslaby@suse.cz
- Linux 4.8.1 (: :).
- commit 4861355
* Fri Oct  7 2016 jroedel@suse.de
- Update blacklisting documentation to contain path-blacklisting
- README.blacklist:
- blacklist.conf:
- commit 57a57d3
* Wed Oct  5 2016 jeffm@suse.com
- apparmor: fix change_hat not finding hat after policy
  replacement (bsc#1000287).
- commit b49afc4
* Wed Oct  5 2016 jeffm@suse.com
- Update AppArmor network mediation patchset.
- AppArmor: basic networking rules (FATE#300516).
- apparmor: Fix quieting of audit messages for network mediation
  (FATE#300516).
- Delete
  patches.apparmor/apparmor-compatibility-patch-for-v5-network-control.
- commit a586694
* Wed Oct  5 2016 mkubecek@suse.cz
- net: add recursion limit to GRO (CVE-2016-7039 bsc#1001486).
- commit 0a6dcd2
* Tue Oct  4 2016 jroedel@suse.de
- Document the process to blacklist upstream commit-ids
- README.blacklist:
- blacklist.conf:
- commit ff3ff42
* Mon Oct  3 2016 jeffm@suse.com
- Update to 4.8-final.
- commit bbbf852
* Mon Oct  3 2016 mmarek@suse.com
- rpm/kernel-binary.spec.in: Simplify debug info switch
  Any CONFIG_DEBUG_INFO sub-options are answered in the configs nowadays.
- commit d404ac5
* Fri Sep 30 2016 jslaby@suse.cz
- rpm/package-descriptions: the flavor is 64kb, not 64k
- commit 2e05d02
* Fri Sep 30 2016 jslaby@suse.cz
- Linux 4.7.6 (bsc#997639 bsc#999600).
- Delete
  patches.fixes/autofs-use-dentry-flags-to-block-walks-during-expire.
- Delete
  patches.suse/btrfs-ensure-that-file-descriptor-used-with-subvol-i.patch.
- commit 0b20275
* Tue Sep 27 2016 mmarek@suse.com
- Refresh malformed patches for series2git
- Refresh patches.arch/acpi_thermal_passive_blacklist.patch.
- Refresh patches.fixes/dm-table-switch-to-readonly.
- commit 991ee60
* Mon Sep 26 2016 jeffm@suse.com
- Update to 4.8-rc8.
- Eliminated 2 patches.
- commit 698a4f4
* Mon Sep 26 2016 schwab@suse.de
- kernel-module-subpackage: Properly quote flavor in expressions
  That fixes a parse error if the flavor starts with a digit or contains
  other non-alphabetic characters.
- commit 19ba528
* Mon Sep 26 2016 agraf@suse.de
- rpm/package-descriptions: Add 64kb kernel flavor description
- commit 7d9e0ef
* Sun Sep 25 2016 bp@suse.de
- scsi: arcmsr: Buffer overflow in arcmsr_iop_message_xfer()
  (bsc#999932 CVE-2016-7425).
- commit 135aa22
* Sun Sep 25 2016 bp@suse.de
- scsi: arcmsr: Buffer overflow in arcmsr_iop_message_xfer()
  (bsc#999932 CVE-2016-7425).
- commit 60fc512
* Sat Sep 24 2016 jslaby@suse.cz
- Linux 4.7.5 (CVE-2016-6828 bnc#994066 bsc#993996 bsc#994296).
- Delete
  patches.fixes/drm-i915-Ignore-OpRegion-panel-type-except-on-select.
- Delete
  patches.fixes/mm-oom-prevent-premature-OOM-killer-invocation-for-h.patch.
- Delete
  patches.fixes/tcp-fix-use-after-free-in-tcp_xmit_retransmit_queue.patch.
- Delete patches.rpmify/i915-fix-build-error-with-werror.
- commit c7aed11
* Fri Sep 23 2016 afaerber@suse.de
- config: arm64: Enable RASPBERRYPI_POWER
- commit bd37084
* Fri Sep 23 2016 afaerber@suse.de
- config: armv7hl: Enable RASPBERRYPI_POWER
- commit 4dc44c4
* Fri Sep 23 2016 afaerber@suse.de
- config: armv7hl: Enable virtio-pci
  Needed for armv7l-on-aarch64 OBS workers.
- commit 2407e65
* Fri Sep 23 2016 afaerber@suse.de
- config: armv6hl: Enable USB OTG
  The Raspberry Pi Zero has an OTG port accessible.
- commit 3f0806a
* Fri Sep 23 2016 jslaby@suse.cz
- Update config files.
- Delete patches.suse/syzkaller-no-gcc-plugin.patch.
  The patch is actually not needed as we have sanitizer support in gcc
  directly (no need for plugins).
- commit 0c67c61
* Fri Sep 23 2016 jslaby@suse.cz
- Update config files.
  Enable UBSAN for syzkaller. It still boots, even though we are down
  at 250 s boot time from 130 s. Might be reconsidered later.
- commit 07d153e
* Thu Sep 22 2016 gqjiang@suse.com
- md-cluster: make resync lock also could be interruptted
  (fate#316335).
- md-cluster: introduce dlm_lock_sync_interruptible to fix tasks
  hang (fate#316335).
- md-cluster: convert the completion to wait queue (fate#316335).
- md-cluster: protect md_find_rdev_nr_rcu with rcu lock
  (fate#316335).
- md-cluster: clean related infos of cluster (fate#316335).
- md: changes for MD_STILL_CLOSED flag (fate#316335).
- md-cluster: remove some unnecessary dlm_unlock_sync
  (fate#316335).
- md-cluster: use FORCEUNLOCK in lockres_free (fate#316335).
- md-cluster: call md_kick_rdev_from_array once ack failed
  (fate#316335).
- commit a983435
* Wed Sep 21 2016 agraf@suse.de
- arm64: disable hvc_dcc
- commit 30c4b0b
* Wed Sep 21 2016 agraf@suse.de
- arm64: Relocate screen_info.lfb_base on PCI BAR allocation (bsc#975159).
- commit c3f6949
* Wed Sep 21 2016 agraf@suse.de
- arm64: Refuse to install 4k kernel on 64k system
- commit 478142f
* Wed Sep 21 2016 mmarek@suse.com
- Delete now unneeded patches.suse/split-package (bsc#1000118)
- Update config files.
- Refresh patches.suse/supported-flag,
- commit 5c1d976
* Wed Sep 21 2016 jeffm@suse.com
- btrfs: ensure that file descriptor used with subvol ioctls is
  a dir (bsc#999600).
- commit cf44e6a
* Wed Sep 21 2016 jeffm@suse.com
- btrfs: ensure that file descriptor used with subvol ioctls is
  a dir (bsc#999600).
- commit c246d58
* Wed Sep 21 2016 mmarek@suse.com
- rpm/package-descriptions: pv has been merged into -default (fate#315712)
- commit 711ab33
* Wed Sep 21 2016 jslaby@suse.cz
- rpm/package-descriptions: add kernel-syzkaller
- commit 620032b
* Wed Sep 21 2016 mmarek@suse.com
- rpm/kernel-binary.spec.in: Build the -base package unconditionally (bsc#1000118)
- commit 1d8c576
* Wed Sep 21 2016 jslaby@suse.cz
- Add syzkaller flavor (bnc#1000094).
- Update config files.
- syzkaller: no need for gcc plugins (bnc#1000094).
- commit 3c1aea1
* Tue Sep 20 2016 agraf@suse.de
- arm64: Add 64kb flavor for 64kb page size
- commit 4f006b4
* Tue Sep 20 2016 agraf@suse.de
- Switch arm64 default config to 4k
- commit 5244f77
* Tue Sep 20 2016 tiwai@suse.de
- rpm/kernel-docs.spec.in: Add support of sphinx with recent kernels
- commit b503754
* Tue Sep 20 2016 tiwai@suse.de
- Refresh
  patches.fixes/autofs-use-dentry-flags-to-block-walks-during-expire.
  Update git commit tag to sync with upstream.
- commit 5c2468b
* Mon Sep 19 2016 jeffm@suse.com
- Update to 4.8-rc7.
- Eliminated 1 patch.
- commit 70952c1
* Thu Sep 15 2016 mmarek@suse.cz
- Delete scripts/mkpatch.py
  It is an obsolete script that does not work with git, as pointed out by
  Benjamin Poirier.
- commit 38a9f7b
* Thu Sep 15 2016 tiwai@suse.de
- drm/i915: Ignore OpRegion panel type except on select machines (bsc#993996).
- commit 7dc014c
* Thu Sep 15 2016 jslaby@suse.cz
- Linux 4.7.4.
- commit b93c795
* Wed Sep 14 2016 jeffm@suse.com
- config: enable RANDOMIZE_BASE and friends (bsc#998554).
- commit 4de94c3
* Wed Sep 14 2016 jeffm@suse.com
- Update to 4.8-rc6.
- commit 01852e1
* Wed Sep 14 2016 tiwai@suse.de
- drm/i915: Ignore OpRegion panel type except on select machines (bsc#993996).
- commit 6a5bbb1
* Mon Sep 12 2016 mhocko@suse.cz
- mm, oom: prevent premature OOM killer invocation for high
  order request (bnc#994066).
- commit d2c8eb9
* Thu Sep  8 2016 tiwai@suse.de
- Refresh patches.fixes/autofs-use-dentry-flags-to-block-walks-during-expire
  Fix schedule_timeout() call with uninterruptible one (bsc#997639)
- commit 7ad9c1d
* Wed Sep  7 2016 tiwai@suse.de
- autofs - use dentry flags to block walks during expire
  (bsc#997639).
- commit 268a807
* Wed Sep  7 2016 jeffm@suse.com
- config: enable FAIL_MAKE_REQUEST for testing purposes
- commit 28527e8
* Wed Sep  7 2016 jslaby@suse.cz
- Linux 4.7.3 (CVE-2016-6480 bsc#991608).
- Delete
  patches.fixes/aacraid-check-size-values-after-double-fetch-from-user.patch.
- commit 2ecc7fe
* Tue Sep  6 2016 jeffm@suse.com
- Update to 4.8-rc5.
- Config changes:
  - ARMV6: HW_RANDOM_MXC_RNGA=m
- commit a0ab922
* Sun Sep  4 2016 afaerber@suse.de
- config: arm64: Enable brcmfmac
  The Raspberry Pi 3 has a BCM43438, with a firmware package being prepared.
- commit 6575948
* Fri Sep  2 2016 mmarek@suse.com
- rpm/mkspec: Read a default release string from rpm/config.sh (bsc997059)
- commit cf65a8d
* Thu Sep  1 2016 afaerber@suse.de
- config: arm64: Update to 4.8-rc4
- commit 5ce1ddf
* Thu Sep  1 2016 afaerber@suse.de
- config: armv6hl: Update to 4.8-rc4
- commit 14bbfb0
* Thu Sep  1 2016 afaerber@suse.de
- config: armv7hl: Update to 4.8-rc4
- commit 8442357
* Tue Aug 30 2016 jeffm@suse.com
- Revert "Btrfs: improve performance on fsync against new inode
  after rename/unlink" (bsc#981597).
- Revert "Btrfs: fix lockdep warning on deadlock against an
  inode's log mutex" (bsc#981597).
- commit 003f624
* Mon Aug 29 2016 tiwai@suse.de
- drm/i915: Fix S4 resume breakage
  (bsc#984629,bsc#984632,bsc#993472).
- commit 7e4bf41
* Mon Aug 29 2016 tiwai@suse.de
- drm/i915: Fix S4 resume breakage
  (bsc#984629,bsc#984632,bsc#993472).
- drm/i915: Add distinct stubs for PM hibernation phases
  (bsc#984632,bsc#993472).
- x86 / hibernate: Use hlt_play_dead() when resuming from
  hibernation (bsc#984629,bsc#993472).
- commit 1d73b85
* Mon Aug 29 2016 jeffm@suse.com
- Update to 4.8-rc4.
- commit fa01113
* Tue Aug 23 2016 mkubecek@suse.cz
- tcp: fix use after free in tcp_xmit_retransmit_queue()
  (CVE-2016-6828 bsc#994296).
- commit 73d7d3e
* Mon Aug 22 2016 jeffm@suse.com
- Update to 4.8-rc3.
- Eliminated 1 patch.
- commit c0d2ef5
* Sun Aug 21 2016 jslaby@suse.cz
- Linux 4.7.2.
- Refresh patches.fixes/block-copy-bi_vcnt-in-_bio_clone_fast.
- commit 34ba8d6
* Sat Aug 20 2016 mmarek@suse.cz
- rpm/old-flavors: Obsolte kernel-compute by kernel-rt (fate#320686)
- commit 964f3e2
* Sat Aug 20 2016 jason.derose@experient-inc.com
- Enable Sea Island GPUs in AMDGPU
- commit 545853f
* Tue Aug 16 2016 mbrugger@suse.com
- Delete
  patches.arch/arm64-1-6-drivers-net-xgene-MAC-and-PHY-configuration-changes.patch.
- Delete
  patches.arch/arm64-2-6-drivers-net-xgene-Backward-compatibility-with-older-firmware.patch.
- Delete
  patches.arch/arm64-3-6-drivers-net-phy-Add-MDIO-driver.patch.
- Delete
  patches.arch/arm64-6-6-drivers-net-xgene-Fix-module-load-unload-crash.patch.
  Newer version of this patches are upstream
- commit 0fce644
* Tue Aug 16 2016 jslaby@suse.cz
- Linux 4.7.1 (CVE-2016-6516 bsc#991604).
- Delete
  patches.fixes/vfs-ioctl-prevent-double-fetch-in-dedupe-ioctl.
- commit 61bf3f1
* Tue Aug 16 2016 mmarek@suse.com
- rpm/kernel-source.spec.in: Unroll a loop with only a single iteration
- commit 601c09e
* Mon Aug 15 2016 jeffm@suse.com
- Re-enable s390 message catalog patches.
  The printk changes that went into v4.8-rc1 were reverted (temporarily)
  for -rc2, so the old patches merge simply again.
- commit 5640fd4
* Mon Aug 15 2016 jeffm@suse.com
- Update to 4.8-rc2.
- Config changes:
  - Global:
  - HARDENED_USERCOPY=n (we need to examine how it affects performance)
  - s390:
  - S390_GUEST_OLD_TRANSPORT=n (deprecated)
- commit 42c9649
* Mon Aug 15 2016 agraf@suse.de
- Delete
  patches.arch/arm64-0010-KVM-ARM-Hack-to-enable-VGIC-mapping-on-64k-PAGE_SIZE.patch.
  - we no longer need to run on non-64k compliant hardware
- commit c55dae1
* Mon Aug 15 2016 agraf@suse.de
- Remove ppc64le support on early POWER7 systems (we build for p8 by now anyway)
- Delete
  patches.arch/ppc64le-ile-0001-powerpc-Add-global-exports-for-all-interrupt-vectors.patch.
- Delete
  patches.arch/ppc64le-ile-0002-powerpc-Add-relocation-code-for-fixups.patch.
- Delete
  patches.arch/ppc64le-ile-0003-powerpc-Add-hack-to-make-ppc64le-work-on-hosts-witho.patch.
- Delete
  patches.arch/ppc64le-ile-0004-powerpc-Don-t-return-to-BE-mode-when-we-are-already-.patch.
- commit c4ff529
* Mon Aug 15 2016 jeffm@suse.com
- Update to 4.8-rc1.
- Eliminated 7 patches.
- ARM configs need updating.
- Several patches need to be merged by their owners.
- Config changes:
  - Global:
  - GCC_PLUGINS=y (menu option)
  - GCC_PLUGIN_CYC_COMPLEXITY=n
  - TPM:
  - TCG_TIS_SPI
  - TCG_VTPM_PROXY
  - TCG_TIS_ST33ZP24_I2C
  - TCG_TIS_ST33ZP24_SPI
  - Sensors:
  - SENSORS_FTSTEUTATES
  - SENSORS_SHT3x
  - SENSORS_INA3221
  - BMA220=n
  - MMA7660=n
  - MAX5487=n
  - Graphics:
  - DRM_I915_GVT=y
  - ACPI:
  - DPTF_POWER
  - ACPI_CONFIGFS
  - CPUFreq:
  - CPU_FREQ_STAT=n (overhead)
  - PCI:
  - PCIE_DPC=y (should be m but it's a bool)
  - RapidIO:
  - RAPIDIO_CHMAN
  - RAPIDIO_RXS_GEN3
  - IP:
  - TCP_CONG_NV
  - Netfilter:
  - NET_CLS_MATCHALL
  - Virtualization:
  - VIRTIO_VSOCKETS
  - VHOST_VSOCK
  - Networking hardware:
  - INTEL_XWAY_PHY
  - B53=n
  - NVME:
  - NVME_RDMA
  - NVME_TARGET
  - NVME_TARGET_LOOP
  - NVME_TARGET_RDMA
  - Infiniband:
  - RDMA_RXE
  - RTC:
  - RTC_DRV_MAX6916=n
  - Storage:
  - SCSI_UFS_DWC_TC_PCI=n (test hardware)
  - SCSI_UFS_DWC_TC_PLATFORM=n
  - Input:
  - TABLET_USB_PEGASUS
  - INPUT_ATMEL_CAPTOUCH
  - HID:
  - HID_LED
  - HID_ALPS
  - LEDs:
  - LEDS_LP3952
  - LEDS_TRIGGER_DISK
  - Touchscreen I2C/SPI:
  - TOUCHSCREEN_RM_TS
  - TOUCHSCREEN_SILEAD
  - TOUCHSCREEN_SIS_I2C
  - TOUCHSCREEN_SURFACE3_SPI
  - File Systems:
  - EXT4_ENCRYPTION=y
  - PSTORE_LZO_COMPRESS=y
  - NFSD_FLEXFILELAYOUT=y
  - SECURITY_APPARMOR_HASH_DEFAULT=y
  - Crypto:
  - CRYPTO_DH
  - CRYPTO_ECDH
  - CRYPTO_SHA3
  - Video:
  - DRM_I2C_ADV7533
  - Staging:
  - MEDIA_CEC=y (will be part of another module when out of staging)
  - KS7010
  - Audio:
  - SND_SOC_INTEL_BXT_DA7219_MAX98357A_MACH
  - SND_SOC_BT_SCO
  - Misc:
  - IIO_SW_DEVICE
  - IIO_TIGHTLOOP_TRIGGER=n
  - MTD_NAND_MTK
  - x86:
  - INTEL_VBTN
  - PWM_CROS_EC
  - x86_64:
  - CRYPTO_SHA256_MB
  - CRYPTO_SHA512_MB
  - powerpc:
  - GEN_RTC=n
  - HOTPLUG_PCI_POWERNV
  - CXL_BIMODAL=y
  - SCSI_IBMVSCSIS
  - ADB_PMU_LED_DISK=y
  - POWERNV_OP_PANEL
  - JUMP_LABEL_FEATURE_CHECKS=y
  - JUMP_LABEL_FEATURE_CHECK_DEBUG=n
  - CRYPT_CRC32C_VPMSUM
  - BPF_JIT=y
  - s390:
  - KCOV=n
  - CRYPTO_CRC32_S390=y
  - ARM (disabled):
  - MDIO_HISI_FEMAC
  - DRM_SII902X
  - DRM_TOSHIBA_TC358767
  - SND_SUN4I_I2S
  - SND_SOC_ADAU7002
  - SND_SOC_CS35L33
  - SND_SOC_CS53L30
  - SND_SOC_MAX98504
  - SND_SOC_MAX9860
  - SND_SOC_WM8985
  - SUNXI_CCU
  - TI_SYSCON_RESET
  - NET_NCSI (only used by Faraday, which is ARM hardware)
- commit d5c4fe8
* Tue Aug  9 2016 jthumshirn@suse.de
- aacraid: Check size values after double-fetch from user
  (CVE-2016-6480 bsc#991608).
- Delete
  patches.drivers/0001-aacraid-prevent-out-of-bounds-access-due-to-changing.patch.
- commit 39024c1
* Fri Aug  5 2016 jslaby@suse.cz
- rpm/constraints.in: set memory minimum for binaries
  Binary packages are sometimes built on machines with 1G. For example
  one arm build ran in a VM with -smp 1 -m 1024. And it caused OOMs.
  So set the minimal memory to 2G for all archs.
- commit b3acaa2
* Thu Aug  4 2016 jthumshirn@suse.de
- aacraid: prevent out-of-bounds access due to changing fip
  header sizes (bsc#991608, CVE-2016-6480).
- commit 162f969
* Thu Aug  4 2016 neilb@suse.com
- Revert "SUNRPC: xs_sock_mark_closed() does not need to trigger
  socket autoclose" (bsc#990356).
- commit fd538ca
* Wed Aug  3 2016 tiwai@suse.de
- vfs: ioctl: prevent double-fetch in dedupe ioctl
  (CVE-2016-6516,bsc#991604).
- commit 4008557
* Wed Aug  3 2016 mkubecek@suse.cz
- Update
  patches.fixes/netfilter-x_tables-speed-up-jump-target-validation.patch
  references (CVE-2016-4998 bsc#986365).
- commit 10e550e
* Tue Aug  2 2016 jdelvare@suse.de
- Make pinctrl-amd driver modular
  The pinctrl-amd driver can now be built as a module.
- commit 52eb238
* Tue Aug  2 2016 jdelvare@suse.de
- config: Enable missing BayTrail and LynxPoint drivers
  We support the Intel BayTrail and LynxPoint systems so I believe we
  should enable all related drivers.
- commit 69e57d4
* Mon Aug  1 2016 jslaby@suse.cz
- rpm/constraints.in: inscrease binary size req to 25G
  Currently, the build of master's -default kernel consumes exactly 20G.
  So increase the limit from 20G to 25G to stop build failures in the
  BS.
- commit c8360d6
* Wed Jul 27 2016 schwab@suse.de
- group-source-files.pl: mark arch/*/scripts as devel
  make[2]: /usr/src/linux-4.6.4-2/arch/powerpc/scripts/gcc-check-mprofile-kernel.sh: Command not found
- commit aa32770
* Mon Jul 25 2016 tiwai@suse.de
- apparmor: fix arg_size computation for when setprocattr is
  null terminated (CVE-2016-6187,bsc#988307).
- commit d1fa560
* Mon Jul 25 2016 mkubecek@suse.cz
- netfilter: x_tables: speed up jump target validation
  (CVE-2016-4997 bsc#986362).
- commit 9105e0d
* Mon Jul 25 2016 jeffm@suse.com
- Update to 4.7-final.
- commit 24f30d5
* Thu Jul 21 2016 agraf@suse.de
- Disable all ARMv8.1 and 8.2 features (bsc#981051)
- commit 684e9e1
* Thu Jul 21 2016 jeffm@suse.com
- config.conf: re-enable arm64/vanilla config
- commit 152f160
* Tue Jul 19 2016 jslaby@suse.cz
- Update patches.kernel.org/patch-4.6.3-4 (bnc#982729 bnc#985604).
  Add one more reference.
- commit 8f4696b
* Mon Jul 18 2016 jeffm@suse.com
- Update to 4.7-rc7.
- Eliminated 2 patches.
- commit f837062
* Mon Jul 18 2016 mmarek@suse.com
- rpm/kernel-spec-macros: Add kver_cmp macro
  This allows to use %%if statements based on the version of the kernel to
  be built.
- commit ea700be
* Fri Jul 15 2016 afaerber@suse.de
- config: armv7hl: Enable POWER_RESET_AS3722 for lpae
  It's needed for the Jetson TK1 (boo#989450).
  (cherry picked from commit 5348402a99300b0b9fbe3e395a0d8d029833cce8)
- config: armv7hl: Enable POWER_RESET_AS3722 for lpae
  It's needed for the Jetson TK1 (boo#989450).
- config: armv7hl: Enable POWER_RESET_AS3722 for lpae
  It's needed for the Jetson TK1.
- commit 4d3bed9
* Fri Jul 15 2016 tiwai@suse.de
- rpm/kernel-source.spec.in: recommends openssl-devel (bsc#987384)
- commit 2c51311
* Fri Jul 15 2016 tiwai@suse.de
- Update patch-tags for ecrpytfs fix patches (boo#989084).
- commit ecd9058
* Wed Jul 13 2016 tiwai@suse.de
- rpm/constraints.in: Increase to 8GB for kernel-source
  4GB seems still too tight for some archs like ppc64le...
- commit d82b2bf
* Mon Jul 11 2016 jslaby@suse.cz
- Linux 4.6.4 (bnc#982729).
- Delete
  patches.drivers/0001-Subject-PATCH-USB-xhci-Add-broken-streams-quirk-for-.patch.
- commit 103c936
* Mon Jul 11 2016 tiwai@suse.de
- apparmor: fix oops, validate buffer size in
  apparmor_setprocattr() (CVE-2016-6187,bsc#988307).
- commit fbe379c
* Fri Jul  8 2016 tiwai@suse.de
- ASoC: intel: Fix sst-dsp dependency on dw stuff (boo#988117).
- commit 7b473e9
* Fri Jul  8 2016 tiwai@suse.de
- Update config files: enable DW_DMAC and ASoC Intel BDW/HSW drivers (boo#988117)
- commit cc11143
* Fri Jul  8 2016 jdelvare@suse.de
- config: Disable RTC_DRV_DS1302
  All other SPI RTC device drivers are disabled, no reason why this
  one would be an exception.
- commit 0721302
* Fri Jul  8 2016 afaerber@suse.de
- config: arm64: Enable TEGRA210_ADMA
- commit 8852ee8
* Fri Jul  8 2016 afaerber@suse.de
- config: arm64: Enable DRM_ANALOGIX_ANX78XX
- commit 2773482
* Fri Jul  8 2016 afaerber@suse.de
- config: armv7hl: Enable HDCP support for Snapdragon
  arm64 already had it enabled.
- commit 1f3ecb7
* Fri Jul  8 2016 afaerber@suse.de
- config: arm64: Align USB gadget options
  Enable serial gadget console support, enable a missing configfs option
  and disable legacy UAC1.
- commit 5065003
* Fri Jul  8 2016 afaerber@suse.de
- config: armv7hl: Enable USB gadget options
  This allows to build solutions like a Ceph USB storage gateway,
  presented at openSUSE Conference:
  https://events.opensuse.org/conference/oSC16/program/proposal/934
- commit a8b4ce6
* Fri Jul  8 2016 afaerber@suse.de
- config: armv6hl: Enable remaining LED triggers
  Also enable flash LED class while at it.
- commit 97b6c11
* Fri Jul  8 2016 afaerber@suse.de
- config: armv6hl: Update to 4.7
- commit 5cd0742
* Thu Jul  7 2016 jeffm@suse.com
- config: restore default cpufreq governor
  The update to 4.7-rc1 mistakenly used CPU_FREQ_DEFAULT_GOV_PERFORMANCE=y.
  This patch reverts to the longtime default of ONDEMAND.
- commit 27cce0c
* Thu Jul  7 2016 neilb@suse.com
- Update patches.fixes/0001-posix_acl-Add-set_posix_acl.patch
  (bsc#986570 CVE-2016-1237).
- Update
  patches.fixes/0002-nfsd-check-permissions-when-setting-ACLs.patch
  (bsc#986570 CVE-2016-1237).
- commit 789949d
* Wed Jul  6 2016 neilb@suse.com
- Update patches.fixes/0001-posix_acl-Add-set_posix_acl.patch
  (bsc#986570 CVE#2016-1237).
- Update
  patches.fixes/0002-nfsd-check-permissions-when-setting-ACLs.patch
  (bsc#986570 CVE#2016-1237).
- commit 10c8c01
* Wed Jul  6 2016 neilb@suse.com
- nfsd: check permissions when setting ACLs (bsc#986570).
- posix_acl: Add set_posix_acl (bsc#986570).
- commit 2763888
* Tue Jul  5 2016 jeffm@suse.com
- Revert "ecryptfs: forbid opening files without mmap handler".
- commit 9fd42f4
* Tue Jul  5 2016 jeffm@suse.com
- Revert "ecryptfs: forbid opening files without mmap handler".
- commit a491e21
* Tue Jul  5 2016 afaerber@suse.de
- config: armv7hl: Enable ipq4019
  It's a Cortex-A7.
- commit 016ff1f
* Tue Jul  5 2016 afaerber@suse.de
- config: armv7hl: Enable BCM2836 support for lpae
  The Raspberry Pi 2 has a Cortex-A7, so let's enable it in lpae flavor.
  Consistently make HW_RANDOM_BCM2835 a module.
- commit fb11bde
* Tue Jul  5 2016 afaerber@suse.de
- config: armv7hl: Enable all LED triggers
  Let's be consistent about offering them. arm64 has them already.
- commit 4dd8d95
* Mon Jul  4 2016 agraf@suse.de
- Remove deprecated patches:
  - Delete patches.arch/arm-arndale-dma.patch.
  - Delete
    patches.arch/arm64-0004-net-xgbe-Add-A0-silicon-support.patch.
- commit 4f0a683
* Mon Jul  4 2016 jeffm@suse.com
- patches.rpmify/i915-fix-build-error-with-werror: actually fix the error
- commit 309a9bd
* Mon Jul  4 2016 jeffm@suse.com
- Update to 4.7-rc6.
- commit 916c4e7
* Mon Jul  4 2016 jeffm@suse.com
- patches.rpmify/i915-fix-build-error-with-werror: fix patch description
- i915: fix build error with -Werror.
- commit cf4ceb9
* Fri Jul  1 2016 jthumshirn@suse.de
- Update config files to allow building of libnvdimm as module.
- commit f8d3041
* Tue Jun 28 2016 mmarek@suse.com
- Delete patches.suse/sd_init.mark_majors_busy.patch (bsc#744658)
  It was only required by the xenlinux frontent drivers.
- commit 50d8ea0
* Mon Jun 27 2016 jeffm@suse.com
- Update to 4.7-rc5.
- Eliminated 1 patch.
- commit 1207339
* Mon Jun 27 2016 jkosina@suse.cz
- HID: hiddev: validate num_values for HIDIOCGUSAGES,
  HIDIOCSUSAGES commands (bsc#986572 CVE-2016-5829).
- commit 0646d06
* Mon Jun 27 2016 mkubecek@suse.cz
- Update patches.kernel.org/patch-4.6.2-3 (add CVE-2016-4997 bsc#986362).
- commit fbd108c
* Sun Jun 26 2016 jslaby@suse.cz
- Linux 4.6.3 (CVE-2016-4951 bsc#981058 bsc#983458).
- Delete
  patches.arch/arm64-mm-always-take-dirty-state-from-new-pte-in-pte.patch.
- Delete
  patches.fixes/tipc-check-nl-sock-before-parsing-nested-attributes.patch.
- commit d4bcf2a
* Wed Jun 22 2016 matwey.kornilov@gmail.com
- config: armv7hl: Update configs for 4.7
  [AF: Updated to -rc6: OMAP5 erratum]
  [AF: Revert CPU_FREQ_DEFAULT_GOV_PERFORMANCE (follows x86)]
  [AF: Keep CONFIG_ARM_EXYNOS[5]_BUS_DEVFREQ enabled]
  [AF: Enable DRM_ANALOGIX_ANX78XX, SND_SOC_WM8960]
- commit 62dcd14
* Tue Jun 21 2016 jlee@suse.com
- KEYS: potential uninitialized variable (bsc#984755,
  CVE-2016-4470).
- commit 96a29db
* Mon Jun 20 2016 jeffm@suse.com
- Update to 4.7-rc4.
- commit 03b01dd
* Mon Jun 20 2016 jslaby@suse.cz
- base: make module_create_drivers_dir race-free (bnc#983977).
- commit 6cfe0b8
* Wed Jun 15 2016 mmarek@suse.cz
- rpm/constraints.in: Really require 4GB for kernel-source, add -rt (bsc#984845)
- commit a0dec36
* Wed Jun 15 2016 mmarek@suse.cz
- rpm/constraints.in: Require 4GB of disk space for kernel-source (bsc#984845)
- commit 1b20111
* Tue Jun 14 2016 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Use the default value for CONFIG_MODULE_SIG_KEY (bsc#983634)
- commit 6eb6cd2
* Mon Jun 13 2016 jeffm@suse.com
- Update to 4.7-rc3.
- 2 patches eliminated.
- commit 59af2d0
* Fri Jun 10 2016 bp@suse.de
- rds: fix an infoleak in rds_inc_info_copy (bsc#983213
  CVE-2016-5244).
- commit 1847ef5
* Fri Jun 10 2016 bp@suse.de
- rds: fix an infoleak in rds_inc_info_copy (bsc#983213
  CVE-2016-5244).
- commit 14295d6
* Fri Jun 10 2016 agraf@suse.de
- enable arm64 config again
- commit c1b6204
* Thu Jun  9 2016 jkosina@suse.cz
- Refresh
  patches.drivers/pstore_disable_efi_backend_by_default.patch.
  pstore_register() error handling is wrong -- it tries to release
  lock before it's acquired, causing spinlock / preemption imbalance.
- commit 0059eb1
* Wed Jun  8 2016 ohering@suse.de
- Delete patches.suse/xen-pv-devmem_is_allowed.patch (bnc#982991)
- commit 66b15dc
* Wed Jun  8 2016 jeffm@suse.com
- ecryptfs: don't allow mmap when the lower file system doesn't
  allow it (bsc#983143 CVE-2016-1583).
- commit c50d3aa
* Wed Jun  8 2016 agraf@suse.de
- arm64: mm: always take dirty state from new pte in
  ptep_set_access_flags (bsc#983458).
- Update config files.
- commit d662464
* Wed Jun  8 2016 jslaby@suse.cz
- Linux 4.6.2.
- commit b664f9a
* Mon Jun  6 2016 ohering@suse.de
- x86/pat: Document the PAT initialization sequence (bnc#982991,
  bnc#974257, bnc#982991).
- x86/xen, pat: Remove PAT table init code from Xen (bnc#982991,
  bnc#974257, bnc#982991).
- x86/mtrr: Fix PAT init handling when MTRR is disabled
  (bnc#982991, bnc#974257, bnc#982991).
- x86/mtrr: Fix Xorg crashes in Qemu sessions (bnc#982991,
  bnc#974257, bnc#982991).
- x86/mm/pat: Replace cpu_has_pat with boot_cpu_has() (bnc#982991,
  bnc#974257, bnc#982991).
- x86/mm/pat: Add pat_disable() interface (bnc#982991, bnc#974257,
  bnc#982991).
- x86/mm/pat: Add support of non-default PAT MSR setting
  (bnc#982991, bnc#974257, bnc#982991).
- commit 3988263
* Mon Jun  6 2016 ohering@suse.de
- Delete patches.suse/xen-pv-devmem_is_allowed.patch (bnc#982991)
- commit 23cb422
* Mon Jun  6 2016 jeffm@suse.com
- Update to 4.7-rc2.
- commit de964ac
* Mon Jun  6 2016 jeffm@suse.com
- config: update ppc64 configs
  Config changes:
- ppc64:
  - PPC_RADIX_MMU=m
  - FSL_LBC=y
  - UIO_FSL_ELBC_GPCM=m
  - UIO_FSL_ELBC_GPCM_NETX5152=y
  - LIVEPATCH=y
- commit 4c2d9e6
* Sat Jun  4 2016 jslaby@suse.cz
- Refresh
  patches.drivers/0001-Subject-PATCH-USB-xhci-Add-broken-streams-quirk-for-.patch.
  Upstream status.
- commit 2720edf
* Sat Jun  4 2016 tiwai@suse.de
- rtlwifi: Fix scheduling while atomic error from commit
  49f86ec21c01 (boo#983036).
- commit 5a9c4b2
* Thu Jun  2 2016 oneukum@suse.com
- USB: xhci: Add broken streams quirk for Frescologic device id
  1009  (bnc#982729).
- commit 4a04f23
* Thu Jun  2 2016 jslaby@suse.cz
- Linux 4.6.1 (boo#978953 bsc#966849 bsc#971799 bsc#979715
  CVE-2016-3713).
- Delete
  patches.fixes/Bluetooth-vhci-Fix-race-at-creating-hci-device.
- Delete
  patches.fixes/Bluetooth-vhci-fix-open_timeout-vs.-hdev-race.
- Delete patches.fixes/Bluetooth-vhci-purge-unhandled-skbs.
- Delete patches.fixes/kvm-remove-variable-physbase-mtrr.patch.
- Delete
  patches.fixes/watchdog-sp5100_tco-properly-check-for-new-register.
- commit 9cdcddd
* Wed Jun  1 2016 mbrugger@suse.com
- arm64: Update config files.
  Build MDIO_XGENE as module
- commit 56eece9
* Wed Jun  1 2016 mbrugger@suse.com
- Revert "Set CONFIG_NET_XGENE=y as a workaround for (bsc#973756)"
  This reverts commit b829bc700eb18f7cd1ef48d42964555e9e9f2357.
- commit 807fbbd
* Wed Jun  1 2016 jeffm@suse.com
- Update to 4.7-rc1.
- Eliminated 14 patches.
- ARM configs need updating.
- Config changes:
  - General:
  - NMI_LOG_BUF_SHIFT=13 (default 8k, old value ~4k)
  - CC_OPTIMIZE_FOR_PERFORMANCE=y (no change)
  - MEMORY_HOTPLUG_DEFAULT_ONLINE=n (no change)
  - CPU_FREQ_DEFAULT_GOV_PERFORMANCE=y (no change)
  - SLAB_FREELIST_RANDOM=y (security feature, minimal performance impact)
  - DEVFREQ_GOV_PASSIVE=m
  - CPU_FREQ_GOV_SCHEDUTIL=m
  - Security:
  - KEY_DH_OPERATIONS=y
  - SECURITY_LOADPIN=n
  - DAX:
  - NVDIMM_DAX=y
  - DEV_DAX=m
  - DEV_DAX_PMEM=m
  - EFI:
  - EFI_BOOTLOADER_CONTROL=m
  - EFI_CAPSULE_LOADER=m
  - Misc:
  - RCU_PERF_TEST=m
  - HIST_TRIGGERS=y
  - TEST_HASH=n
  - Z3FOLD=m
  - ACPI_TABLE_UPGRADE=y
  - Options for existing drivers:
  - F2FS
  - F2FS_FAULT_INJECTION=y
  - QED
  - QED_SRIOV=y
  - QEDE
  - QEDE_GENEVE=y
  - QEDE_VXLAN=y
  - MLXSW_SPECTRUM
  - MLXSW_SPECTRUM_DCB=y
  - SERIAL_8250
  - SERIAL_8250_FINTEK=y
  - DRM_I915
  - DRM_I915_WERROR=y
  - DRM_I915_DEBUG=n
  - DRM_I915_DEBUG_GEM=n
  - NFC_PN533
  - NFC_PN533_USB=m
  - NFC_PN533_I2C=m
  - TCM_QLA2XXX
  - TCM_QLA2XXX_DEBUG=n
  - DRM_AMDGPU
  - DRM_AMDGPU_GART_DEBUGFS=n
  - WIZNET_W5100
  - WIZNET_W5100_SPI=m
  - Storage:
  - ISCSI_TARGET_CXGB4=m
  - SATA_DWC=n -- ppc32 only
  - Networking:
  - RXKAD=y
  - GTP=m
  - Sound:
  - SND_SOC_TAS5720=m
  - USB:
  - UCSI=m
  - Video:
  - VIDEO_TW686X=m
  - Misc drivers:
  - MFD_MAX77620=n
  - DRM_ARCPGU=n
  - PWRSEQ_EMMC=m
  - PWRSEQ_SIMPLE=m
  - PCIE_DPC=m
  - SENSORS_MAX31722=m
  - INT3406_THERMAL=m
  - GENERIC_ADC_THERMAL=m
  - LEDS_TRIGGER_MTD=n (bool)
  - LEDS_TRIGGER_PANIC=n (bool)
  - RTC_DRV_DS1302=m
  - SYNC_FILE=n
  - AD5592R=n
  - AD5593R=n
  - AM2315=m
  - BMI160_I2C=m
  - BMI160_SPI=m
  - BH1780=m
  - MAX44000=m
  - VEML6070=m
  - BMC150_MAGN_I2C=m
  - BMC150_MAGN_SPI=m
  - DS1803=m
  - MCP4131=m
  - HP03=m
  - HP206C=m
  - x86:
  - PERF_EVENTS_INTEL_RAPL=y
  - PERF_EVENTS_INTEL_CSTATE=y
  - SND_SOC_INTEL_BXT_RT298_MACH=m
  - INTEL_PMC_CORE=y
  - CROS_KBD_LED_BACKLIGHT=m
  - MCE_AMD_INJ=m
  - HID_ASUS=m
  - s390:
  - GPIOLIB=n
  - ARM:
  - SPI_ROCKCHIP=n
  - DRM_ANALOGIX_ANX78XX=n
  - SND_SOC_WM8960=n
  - COMMON_CLK_OXNAS=n
- commit 7dd2551
* Wed Jun  1 2016 mbrugger@suse.com
- [v1,6/6] drivers: net: xgene: Fix module load/unload crash
  (bsc#981652 bsc#979043).
- Update config files.
- [v1,3/6] drivers: net: phy: Add MDIO driver (bsc#981652
  bsc#979043).
- [v1, 2/6] drivers: net: xgene: Backward compatibility with
  older firmware (bsc#981652 bsc#979043).
- [v1,1/6] drivers: net: xgene: MAC and PHY configuration changes
  (bsc#981652 bsc#979043).
- [v1,6/6] drivers: net: xgene: Fix module load/unload crash
  (bsc#981652 bsc#979043).
- Update config files.
- [v1,3/6] drivers: net: phy: Add MDIO driver (bsc#981652
  bsc#979043).
- [v1, 2/6] drivers: net: xgene: Backward compatibility with
  older firmware (bsc#981652 bsc#979043).
- [v1,1/6] drivers: net: xgene: MAC and PHY configuration changes
  (bsc#981652 bsc#979043).
- commit d0e3d83
* Thu May 26 2016 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Obsolete SLE12-SP1 compat-wireless-kmp (bsc#975894)
- commit 127728b
* Wed May 25 2016 dmueller@suse.com
- Set CONFIG_NET_XGENE=y as a workaround for (bsc#973756)
- commit b829bc7
* Wed May 25 2016 tiwai@suse.de
- Fix build breakage due to missing buildroot in rpm/kernel-binary.spec.in
- commit c03eb71
* Wed May 25 2016 tiwai@suse.de
- Update patch-mainline tags
- patches.fixes/ALSA-timer-Fix-leak-in-SNDRV_TIMER_IOCTL_PARAMS
- patches.fixes/ALSA-timer-Fix-leak-in-events-via-snd_timer_user_cca
- patches.fixes/ALSA-timer-Fix-leak-in-events-via-snd_timer_user_tin
- patches.fixes/Bluetooth-vhci-Fix-race-at-creating-hci-device
- patches.fixes/Bluetooth-vhci-fix-open_timeout-vs.-hdev-race
- patches.fixes/Bluetooth-vhci-purge-unhandled-skbs
- commit f3a62f6
* Wed May 25 2016 tiwai@suse.de
- Bluetooth: fix power_on vs close race (bsc#966849).
- commit d1682e1
* Tue May 24 2016 jeffm@suse.com
- drm/amd: add Kconfig dependency for ACP on DRM_AMDGPU.
- Update config files.
- commit 99e9d31
* Tue May 24 2016 ohering@suse.de
- Use CONFIG_64bit instead of IS_ENABLED in hv_storvsc
- commit 2369093
* Tue May 24 2016 tiwai@suse.de
- rpm/kernel-binary.spec.in: Fix build error when no firmware is installed
- commit a09ef60
* Tue May 24 2016 mmarek@suse.com
- rpm/kernel-binary.spec.in: Do not package helper files in -devel (bsc#981204)
- commit 4c334f0
* Tue May 24 2016 mkubecek@suse.cz
- tipc: check nl sock before parsing nested attributes
  (CVE-2016-4951 bsc#981058).
- commit 353e24b
* Mon May 23 2016 mmarek@suse.com
- rpm/kernel-binary.spec.in: Install only needed firmware for -base (bsc#966447)
- commit f685839
* Mon May 23 2016 mmarek@suse.com
- rpm/kernel-binary.spec.in: Fix placement of the reproducible build hack
- commit 26e4b73
* Mon May 23 2016 ohering@suse.de
- Update change for hv-storvsc to set sg_tablesize on x86
- commit 758fc22
* Tue May 17 2016 tiwai@suse.de
- ALSA: hrtimer: Handle start/stop more properly (bsc#973378).
- commit 713ff49
* Tue May 17 2016 tiwai@suse.de
- watchdog: sp5100_tco: properly check for new register layouts
  (boo#978953).
- commit 8096c43
* Mon May 16 2016 bp@suse.de
- kvm: Remove variable physbase MTRR 0x2f8 (bsc#979715,
  CVE-2016-3713).
- commit ffec37b
* Mon May 16 2016 jeffm@suse.com
- Update to 4.6-final.
- Eliminated 1 patch.
- Config changes:
  - MLX5_CORE_EN_VXLAN=y
- commit d9e67cc
* Fri May 13 2016 bp@suse.de
- net: fix infoleak in llc (bsc#978821, CVE-2016-4485).
- commit 4715b83
* Fri May 13 2016 bp@suse.de
- net: fix infoleak in llc (bsc#978821, CVE-2016-4485).
- commit f2da272
* Fri May 13 2016 tiwai@suse.de
- Update tags in two patches for CVE-2016-4578, bsc#979879
- commit f3ff4d1
* Wed May 11 2016 jslaby@suse.cz
- Linux 4.5.4 (bsc#969870).
- Delete
  patches.arch/ACPI-processor-Request-native-thermal-interrupt-hand.
- commit db90c25
* Wed May 11 2016 jeffm@suse.com
- config: FRAME_POINTER is required on i386/x86_64 vanilla configs
- commit 7b99bd4
* Wed May 11 2016 jeffm@suse.com
- config: re-disable FRAME_POINTER on i386/x86_64
  It was enabled during the brief time that STACK_UNWIND was disabled and
  should have been disabled once that patchset was updated.
- commit 7303146
* Wed May 11 2016 tiwai@suse.de
- ALSA: timer: Fix leak in events via snd_timer_user_tinterrupt
  (CVE-2016-4569,bsc#979213).
- ALSA: timer: Fix leak in events via snd_timer_user_ccallback
  (CVE-2016-4569,bsc#979213).
- ALSA: timer: Fix leak in SNDRV_TIMER_IOCTL_PARAMS
  (CVE-2016-4569,bsc#979213).
- ALSA: timer: Fix leak in events via snd_timer_user_tinterrupt
  (CVE-2016-4569,bsc#979213).
- ALSA: timer: Fix leak in events via snd_timer_user_ccallback
  (CVE-2016-4569,bsc#979213).
- ALSA: timer: Fix leak in SNDRV_TIMER_IOCTL_PARAMS
  (CVE-2016-4569,bsc#979213).
- commit 875e079
* Wed May 11 2016 tiwai@suse.de
- Bluetooth: vhci: Fix race at creating hci device
  (bsc#971799,bsc#966849).
- Bluetooth: vhci: purge unhandled skbs (bsc#971799,bsc#966849).
- Bluetooth: vhci: fix open_timeout vs. hdev race
  (bsc#971799,bsc#966849).
- Bluetooth: vhci: Fix race at creating hci device
  (bsc#971799,bsc#966849).
- Bluetooth: vhci: purge unhandled skbs (bsc#971799,bsc#966849).
- Bluetooth: vhci: fix open_timeout vs. hdev race
  (bsc#971799,bsc#966849).
- commit c39ec8d
* Tue May 10 2016 mkubecek@suse.cz
- net: fix infoleak in rtnetlink (CVE-2016-4486 bsc#978822).
- commit 61212a2
* Tue May 10 2016 mkubecek@suse.cz
- bpf: fix refcnt overflow (CVE-2016-4558 bsc#979019).
- commit 6f2153b
* Tue May 10 2016 mkubecek@suse.cz
- bpf: fix double-fdput in replace_map_fd_with_map_ptr()
  (CVE-2016-4557 bsc#979018).
- commit c96cd1e
* Mon May  9 2016 mmarek@suse.com
- rpm/kernel-binary.spec.in: Make KMPs provide "$name-kmp" (bsc#976634)
- commit c1a48cb
* Mon May  9 2016 jeffm@suse.com
- Update to 4.6-rc7
- Eliminated 1 patch.
- Config changes:
  - ARM64:
  - SATA_AHCI_SEATTLE=m
- commit 7e682be
* Thu May  5 2016 jslaby@suse.cz
- Linux 4.5.3.
- Delete patches.arch/arm64-kvm-fix-hrtimer.patch.
- Delete
  patches.fixes/sched-cgroup-Fix-cleanup-cgroup-teardown-init.patch.
- Update config files (BMP085 changed to m).
- commit d29747f
* Tue May  3 2016 jslaby@suse.cz
- sched/cgroup: Fix/cleanup cgroup teardown/init.
- commit 4da1329
* Mon May  2 2016 jeffm@suse.com
- Update to 4.6-rc6.
- Config changes:
  - ARM64:
  - I2C_XLP9XX=m
- commit a3fdd2b
* Mon May  2 2016 jeffm@suse.com
- config: use fragment configs for vanilla
  scripts/run_oldconfig.sh now preserves the options needed by the spec file.
- commit db91738
* Fri Apr 29 2016 mmarek@suse.com
- rpm/kernel-binary.spec.in: CONFIG_MODULE_SIG_KEY is not needed as a macro
- commit f445774
* Thu Apr 28 2016 jeffm@suse.com
- Revert "config: use fragment configs for vanilla"
  This reverts commit aa69781bd1b338ca6d45d2e2f3f88296c3d5f3f5.
  The macros in the spec file don't work with the fragments yet.
- commit 9f363d4
* Thu Apr 28 2016 jeffm@suse.com
- config: use fragment configs for vanilla
- commit aa69781
* Wed Apr 27 2016 jeffm@suse.com
- rpm/kernel-binary.spec.in: only merge configs when vanilla is a fragment
  We can skip the (slow) merging when we know that the config isn't a
  fragment by keying off of an always-defined option like CONFIG_MMU.
- commit 66c90c3
* Tue Apr 26 2016 jeffm@suse.com
- config: resync vanilla configs with default
  This is the result of copying default (or pae) to vanilla and running
  run_oldconfig.sh --vanilla.
  Differences from default:
- General:
  - LOCALVERSION="-vanilla" -- obvious
- x86_64/i386:
  - SCHED_OMIT_FRAME_POINTER=y -- option is removed with STACK_UNWIND=y
- commit 4885ab3
* Mon Apr 25 2016 jeffm@suse.com
- Update to 4.6-rc5.
- Config changes:
  - SERIAL_8250_RT288X=n (mips32 only)
- commit 8f81955
* Mon Apr 25 2016 jeffm@suse.com
- rpm/kernel-binary.in: reassemble vanilla config from arch default and fragment
  This patch reassembles the vanilla config using the default config
  for the arch ("default" for everything but i386 which uses "pae") and
  the vanilla config fragment.
  This will do the right thing even if the vanilla config is still a
  standalone config, but scripts/kconfig/merge_config.sh will be slow.  Care
  should be taken to convert the vanilla configs on any branch that pulls
  this commit.
- commit a9a75a0
* Thu Apr 21 2016 jslaby@suse.cz
- Update patches.kernel.org/patch-4.5.1-2 (fate#318900 bsc#963490
  bnc#972330).
  One more bnc.
- commit 0454a6e
* Wed Apr 20 2016 afaerber@suse.de
- arm: Drop patches.arch/arm-xen-fixup.patch
  The SUSE Xen patches are no longer applied on master branch, so this
  fixup is unneeded. The define added is not used elsewhere.
- commit 23accf5
* Wed Apr 20 2016 eich@suse.com
- rpm/kernel-binary.spec.in:
  Add
  Recommends: perl make gcc
  to kernel-devel. This will install the tools requires to build
  kernels or kernel modules.
- commit 9c9087c
* Wed Apr 20 2016 jslaby@suse.cz
- Linux 4.5.2 (fate#318900 bsc#963490).
- Delete patches.suse/fs_add_file_dentry.patch.
- Delete patches.suse/nfs-use-file-dentry.patch.
- commit 8a6791e
* Tue Apr 19 2016 mkubecek@suse.cz
- series.conf: move netfilter section right after core networking
- commit c7ac3f0
* Tue Apr 19 2016 mkubecek@suse.cz
- netfilter: x_tables: fix unconditional helper (CVE-2016-3134
  bsc#971126).
- netfilter: x_tables: make sure e->next_offset covers remaining
  blob size (CVE-2016-3134 bsc#971126).
- netfilter: x_tables: validate e->target_offset early
  (CVE-2016-3134 bsc#971126).
- netfilter: x_tables: check for size overflow (CVE-2016-3135
  bsc#970904).
- commit 99697f1
* Tue Apr 19 2016 mkubecek@suse.cz
- series.conf: move netfilter section right after core networking
- commit 9105886
* Mon Apr 18 2016 jeffm@suse.com
- Update to 4.6-rc4.
- Eliminated 1 patch.
- commit 059d33a
* Mon Apr 18 2016 rgoldwyn@suse.com
- cifs: Use file_dentry() (bsc#974527).
- commit e46ea9c
* Mon Apr 18 2016 jslaby@suse.cz
- Update patches.kernel.org/patch-4.5.1 (CVE-2016-2184
  CVE-2016-2185 CVE-2016-2186 CVE-2016-3140 CVE-2016-3689
  bnc#967903 bnc#970892 bnc#970958 bnc#971124 bnc#971628
  boo#969098 boo#970968 boo#971737 boo#971853 bsc#969383
  bsc#969870 bsc#971125 bnc#970955 CVE-2016-3136).
  One more reference.
- commit da73f3b
* Thu Apr 14 2016 jeffm@suse.com
- Update to 4.6-rc3.
- Eliminated 3 patches.
- Config changes:
  - i386/default: FB_OLPC_DCON=m
- commit 43f1ed4
* Thu Apr 14 2016 afaerber@suse.de
- arm64: Drop broken non-mainline Synopsys USB driver
  For 13.2 a downstream USB driver was added (USB_EHCI_HCD_SYNOPSYS)
  for the Juno board (boo#902632). With 4.6 that driver no longer builds.
  A check of arch/arm64/boot/dts/arm/juno-base.dtsi indicates that it
  is using the "generic-ehci" compatible string, i.e. not this driver.
  Therefore drop these patches:
  patches.arch/arm64-0001-usb-Add-support-for-Synopsis-H20AHB-EHCI-host-contro.patch
  patches.arch/arm64-0002-usb-fix-hcd-h20ahb-driver-depends.patch
  Cc: Andreas Schwab <schwab@suse.de>
- commit aab4a72
* Thu Apr 14 2016 afaerber@suse.de
- config: armv7hl: Disable USB_EHCI_HCD_SYNOPSYS
  patches.arch/arm64-0001-usb-Add-support-for-Synopsis-H20AHB-EHCI-host-contro.patch
  was added for the arm64 Juno board (bsc#902632).
  Is no longer building okay in 4.6, so disable it where not needed, as a
  first step.
- commit e96d206
* Thu Apr 14 2016 afaerber@suse.de
- config: arm64: Enable drivers for ZynqMP
  Enable options reported missing for Xilinx Zynq UltraScale+ MPSoC.
- commit b513584
* Thu Apr 14 2016 agraf@suse.de
- Update config files: arm64: Enable Xilinx ZynqMP
- Update config files: Enable Xlilinx ZynqMP
- commit fd7ad3d
* Wed Apr 13 2016 mmarek@suse.cz
- rpm/kernel-binary.spec.in: No -kgraft subpackage for openSUSE (fate#320268)
- commit 269d6bf
* Wed Apr 13 2016 jslaby@suse.cz
- Linux 4.5.1 (CVE-2016-2184 CVE-2016-2185 CVE-2016-2186
  CVE-2016-3140 CVE-2016-3689 bnc#967903 bnc#970892 bnc#970958
  bnc#971124 bnc#971628 boo#969098 boo#970968 boo#971737
  boo#971853 bsc#969383 bsc#969870 bsc#971125).
- Delete
  patches.arch/intel_idle-prevent-SKL-H-boot-failure-when-C8-C9-C10.
- Delete
  patches.drivers/0001-Input-ims-pcu-sanity-check-against-missing-interface.patch.
- Delete
  patches.drivers/0001-Input-powermate-fix-oops-with-malicious-USB-descript.patch.
- Delete
  patches.drivers/0001-USB-digi_acceleport-do-sanity-checking-for-the-numbe.patch.
- Delete
  patches.drivers/0001-USB-usb_driver_claim_interface-add-sanity-checking.patch.
- Delete
  patches.drivers/ALSA-hda-Don-t-handle-ELD-notify-from-invalid-port.
- Delete
  patches.drivers/ALSA-hda-Fix-forgotten-HDMI-monitor_present-update.
- Delete
  patches.drivers/ALSA-hda-Fix-spurious-kernel-WARNING-on-Baytrail-HDM.
- Delete
  patches.drivers/ALSA-hda-Fix-unexpected-resume-through-regmap-code-p.
- Delete
  patches.drivers/ALSA-hda-Limit-i915-HDMI-binding-only-for-HSW-and-la.
- Delete
  patches.drivers/ALSA-hda-Really-restrict-i915-notifier-to-HSW.
- Delete
  patches.drivers/ALSA-usb-audio-Add-sanity-checks-for-endpoint-access.
- Delete
  patches.drivers/ALSA-usb-audio-Fix-NULL-dereference-in-create_fixed.
- Delete
  patches.drivers/drm-radeon-rework-fbdev-handling-on-chips-with-no-co.
- Delete
  patches.fixes/net-irda-Fix-use-after-free-in-irtty_open.patch.
- commit cf9b28d
* Sun Apr 10 2016 afaerber@suse.de
- config: armv7hl: Disable SND_SOC_MT8173_*
  MediaTek MT8173 is arm64.
- commit 43b03db
* Sun Apr 10 2016 afaerber@suse.de
- config: armv7hl: Update for 4.6-rc2
- commit 8c87f3a
* Sun Apr 10 2016 afaerber@suse.de
- config: armv6hl: Update for 4.6-rc2
- commit 5a8a02f
* Sun Apr 10 2016 afaerber@suse.de
- config: arm64: Update for 4.6-rc2
  Update configs and align vanilla with default again.
- commit 3ec8358
* Sat Apr  9 2016 afaerber@suse.de
- config: armv7hl: Enable R8169
  Enable RTL8169 PCI NIC, found on Jetson TK1 board.
- commit 3cbd7e2
* Thu Apr  7 2016 jeffm@suse.com
- Delete patches.suse/dm-mpath-no-activate-for-offlined-paths.
  According to Hannes, this patch is obsoleted by an upstream implementation.
- commit c78ad02
* Thu Apr  7 2016 ohering@suse.de
- Delete POWER4 specific patches.suse/8250-sysrq-ctrl_o.patch.
- commit 05568ac
* Thu Apr  7 2016 oneukum@suse.com
- USB: digi_acceleport: do sanity checking for the number of ports
  (bnc#970892, CVE-2016-3140).
- commit c3d2a95
* Wed Apr  6 2016 agraf@suse.de
- KVM: arm/arm64: Handle forward time correction gracefully (bnc#974266).
- commit 76b2c0d
* Tue Apr  5 2016 oneukum@suse.com
- Input: powermate - fix oops with malicious USB descriptors
  (bnc#970958, CVE-2016-2186).
- commit 9c51535
* Tue Apr  5 2016 jslaby@suse.cz
- Disable KASAN+KCOV for stack unwinder code.
  Disable kcov too.
- commit 7f2acea
* Tue Apr  5 2016 oneukum@suse.com
- USB: usb_driver_claim_interface: add sanity checking
  (bnc#971124, CVE-2016-2185).
- commit babf987
* Tue Apr  5 2016 oneukum@suse.com
- Input: ims-pcu - sanity check against missing interfaces
  (bnc#971628, CVE-2016-3689).
- commit f5cb5e8
* Mon Apr  4 2016 jeffm@suse.com
- lightnvm: fix "warning: ‘ret’ may be used uninitialized".
- virtio: fix "warning: ‘queue’ may be used uninitialized".
- mac80211: fix "warning: ‘target_metric’ may be used
  uninitialized".
- commit a05f04c
* Mon Apr  4 2016 jeffm@suse.com
- Update to 4.6-rc2.
- commit 8678e34
* Mon Apr  4 2016 mmarek@suse.com
- rpm/find-requires: Generate dependencies for KMPs defined in supported.conf (fate#319339)
- commit 007a83c
* Mon Apr  4 2016 jeffm@suse.com
- Merge mpath-fix into patch into feature patch.
- Refresh patches.suse/dm-mpath-no-activate-for-offlined-paths.
- Delete patches.suse/mpath-fix.
- commit e104ad5
* Mon Apr  4 2016 jeffm@suse.com
- Update to 4.6-rc1.
- Eliminated 12 patches.
- ARM configs need updating.
- Config changes:
  - i386/x86_64
  - PERF_EVENTS_AMD_POWER=m
  - DELL_SMBIOS=m
  - x86_64:
  - ZONE_DEVICE=y (required by DAX)
  - X86_INTEL_MEMORY_PROTECTION_KEYS=y
  - PCI_HYPERV=m
  - CONFIG_VOP_BUS=m
  - VOP=m
  - ppc64:
  - DEFERRED_STRUCT_PAGE_INIT=y
  - DISABLE_MPROFILE_KERNEL=n
  - s390:
  - IRQ_DOMAIN_DEBUG=y
  - Networking:
  - NET_ACT_IFE=m
  - NET_IFE_SKBMARK=m
  - NET_IFE_SKBPRIO=m
  - AF_KCM=m
  - NET_DEVLINK=m
  - MACSEC=m
  - NET_DSA_MV88E6123=m
  - BNX2X_GENEVE=y
  - CHELSIO_T4_UWIRE=y
  - E1000E_HWTS=y
  - MLX5_CORE_EN_DCB=y
  - IWLWIFI_PCIE_RTPM=y
  - BATMAN_ADV_BATMAN_V=y
  - CAN_IFI_CANFD=m
  - INFINIBAND_I40IW=m
  - INFINIBAND_RDMAVT=m
  - MM:
  - NVDIMM_PFN=y
  - FS:
  - FS_ENCRYPTION=m
  - FAT_DEFAULT_UTF8=n (change in default)
  - ORANGEFS_FS=m
  - NFSD_BLOCKLAYOUT=y
  - NFSD_SCSILAYOUT=y
  - Debug:
  - PAGE_POISONING=n
  - DEBUG_PAGE_REF=n
  - CPU_HOTPLUG_STATE_CONTROL=n
  - OF_RECONFIG_NOTIFIER_ERROR_INJECT=n
  - TEST_BITMAP=n
  - STACK_VALIDATION=y (compile time)
  - KASAN=n (runtime)
  - KCOV=n (runtime)
  - Input:
  - MOUSE_PS2_BYD=y
  - TOUCHSCREEN_MELFAS_MIP4=m
  - RMI4_CORE=m
  - RMI4_I2C=m
  - RMI4_SPI=m
  - RMI4_F11=y
  - RMI4_F12=y
  - RMI4_F30=y
  - SERIAL_8250_MOXA=m
  - SERIAL_MVEBU_UART=n (no module option)
  - HID:
  - HID_CMEDIA=m
  - Bluetooth:
  - BT_LEDS=y
  - BT_HCIUART_AG6XX=y
  - DRM:
  - DRM_DP_AUX_CHARDEV=y
  - DRM_AMD_ACP=y
  - DRM_I915_USERPTR=y
  - Misc:
  - LEDS_IS31FL32XX=m
  - I2C_DEMUX_PINCTRL=m
  - GPIO_104_DIO_48E=m
  - GPIO_WS16C48=m
  - GPIO_TPIC2810=m
  - GPIO_PISOSR=m
  - SENSORS_LTC2990=m
  - RTC_DRV_DS1307_HWMON=y
  - ATLAS_PH_SENSOR=m
  - INV_MPU6050_I2C=m
  - TPL0102=m
  - STM_SOURCE_HEARTBEAT=m
  - FW_CFG_SYSFS=m
  - FW_CFG_SYSFS_CMDLINE=y
  - RAPIDIO_MPORT_CDEV
  - Watchdog:
  - EBC_C384_WDT=m
  - INTEL_MEI_WDT=m
  - NI903X_WDT=m
  - MFD:
  - MFD_ACT8945A=n
  - MFD_AXP20X_I2C=n
  - MFD_TPS65086=n
  - Sensors and DACs for specialty applications:
  - TI_ADC0832=n
  - TI_ADS1015=n
  - AD5761 (go fix)
  - STX104=n
  - VF610_DAC=n
  - AFE4403=n
  - AFE4404=n
  - INV_MPU6050_SPI=n
  - MPL115_I2C=n
  - MPL115_SPI=n
  - ARM:
  - PCIE_DW_PLAT=n
  - ATH10K_AHB=n
  - SPI_AXI_SPI_ENGINE=n
  - SND_SUN4I_SPDIF=n
  - SND_SOC_PCM179X_I2C=n
  - SND_SOC_PCM179X_SPI=n
  - SND_SOC_RT5616=n
  - RTC_DRV_RX6110=n
  - QCOM_HIDMA_MGMT=n
  - QCOM_HIDMA=n
  - GOLDFISH=n
  - MDIO_THUNDER=n
- commit d293079
* Mon Apr  4 2016 jeffm@suse.com
- Delete patches.fixes/scsi-ibmvscsi-show-config.patch.
  This patch was added to address empty sysfs files in SLES9.  The root
  cause was ultimately identified later: the buffer size passed to the
  hardware to query was a 16-bit value, so 64k caused nothing to be
  returned.  It was fixed correctly in v3.7 commit 225c56960fc
  (ibmvscsi: Fix host config length field overflow), rendering this
  patch unnecessary.
- commit 9afce9b
* Mon Apr  4 2016 mmarek@suse.com
- rpm/kernel-source.rpmlintrc: Disable rpmlint check for KMP subpackages
  The check is there to ensure that KMPs are built using the
  %%kernel_module_package macro, but we are deliberately not doing this for
  KMPs built from the kernel specfile (fate#319339).
- commit 7c48b60
* Sun Apr  3 2016 jslaby@suse.cz
- Update config files.
  Set SERIAL_8250_SHARE_IRQ (bnc#973748).
- commit 606f94a
* Sat Apr  2 2016 tiwai@suse.de
- ACPI / processor: Request native thermal interrupt handling
  via _OSC (bsc#969870).
- commit f6eec7e
* Fri Apr  1 2016 mmarek@suse.com
- rpm/kernel-binary.spec.in: Only build the -kgraft package for modular kernels (fate#320268)
- commit 9bab96f
* Fri Apr  1 2016 mmarek@suse.com
- rpm/kernel-binary.spec.in: Only build KMPs if CONFIG_SPLIT_PACKAGE=y (fate#319339)
- commit def905b
* Fri Apr  1 2016 mmarek@suse.com
- rpm/kernel-binary.spec.in: Tag KMPs so that weak-modules2 ignores them
  Also require a suse-module-tools version that can handle this (fate#319339).
- commit 58d21f9
* Fri Apr  1 2016 mmarek@suse.com
- rpm/kernel-binary.spec.in: Add rpm scriptlets for KMPs (fate#319339)
  Use the --{add,remove}-kernel-modules options of weak-modules2 instead
  of --{add,remove}-kmp, because we do not want any symlinks to be created
  for these KMPs.
- commit 95f8b94
* Thu Mar 31 2016 mmarek@suse.com
- rpm/split-modules: Split modules into KMPs defined in supported.conf (fate#319339)
- commit 39da39b
* Thu Mar 31 2016 mmarek@suse.com
- rpm/mkspec: Generate KMP subpackage sections from a template (fate#319339)
  The KMPs are defined in the supported.conf file using a +<name>-kmp
  guard.
- commit 09cb6b1
* Thu Mar 31 2016 dvaleev@suse.com
- rpm/kernel-obs-build.spec.in:add e1000 and ibmveth
  Those modules are required in order to have --vm-telnet option
  working
- commit 1e87b6d
* Wed Mar 30 2016 mmarek@suse.com
- rpm/kernel-binary.spec.in: Simplify parsing of supported.conf (fate#319339)
- commit 006b146
* Wed Mar 30 2016 mmarek@suse.com
- rpm/kernel-binary.spec.in: Introduce a kernel-default-kgraft metapackage (fate#320268)
- commit 0439a47
* Mon Mar 28 2016 tiwai@suse.de
- intel_idle: prevent SKL-H boot failure when C8+C9+C10 enabled
  (bsc#969870,boo#970968,boo#969098).
- commit 8cf0ce6
* Thu Mar 24 2016 rgoldwyn@suse.com
- fs: add file_dentry() (bsc#963490,fate#318900).
- nfs: use file_dentry() (fate#318900).
- commit ede6caf
* Thu Mar 24 2016 jdelvare@suse.de
- supported.conf: Fix usb-common path
  usb-common moved to its own subdirectory in kernel v3.16.
- commit 92e1e68
* Thu Mar 24 2016 tiwai@suse.de
- drm/radeon: rework fbdev handling on chips with no connectors
  (boo#971853).
- commit af68ff6
* Wed Mar 23 2016 rgoldwyn@suse.com
- fs: add file_dentry() (bsc#963490,fate#318900).
- commit 66ef336
* Wed Mar 23 2016 rgoldwyn@suse.com
- nfs: use file_dentry() (fate#318900).
- commit 69a3e57
* Fri Mar 18 2016 tiwai@suse.de
- ALSA: hda - Fix spurious kernel WARNING on Baytrail HDMI
  (boo#971737).
- ALSA: hda - Fix forgotten HDMI monitor_present update
  (boo#971737).
- ALSA: hda - Really restrict i915 notifier to HSW+ (boo#971737).
- commit 9ebd8b6
* Fri Mar 18 2016 hare@suse.de
- Update config files: Enable CONFIG_BLK_DEV_NVME_SCSI (bsc#965497)
- commit 766f032
* Fri Mar 18 2016 jslaby@suse.cz
- net: irda: Fix use-after-free in irtty_open() (bnc#967903).
- commit ff61c16
* Fri Mar 18 2016 tiwai@suse.de
- ALSA: hda - Limit i915 HDMI binding only for HSW and later
  (boo#971737).
- ALSA: hda - Don't handle ELD notify from invalid port
  (boo#971737).
- commit a6b682e
* Thu Mar 17 2016 tiwai@suse.de
- ALSA: hda - Fix unexpected resume through regmap code path
  (bsc#969383).
- commit 56796b8
* Wed Mar 16 2016 tiwai@suse.de
- Disable relax relocations for x86 loader (bsc#970239).
- commit a92e8a7
* Wed Mar 16 2016 tiwai@suse.de
- ALSA: usb-audio: Add sanity checks for endpoint accesses
  (CVE-2016-2184,bsc#971125).
- ALSA: usb-audio: Fix NULL dereference in
  create_fixed_stream_quirk() (CVE-2016-2184,bsc#971125).
- commit 8336511
* Mon Mar 14 2016 jeffm@suse.com
- Update to 4.5-final.
- commit 3c4edc5
* Thu Mar 10 2016 jslaby@suse.cz
- Linux 4.4.5.
- Refresh patches.suse/stack-unwind.
- commit 09dee88
* Wed Mar  9 2016 jdelvare@suse.de
- Update s390x config files: Bump NR_CPUS to 256
  It was set to 256 in the SLES kernel 2 years ago already.
- commit 43cf630
* Tue Mar  8 2016 afaerber@suse.de
- config: armv7hl: Enable DRM_ROCKCHIP
  Firefly-RK3288 is among the boards that this will benefit.
- commit 2a3d0e4
* Mon Mar  7 2016 jeffm@suse.com
- Update to 4.5-rc7.
- commit 924f2b7
* Mon Mar  7 2016 jdelvare@suse.de
- Update config files: Modularize NF_REJECT_IPV4/V6
  There is no reason why these helper modules should be built-in when
  the rest of netfilter is built as modules.
- commit c81fe72
* Fri Mar  4 2016 jslaby@suse.cz
- Update config files. (vanillas)
- commit 0c1f87e
* Fri Mar  4 2016 jslaby@suse.cz
- Linux 4.4.4 (bnc#910440 bnc#968396 bnc#969064 boo#955096
  boo#961263 boo#961887 boo#967938 bsc#962535 bsc#966137).
- Delete
  patches.drivers/0001-bcache-Add-a-cond_resched-call-to-gc.patch.
- Delete
  patches.drivers/0002-bcache-BUG-clear-BCACHE_DEV_UNLINK_DONE-flag-when-at.patch.
- Delete
  patches.drivers/0003-bcache-fix-a-livelock-in-btree-lock.patch.
- Delete
  patches.drivers/0004-bcache-unregister-reboot-notifier-when-bcache-fails-.patch.
- Delete
  patches.drivers/0005-fix-a-leak-in-bch_cached_dev_run.patch.
- Delete
  patches.drivers/ALSA-hda-Apply-clock-gate-workaround-to-Skylake-too.
- Delete
  patches.drivers/bcache-fix-writeback-thread-incomplete-stripes-starvation.patch.
- Delete
  patches.drivers/drm-i915-shut-up-gen8-SDE-irq-dmesg-noise.
- Delete
  patches.drivers/drm-radeon-Add-a-common-function-for-DFS-handling.
- Delete
  patches.drivers/drm-radeon-Don-t-hang-in-radeon_flip_work_func-on-di.
- Delete
  patches.drivers/drm-radeon-Fix-off-by-one-errors-in-radeon_vm_bo_set.
- Delete
  patches.drivers/drm-radeon-Fix-slow-audio-over-DP-on-DCE8.
- Delete patches.drivers/drm-radeon-call-hpd_irq_event-on-resume.
- Delete
  patches.drivers/drm-radeon-cleaned-up-VCO-output-settings-for-DP-aud.
- Delete
  patches.drivers/drm-radeon-fix-DP-audio-support-for-APU-with-DCE4.1-.
- Delete
  patches.drivers/drm-radeon-hold-reference-to-fences-in-radeon_sa_bo_.
- Delete
  patches.drivers/drm-radeon-pm-adjust-display-configuration-after-pow.
- Delete
  patches.drivers/drm-radeon-properly-byte-swap-vce-firmware-setup.
- Delete
  patches.drivers/drm-radeon-use-post-decrement-in-error-handling.
- Delete
  patches.fixes/drm-Fix-drm_vblank_pre-post_modeset-regression-from.
- Delete
  patches.fixes/drm-Fix-treatment-of-drm_vblank_offdelay-in-drm_vbla.
- Delete
  patches.fixes/drm-No-Op-redundant-calls-to-drm_vblank_off-v2.
- Delete
  patches.fixes/drm-Prevent-vblank-counter-bumps-1-with-active-vblan.
- Delete
  patches.fixes/drm-nouveau-display-Enable-vblank-irqs-after-display.
- Delete
  patches.fixes/genirq-Validate-action-before-dereferencing-it-in-ha.patch.
- Delete
  patches.fixes/sd-Optimal-I-O-size-is-in-bytes-not-sectors.
- Delete
  patches.fixes/tcp-do-not-drop-syn_recv-on-all-icmp-reports.patch.
- Update config files.
- commit b719bbe
* Fri Mar  4 2016 jslaby@suse.cz
- Refresh
  patches.drivers/0001-bcache-Add-a-cond_resched-call-to-gc.patch.
- Refresh
  patches.drivers/0002-bcache-BUG-clear-BCACHE_DEV_UNLINK_DONE-flag-when-at.patch.
- Refresh
  patches.drivers/0003-bcache-fix-a-livelock-in-btree-lock.patch.
- Refresh
  patches.drivers/0004-bcache-unregister-reboot-notifier-when-bcache-fails-.patch.
- Refresh
  patches.drivers/0005-fix-a-leak-in-bch_cached_dev_run.patch.
  Update upstream status.
- commit 859059c
* Thu Mar  3 2016 dsterba@suse.com
- Add build dependency for objtool
  objtool requires libelf development headers.
- commit 16f65f2
* Thu Mar  3 2016 ohering@suse.de
- Refresh patches.suse/xen-pv-devmem_is_allowed.patch.
- commit a55dde2
* Wed Mar  2 2016 ohering@suse.de
- Disable access to lowmem in a Xen PV guest (bnc#964342).
- commit e7a0da2
* Wed Mar  2 2016 jslaby@suse.cz
- tcp: do not drop syn_recv on all icmp reports (bnc#969064).
- commit 1ed9fdd
* Wed Mar  2 2016 tiwai@suse.de
- radeon: r100: Silence 'may be used uninitialized' warnings
  (boo#955096,boo#967938).
- drm/radeon/pm: adjust display configuration after powerstate
  (boo#955096,boo#967938).
- drm/radeon: Don't hang in radeon_flip_work_func on disabled
  crtc. (v2) (boo#955096,boo#967938).
- drm/radeon/pm: Handle failure of drm_vblank_get
  (boo#955096,boo#967938).
- drm/radeon: use post-decrement in error handling
  (boo#955096,boo#967938).
- drm/radeon: hold reference to fences in radeon_sa_bo_new
  (boo#955096,boo#967938).
- drm/radeon: fix DP audio support for APU with DCE4.1 display
  engine (boo#955096,boo#967938).
- drm/radeon: Add a common function for DFS handling
  (boo#955096,boo#967938).
- drm/radeon: cleaned up VCO output settings for DP audio
  (boo#955096,boo#967938).
- drm/radeon: only init fbdev if we have connectors
  (boo#955096,boo#967938).
- drm/radeon: Ensure radeon bo is unreserved in
  radeon_gem_va_ioctl (boo#955096,boo#967938).
- drm/radeon: properly byte swap vce firmware setup
  (boo#955096,boo#967938).
- drm/radeon: Fix off-by-one errors in radeon_vm_bo_set_addr
  (boo#955096,boo#967938).
- drm/radeon: fix dp link rate selection (v2)
  (boo#955096,boo#967938).
- drm/radeon: only increment sync_seq when a fence is really
  emitted (boo#955096,boo#967938).
- drm/radeon: Fix "slow" audio over DP on DCE8+
  (boo#955096,boo#967938).
- drm/radeon: Use unlocked gem unreferencing
  (boo#955096,boo#967938).
- drm/radeon: call hpd_irq_event on resume
  (boo#955096,boo#967938).
- commit 803bd2e
* Tue Mar  1 2016 dmueller@suse.com
- config: ARM64: Remove hardcoded console setting
  Proper way would be to derive it from the ACPI or
  Device tree chosen output.
- commit ad7dbb8
* Tue Mar  1 2016 mmarek@suse.com
- rpm/kernel-module-subpackage: Fix obsoleting dropped flavors (bsc#968253)
- commit 5295c19
* Mon Feb 29 2016 mmarek@suse.com
- rpm/kernel-binary.spec.in: Obsolete xen-kmp (fate#315712, bsc#968253)
- commit 0e7c4d5
* Mon Feb 29 2016 mmarek@suse.com
- Copy packaging changes from master to the packaging branch
- commit 0a2490d
* Mon Feb 29 2016 jeffm@suse.com
- Update to 4.5-rc6.
- commit b239884
* Fri Feb 26 2016 jslaby@suse.cz
- genirq: Validate action before dereferencing it in
  handle_irq_event_percpu() (bnc#968396).
- commit 171b8f1
* Fri Feb 26 2016 jslaby@suse.cz
- Linux 4.4.3 (boo#962250 bsc#960910).
- Delete
  patches.fixes/Revert-xfs-clear-PF_NOFREEZE-for-xfsaild-kthread.
- Delete
  patches.suse/btrfs-fix-fitrim-discarding-device-area-reserved-for.patch.
- commit 3ae1dff
* Wed Feb 24 2016 dsterba@suse.com
- btrfs: remove error message from search ioctl for nonexistent tree.
- commit c2c16d5
* Wed Feb 24 2016 tiwai@suse.de
- drm/nouveau/display: Enable vblank irqs after display engine
  is on again (bsc#962535).
- drm: Fix treatment of drm_vblank_offdelay in drm_vblank_on()
  (v2) (bsc#962535).
- drm: Fix drm_vblank_pre/post_modeset regression from Linux 4.4
  (bsc#962535).
- drm: Prevent vblank counter bumps > 1 with active vblank
  clients. (v2) (bsc#962535).
- drm: No-Op redundant calls to drm_vblank_off() (v2)
  (bsc#962535).
- commit 46e3b92
* Tue Feb 23 2016 guillaume.gardet@free.fr
- config: armv7hl: Enable CONFIG_DRM_ETNAVIV
  Enable CONFIG_DRM_ETNAVIV for armv7 (default and vanilla) to get graphics
  acceleration on top of the Vivante GPU IP cores used in different SoCs,
  such as the Freescale i.MX6.
- commit 13c5905
* Tue Feb 23 2016 mmarek@suse.com
- rpm/kernel-binary.spec.in: Sync the main and -base package dependencies
  (bsc#965830#c51).
- commit bf655ed
* Tue Feb 23 2016 tiwai@suse.de
- ALSA: hda - Apply clock gate workaround to Skylake, too
  (bsc#966137).
- commit c601f8d
* Tue Feb 23 2016 jeffm@suse.com
- Update to v4.5-rc5.
- commit 7733b9a
* Tue Feb 23 2016 jeffm@suse.com
- config: complete disabling THERMAL from s390
  Commit fd5ffd694f9 (Update s390x config files: Disable THERMAL)
  left some stray config options around.  Clean them up.
- commit 5cd1d35
* Mon Feb 22 2016 jdelvare@suse.de
- Update config files: Set CRYPTO_CHACHA20POLY1305=m
  We support every other crypto algorithm so why not this one.
- commit 68344d0
* Mon Feb 22 2016 jdelvare@suse.de
- Update config files: Disable SERIAL_8250_RT288X
  This option is only useful on MIPS.
- commit a8e3297
* Sun Feb 21 2016 dmueller@suse.com
- config: armv6hl: Disable CMA and DEBUGFS settings
  CMA allocates 16MB of reserved memory on boot, which takes
  away a very scarce resource for unpacking the kiwi initrd
  and provides little value (is also disabled on other x86*)
- commit 9f2a122
* Sat Feb 20 2016 jdelvare@suse.de
- Update s390x config files: Disable THERMAL
  The THERMAL subsystem serves no purpose on S/390, disable it. It was
  already disabled in the SLES kernel long ago.
- commit fd5ffd6
* Thu Feb 18 2016 dsterba@suse.com
- Fix lint warnings: E: summary-ended-with-dot
  kernel-source-vanilla.noarch: E: summary-ended-with-dot (Badness: 89) C
  Vanilla Linux kernel sources with minor build fixes.
  Summary ends with a dot.
- commit 9050a39
* Thu Feb 18 2016 jslaby@suse.cz
- floppy: fix lock_fdc() signal handling (bnc#966880).
- commit f12d966
* Thu Feb 18 2016 jslaby@suse.cz
- floppy: refactor open() flags handling (bnc#966880).
- commit 70a427d
* Thu Feb 18 2016 jslaby@suse.cz
- Update patches.kernel.org/patch-4.4.1-2 (CVE-2016-0723
  CVE-2016-2384 bnc#961500 bnc#966883 boo#954532 bsc#966693).
- commit 5c471bf
* Thu Feb 18 2016 jslaby@suse.cz
- Linux 4.4.2 (CVE-2016-0723 CVE-2016-2384 bnc#961500 boo#954532
  bsc#966693).
- Delete
  patches.drivers/ALSA-usb-audio-avoid-freeing-umidi-object-twice.
- Delete
  patches.fixes/0001-tty-Fix-unsafe-ldisc-reference-via-ioctl-TIOCGETD.patch.
- Delete
  patches.fixes/0002-n_tty-Fix-unsafe-reference-to-other-ldisc.patch.
- Delete
  patches.fixes/HID-multitouch-fix-input-mode-switching-on-some-Elan.
- commit 19ca782
* Wed Feb 17 2016 mbrugger@suse.com
- series.conf: mark xgbe-a0 ethernet driver as needs_update
- commit 9efcaae
* Wed Feb 17 2016 mbrugger@suse.com
- Update config files for arm64.
  Enable ACPI.
- commit fa0917c
* Tue Feb 16 2016 jslaby@suse.cz
- Refresh patches.suse/stack-unwind.patch.
  Remove text_base parameter from read_pointer as it is always 0.
- commit b3ba789
* Tue Feb 16 2016 mmarek@suse.com
- rpm/kernel-binary.spec.in: Set CONFIG_MODULE_SIG_KEY only if a cert is present
  This allows using the unmodified .config from the kernel-source tree in
  the expanded tree.
- commit 5fa6ddd
* Mon Feb 15 2016 jdelvare@suse.de
- Update x86 config files: Enable Intel RAPL
  This driver is useful when power caping is needed. It was enabled in
  the SLE kernel 2 years ago.
- commit 5c509fc
* Mon Feb 15 2016 jdelvare@suse.de
- Update config files: Disable MFD_TPS65218
  The TPS65218 is a power management IC for 32-bit ARM systems. Its
  driver serves no purpose on other architectures. All sub-drivers were
  already disabled anyway.
- commit 2c2300d
* Mon Feb 15 2016 tiwai@suse.de
- ALSA: usb-audio: avoid freeing umidi object twice
  (CVE-2016-2384,bsc#966693).
- commit 6398c2d
* Mon Feb 15 2016 jeffm@suse.com
- Update to 4.5-rc4.
- commit 4fd18f0
* Thu Feb 11 2016 mmarek@suse.com
- rpm/kernel-binary.spec.in: Use correct variable to point to the keyring
- commit f026a54
* Thu Feb 11 2016 jdelvare@suse.de
- Update config/armv7hl: Clean up TS-4800 support
  The Technologic Systems TS-4800 is an i.MX515 board. The lpae flavor
  doesn't support this platform so it shouldn't include any TS-4800
  driver. The default and vanilla flavors do support it. If we want
  them to support the board properly then all its drivers should be
  enabled.
- commit 59e9c51
* Thu Feb 11 2016 jslaby@suse.cz
- rpm/kernel-obs-build.spec.in: do not limit TasksMax
  We run with build as PID 1 (boo#965564).
- commit 39b708b
* Wed Feb 10 2016 mmarek@suse.com
- rpm/kernel-binary.spec.in: Adapt certificate handling for changes in v4.3
- commit 589be33
* Tue Feb  9 2016 jdelvare@suse.de
- Update config files: disable MFD_SYSCON on non-arm
  Disable MFD_SYSCON, GPIO_SYSCON and LEDS_SYSCON in non-arm
  configurations. SYSCON is an arm thing, it was enabled accidentally
  in other configurations because STMMAC_PLATFORM and
  TOUCHSCREEN_TS4800, which were once enabled by accident, select it.
  As REGMAP_MMIO was also only selected by MFD_SYSCON, we can disable
  it too.
- commit 7d6958a
* Tue Feb  9 2016 jdelvare@suse.de
- Update config files: disable TS-4800 drivers on non-arm
  The TS-4800 is an arm board, so its drivers are useless on i386 and
  ppc64. Disable TOUCHSCREEN_TS4800 on these architectures.
- commit e2289c8
* Tue Feb  9 2016 jslaby@suse.cz
- Disable KASAN for stack unwinder code.
- commit 40617c9
* Tue Feb  9 2016 dmueller@suse.com
- config: reenable Exynos4 support for default kernel
  needed for odroid
- commit ae765f1
* Tue Feb  9 2016 jslaby@suse.cz
- DWARF2 EH-frame based stack unwinding.
- Delete patches.suse/stack-unwind.
  Add .patch suffix, so that syntax highlighting works.
- commit 741781b
* Tue Feb  9 2016 dmueller@suse.com
- Config: ARMv7: Disable Exynos 4 related drivers
  We don't have Exynos 4 support enabled, so there
  is no point in building the drivers for it.
- commit 0d649a0
* Mon Feb  8 2016 jeffm@suse.com
- Update to 4.5-rc3.
- commit b0ea7eb
* Mon Feb  8 2016 jdelvare@suse.de
- Update s390x config files: CONFIG_ENCLOSURE_SERVICES
  Per bsc#884701, CONFIG_ENCLOSURE_SERVICES isn't needed on S/390. It
  was already disabled in SLE, so disable it in openSUSE too.
- commit 0017810
* Mon Feb  8 2016 jeffm@suse.com
- Update to 4.5-rc2.
- Eliminated 2 patches.
- commit 52dbbed
* Mon Feb  8 2016 dvaleev@suse.com
- Delete config/ppc/default.
- Delete config/ppc/vanilla.
  Drop building for ppc architecture. We use 64bit kernel nowadays.
- commit 54461b6
* Fri Feb  5 2016 dmueller@suse.com
- config: ARM64: disable CONFIG_DDR again
  Was accidentally reeanbled in the 4.5-rc1 bump
- commit c76df01
* Thu Feb  4 2016 afaerber@suse.de
- config: arm64: Enable Tegra 210 and SMMU
  The new Tegra210 option did not get enabled during the 4.5-rc1 update.
  Also enable the Tegra IOMMU for 132 and 210.
- commit d6d686e
* Tue Feb  2 2016 tiwai@suse.de
- Revert "xfs: clear PF_NOFREEZE for xfsaild kthread"
  (boo#962250).
- commit ddc5d70
* Tue Feb  2 2016 jdelvare@suse.de
- Update config files: Disable CONFIG_DDR
  CONFIG_DDR is selected automatically by drivers which need it. This
  piece of helper code is useless in the absence of any such driver.
- commit 1769308
* Tue Feb  2 2016 dmueller@suse.com
- Disable CMOS RTC
  This Motorola compatible RTC doesn't exist on ARMv7, and triggers
  an non-root triggerable immediate panic  on the system when being
  accessed, so we better don't include it.
- commit 2b16688
* Mon Feb  1 2016 jslaby@suse.cz
- drm/i915: Pin the ifbdev for the info->system_base GGTT mmapping
  (bnc#962866).
- drm/i915: Fix failure paths around initial fbdev allocation
  (bnc#962866).
- drm/i915: Fix double unref in intelfb_alloc failure path
  (bnc#962866).
- commit 283b562
* Mon Feb  1 2016 jslaby@suse.cz
- Refresh
  patches.fixes/0001-tty-Fix-unsafe-ldisc-reference-via-ioctl-TIOCGETD.patch.
- Refresh
  patches.fixes/0002-n_tty-Fix-unsafe-reference-to-other-ldisc.patch.
  Upstream status.
- commit ce7756a
* Mon Feb  1 2016 jslaby@suse.cz
- Linux 4.4.1 (boo#960710 bnc#962075 CVE-2016-0728).
- Delete
  patches.drivers/ALSA-hda-Flush-the-pending-probe-work-at-remove.
- Delete patches.fixes/keys-fix-leak.patch.
- commit b969f5d
* Sun Jan 31 2016 tiwai@suse.de
- sd: Optimal I/O size is in bytes, not sectors (boo#961263).
- commit 2198765
* Sun Jan 31 2016 dmueller@suse.com
- config: Update armv6hl config for 4.5-rc1
- Enable BCM2835 related options
- Rest disabled if arch specific
- Generic follows x86_64
- commit 185883e
* Sun Jan 31 2016 dmueller@suse.com
- config: armv7hl: Enable VDSO
  VDSO provides, starting with glibc 2.22, a lower latency implementation
  for time related syscalls.
- commit 42096c4
* Sun Jan 31 2016 dmueller@suse.com
- config: Update armv7hl config to 4.5-rc1
- Disable Mobile ARCH
- Enable BCM2835/BCM2836 options (RPI 1 B/2 B)
- set voltage regulators to =m
- Rest follows x86_64 update, see there for details
- commit afef73d
* Sun Jan 31 2016 dmueller@suse.com
- config: Update ARM64 config to 4.5-rc1
- Enabled support for Qualcom SoC
- Rest follows update for x86_64
- commit 3a8952a
* Thu Jan 28 2016 jslaby@suse.cz
- drm/radeon: Update radeon_get_vblank_counter_kms() (bnc#962535).
- commit 9f68b90
* Wed Jan 27 2016 jeffm@suse.com
- Revert "Merge remote-tracking branch 'origin/users/tiwai/master/for-next'"
  This reverts commit b27160caadedcda2dc864615e51461c7db19bba1, reversing
  changes made to e1ac7b484beda5dfd27b84365f83a308de7c7a9c.
- commit 36aac98
* Wed Jan 27 2016 bp@suse.de
- Update config files.
  Disable CONFIG_DEBUG_WX as stuff needs to be sorted out upstream first.
- commit 09b6275
* Tue Jan 26 2016 jeffm@suse.com
- Update to 4.5-rc1
- Eliminated 15 patches.
- ARM configs need updating.
- Config changes:
  - Generic changes:
  - ARCH_MMAP_RND_BITS=<default>
  - MANDATORY_FILE_LOCKING=n (removes "dead" code, can re-enable if needed)
  - WQ_WATCHDOG=y
  - NETDEV_NOTIFIER_ERROR_INJECT=m
  - UBSAN=n (performance penalty)
  - IO_STRICT_DEVMEM=y
  - VFIO_NOIOMMU=n
  - NTB_PERF=m
  - x86:
  - VMD=m
  - DRM_AMD_POWERPLAY=y
  - CRYPTO_DEV_QAT_C3XXX=m
  - CRYPTO_DEV_QAT_C62X=m
  - CRYPTO_DEV_QAT_C3XXXVF=m
  - CRYPTO_DEV_QAT_C62XVF=m
  - QUEUED_LOCK_STAT=n
  - INTEL_TELEMETRY=m
  - INTEL_HID_EVENT=m
  - INTEL_PUNIT_IPC=m
  - NTB_AMD=m
  - ASUS_WIRELESS=m
  - s390x:
  - SCLP_OFB=y
  - ppc64:
  - IBMVNIC=m
  - Networking:
  - INET_DIAG_DESTROY=y (built as part of inet_diag.ko)
  - NF_DUP_NETDEV=m
  - NFT_FWD_NETDEV=m
  - 6LOWPAN_DEBUGFS=n
  - 6LOWPAN_GHC_EXT_HDR_HOP=m
  - 6LOWPAN_GHC_UDP=m
  - 6LOWPAN_GHC_ICMPV6=m
  - 6LOWPAN_GHC_EXT_HDR_DEST=m
  - 6LOWPAN_GHC_EXT_HDR_FRAG=m
  - 6LOWPAN_GHC_EXT_HDR_ROUTE=m
  - ATH9K_HWRNG=y
  - GENEVE=y
  - NFP_NETVF=m
  - IEEE802154_ADF7242=m
  - Storage:
  - BLK_DEV_NVME_SCSI=n (dangerous)
  - SCSI_HISI_SAS=m
  - DM_VERITY_FEC=y
  - Misc platform-independent drivers:
  - NFC_ST21NFCA_I2C=m
  - NFC_ST95HF=m
  - MTD_MT81xx_NOR=m
  - MLXSW_CORE_HWMON=y
  - TOUCHSCREEN_EGALAX_SERIAL=m
  - SPI_LOOPBACK_TEST=m
  - GPIO_SYSCON=m
  - GPIO_104_IDI_48=m
  - SENSORS_LTC3815=m
  - WATCHDOG_SYSFS=y
  - ZIIRAVE_WATCHDOG=m
  - COMMON_CLK_CS2000_CP=m
  - EXTCON_MAX3355=m
  - IIO_CONFIGFS=m
  - IIO_SW_TRIGGER=m
  - MMA7455_I2C=m
  - MMA7455_SPI=m
  - MXC6255=m
  - INA2XX_ADC=n (use hwmon)
  - USB_SERIAL_MXUPORT11=m
  - LEDS_SYSCON=y
  - RTC_DRV_RX8010=m
  - IAQCORE=m
  - MAX30100=m
  - IIO_HRTIMER_TRIGGER=m
  - ARM (disabled):
  - IMX_THERMAL=n
  - TS4800_WATCHDOG=n
  - TS4800_IRQ=n
  - DRM_PANEL_PANASONIC_VVX10F034N00=n
  - DRM_PANEL_SHARP_LS043T1LE01=n
  - TI_ADS8688=n
  - PHY_HI6220_USB=n
  - WILC1000_SDIO=n
  - WILC1000_SPI=n
- commit f1286ba
* Tue Jan 26 2016 jeffm@suse.com
- config: disable POWER_RESET on non-ARM platforms.
- commit 145928b
* Tue Jan 26 2016 bp@suse.de
- Update config files.a
  Disable CONFIG_DEBUG_WX as stuff needs to be sorted out upstream first.
- commit c7d52bd
* Tue Jan 26 2016 jslaby@suse.cz
- n_tty: Fix unsafe reference to "other" ldisc (bnc#961500
  CVE-2016-0723).
- tty: Fix unsafe ldisc reference via ioctl(TIOCGETD) (bnc#961500
  CVE-2016-0723).
- n_tty: Fix unsafe reference to "other" ldisc (bnc#961500
  CVE-2016-0723).
- tty: Fix unsafe ldisc reference via ioctl(TIOCGETD) (bnc#961500
  CVE-2016-0723).
- commit 4ca6fa4
* Tue Jan 26 2016 mmarek@suse.com
- rpm/kernel-spec-macros: Do not modify the release string in PTFs (bsc#963449)
- commit dc2b096
* Tue Jan 26 2016 tiwai@suse.de
- Enable kconfigs for a few intel ASoC drivers (bsc#963456)
- commit 390de0f
* Mon Jan 25 2016 jeffm@suse.com
- Delete patches.fixes/tulip-quad-NIC-ifdown.
  The original bug that this patch fixed was addressed in 2004, in v2.6.10
  (6379dd57 of linux-2.6-bk), but pci_disable_device was still required to
  shut down the device.
  Commit c321f7d7c87 in v3.14 added the pci_disable_device at the end of
  tulip_remove_one just far enough out of context so that this patch still
  applied.
- commit 05c9dcc
* Sat Jan 23 2016 tiwai@suse.de
- Delete obsoleted patches.fixes/ptrace-getsiginfo
  This has been fixed in 2.6.26 by e16b278.
- commit 250ec53
* Fri Jan 22 2016 mmarek@suse.com
- rpm/kernel-source.spec.in: Install kernel-macros for kernel-source-vanilla
  (bsc#959090)
- commit cd33617
* Fri Jan 22 2016 mmarek@suse.com
- rpm/kernel-binary.spec.in: Fix paths in kernel-vanilla-devel (bsc#959090).
- commit 2d2ec7f
* Fri Jan 22 2016 mmarek@suse.com
- rpm/kernel-binary.spec.in: Fix kernel-vanilla-devel dependency (bsc#959090)
- commit fbbc989
* Fri Jan 22 2016 mmarek@suse.com
- rpm/kernel-binary.spec.in: Use bzip compression to speed up build (bsc#962356)
- commit e8f8f54
* Thu Jan 21 2016 dvaleev@suse.com
- Add sd_mod to initrd modules
  For some reason PowerVM backend can't work without sd_mod
- commit 7c2bd21
* Thu Jan 21 2016 mmarek@suse.com
- rpm/package-descriptions: Add kernel-zfcpdump and drop -desktop
- commit 54e8f7c
* Wed Jan 20 2016 tiwai@suse.de
- scsi: ignore errors from scsi_dh_add_device() (boo#962813).
- commit 1b0ab71
* Wed Jan 20 2016 mgorman@suse.com
- Refresh patches.suse/readahead-request-tunables.patch.
- commit 02b8b18
* Wed Jan 20 2016 tiwai@suse.de
- ALSA: hda - Flush the pending probe work at remove (boo#960710).
- commit 1a7f7c2
* Wed Jan 20 2016 mmarek@suse.com
- rpm/old-flavors: Obsolete kernel-xen <= 4.4, to match 4.3.anything
- commit cd04346
* Wed Jan 20 2016 mgorman@suse.com
- mm: readahead: Increase default readahead window (VM Performance, bnc#548529).
- Delete
  patches.fixes/cpufreq_ondemand_performance_optimise_default_settings.patch.
  patches.fixes/mm-Fix-assertion-mapping-nrpages-0-in-end_writeback.patch.
- commit 42f90c8
* Wed Jan 20 2016 tiwai@suse.de
- HID: multitouch: fix input mode switching on some Elan panels
  (boo#954532).
- commit 71b733e
* Wed Jan 20 2016 tiwai@suse.de
- Enable CONFIG_PINCTRL_CHERRYVIEW and _BROXTON (boo#954532)
  Needed for recent tablets/laptops.
  CONFIG_PINCTRL_BAYTRAIL is still disabled as it can't be built as a
  module.
- commit d33a340
* Wed Jan 20 2016 jlee@suse.com
- patches.fixes/keys-fix-leak.patch: (bnc#962075, CVE-2016-0728).
- commit e2007ee
* Tue Jan 19 2016 jslaby@suse.cz
- hwrng: core - sleep interruptible in read (bnc#962597).
- commit d407b31
* Fri Jan 15 2016 neilb@suse.com
- Delete
  patches.fixes/0001-NFSv4-do-not-accept-an-incompatible-delegation.patch.
  This was fixed in 4.3 by
  Commit: 24311f884189 ("NFSv4: Recovery of recalled read delegations is broken")
- commit c67a4b2
* Thu Jan 14 2016 tiwai@suse.de
- drm/i915: shut up gen8+ SDE irq dmesg noise (boo#961887).
- commit ef6f4af
* Thu Jan 14 2016 mbrugger@suse.com
- Delete obsolete patches
- Delete
  patches.arch/arm64-gpex-0001-device-core-Introduce-per-device-MSI-domain-pointer.patch.
- Delete
  patches.arch/arm64-gpex-0002-PCI-MSI-add-hooks-to-populate-the-msi_domain-field.patch.
- Delete
  patches.arch/arm64-gpex-0003-PCI-MSI-of-add-support-for-OF-provided-msi_domain.patch.
- Delete
  patches.arch/arm64-gpex-0004-PCI-MSI-Let-pci_msi_get_domain-use-struct-device-s-m.patch.
- Delete
  patches.arch/arm64-gpex-0005-irqchip-GICv2m-Get-rid-of-struct-msi_controller.patch.
- Delete
  patches.arch/arm64-gpex-0006-irqchip-gicv3-its-Get-rid-of-struct-msi_controller.patch.
- Delete
  patches.arch/arm64-gpex-0007-PCI-MSI-Drop-domain-field-from-msi_controller.patch.
- Delete
  patches.arch/arm64-gpex-0008-PCI-MSI-of-Allow-msi_domain-lookup-using-the-PHB-nod.patch.
- commit 370a5bb
* Wed Jan 13 2016 jeffm@suse.com
- Delete patches.fixes/nouveau-fix-race-with-fence-signaling.
  This patch was obsoleted by protecting ->channel with RCU.
- commit a704b3b
* Wed Jan 13 2016 jeffm@suse.com
- Delete patches.fixes/dm-release-map_lock-before-set_disk_ro.
  The drivers/md/dm.c:__bind has changes significantly and this patch
  is no longer relevant.
- commit 75554c0
* Tue Jan 12 2016 mmarek@suse.com
- rpm/kernel-binary.spec.in: Fix build if no UEFI certs are installed
- commit ef1b7d3
* Tue Jan 12 2016 mmarek@suse.com
- rpm/kernel-binary.spec.in: Install libopenssl-devel for newer sign-file
- commit fbdf0b8
* Mon Jan 11 2016 mmarek@suse.cz
- series.conf: Whitespace cleanup
- commit 4a33d40
* Mon Jan 11 2016 mmarek@suse.cz
- rpm/constraints.in: Bump disk space requirements up a bit
  Require 10GB on s390x, 20GB elsewhere.
- commit 558b7b3
* Mon Jan 11 2016 jeffm@suse.com
- Update to 4.4-final.
- commit f1e5f1f
* Fri Jan  8 2016 fdmanana@suse.com
- Btrfs: fix fitrim discarding device area reserved for boot
  loader's use (bsc#960910).
- commit 238d0b8
* Fri Jan  8 2016 jbeulich@suse.com
- Refresh patches.suse/supported-flag (fix modpost command line
  option spec).
- commit 2566c29
* Thu Jan  7 2016 tiwai@suse.de
- ethernet/atheros/alx: sanitize buffer sizing and padding
  (boo#952621).
- commit f8f6570
* Thu Jan  7 2016 dchang@suse.com
- bnx2x: Fix VLANs null-pointer for 57710, 57711 (boo#960923).
- commit a1b48ad
* Mon Jan  4 2016 jeffm@suse.com
- Update to 4.4-rc8.
- commit e628e30
* Mon Jan  4 2016 dvaleev@suse.com
- Driver for IBM System i/p VNIC protocol.
- Update config files: CONFIG_IBMVNIC=m
- commit eae9134
* Mon Jan  4 2016 dvaleev@suse.com
- Driver for IBM System i/p VNIC protocol.
- Update config files CONFIG_VNIC=m
- commit 85261f3
* Mon Jan  4 2016 jlee@suse.com
- KEYS: Fix race between read and revoke (bnc#958951,
  CVE-2015-7550).
- commit 1c9407b
* Fri Jan  1 2016 afaerber@suse.de
- config: armv7hl: Enable more RK3288 options for lpae
  Namely MMC and IO domains, already enabled for default/vanilla.
- commit 49467f0
* Wed Dec 30 2015 jlee@suse.com
- KEYS: Fix handling of stored error in a negatively instantiated
  user key (bnc#958463, CVE-2015-8539OD).
- commit 008195a
* Mon Dec 28 2015 jeffm@suse.com
- ovl: fix permission checking for setattr (CVE-2015-8660
  bsc#960281).
- commit 77a3e32
* Mon Dec 28 2015 jeffm@suse.com
- Update to 4.4-rc7.
- commit 276c9f4
* Tue Dec 22 2015 jeffm@suse.com
- Update to 4.4-rc6.
- commit f4ac202
* Tue Dec 22 2015 afaerber@suse.de
- config: armv7hl: Enable EXTCON (boo#959818)
  CONFIG_PHY_SUN4I_USB could not be enabled, breaking USB on several
  popular ARM boards such as Cubietruck.
- commit 10b7cff
* Wed Dec 16 2015 tiwai@suse.de
- drm/i915: Do a better job at disabling primary plane in the
  noatomic case (bnc#954137).
- commit db72752
* Tue Dec 15 2015 tiwai@suse.de
- ALSA: hda - Add a fixup for Thinkpad X1 Carbon 2nd (bsc#958439).
- ALSA: hda - Set codec to D3 at reboot/shutdown on Thinkpads
  (bsc#958439).
- ALSA: hda - Apply click noise workaround for Thinkpads
  generically (bsc#958439).
- commit 7b4772e
* Tue Dec 15 2015 mmarek@suse.com
- rpm/compute-PATCHVERSION.sh: Skip stale directories in the package dir
- commit 014bd26
* Tue Dec 15 2015 jslaby@suse.cz
- Linux 4.3.3.
- commit 0baa1c7
* Tue Dec 15 2015 jeffm@suse.com
- Update to 4.4-rc5.
- commit da8b87d
* Sun Dec 13 2015 afaerber@suse.de
- config: armv7hl: Enable ACT8865 for lpae, too
  It is needed for the Firefly-RK3288 board.
  (cherry picked from commit a9615824052d71ec99a224fb9f6e91795edc5d7a)
- config: armv7hl: Enable ACT8865 for lpae, too
  It is needed for the Firefly-RK3288 board.
- commit 4ab0c5d
* Fri Dec 11 2015 jslaby@suse.cz
- Linux 4.3.2 (bsc#954414).
- Delete
  patches.fixes/0001-X.509-Fix-the-time-validation-ver-2.patch.
- commit 2aebb11
* Wed Dec  9 2015 jslaby@suse.cz
- Linux 4.3.1.
- commit 0e3e409
* Wed Dec  9 2015 tiwai@suse.de
- ALSA: hda - Fix noise problems on Thinkpad T440s (boo#958504).
- commit 6945bb0
* Mon Dec  7 2015 jeffm@suse.com
- Update to 4.4-rc4.
- Eliminated 5 patches.
- commit 923c13b
* Mon Dec  7 2015 jslaby@suse.cz
- Refresh patches.suse/stack-unwind.
  Use the fix from master.
- commit d3f999c
* Mon Dec  7 2015 jslaby@suse.cz
- Refresh patches.suse/stack-unwind.
- Fix these warnings (since 4.4 as of 0ab32b6f1):
  kernel/unwind.c:672: warning: passing argument 2 of ‘probe_kernel_read’ makes pointer from integer without a cast
- commit 6bcd0e3
* Sun Dec  6 2015 jslaby@suse.cz
- Refresh patches.suse/stack-unwind.
  Add missing put_cpu() in case dwarf unwinder succeeds (bnc#943107)
- commit 68ab1c1
* Tue Dec  1 2015 mbrugger@suse.com
- Delete
  patches.arch/arm64-gpex-0009-pci-Enable-pci-host-generic-support-for-ARM64.patch.
- commit 7985c89
* Tue Dec  1 2015 mbrugger@suse.com
- Delete
  patches.arch/arm64-0005-arm64-dts-Add-X-Gene-reboot-driver-dts-node.patch.
- commit 435b78e
* Mon Nov 30 2015 jeffm@suse.com
- config: sync SWIOTLB config change to ppc/vanilla
- commit 3d7391b
* Mon Nov 30 2015 duwe@suse.de
- On ppc, SWIOTLB is just an alias for DMA bounce buffers
  (see Kconfig help:
  "Support for IO bounce buffering for systems without an IOMMU..." )
  The systems we support all have proper IOMMUs and thus don't need
  it.
- commit d43936a
* Mon Nov 30 2015 jeffm@suse.com
- Update to 4.4-rc3.
- Eliminated 2 patches.
- commit 916e346
* Mon Nov 30 2015 dvaleev@suse.com
- Add RHEL to kernel-obs-build
- commit a010d5e
* Mon Nov 30 2015 mmarek@suse.com
- Enable Xen in x86 vanilla configs
  Align the vanilla configs with i386/pae and x86_64/default,
  respectively.
- commit defd50c
* Mon Nov 30 2015 mmarek@suse.com
- Enable pae in i386/vanilla
  We use kernel-pae in majority of 32bit installs, so it makes sense to
  sync i386/vanilla with this flavor.
- commit 3557f7c
* Mon Nov 30 2015 mmarek@suse.com
- Drop SUSE_KERNEL and SPLIT_PACKAGE patches from vanilla (bsc#957159)
- commit fa79c63
* Mon Nov 30 2015 tiwai@suse.de
- thinkpad_acpi: Don't yell on unsupported brightness interfaces
  (boo#957152).
- commit 0e6e680
* Fri Nov 27 2015 tiwai@suse.de
- drm/i915: Don't override output type for DDI HDMI (boo#955190).
- drm/i915: Don't compare has_drrs strictly in pipe config
  (bsc#956397).
- drm/i915: Don't override output type for DDI HDMI (boo#955190).
- drm/i915: Don't compare has_drrs strictly in pipe config
  (bsc#956397).
- commit 7c0fedd
* Thu Nov 26 2015 mkubecek@suse.cz
- Delete patches.fixes/bridge-module-get-put.patch.
  As discussed in
  http://lists.opensuse.org/opensuse-kernel/2015-11/msg00046.html
- commit 91e30a7
* Thu Nov 26 2015 mkubecek@suse.cz
- Delete patches.fixes/bridge-module-get-put.patch.
  As discussed in
  http://lists.opensuse.org/opensuse-kernel/2015-11/msg00046.html
- commit 856bef8
* Mon Nov 23 2015 jeffm@suse.com
- config: refresh ARM configs for 4.4-rc2.
- commit 7eabae5
* Mon Nov 23 2015 jeffm@suse.com
- Update to 4.4-rc2.
- Eliminated 1 patch.
- commit dea70ff
* Sun Nov 22 2015 afaerber@suse.de
- config: arm64: Update configs for 4.4-rc1
  Align vanilla and default while at it.
- commit f5e67d3
* Sun Nov 22 2015 afaerber@suse.de
- config: armv6hl: Update configs for 4.4-rc1
  Align vanilla and default while at it.
- commit 11c6acd
* Sun Nov 22 2015 afaerber@suse.de
- config: armv7hl: Update configs for 4.4-rc1
  Disable FW_LOADER_USER_HELPER_FALLBACK for vanilla (boo#944661, boo#951260).
- commit d412cf8
* Fri Nov 20 2015 mmarek@suse.com
- Enable pvops Xen for x86_64/vanilla as well
  i386/vanilla is left as is for now, because it matches the non-pae
  - default kernel which does not support Xen either.
- commit 6a48ac7
* Thu Nov 19 2015 jeffm@suse.com
- serial: export fsl8250_handle_irq.
- commit 42fd13e
* Thu Nov 19 2015 mmarek@suse.com
- xen/events: Always allocate legacy interrupts on PV guests.
- commit b63d753
* Thu Nov 19 2015 tiwai@suse.de
- ethernet/atheros/alx: add Killer E2400 device ID (boo#955363).
- commit aa7197b
* Thu Nov 19 2015 mmarek@suse.cz
- staging: lustre: remove IOC_LIBCFS_PING_TEST ioctl.
- commit 6772624
* Wed Nov 18 2015 mmarek@suse.cz
- XEN: Use the PVOPS kernel (fate#315712)
  Merge the -pv configs into -default (-pae on i386) and -debug and drop
  the -xen flavor and the associated patches.xen series. For a
  transitional period, the -xen flavor will be maintained in a separate
  branch as a reference.
- commit ff1dcd9
* Wed Nov 18 2015 mmarek@suse.cz
- Refresh config files.
- commit f8f53b4
* Wed Nov 18 2015 jeffm@suse.com
- btrfs: qgroup: fix quota disable during rescan.
- commit 85158a1
* Tue Nov 17 2015 jlee@suse.com
- X.509: Fix the time validation [ver #2] (bsc#954414).
- commit 6b3b033
* Mon Nov 16 2015 jeffm@suse.com
- Update to 4.4-rc1.
- Xen is disabled.
- ARM configs need updating.
- 7 patches eliminated.
- Config changes:
  - Networking:
  - NETFILTER_NETLINK_GLUE_CT=y
  - renamed from NETFILTER_NETLINK_QUEUE_CT
  - IEEE802154_NL802154_EXPERIMENTAL=n
  - still in development, assumed the option
    will be renamed when it's finalized
  - NET_L3_MASTER_DEV=y (library, no code execution by itself)
  - NFC_FDP=m
  - NFC_FDP_I2C=m
  - NFC_MRVL_I2C=m
  - BNXT=m
  - BNXT_SRIOV=y
  - MLXSW_SPECTRUM=m
  - QED=m
  - QEDE=m
  - RTL8XXXU=m
  - RTL8XXXU_UNTESTED=y
  - WILC1000_DRIVER=n (no module option)
  - Storage:
  - NVM=y
  - NVM_DEBUG=n
  - NVM_GENNVM=m
  - NVM_RRPC=m
  - Input/Serial:
  - TOUCHSCREEN_FT6236=m
  - TOUCHSCREEN_TSC2004=m
  - TOUCHSCREEN_ROHM_BU21023=m
  - INPUT_DA9063_ONKEY=m
  - USERIO=m
  - SERIAL_8250_RT288X=y
  - SERIAL_8250_MID=m
  - HID_CORSAIR=m
  - HID_GFRM=m
  - Misc:
  - PINCTRL_BROXTON=n
  - GPIO_AMDPT=m
  - GPIO_104_IDIO_16=m
  - GPIO_IT87=m
  - BATTERY_BQ27XXX=m
  - BATTERY_BQ27XXX_I2C=y
  - BATTERY_BQ27XXX_PLATFORM=y
  - Video:
  - VIDEO_VIVID_MAX_DEVS=64 (default)
  - FB_IBM_GXT4500=m
  - Audio:
  - SND_PCM_TIMER=y
  - SND_FIREWIRE_DIGI00X=m
  - SND_FIREWIRE_TASCAM=m
  - Sensors:
  - MXC4005=m
  - HI8435=m
  - VZ89X=m
  - HDC100X=m
  - HTU21=m
  - APDS9960=m
  - US5182D=m
  - MCP4531=m
  - MS5637=m
  - LIDAR_LITE_V2=m
  - TSYS01=m
  - TSYS02D=m
  - SENSORS_MAX31790=m
  - Misc:
  - FPGA=m
  - FPGA_MGR_ZYNQ_FPGA=n
  - UBIFS_ATIME_SUPPORT=y
  - VFIO_NOIOMMU=n
  - COMMON_CLK_SI514=m
  - RTC_DRV_RV8803=m
  - Tracing:
  - STM=m
  - STM_DUMMY=m
  - STM_SOURCE_CONSOLE=m
  - TRACING_EVENTS_GPIO=y
  - Debugging:
  - TEST_PRINTF=n
  - SECTION_MISMATCH_WARN_ONLY=y (current behavior)
  - ACPI_DEBUGGER=n
  - EFI:
  - EFI_FAKE_MEMMAP=n
  - EFI_PGT_DUMP=n
  - DEBUG_WX=y
  - Crypto:
  - CRYPTO_KEYWRAP=m
  - PWM_PCA9685=m
  - x86:
  - MIC_COSM=m
  - UNISYS_VISORINPUT=m
  - UNISYS_VISORHBA=m
  - LEGACY_VSYSCALL_EMULATE=emulate
  - INTEL_TH=m
  - INTEL_TH_PCI=m
  - INTEL_TH_GTH=m
  - INTEL_TH_STH=m
  - INTEL_TH_MSU=m
  - INTEL_TH_PTI=m
  - INTEL_TH_DEBUG=n
  - INTEL_IOMMU_SVM=y
  - INTEL_IDMA64=m
  - TOSHIBA_WMI=m
  - ARM:
  - AHCI_QORIQ=n
  - BCM7038_WDT=n
  - SSB_HOST_SOC=n
  - MFD_ATMEL_FLEXCOM=n
- commit ac3c385
* Sun Nov 15 2015 jslaby@suse.cz
- Update config files.
  Enable CRASHER on s390x to be the same as in all other configs.
- commit 71162f2
* Sun Nov 15 2015 jslaby@suse.cz
- Rename patches.suse/crasher-26.diff to patches.suse/crasher.patch
  It is no longer anything for 2.6 :).
- commit d407cb2
* Sun Nov 15 2015 jslaby@suse.cz
- Refresh patches.suse/crasher.patch
  See the patch to see what the update consists of.
- commit 57989db
* Thu Nov 12 2015 tiwai@suse.de
- Clear CONFIG_FW_LOADER_USER_HELPER_FALLBACK in vanilla configs (boo#944661)
  armv7hl/vanilla still contains it because of boo#951260
- commit 18c4504
* Wed Nov 11 2015 dvaleev@suse.com
- Update config files (bsc#951533).
  Set CONFIG_SPARSEMEM_VMEMMAP=y for Power
- commit 5a67c8d
* Wed Nov 11 2015 dvaleev@suse.com
- Update config files (bsc#951533).
  Set CONFIG_SPARSEMEM_VMEMMAP=y for Power
- commit fd42e9a
* Wed Nov 11 2015 tiwai@suse.de
- Refresh tags in patches.drivers/ALSA-hda-Disable-64bit-address-for-Creative-HDA-cont.
- commit 9005e93
* Wed Nov 11 2015 tiwai@suse.de
- ALSA: hda - Fix lost 4k BDL boundary workaround (bnc#814440).
- commit 05bd5d3
* Tue Nov 10 2015 jbeulich@suse.com
- Refresh Xen patches:
  - Several fixes for Dom0 use of PV flavor.
  - Interrupt setup fix for Xen flavor.
- supported.conf: blktap.ko is unsupported.
- commit 52f9791
* Fri Nov  6 2015 jeffm@suse.com
- patches.apparmor/apparmor-allow-sys_cap_resource-to-be-sufficient-to-prlimit-another-task: fix incomplete backport
- commit 1e85ded
* Fri Nov  6 2015 jeffm@suse.com
- apparmor: allow SYS_CAP_RESOURCE to be sufficient to prlimit
  another task (bsc#921949).
- commit d7c44a5
* Fri Nov  6 2015 tiwai@suse.de
- Input: elantech - add Fujitsu Lifebook U745 to force crc_enabled
  (boo#883192).
- commit 8e60887
* Tue Nov  3 2015 jbeulich@suse.com
- Update Xen patches to 4.3-final and c/s 1298.
- Update Xen config files.
- commit 2b74ad8
* Tue Nov  3 2015 schwab@suse.de
- group-source-files: mark module.lds as devel file
  ld: cannot open linker script file /usr/src/linux-4.2.5-1/arch/arm/kernel/module.lds: No such file or directory
- commit ec6d351
* Mon Nov  2 2015 jslaby@suse.cz
- rpm/kernel-binary.spec.in: sync with master
- commit 7b374a4
* Mon Nov  2 2015 jeffm@suse.com
- Update to 4.3-final.
  - 1 patch eliminated.
- commit e20b856
* Wed Oct 28 2015 jslaby@suse.cz
- rpm/kernel-binary.spec.in: really pass down %%{?_smp_mflags}
- commit 273a7fb
* Wed Oct 28 2015 tiwai@suse.de
- ALSA: hda - Disable 64bit address for Creative HDA controllers
  (bnc#814440).
- commit 1b5a73d
* Tue Oct 27 2015 jslaby@suse.cz
- Linux 4.2.5.
- commit 27d2719
* Mon Oct 26 2015 mmarek@suse.com
- rpm/kernel-binary.spec.in: Use parallel make in all invocations
  Also, remove the lengthy comment, since we are using a standard rpm
  macro now.
- commit 4d6ba88
* Mon Oct 26 2015 mmarek@suse.com
- rpm/kernel-binary.spec.in: Delete one more DEBUG_SECTION_MISMATCH assignment
- commit fce45dc
* Mon Oct 26 2015 mmarek@suse.com
- rpm/kernel-binary.spec.in: Do not explicitly set DEBUG_SECTION_MISMATCH
  CONFIG_DEBUG_SECTION_MISMATCH is a selectable Kconfig option since
  2.6.39 and is enabled in our configs.
- commit 15aa4f8
* Sat Oct 24 2015 stefan.bruens@rwth-aachen.de
- config: arm: Enable ADS7846 touchscreen driver
  This SPI connected chip is common on RPi TFT displays.
  (cherry picked from commit 71386ea914fddea7d598c24a38a312ba210a51ae)
- config: arm: Enable ADS7846 touchscreen driver
  This SPI connected chip is common on RPi TFT displays.
- commit 48484ee
* Sat Oct 24 2015 jslaby@suse.cz
- Refresh patches.xen/xen3-fixup-xen.
  Use the origin/master approach.
- commit 6ae5577
* Sat Oct 24 2015 jslaby@suse.cz
- Linux 4.2.4 (bsc#943982).
- Refresh patches.xen/xen3-fixup-xen.
- Delete
  patches.drivers/ALSA-hda-Disable-power_save_node-for-Thinkpads.
- Delete
  patches.fixes/leds-lp55xx-Correct-Kconfig-dependency-for-f-w-user-.
- commit 6239f7d
* Fri Oct 23 2015 tiwai@suse.de
- [media] media/vivid-osd: fix info leak in ioctl (CVE-2015-7884,
  bnc#951626).
- staging/dgnc: fix info leak in ioctl (CVE-2015-7885,
  boo#951627).
- [media] media/vivid-osd: fix info leak in ioctl (CVE-2015-7884,
  bnc#951626).
- commit f554650
* Thu Oct 22 2015 guillaume.gardet@free.fr
- config: arm: Enable CONFIG_PPS_CLIENT_GPIO
  Set CONFIG_PPS_CLIENT_GPIO=m for all ARM configs to be able to use GPS
  with PPS line connected to a GPIO, as a high-precision time reference.
- commit 29faced
* Thu Oct 22 2015 jbeulich@suse.com
- supported.conf: Add pv-ops Xen drivers, 8250-base, and xhci-pci.
- commit ff3f596
* Wed Oct 21 2015 guillaume.gardet@free.fr
- config: arm: Enable CONFIG_PPS_CLIENT_GPIO
  Set CONFIG_PPS_CLIENT_GPIO=m for all ARM configs to be able to use GPS
  with PPS line connected to a GPIO, as a high-precision time reference.
- commit f01eb6a
* Tue Oct 20 2015 tiwai@suse.de
- Disable leftover CONFIG_FW_LOADER_USER_HELPER_FALLBACK in armv6hl/* (boo#951260)
- commit 60f5033
* Tue Oct 20 2015 tiwai@suse.de
- drm/sti: Remove select of CONFIG_FW_LOADER_USER_HELPER_FALLBACK
  (boo#951260).
- commit e9cf2df
* Tue Oct 20 2015 tiwai@suse.de
- Disable leftover CONFIG_FW_LOADER_USER_HELPER_FALLBACK in armv7hl/* (boo#951260)
- commit 007f6ba
* Tue Oct 20 2015 tiwai@suse.de
- [media] c8sectpfe: Remove select on
  CONFIG_FW_LOADER_USER_HELPER_FALLBACK (boo#951260).
- drm/sti: Remove select of CONFIG_FW_LOADER_USER_HELPER_FALLBACK
  (boo#951260).
- commit 23d5c78
* Tue Oct 20 2015 tiwai@suse.de
- Disable CONFIG_RT_GROUP_SCHED (boo#950955)
  Even people originally demanded suggest to drop it now...
- commit 58efde7
* Tue Oct 20 2015 tiwai@suse.de
- Disable CONFIG_RT_GROUP_SCHED (boo#950955)
  Even people originally demanded suggest to drop it now...
- commit c229932
* Tue Oct 20 2015 tiwai@suse.de
- ALSA: hda - Fix deadlock at error in building PCM (bsc#948758).
- commit e5082ca
* Mon Oct 19 2015 jeffm@suse.com
- config: Re-enable DEBUG_INFO on ec2 flavors.
  It was disabled in commit a104accda85, but is enabled explicitly in the
  spec file.  The options that depend on it must be in the config file for
  the build to succeed.
- commit 4415ce9
* Mon Oct 19 2015 jeffm@suse.com
- Update to 4.3-rc6.
- commit d6b2a93
* Fri Oct 16 2015 mmarek@suse.com
- Delete unused rpm/config-subst.
- commit 01841f4
* Fri Oct 16 2015 mmarek@suse.com
- rpm/kernel-source.rpmlintrc: Update the filters
- commit e26b4cc
* Fri Oct 16 2015 guillaume.gardet@free.fr
- config: armv6hl: Update and re-enable default and vanilla configs
  Update and re-enable default and vanilla configs.
  [AF: Made FW_LOADER_USER_HELPER_FALLBACK consistent]
- commit 549889b
* Fri Oct 16 2015 mmarek@suse.com
- rpm/kernel-binary.spec.in: Use upstream script to support config.addon
- commit e8739f8
* Fri Oct 16 2015 mmarek@suse.com
- rpm/kernel-binary.spec.in: Drop the %%build_src_dir macro
  It is the parent directory of the O= directory.
- commit 2ed0dbe
* Thu Oct 15 2015 tiwai@suse.de
- rtlwifi: rtl8821ae: Fix system lockups on boot (boo#944978).
- commit 9c478b9
* Thu Oct 15 2015 jbeulich@suse.com
- Update Xen patches to 4.3-rc5 and c/s 1293.
- netback: coalesce (guest) RX SKBs as needed (bsc#919154).
- config.conf: Re-enable Xen and PV configs.
- Update config files.
- commit a104acc
* Wed Oct 14 2015 matwey.kornilov@gmail.com
- config: armv7hl: Enable new OMAP serial driver
- commit 54af7c7
* Mon Oct 12 2015 jeffm@suse.com
- Update to 4.3-rc5.
- commit 36c0ed4
* Mon Oct 12 2015 mmarek@suse.com
- rpm/kernel-obs-build.spec.in: Add virtio_rng to the initrd
  This allows to feed some randomness to the OBS workers.
- commit fbb0589
* Mon Oct  5 2015 dmueller@suse.com
- Update config files.
  Disable CONFIG_LEDS_BCM6328 and CONFIG_LEDS_BCM6358, as those
  are MIPS and unlikely to exist on an ARM board.
- commit efc53bd
* Mon Oct  5 2015 jeffm@suse.com
- Update to 4.3-rc4.
- commit 48d7e75
* Sun Oct  4 2015 matwey.kornilov@gmail.com
- config: armv7hl: Sync vanilla with default
  Let vanilla follow changes made in default.
- commit 00ad273
* Sun Oct  4 2015 afaerber@suse.de
- config: armv7hl: Disable all msm8916/apq8016 options
  They are arm64 SoCs, so not needed for armv7hl.
- commit b333226
* Sun Oct  4 2015 matwey.kornilov@gmail.com
- config: armv7hl: Enable preemption
  This patch is to follow 1fcdac3f3d277ffea3462af635a3dea6b854a09a.
  [AF/MK: Enable preemption for vanilla config as well]
- commit d795f96
* Sat Oct  3 2015 jslaby@suse.cz
- Linux 4.2.3.
- commit f17d4c9
* Sat Oct  3 2015 afaerber@suse.de
- config: armv7hl: Enable missing STMMAC Ethernet options
  This attempts to fix regressions from 4.1 like built-in Ethernet on
  Cubietruck not working.
  (cherry picked from commit 68608454650632c84ab3c4c67a923ba834be6c59)
- config: armv7hl: Enable missing STMMAC Ethernet options
  This attempts to fix regressions from 4.1 like built-in Ethernet on
  Cubietruck not working.
- commit 2a10792
* Fri Oct  2 2015 mmarek@suse.com
- Obsolete kernel-desktop also in Tumbleweed
- commit 7a85c9f
* Fri Oct  2 2015 tiwai@suse.de
- apparmor: temporary work around for bug while unloading policy
  (boo#941867).
- commit fee03a3
* Wed Sep 30 2015 jlee@suse.com
- Update config files. (bsc#947816)
  Put # CONFIG_KEXEC_VERIFY_SIG is not set (bsc#947816)
- commit ab4942d
* Wed Sep 30 2015 jlee@suse.com
- Update config files. (bsc#947816)
  Put # CONFIG_KEXEC_VERIFY_SIG is not set (bsc#947816)
- commit 0dc8788
* Wed Sep 30 2015 jeffm@suse.com
- Update to 4.3-rc3.
- Eliminated 1 patch.
- commit 66bc908
* Tue Sep 29 2015 jslaby@suse.cz
- Update config files.
  (vanilla)
- commit b3ecf72
* Tue Sep 29 2015 jslaby@suse.cz
- Linux 4.2.2 (bnc#934531).
- Delete
  patches.fixes/mmc-sdhci-fix-dma-memory-leak-in-sdhci_pre_req.patch.
- Delete
  patches.fixes/workqueue-Make-flush_workqueue-available-again-to-no.patch.
- Update config files.
- commit 5256b5c
* Fri Sep 25 2015 mmarek@suse.cz
- Delete patches.suse/kconfig-automate-kernel-desktop.
  No longer needed.
- commit 74bcdcc
* Fri Sep 25 2015 mmarek@suse.cz
- Merge kernel-desktop back into kernel-default/kernel-pae (fate#319416)
- commit ad49492
* Fri Sep 25 2015 tiwai@suse.de
- ALSA: hda - Disable power_save_node for Thinkpads (bsc#943982).
- commit 6996a42
* Wed Sep 23 2015 dmueller@suse.com
- Backport of https://lkml.org/lkml/2015/9/11/507
  Fixes a build issue with aarch64, see
  http://www.spinics.net/lists/arm-kernel/msg446809.html.
- Update config files.
- commit 2947252
* Wed Sep 23 2015 dmueller@suse.com
- Delete
  patches.arch/arm64-0007-arm64-Do-not-call-enable-PCI-resources-when-specify-.patch.
- commit a608d6a
* Wed Sep 23 2015 jdelvare@suse.de
- Update x86 config files: CONFIG_SURFACE_PRO3_BUTTON=m
  This is an x86 driver, no reason to not enable it.
- commit c28e82c
* Wed Sep 23 2015 jeffm@suse.com
- config: re-enabled EXT4_USE_FOR_EXT2
- commit 681c071
* Tue Sep 22 2015 jslaby@suse.cz
- Refresh patches.xen/xen3-stack-unwind.
  XEN needs a fix for stack unwinder too.
- commit 9c7cacf
* Tue Sep 22 2015 jslaby@suse.cz
- Update config files.
- Refresh patches.suse/stack-unwind.
- Refresh patches.xen/xen3-patch-2.6.27.
  Reenable dwarf stack unwinder for C. Assembler is not dwarf-friendly
  annotated (removed in upstream and neither
  patches.arch/x86_64-unwind-annotations is enabled (yet)), so dwarf
  unwinder does not work there (yet).
  This should be fixed by Josh Poimbeouf's stacktool later. But until
  then, dwarf-unwind at least C and use frame pointers for asm.
  I.e. no more question marks for most cases:
  [<ffffffff81008415>] try_stack_unwind+0x175/0x190
  [<ffffffff81007293>] dump_trace+0x93/0x3a0
  [<ffffffff8100847b>] show_trace_log_lvl+0x4b/0x60
  [<ffffffff810076ac>] show_stack_log_lvl+0x10c/0x180
  [<ffffffff81008515>] show_stack+0x25/0x50
  [<ffffffff81364619>] dump_stack+0x4b/0x72
  [<ffffffffa01a302e>] init1+0xe/0x20 [aaa]
  [<ffffffff810002f3>] do_one_initcall+0xb3/0x200
  [<ffffffff8116e4da>] do_init_module+0x5f/0x1f6
  [<ffffffff810ee87e>] load_module+0x15fe/0x1b60
  [<ffffffff810eefe8>] SYSC_finit_module+0x98/0xc0
  [<ffffffff810ef02e>] SyS_finit_module+0xe/0x10
  [<ffffffff816b07b6>] entry_SYSCALL_64_fastpath+0x16/0x75
  DWARF2 unwinder stuck at entry_SYSCALL_64_fastpath+0x16/0x75
  Leftover inexact backtrace:
  <nothing>
  Instead of the funny:
  [<ffffffff81364619>] ? dump_stack+0x4b/0x72
  [<ffffffffa022a02e>] ? init1+0xe/0x20 [aaa]
  [<ffffffff810002f3>] ? do_one_initcall+0xb3/0x200
  [<ffffffff8116e4a2>] ? do_init_module+0x27/0x1f6
  [<ffffffff8116e4da>] ? do_init_module+0x5f/0x1f6
  [<ffffffff810ee87e>] ? load_module+0x15fe/0x1b60
  [<ffffffff810eaa40>] ? __symbol_put+0x50/0x50
  [<ffffffff811e9501>] ? kernel_read+0x41/0x60
  [<ffffffff810eefe8>] ? SYSC_finit_module+0x98/0xc0
  [<ffffffff810ef02e>] ? SyS_finit_module+0xe/0x10
  [<ffffffff816b07b6>] ? entry_SYSCALL_64_fastpath+0x16/0x75
  where __symbol_put and do_init_module+0x27 should not be there at all.
- Update config files.
- Refresh patches.suse/stack-unwind.
  Reenable dwarf stack unwinder for C. Assembler is not dwarf-friendly
  annotated (removed in upstream and neither
  patches.arch/x86_64-unwind-annotations is enabled (yet)), so dwarf
  unwinder does not work there (yet).
  This should be fixed by Josh Poimbeouf's stacktool later. But until
  then, dwarf-unwind at least C and use frame pointers for asm.
  I.e. no more question marks for most cases:
  [<ffffffff81008415>] try_stack_unwind+0x175/0x190
  [<ffffffff81007293>] dump_trace+0x93/0x3a0
  [<ffffffff8100847b>] show_trace_log_lvl+0x4b/0x60
  [<ffffffff810076ac>] show_stack_log_lvl+0x10c/0x180
  [<ffffffff81008515>] show_stack+0x25/0x50
  [<ffffffff81364619>] dump_stack+0x4b/0x72
  [<ffffffffa01a302e>] init1+0xe/0x20 [aaa]
  [<ffffffff810002f3>] do_one_initcall+0xb3/0x200
  [<ffffffff8116e4da>] do_init_module+0x5f/0x1f6
  [<ffffffff810ee87e>] load_module+0x15fe/0x1b60
  [<ffffffff810eefe8>] SYSC_finit_module+0x98/0xc0
  [<ffffffff810ef02e>] SyS_finit_module+0xe/0x10
  [<ffffffff816b07b6>] entry_SYSCALL_64_fastpath+0x16/0x75
  DWARF2 unwinder stuck at entry_SYSCALL_64_fastpath+0x16/0x75
  Leftover inexact backtrace:
  <nothing>
  Instead of the funny:
  [<ffffffff81364619>] ? dump_stack+0x4b/0x72
  [<ffffffffa022a02e>] ? init1+0xe/0x20 [aaa]
  [<ffffffff810002f3>] ? do_one_initcall+0xb3/0x200
  [<ffffffff8116e4a2>] ? do_init_module+0x27/0x1f6
  [<ffffffff8116e4da>] ? do_init_module+0x5f/0x1f6
  [<ffffffff810ee87e>] ? load_module+0x15fe/0x1b60
  [<ffffffff810eaa40>] ? __symbol_put+0x50/0x50
  [<ffffffff811e9501>] ? kernel_read+0x41/0x60
  [<ffffffff810eefe8>] ? SYSC_finit_module+0x98/0xc0
  [<ffffffff810ef02e>] ? SyS_finit_module+0xe/0x10
  [<ffffffff816b07b6>] ? entry_SYSCALL_64_fastpath+0x16/0x75
  where __symbol_put and do_init_module+0x27 should not be there at all.
- commit 68d392a
* Tue Sep 22 2015 jslaby@suse.cz
- Linux 4.2.1.
- commit 0d0e86c
* Mon Sep 21 2015 jeffm@suse.com
- Update to 4.3-rc2.
- Eliminated 1 patch.
- Config changes:
  - ARM (32/64-bit)
  - STUB_CLK_HI6220=n
  - ARM64
  - ARM64_ERRATUM_843419=y
- commit 2b75354
* Sun Sep 20 2015 afaerber@suse.de
- config: armv6hl: Update for 4.3-rc1
- commit f41e9a5
* Sun Sep 20 2015 afaerber@suse.de
- config: arm64: Update for 4.3-rc1
- commit bd3ad83
* Thu Sep 17 2015 jeffm@suse.com
- config: disable MTD_NAND_DENALI_PCI
- commit a9273ca
* Wed Sep 16 2015 matwey.kornilov@gmail.com
- config: armv7hl: Reenable for 4.3
  [AF: Keep STM32 serial disabled, sanitize STi, enable more Qualcomm,
    MediaTek and Renesas options, disable i.MX6 for lpae, switch
    MUSB to Dual Mode while at it, keep SUSE options out of vanilla]
- commit 17ed601
* Wed Sep 16 2015 jeffm@suse.com
- btrfs: provide super_operations->inode_get_dev (bsc#927455).
- vfs: add super_operations->get_inode_dev (bsc#927455).
- Delete patches.suse/btrfs-use-correct-device-for-maps.patch.
- commit 6c14ee2
* Wed Sep 16 2015 jeffm@suse.com
- btrfs: advertise which crc32c implementation is being used on
  mount (bsc#946057).
- commit 75a78f6
* Wed Sep 16 2015 jeffm@suse.com
- config: resync vanilla configs
- commit 8f87143
* Wed Sep 16 2015 jeffm@suse.com
- Update to 4.3-rc1.
- Eliminated 8 patches.
- Xen needs updating.
- ARM configs need updating.
- Config changes:
  - General options:
  - CGROUP_PIDS=y
  - USERFAULTFD=y
  - MEMBARRIER=y
  - EXT4_USE_FOR_EXT2=n
  - TEST_STATIC_KEYS=n
  - NVMEM=m
  - SCSI_DH=y
  - [debug] FAIL_FUTEX=y
  - IDLE_PAGE_TRACKING=n
  - SUSPEND_SKIP_SYNC=n
  - x86 options:
  - X86_LEGACY_VM86=n (dosemu vm86 support eliminaed, use a vm or emulation)
  - MODIFY_LDT_SYSCALL=y
  - CRYPTO_POLY1305_X86_64=m
  - CRYPTO_CHACHA20_X86_64=m
  - IDMA64=m
  - AMD_MCE_INJ=m
  - Networking:
  - IPV6_ILA=m
  - IP_VS_OVF=m
  - NFT_DUP_IPV4=m (go back and check)
  - NF_DUP_IPV4=m
  - NFT_DUP_IPV6=m
  - NF_DUP_IPV6=m
  - MPLS_IPTUNNEL=m
  - BT_HS=y
  - BT_HCIUART_QCA=y
  - NFC_ST_NCI_SPI=m
  - NFC_S3FWRN5_I2C=m
  - NET_VRF=m
  - BNX2X_VXLAN=y
  - MLXSW_CORE=m
  - MLXSW_PCI=m
  - MLXSW_SWITCHX2=m
  - NET_VENDOR_SYNOPSYS=y
  - SYNOPSYS_DWC_ETH_QOS=m
  - AQUANTIA_PHY=m
  - TERANETICS_PHY=m
  - MICROCHIP_PHY=m
  - USB_LAN78XX=m
  - FUJITSU_ES=m
  - INFINIBAND_HFI1=m
  - HFI1_DEBUG_SDMA_ORDER=n
  - HFI1_VERBS_31BIT_PSN=y
  - ESCAN_RXQ=n
  - Other:
  - MTD_NAND_DENALI_PCI=m (do we support moorestown?)
  - MTD_NAND_DENALI_DT=n
  - TOUCHSCREEN_IMX6UL_TSC=m
  - I2C_MUX_REG=m
  - SENSORS_MAX20751=m
  - INTEL_PCH_THERMAL=m
  - MFD_DA9062=m
  - MFD_INTEL_LPSS_ACPI=m
  - DVB_NETUP_UNIDVB=m
  - DVB_PLATFORM_DRIVERS=y
  - DRM_FBDEV_EMULATION=y
  - BACKLIGHT_PM8941_WLED=m
  - HID_GEMBIRD=m
  - STAGING_RDMA=y
  - RPR0521=m
  - CRYPTO_DEV_QAT_DH895xCCVF=m
  - DA9062_WATCHDOG=m
  - ARM:
  - MDIO_OCTEON=n
  - MOST=n
  - SURFACE_PRO3_BUTTON=n
  - USB_XHCI_PLATFORM=n
  - MMC_SDHCI_OF_AT91=n
  - RTC_DRV_DA9063=n
  - RTC_DRV_ZYNQMP=n
  - OPT3001=n
  - PA12203001=n
  - DRM_PANEL_SAMSUNG_LD9040=n
  - DRM_PANEL_LG_LG4573=n
  - DRM_PANEL_SAMSUNG_S6E8AA0=n
  - DRM_NXP_PTN3460=n
  - DRM_PARADE_PS8622=n
  - FB_SM712=n
  - SERIAL_UARTLITE=n
  - I2C_EMEV2=n
  - GPIO_ZX=n
  - ppc64:
  - CXLFLASH=m
  - LEDS_POWERNV=m
- commit 0d41d58
* Mon Sep 14 2015 jslaby@suse.cz
- Refresh
  patches.fixes/mmc-sdhci-fix-dma-memory-leak-in-sdhci_pre_req.patch.
  Fix upstream status.
- commit 9af8b5d
* Sun Sep 13 2015 dmueller@suse.com
- Update config files: ARM64: Raise CPUs to 128
  There are machines with more than 64 CPUs, allow them
  to be used. Update vanilla config from default.
- commit de7016d
* Fri Sep 11 2015 jslaby@suse.cz
- Update config files.
  Fix FW fixes fallout (bnc#944661).
- commit 6a28e38
* Thu Sep 10 2015 mmarek@suse.com
- rpm/kernel-spec-macros: Include the version string in the Obsoletes line
- commit 083cdb4
* Thu Sep 10 2015 mmarek@suse.com
- rpm/kernel-binary.spec.in: Obsolete previous builds of the same package (boo#867595)
- commit ffb73eb
* Wed Sep  9 2015 jdelvare@suse.de
- config/x86_64/ec2: Align CONFIG_STRICT_DEVMEM
  CONFIG_STRICT_DEVMEM is enabled in every other kernel flavor, so
  enable it for x86_64/ec2 as well.
- commit c156734
* Mon Sep  7 2015 tiwai@suse.de
- leds:lp55xx: Correct Kconfig dependency for f/w user helper
  (boo#944661).
- commit 589a02c
* Mon Sep  7 2015 tiwai@suse.de
- Disable CONFIG_FW_LOADER_USER_HELPER_FALLBACK that was reenabled unexpectedly (boo#944661)
- commit 14a23c3
* Mon Sep  7 2015 tiwai@suse.de
- Update config files: enable leftover CONFIG_FB_TFT_HX8357D=m for arm
- commit cae15fc
* Mon Sep  7 2015 tiwai@suse.de
- drm/vmwgfx: Allow dropped masters render-node like access on
  legacy nodes v2 (boo#934266).
-  vmwgfx: Rework device initialization (boo#934266).
- commit 28dbc80
* Mon Sep  7 2015 jslaby@suse.cz
- workqueue: Make flush_workqueue() available again to non
  GPL modules.
- commit 82076fa
* Mon Sep  7 2015 jkosina@suse.cz
- Update config files: update arm config files so that they are up-to-date
  and don't break build.
- commit c1a445e
* Mon Sep  7 2015 jkosina@suse.cz
- bcache: Fix writeback_thread never writing back incomplete
  stripes.
- commit 395add4
* Mon Aug 31 2015 jbeulich@suse.com
- Update Xen patches to 4.2-final.
- commit 7b8109d
* Mon Aug 31 2015 jslaby@suse.cz
- Refresh
  patches.apparmor/apparmor-compatibility-patch-for-v5-network-control.
  Fix this:
  patches.apparmor/apparmor-compatibility-patch-for-v5-network-control:25:
  error: Timestamp after filename
  by scripts/refresh_patch.sh.
- commit 2089c9a
* Mon Aug 31 2015 jslaby@suse.cz
- Refresh
  patches.fixes/btrfs-fix-stale-dir-entries-after-unlink-inode-eviction-and-fsync.
  Fix this:
  missing header for unified diff at line 107 of patch
  (Patch is indented 4 spaces.)
  can't find file to patch at input line 107
  by commenting also the @@ sign.
- commit 8e48b46
* Mon Aug 31 2015 jeffm@suse.com
- Update to 4.2-final.
- commit c617119
* Fri Aug 28 2015 jslaby@suse.cz
- Refresh
  patches.fixes/mmc-sdhci-fix-dma-memory-leak-in-sdhci_pre_req.patch.
  Hmm, mmc_data does not have sg_count yet. Fix it.
- commit d867e86
* Fri Aug 28 2015 jslaby@suse.cz
- Refresh
  patches.fixes/mmc-sdhci-fix-dma-memory-leak-in-sdhci_pre_req.patch.
  Forgot to refresh :/.
- commit 9b2d57c
* Fri Aug 28 2015 jslaby@suse.cz
- mmc: sdhci: fix dma memory leak in sdhci_pre_req() (bnc#934531).
- commit 3cca62a
* Wed Aug 26 2015 mmarek@suse.com
- rpm/constraints.in: Require 14GB worth of disk space on POWER
  The builds started to fail randomly due to ENOSPC errors.
- commit 9012f40
* Mon Aug 24 2015 jeffm@suse.com
- Btrfs: fix stale dir entries after unlink, inode eviction and
  fsync (bsc#942925).
- Btrfs: fix stale directory entries after fsync log replay
  (bsc#942925).
- Btrfs: fix stale dir entries after unlink, inode eviction and
  fsync (bsc#942925).
- Btrfs: fix stale directory entries after fsync log replay
  (bsc#942925).
- commit 42e403f
* Mon Aug 24 2015 jbeulich@suse.com
- Update EC2 config files: Re-enable DEBUG_INFO.
- commit c02428d
* Mon Aug 24 2015 jeffm@suse.com
- Update to 4.2-rc8.
- commit 46c5271
* Fri Aug 21 2015 jbeulich@suse.com
- Update Xen patches to 4.2-rc7.
- config.conf: Re-enable Xen and PV configs.
- Update config files.
- commit e077731
* Wed Aug 19 2015 dvaleev@suse.com
- Update config files.
  Enable KSM on Power
- commit 25f2e01
* Mon Aug 17 2015 zombah@gmail.com
- config: armv7hl: Disable Exynos IOMMU
  Enabling DRM Exynos IOMMU is currently broken, source
  commit: 6562f3bd396a ("ARM: exynos_defconfig: Disable IOMMU support").
- commit ce0123d
* Mon Aug 17 2015 jeffm@suse.com
- Update to 4.2-rc7.
- commit de135e9
* Mon Aug 17 2015 jslaby@suse.cz
- Linux 4.1.6.
- commit 9dbe563
* Fri Aug 14 2015 ohering@suse.de
- hv_storvsc: use small sg_tablesize on x86 (bnc#937256).
- commit 91e5c2c
* Wed Aug 12 2015 jeffm@suse.com
- config: enable IPV6_SIT_6RD on all flavors
  The option was initially disabled because it was labeled experimental.
- commit 83fbd4e
* Tue Aug 11 2015 stefan.bruens@rwth-aachen.de
- config: arm*: Enable FB_TFT
  Set CONFIG_FB_TFT*=m for arm64/armv6hl/armv7hl.
  There are several TFT capes/hats/... for all kinds of SBCs, enable these.
  Tested on RPi B with 3.2" TFT connected over SPI.
  (cherry picked from commit 204e76a92701639c1e807f12cca412a2655f7a24)
- config: arm*: Enable FB_TFT
  Set CONFIG_FB_TFT*=m for arm64/armv6hl/armv7hl.
  There are several TFT capes/hats/... for all kinds of SBCs, enable these.
  Tested on RPi B with 3.2" TFT connected over SPI.
- commit c4d41ea
* Tue Aug 11 2015 jslaby@suse.cz
- Linux 4.1.5.
- Refresh patches.xen/xen-x86-EFI.
- commit efe368a
* Mon Aug 10 2015 jeffm@suse.com
- Update to 4.2-rc6.
- commit 4a2cf4a
* Mon Aug  3 2015 jslaby@suse.cz
- Update
  patches.suse/0001-Revert-mmc-sdhci-fix-low-memory-corruption.patch
  (bnc#934531).
- Update
  patches.suse/0002-Revert-mmc-sdhci-use-pipeline-mmc-requests-to-improv.patch
  (bnc#934531).
- commit 3081bf0
* Mon Aug  3 2015 jslaby@suse.cz
- Linux 4.1.4 (CVE-2015-1333 bnc#938645 boo#939394).
- Refresh patches.xen/pci-guestdev.
- Delete
  patches.arch/arm64-Don-t-report-clear-pmds-and-puds-as-huge.patch.
- Delete
  patches.drivers/ideapad_laptop-lenovo-g50-30-fix-rfkill-reports-wireless-blocked.
- Delete
  patches.fixes/KEYS-ensure-we-free-the-assoc-array-edit-if-edit-is-.patch.
- commit a37e14f
* Mon Aug  3 2015 jslaby@suse.cz
- Refresh
  patches.fixes/KEYS-ensure-we-free-the-assoc-array-edit-if-edit-is-.patch.
  Ad git commit id.
- commit 7cf8f32
* Mon Aug  3 2015 afaerber@suse.de
- config: arm64: Clean up serial options
  [this commit was somehow overwritten with the update to -rc6]
  Change SERIAL_8250_DW from =m to =y.
  Change SERIAL_SAMSUNG from =m to =y and enable SERIAL_SAMSUNG_CONSOLE=y.
  Enable Qualcomm serial: SERIAL_MSM=y and SERIAL_MSM_CONSOLE=y
  Enable Spreadtrum serial: SERIAL_SPRD=y and SERIAL_SPRD_CONSOLE=y
  Disable Altera serial: SERIAL_ALTERA_JTAGUART and SERIAL_ALTERA_UART
  We can revisit this when they have arm64 support out.
  Disable Conexant serial: SERIAL_CONEXANT_DIGICOLOR (not arm64)
- config: arm64: Clean up serial options
  Change SERIAL_8250_DW from =m to =y.
  Change SERIAL_SAMSUNG from =m to =y and enable SERIAL_SAMSUNG_CONSOLE=y.
  Enable Qualcomm serial: SERIAL_MSM=y and SERIAL_MSM_CONSOLE=y
  Enable Spreadtrum serial: SERIAL_SPRD=y and SERIAL_SPRD_CONSOLE=y
  Disable Altera serial: SERIAL_ALTERA_JTAGUART and SERIAL_ALTERA_UART
  We can revisit this when they have arm64 support out.
  Disable Conexant serial: SERIAL_CONEXANT_DIGICOLOR (not arm64)
  (cherry picked from commit 26cb131d91a7ba44068f1abed841b890518ea176)
- config: arm64: Clean up serial options
  Change SERIAL_8250_DW from =m to =y.
  Change SERIAL_SAMSUNG from =m to =y and enable SERIAL_SAMSUNG_CONSOLE=y.
  Enable Qualcomm serial: SERIAL_MSM=y and SERIAL_MSM_CONSOLE=y
  Enable Spreadtrum serial: SERIAL_SPRD=y and SERIAL_SPRD_CONSOLE=y
  Disable Altera serial: SERIAL_ALTERA_JTAGUART and SERIAL_ALTERA_UART
  We can revisit this when they have arm64 support out.
  Disable Conexant serial: SERIAL_CONEXANT_DIGICOLOR (not arm64)
- commit 7ae9442
* Mon Aug  3 2015 afaerber@suse.de
- config: armv7hl: Clean up serial options
  Fix SERIAL_OF_PLATFORM to be =y. This unbreaks AC100 serial.
  SERIAL_STM32 is for armv7ml and thus irrelevant for armv7hl, disable it.
  SERIAL_8250_INGENIC is for MIPS SoCs, so disable it for armv7hl.
  Fix CONFIG_SERIAL_CONEXANT_DIGICOLOR from =m to =y and
  enable CONFIG_SERIAL_CONEXANT_DIGICOLOR_CONSOLE=y,
  but only for default and vanilla, as it is a Cortex-A8.
  Fix SERIAL_AMBA_PL010 from =m to =y for lpae, matching default, and
  enable CONFIG_SERIAL_AMBA_PL010_CONSOLE=y for lpae, too.
  Disable SERIAL_ST_ASC for lpae, as STi are Cortex-A9 only.
  (cherry picked from commit 5f5dbd3a9cd58bfb803b83459a564d06eb1e1a37)
  [AF: Accidentally reverted in 4a2cf4a409b54e75f8ac4cd7a19fa8e8bc516aca]
- config: armv7hl: Clean up serial options
  Fix SERIAL_OF_PLATFORM to be =y. This unbreaks AC100 serial and
  hopefully Cubietruck as well.
  Fix CONFIG_SERIAL_CONEXANT_DIGICOLOR from =m to =y and
  enable CONFIG_SERIAL_CONEXANT_DIGICOLOR_CONSOLE=y,
  but only for default and vanilla, as it is a Cortex-A8.
  Fix SERIAL_AMBA_PL010 from =m to =y for lpae, matching default, and
  enable CONFIG_SERIAL_AMBA_PL010_CONSOLE=y for lpae, too.
  Disable SERIAL_ST_ASC for lpae, as STi are Cortex-A9 only.
  (cherry picked from commit 5f5dbd3a9cd58bfb803b83459a564d06eb1e1a37)
- config: armv7hl: Clean up serial options
  Fix SERIAL_OF_PLATFORM to be =y. This unbreaks AC100 serial and
  hopefully Cubietruck as well.
  SERIAL_STM32 is for armv7ml and thus irrelevant for armv7hl, disable it.
  SERIAL_8250_INGENIC is for MIPS SoCs, so disable it for armv7hl.
  Fix CONFIG_SERIAL_CONEXANT_DIGICOLOR from =m to =y and
  enable CONFIG_SERIAL_CONEXANT_DIGICOLOR_CONSOLE=y,
  but only for default and vanilla, as it is a Cortex-A8.
  Fix SERIAL_AMBA_PL010 from =m to =y for lpae, matching default, and
  enable CONFIG_SERIAL_AMBA_PL010_CONSOLE=y for lpae, too.
  Disable SERIAL_ST_ASC for lpae, as STi are Cortex-A9 only.
- commit 373b6db
* Mon Aug  3 2015 jeffm@suse.com
- Update to 4.2-rc5.
- commit 1ac4f2f
* Mon Aug  3 2015 jslaby@suse.cz
- KEYS: ensure we free the assoc array edit if edit is valid
  (bnc#938645 CVE-2015-1333).
- commit e755463
* Wed Jul 29 2015 mkubecek@suse.cz
- config: x86_64: enable EFI_MIXED in nonvirtual configs
  An x86_64 kernel needs CONFIG_EFI_MIXED to be able to access EFI
  variables and services if booted under 32-bit UEFI. Some bootloaders
  also need it to be able to boot 64-bit kernel under 32-bit UEFI.
  (boo#935027 fate#318252)
- commit 41613e2
* Wed Jul 29 2015 mkubecek@suse.cz
- config: enable NET_DROP_MONITOR=m
  The drop_monitor module is useful for debugging networking issues. It
  collects information where in the kernel code are packets dropped;
  dropwatch utility can be used to process the data.
- commit 5e4468b
* Tue Jul 28 2015 jslaby@suse.cz
- Revert "mmc: sdhci: use pipeline mmc requests to improve
  performance".
- Revert "mmc: sdhci: fix low memory corruption".
- commit 5696612
* Mon Jul 27 2015 dmueller@suse.com
- Update config files.
  Disable Exynos 3/4 related options.
- commit ada1a44
* Mon Jul 27 2015 dmueller@suse.com
- Update config files.
  Disable Exynos 5 related config options.
- commit 6fd21aa
* Mon Jul 27 2015 jeffm@suse.com
- config: disable HIBERNATION on ppc64* vanilla configs
- commit 2a5007c
* Mon Jul 27 2015 jeffm@suse.com
- Update to 4.2-rc4.
- commit 75c1ba1
* Mon Jul 27 2015 mkubecek@suse.cz
- config: x86_64: enable EFI_MIXED in nonvirtual configs
  An x86_64 kernel needs CONFIG_EFI_MIXED to be able to access EFI
  variables and services if booted under 32-bit UEFI. Some bootloaders
  also need it to be able to boot 64-bit kernel under 32-bit UEFI.
  (boo#935027 fate#318252)
- commit f807859
* Mon Jul 27 2015 mkubecek@suse.cz
- config: enable NET_DROP_MONITOR=m
  The drop_monitor module is useful for debugging networking issues. It
  collects information where in the kernel code are packets dropped;
  dropwatch utility can be used to process the data.
- commit f8a6191
* Mon Jul 27 2015 dvaleev@suse.com
- Update config files.
  Update config files for vanilla ppc64 and ppc64le.
  Fixes boo#939502
- commit 0fd34b1
* Fri Jul 24 2015 jeffm@suse.com
- ideapad_laptop: Lenovo G50-30 fix rfkill reports wireless
  blocked (boo#939394).
- commit f45c09a
* Fri Jul 24 2015 fdmanana@suse.com
- Btrfs: fix hang during inode eviction due to concurrent
  readahead (bnc#937403).
- commit 9ec57fb
* Thu Jul 23 2015 mbrugger@suse.com
- Enable PCI host controller dirver for arm64
  PCI host controller is not yet supported on mainline.
  We need this patch to get lspci working.
- commit 3b6a8b8
* Thu Jul 23 2015 dvaleev@suse.com
- Update config files.
  Disable HIBERNATION on power due to invalid code generation (bsc#938934)
- commit 2b9aa48
* Thu Jul 23 2015 dvaleev@suse.com
- Update config files.
  Disable HIBERNATION on power due to invalid code generation (bsc#938934)
- commit 03e948d
* Wed Jul 22 2015 jeffm@suse.com
- Update to 4.2-rc3.
- commit bd67def
* Wed Jul 22 2015 jslaby@suse.cz
- Linux 4.1.3.
- Refresh patches.xen/pci-guestdev.
- Refresh patches.xen/xen3-patch-2.6.25.
- Update config files.
- commit 33413c9
* Tue Jul 21 2015 oneukum@suse.com
- qmi_wwan: Add support for Dell Wireless 5809e 4G Modem
  (bnc#937974).
- commit 3fae52e
* Tue Jul 21 2015 dmueller@suse.com
- Disable PCI host support for ARM64
  This needs to be rebased on top of 4.2-rcX before they can be enabled
  as they break the build right now, and for now we don't really need it.
  Update config files.
- commit fc75db1
* Tue Jul 21 2015 jslaby@suse.cz
- Update
  patches.fixes/0001-NFSv4-do-not-accept-an-incompatible-delegation.patch
  (bsc#934202).
  Fix bsc #.
- commit 06dac28
* Mon Jul 20 2015 dmueller@suse.com
- Update config files.
  Disable Xen on ARM64 default configs, should only be enabled
  on the pv flavor (which does not yet exist for ARM64)
- commit eea4145
* Mon Jul 20 2015 dmueller@suse.com
- Update config files:
  ARM64/default,vanilla: Disable CONFIG_XEN as that should
  only be enabled in the pv flavor
- commit 7010139
* Wed Jul 15 2015 jeffm@suse.com
- Update to 4.2-rc2.
- commit 288d56b
* Tue Jul 14 2015 jslaby@suse.cz
- Linux 4.1.2 (bnc#907092 bnc#934531).
- Delete patches.fixes/mmc-sdhci-fix-low-memory-corruption.patch.
- Delete
  patches.fixes/x86-PCI-Use-host-bridge-_CRS-info-on-Foxconn-K8M890.
- Delete
  patches.fixes/x86-PCI-Use-host-bridge-_CRS-info-on-systems-with-32.
- commit 5ccacb4
* Wed Jul  8 2015 dmueller@suse.com
- arm64: Don't report clear pmds and puds as huge.
- commit cac28b3
* Wed Jul  8 2015 dmueller@suse.com
- AArch64: config: Update to 4.2-rc1
- config.conf:
- Enabling Hisilicon, Cavium and XGene related options
- rest is synced with x86_64
- commit 5e2f263
* Tue Jul  7 2015 matwey.kornilov@gmail.com
- config: Update armv7hl config for 4.2-rc1
- commit f80d0b6
* Tue Jul  7 2015 jeffm@suse.com
- config: sync CIFS_SMB2=y across all configs
  Note that since Xen and ARM are disabled, these need to updated
  independently.
- commit 7d11dbe
* Mon Jul  6 2015 jeffm@suse.com
- Update to 4.2-rc1.
- Xen needs updating.
- ARM configs need updating.
- DWARF2 / stack unwinding need updating.
- 5 patches eliminated.
- Config changes:
  - Generic:
  - RCU_EXPERT=n (default)
  - SCHED_OMIT_FRAME_POINTER=y (temporary)
  - ACPI_REV_OVERRIDE_POSSIBLE=y (default)
  - OF_UNITTEST=n (default)
  - THERMAL_WRITABLE_TRIPS=n
  - THERMAL_DEFAULT_GOV_STEP_WISE=y
  - THERMAL_GOV_POWER_ALLOCATOR=n
  - SND_PROC_FS=y
  - DEFERRED_STRUCT_PAGE_INIT=y
  - PROC_CHILDREN=y
  - RCU_EQS_DEBUG=n
  - Networking:
  - GENEVE_CORE=m
  - TCP_CONG_CDG=m
  - NETFILTER_INGRESS=y
  - NF_TABLES_NETDEV=m
  - NET_CLS_FLOWER=m
  - SUNRPC_XPRT_RDMA=m
  - Network drivers:
  - BE2NET_HWMON=y (option to existing driver)
  - EZCHIP_NPS_MANAGEMENT_ENET=m
  - MLX5_CORE_EN=y (option to existing driver)
  - SFC_MCDI_LOGGING=y (option to existing driver)
  - DP83867_PHY=m
  - MT7601U=m
  - IEEE802154_ATUSB=n
  - PHY_PXA_28NM_HSIC=n
  - PHY_PXA_28NM_USB2=n
  - PHY_TUSB1210=n
  - DELL_RBTN=m
  - Input:
  - INPUT_LEDS=y
  - LEDS_AAT1290=n
  - LEDS_BCM6328=n
  - LEDS_BCM6358=n
  - LEDS_TLC591XX=n
  - LEDS_KTD2692=n
  - TOUCHSCREEN_WDT87XX_I2C=m
  - INPUT_DRV2665_HAPTICS=m
  - SERIAL_SC16IS7XX_I2C=y
  - SERIAL_SC16IS7XX_SPI=n
  - Chargers:
  - CHARGER_BQ24257=m
  - CHARGER_BQ25890=m
  - CHARGER_RT9455=m
  - Sensors:
  - SENSORS_TC74=m
  - MAX63XX_WATCHDOG=n
  - GPU:
  - DRM_AMDGPU=m
  - DRM_AMDGPU_CIK=n (experimental)
  - DRM_AMDGPU_USERPTR=y
  - DRM_VIRTIO_GPU=m
  - USB_ULPI_BUS=m
  - Android:
  - STAGING_BOARD=n
  - Accelerometers:
  - STK8312=m
  - STK8BA50=m
  - Light sensors:
  - ACPI_ALS=m
  - BH1750=n
  - STK3310=n
  - MMC35240=n
  - BMC150_MAGN=n
  - Non-Transparent Bridging:
  - NTB_PINGPONG=n
  - NTB_TOOL=n
  - NTB_TRANSPORT=m
  - NTB=n (ppc)
  - Other:
  - F2FS_FS_ENCRYPTION=y
  - Crypto:
  - CRYPTO_RSA=m
  - CRYPTO_CHACHA20POLY1305=m
  - CRYPTO_ECHAINIV=m
  - CRYPTO_POLY1305=m
  - CRYPTO_CHACHA20=m
  - CRYPTO_842=m
  - CRYPTO_JITTERENTROPY=m
  - CRYPTO_USER_API_AEAD=m
  - NV-DIMM:
  - ACPI_NFIT=m
  - ACPI_NFIT_DEBUG=n
  - ND_BLK=m
  - BTT=y
  - Bluetooth:
  - BT_HCIBTUSB_RTL=y (default)
  - NFC:
  - NFC_NCI_UART=m
  - NFC_MRVL_UART=m
  - NFC_ST_NCI=m
  - NFC_ST_NCI_I2C=m
  - Storage:
  - SCSI_SNIC=m
  - SCSI_SNIC_DEBUG_FS=n
  - DM_CACHE_SMQ=m (EXPERIMENTAL)
  - MMC_MTK=m
  - x86:
  - X86_DEBUG_FPU=n
  - PUNIT_ATOM_DEBUG=n
  - UNISYS_VISORBUS=m
  - UNISYS_VISORNIC=m
  - NTB_INTEL=m
  - SCIF_BUS=m
  - SCIF=m
  - INTEL_QUARK_DTS_THERMAL=m
  - INTEL_PMC_IPC=m
  - ppc:
  - GIANFAR=n
  - SERIAL_8250_INGENIC=n
  - ppc64:
  - OPAL_PRD=m
  - MTD_POWERNV_FLASH=m
  - CRYPTO_DEV_NX_COMPRESS_PSERIES=m
  - CRYPTO_DEV_NX_COMPRESS_POWERNV=m
  - CRYPTO_DEV_NX_COMPRESS_CRYPTO=m
  - Cross-endian virtio:
  - TUN_VNET_CROSS_LE=n
  - VHOST_CROSS_ENDIAN_LEGACY=n
  - ARM:
  - SPI_ZYNQMP_GQSPI=n
  - AHCI_CEVA=n (Xilinx Zynq UltraScale+ MPSoC.)
  - QCOM_SPMI_TEMP_ALARM=n
  - THUNDER_NIC_PF=n
  - THUNDER_NIC_VF=n
  - THUNDER_NIC_BGX=n
  - LIQUIDIO=n
  - COMMON_CLK_CDCE925=n
  - UIO_PRUSS=n
- commit 771d075
* Mon Jul  6 2015 jeffm@suse.com
- config: disable CONFIG_GPIO_MCP23S08 on non-ARM platforms
- commit 1c68e62
* Mon Jul  6 2015 jeffm@suse.com
- config: disable MFD_SYSCON on non-ARM platforms
- commit a4a41a7
* Mon Jul  6 2015 jeffm@suse.com
- config: BLK_DEV_SKD=m on ppc64 vanilla configs
  BLK_DEV_SKD was disabled on ppc64 vanilla configs but enabled for
  default.
- commit 16b304b
* Mon Jul  6 2015 jeffm@suse.com
- config: disable BCMGENET on non-ARM platforms
  The Broadcom GENET ethernet chip is part of their BCM7xxx Set Top Box
  chipset and doesn't need to be built on non-ARM architectures.
- commit 8d51fac
* Mon Jul  6 2015 jeffm@suse.com
- Removed invalid Git-commit tags from bcache patches.
- commit c7da326
* Wed Jul  1 2015 jeffm@suse.com
- sysctl/defaults: remove semaphore sysctl override (bsc#936290).
  The sysctl values were lower than the new defaults.
- commit 8e3d11a
* Tue Jun 30 2015 jslaby@suse.cz
- Linux 4.1.1.
- commit ab48011
* Mon Jun 29 2015 jslaby@suse.cz
- Refresh
  patches.fixes/drm-i915-Ensure-cache-flushes-prior-to-doing-CS-flip.patch.
- Refresh patches.fixes/mmc-sdhci-fix-low-memory-corruption.patch.
  Update upstream statuses.
- commit 11b8ced
* Mon Jun 29 2015 jslaby@suse.cz
- drm/i915: Ensure cache flushes prior to doing CS flips
  (bnc#931300).
- commit 406255f
* Thu Jun 25 2015 dmueller@suse.com
- ARM64: config: UNWIND_INFO=y
- commit 8193a68
* Wed Jun 24 2015 jbeulich@suse.com
- Update Xen patches to 4.1-final and c/s 1289.
- guarantee M2P to be invisible to user mode.
- commit fc59188
* Wed Jun 24 2015 neilb@suse.com
- NFSv4: When returning a delegation, don't reclaim an incompatible open mode (bnc#934202).
- commit 6c74958
* Tue Jun 23 2015 jeffm@suse.com
- Update to 4.1-final.
- commit d6cfe1f
* Mon Jun 22 2015 schwab@suse.de
- kernel-obs-build: add btrfs to initrd
  This is needed for kiwi builds.
- commit 1ebf037
* Mon Jun 22 2015 neilb@suse.com
- NFSv3 - do not accept an incompatible delegation (bsc#934203).
- commit ccdebbf
* Thu Jun 18 2015 tiwai@suse.de
- x86/PCI: Use host bridge _CRS info on systems with >32 bit
  addressing (bnc#907092).
- x86/PCI: Use host bridge _CRS info on Foxconn K8M890-8237A
  (bnc#907092).
- x86/PCI: Use host bridge _CRS info on systems with >32 bit
  addressing (bnc#907092).
- x86/PCI: Use host bridge _CRS info on Foxconn K8M890-8237A
  (bnc#907092).
- commit 1d9da2e
* Thu Jun 18 2015 dsterba@suse.cz
- Btrfs: fix regression in raid level conversion.
- Btrfs: fix uninit variable in clone ioctl.
- Btrfs: fix range cloning when same inode used as source and
  destination.
- btrfs: cleanup orphans while looking up default subvolume.
- btrfs: incorrect handling for fiemap_fill_next_extent return.
- Btrfs: send, don't leave without decrementing clone root's
  send_progress.
- Btrfs: send, add missing check for dead clone root.
- commit 56152db
* Tue Jun 16 2015 tiwai@suse.de
- Enable brcmfmac driver for x86-64 and i586 (boo#934932)
- commit 3e79c51
* Tue Jun 16 2015 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Change BuildRequires to match OBS's taste
- commit 15501f0
* Mon Jun 15 2015 jeffm@suse.com
- Update to 4.1-rc8.
- commit d3aa377
* Fri Jun 12 2015 tiwai@suse.de
- Update config files: extend CONFIG_DPM_WATCHDOG_TIMEOUT to 60 (bnc#934397)
- commit b3acd3f
* Fri Jun 12 2015 tiwai@suse.de
- Update config files: extend CONFIG_DPM_WATCHDOG_TIMEOUT to 60 (bnc#934397)
- commit b5e86cc
* Fri Jun 12 2015 jslaby@suse.cz
- mmc: sdhci: fix low memory corruption (bnc#934531).
- commit ea963c7
* Tue Jun  9 2015 jeffm@suse.com
- Update to 4.1-rc7.
- Config changes:
  - arm64/armv7hl:
  - PHY_QCOM_UFS=m
- commit abe587d
* Mon Jun  8 2015 jslaby@suse.cz
- Linux 4.0.5 (bnc#927786 bnc#931580).
- Refresh
  patches.fixes/btrfs-revert-delete-chunk-allocation.patch.
- Delete patches.fixes/drm-radeon-retry-dcpd-fetch.patch.
- Delete patches.fixes/rtlwifi-rtl8192cu-Fix-kernel-deadlock.
- commit f4cd21b
* Sat Jun  6 2015 dirk@dmllr.de
- ARM: config: Sync more settings with x86_64
  Compile in modules that are =y on x86_64, remove modules
  that are not compiled on x86_64
- commit d36ab59
* Sat Jun  6 2015 dirk@dmllr.de
- config: armv7hl: Disable CONFIG_FW_LOADER_USER_HELPER_FALLBACK
  Only needed by DRM_STI, which we don't need, so disable
  it alltogether (it isn't configured in userspace anyway
  and deprecated)
- commit 6ad70fc
* Sat Jun  6 2015 dirk@dmllr.de
- config: armv7hl: Disable DECNET
  DECNET is not enabled on any other arch either
  and we don't need it
- commit ec172d8
* Sat Jun  6 2015 dirk@dmllr.de
- armv6hl: config: Reenable for 4.1
  Generic options follow x86_64 ones.
- commit 1d5f3b2
* Sat Jun  6 2015 dmueller@suse.com
- config: armv7hl: Enable ARM optimized crypto
  Enable the CONFIG_ARM_CRYPTO related options for up to
  45%% speed improvement on some of the algorithms.
- commit 8a1306d
* Fri Jun  5 2015 mmarek@suse.cz
- Delete disabled patches that have not been updated for years
- Delete
  patches.arch/kvm-only-export-selected-pv-ops-feature-structs.
- Delete
  patches.arch/kvm-replace-kvm-io-delay-pv-ops-with-linux-magic.
- Delete patches.arch/kvm-split-paravirt-ops-by-functionality.
- Delete patches.arch/kvm-split-the-KVM-pv-ops-support-by-feature.
- Delete patches.arch/ppc64-xmon-dmesg-printing.patch.
- Delete patches.suse/ppc-no-LDFLAGS_MODULE.patch.
- commit 6e78d78
* Tue Jun  2 2015 jbeulich@suse.com
- Fix patch headers of just updated Xen patches.
- commit 78a3079
* Tue Jun  2 2015 jbeulich@suse.com
- Update Xen patches to 4.1-rc6.
- config.conf: Re-enabled Xen and PV configs.
- Update config files.
- commit 0447183
* Mon Jun  1 2015 jeffm@suse.com
- config: restore FRAME_POINTER configs to pre-4.1-rc1 values
  The disabling of the stack unwind patches due to required merging
  ended up enabling FRAME_POINTER on some configs. Now that stack
  unwinding is re-enabled, we can disable it again.
- commit e3d8f0a
* Mon Jun  1 2015 jeffm@suse.com
- config: revert options initially selected by EXT4_ENCRYPTION
  EXT4_ENCRYPTION was initially a bool, which caused anything
  selected by it to be selected as =y even if EXT4 was =m.
  We can restore the following options back to being modular:
- CRYPTO_CTS
- CRYPTO_ECB
- CRYPTO_GF128MUL
- CRYPTO_XTS
  Other crypto-related options enabled in the v4.1-rc1 update are
  a result of INTEGRITY=y and can't be returned to modular options
  without also disabling INTEGRITY.
- commit 1c78a8e
* Mon Jun  1 2015 jeffm@suse.com
- Update to 4.1-rc6.
- commit 9abfb15
* Fri May 29 2015 jeffm@suse.com
- Update to 4.1-rc5.
- commit 5c5c1d1
* Fri May 29 2015 tiwai@suse.de
- rtlwifi: rtl8192cu: Fix kernel deadlock (bnc#927786).
- commit ac67377
* Thu May 28 2015 dmueller@suse.com
- arm64-0004-net-xgbe-Add-A0-silicon-support: adjust for gettime64/settime64
- commit 8f2a4d1
* Thu May 28 2015 jslaby@suse.cz
- drm/radeon: retry dcpd fetch (bnc#931580).
- commit ad54361
* Thu May 28 2015 jbeulich@suse.com
- Refresh patches.arch/x86_64-unwind-annotations.
- Refresh
  patches.suse/revert-x86-remove-warning-and-warning_symbol-from-struct-stacktrace_ops.
- Refresh patches.suse/stack-unwind.
- Delete
  patches.arch/stack-unwind-cfi_ignore-takes-more-arguments,
  patches.suse/no-frame-pointer-select,
  patches.suse/unwind-remove-check-for-vdso32-compat-range:
  All folded into base patch.
- Update config files.
- commit 4631e0c
* Mon May 25 2015 tiwai@suse.de
- drm/nouveau/bios: fix fetching from acpi on certain systems
  (boo#932184).
- commit e14fcc2
* Tue May 19 2015 dsterba@suse.cz
- Revert "btrfs: delete chunk allocation attemp when setting block group ro".
  High user impact, should land in 4.1.
- commit 4f5e0d5
* Tue May 19 2015 jeffm@suse.com
- Update to 4.1-rc4.
- Config changes:
  - armv7hl: SPI_FSL_DSPI=m
- commit 9c4ab6c
* Tue May 19 2015 jslaby@suse.cz
- Update config files.
  Unset PKCS7_TEST_KEY, so that SYSTEM_TRUSTED_KEYRING can stay
  disabled. I.e. make it the same as on other configs/arches.
- commit 6355689
* Tue May 19 2015 jslaby@suse.cz
- Update config files.
  Unset PKCS7_TEST_KEY, so that SYSTEM_TRUSTED_KEYRING can stay
  disabled. I.e. make it the same as on other configs/arches.
- commit c9bc255
* Mon May 18 2015 jslaby@suse.cz
- drm/i915: Ensure cache flushes prior to doing CS flips -- take two
  (bnc#931300).
- commit 48c0b76
* Mon May 18 2015 jslaby@suse.cz
- Linux 4.0.4.
- Revert "xen/xenbus: Update xenbus event channel on resume".
- commit 383ecdf
* Wed May 13 2015 jslaby@suse.cz
- Linux 4.0.3.
- commit 3ee3773
* Mon May 11 2015 jeffm@suse.com
- Update to 4.1-rc3.
- Config changes:
  - RTC_DRV_ABX80X=m
- commit b798b43
* Thu May  7 2015 jslaby@suse.cz
- Linux 4.0.2 (boo#905088).
- Refresh patches.xen/xen-x86_64-vread-pvclock.
- Refresh patches.xen/xen3-patch-3.11.
- Delete
  patches.fixes/btrfs-fix-inode-eviction-infinite-loop-after-cloning.patch.
- Update config files.
  CONFIG_ARM64_ERRATUM_845719=y, the same as master.
- commit a425d38
* Thu May  7 2015 jdelvare@suse.de
- config/armv7hl: Disable AMD_XGBE_PHY
  The AMD XGBE ethernet chip is only used on ARM64 systems.
- commit 3541e77
* Wed May  6 2015 dmueller@suse.com
- config: arm64: Reenable for 4.1
  ACPI left disabled for now, Qualcom/Xen enabled,
  rest synced with x86_64
- commit da874b0
* Mon May  4 2015 jeffm@suse.com
- config: disable XGBE on non-ARM hardware
  It's documented as being present only on AMD SoCs.
- commit a32d077
* Mon May  4 2015 jeffm@suse.com
- Update to 4.1-rc2.
- Config changes:
  - CONFIG_EXT4_ENCRYPTION y->m (changed to tristate)
- commit d8dfb45
* Sat May  2 2015 matwey.kornilov@gmail.com
- config: Reenable armv7hl for 4.1
  Update armv7hl configs for 4.1
  Generic options follow x86_64 ones.
  CONFIG_DRM_I2C_NXP_TDA998X set to y as it is single known way to make video work on BBB
- commit 749ab51
* Fri May  1 2015 jeffm@suse.com
- scripts/sequence-patch.sh, scripts/tar-up.sh: Fix detection of SKIP_XEN.
  With the stricter checks to ensure all files in the repository are
  referenced, it's no longer possible to comment out configs in
  config.conf.  It is possible to exclude them via rule, but then
  scripts/guards --list will list them unconditionally.  That breaks the
  automatic no-xen handling.  The fix is to use scripts/guards
  $(scripts/arch-symbols --list) instead.
- commit fbf7f40
* Fri May  1 2015 jeffm@suse.com
- Update to 4.1-rc1.
- Xen needs updating.
- ARM configs need updating.
- Stack unwinding needs updating.
- 11 patches eliminated.
- Config changes:
  - Generic:
  - MULTIUSER=y (default)
  - Networking
  - 6LOWPAN_NHC=m
  - 6LOWPAN_NHC_DEST=m
  - 6LOWPAN_NHC_FRAGMENT=m
  - 6LOWPAN_NHC_HOP=m
  - 6LOWPAN_NHC_IPV6=m
  - 6LOWPAN_NHC_MOBILITY=m
  - 6LOWPAN_NHC_ROUTING=m
  - 6LOWPAN_NHC_UDP=m
  - MPLS_ROUTING=m
  - BT_DEBUGFS=n
  - Driver options:
  - BT_HCIBTUSB
  - BT_HCIBTUSB_BCM=y
  - BT_HCIUART
  - BT_HCIUART_INTEL=y
  - BT_HCIUART_BCM=y
  - TARGET_CORE
  - TCM_USER2=m
  - CHELSIO_T4
  - CHELSIO_T4_FCOE=y
  - MOUSE_PS2
  - MOUSE_PS2_VMMOUSE=y
  - New modules:
  - TOUCHSCREEN_CHIPONE_ICN8318=m
  - TOUCHSCREEN_SX8654=m
  - NFC_NXP_NCI=m
  - NFC_NXP_NCI_I2C=m
  - Storage:
  - BLK_DEV_PMEM=m
  - MD_CLUSTER=m
  - DM_MQ_DEFAULT=n (needs performance testing)
  - DM_LOG_WRITES=m
  - MTD_PARTITIONED_MASTER=y
  - x86/x86_64:
  - SCHED_OMIT_FRAME_POINTER=y (only because unwinding needs updating)
  - X86_PMEM_LEGACY=y (compatibility)
  - MFD_INTEL_QUARK_I2C_GPIO=m
  - PINCTRL_AMD=y
  - ARM (disabled):
  - MACB=n
  - KEYBOARD_BCM=n
  - TCG_TIS_ST33ZP24=n
  - SPI_CADENCE=n
  - GPIO_ALTERA=n
  - GPIO_DWAPB=n
  - POWER_RESET_SYSCON_POWEROFF=n
  - CADENCE_WATCHDOG=n
  - MFD_MAX77843=n
  - MFD_MT6397=n
- commit e5a9df9
* Wed Apr 29 2015 jslaby@suse.cz
- Linux 4.0.1.
- commit b77e339
* Wed Apr 29 2015 jdelvare@suse.de
- rpm/guards: Clarify user message
  When --config=series is used and a listed file is not found on the
  disk, guards prints the following message:
  Not found in series: file
  This message is confusing, as the file was found in series, it is
  missing on the disk. Change the message to make this more obvious.
- commit 3fbe9e5
* Fri Apr 24 2015 jdelvare@suse.de
- rpm/guards: Documentation update
  * Fix synopsis format.
  * Document the new --path=@<file> option.
- commit 7fd4136
* Fri Apr 24 2015 jdelvare@suse.de
- rpm/guards: White space cleanups
- commit d8089eb
* Wed Apr 22 2015 pmladek@suse.cz
- ftrace/x86/xen: use kernel identity mapping only when really needed
  (bsc#873195, bsc#886272, bsc#903727, bsc#927725)
- commit 63ed720
* Wed Apr 22 2015 mmarek@suse.cz
- scripts/refresh: Obsoleted by refresh_patch.sh
- commit d1dd729
* Wed Apr 22 2015 mmarek@suse.cz
- rpm/kernel-obs-build.spec.in: Add .build.hostarch.kvm to the filelist
- commit c65f3ca
* Tue Apr 21 2015 jbeulich@suse.com
- Update Xen patches to 4.0-final.
- commit eee4e07
* Tue Apr 21 2015 mmarek@suse.cz
- rpm/mkspec: Do not build kernel-obs-* on 32bit ppc
  The buildservice uses the ppc64 kernel-obs-build package for 32bit
  workers.
- commit d1e0beb
* Tue Apr 21 2015 dvaleev@suse.com
- create .build.hostarch.kvm for kernel-obs-build
  OBS needs to know hostarch, with ppc64/ppc64le this is not that easy.
  Lets create a marker file to help with it.
  See obs-build commit: e47399d738e51
- commit e5d9da9
* Tue Apr 14 2015 mmarek@suse.cz
- rpm/kernel-obs-qa.spec.in: Do not fail if the kernel versions do not match
- commit 28e9e74
* Tue Apr 14 2015 jlee@suse.com
- Update config files. (boo#925479)
  Do not set CONFIG_SYSTEM_TRUSTED_KEYRING until we need it in future
  openSUSE version:
  e.g. MODULE_SIG, IMA, PKCS7(new), KEXEC_BZIMAGE_VERIFY_SIG(new)
- commit 5c4d917
* Tue Apr 14 2015 jlee@suse.com
- Update config files. (boo#925479)
  Do not set CONFIG_SYSTEM_TRUSTED_KEYRING until we need it in future
  openSUSE version:
  e.g. MODULE_SIG, IMA, PKCS7(new), KEXEC_BZIMAGE_VERIFY_SIG(new)
- commit 74c332b
* Mon Apr 13 2015 jeffm@suse.com
- Update to 4.0-final.
- commit 6dbc1a6
* Mon Apr 13 2015 jslaby@suse.cz
- Linux 3.19.4.
- commit 51ddeac
* Fri Apr 10 2015 jeffm@suse.com
- Update to 4.0-rc7.
- Config changes:
  - x86_64/pv:
  - CONFIG_XEN_BALLOON_MEMORY_HOTPLUG_LIMIT=512 (default)
- commit 1925449
* Thu Apr  9 2015 agraf@suse.de
- of: Fix size when dma-range is not used.
- of: Move of_dma_configure() to device.c to help re-use.
- of: iommu: Add ptr to OF node arg to of_iommu_configure().
- PCI: Add helper functions pci_get[put]_host_bridge_device().
- PCI: Update DMA configuration from DT.
- of/pci: Add of_pci_dma_configure() to update DMA configuration.
- commit 7d1f328
* Wed Apr  8 2015 dsterba@suse.cz
- Btrfs: fix inode eviction infinite loop after cloning into it.
- commit ba5700e
* Wed Apr  8 2015 dsterba@suse.cz
- btrfs: simplify insert_orphan_item (boo#926385).
- commit 6d5e057
* Wed Apr  8 2015 tiwai@suse.de
- drm: Fixup racy refcounting in plane_force_disable (boo#925946).
- commit 7c1f29a
* Tue Apr  7 2015 agraf@suse.de
- Update XGBE-A0 support to latest code
- commit 2121347
* Mon Apr  6 2015 dmueller@suse.com
- ARMv7: config: Enable more features
  Sync over config settings that have been enabled on x86_64 in the
  last few years also to ARMv7
- commit d480a34
* Sun Apr  5 2015 dmueller@suse.com
- ARMv8: config: Enable more modules / feature flags
- commit 107eae5
* Sun Apr  5 2015 dmueller@suse.com
- ARM64: config: Disable CONFIG_INPUT_E3X0_BUTTON
- commit 9774a1b
* Sun Apr  5 2015 dmueller@suse.com
- ARMv6/v7/v8: config: Disable ISA bus related drivers
  There is no ISA bus here
- commit 469d5c3
* Sun Apr  5 2015 dmueller@suse.com
- ARMv7/v8: config: Disable IIO dummy drivers
  Not enabled on any other arch either.
- commit b10b70d
* Sun Apr  5 2015 dmueller@suse.com
- ARMv7: config: Disable accessibility
  Its not enabled on any other architecture, and enablement was
  an accident.
- commit 7197f38
* Sun Apr  5 2015 dmueller@suse.com
- ARMv6/v7/v8: config: Disable debug/compat/self test options
  Disable those options that shouldn't be enabled on a production
  kernel and are not either enabled on x86_64
- commit 5f7e741
* Sun Apr  5 2015 dmueller@suse.com
- ARMv8/v7: config: Sync more features from x86_64
  Enable various feature flags on ARM if they're also set on x86_64
  to ensure that the feature sets available is roughly compareable
- commit f250654
* Sat Apr  4 2015 dmueller@suse.com
- ARMv6/v7: config: build uncommon HID drivers as modules
  92db3f1ad forgot to update ARM configs accordingly.
- commit a83ec68
* Sat Apr  4 2015 dmueller@suse.com
- ARM64: config: Sync vanilla with default config
- commit 7be032d
* Sat Apr  4 2015 dmueller@suse.com
- ARM64/ARMv6/ARMv7: config: Sync tunables with x86_64
  Set numeric tunables to the same values as on x86_64 if they're
  available for both platforms.
- commit e4e34f2
* Fri Apr  3 2015 mmarek@suse.cz
- Automatically Provide/Obsolete all subpackages of old flavors (bnc#925567)
- commit e3547a5
* Thu Apr  2 2015 dmueller@suse.com
- ARMv6: config: Update and reenable for 4.0-rc6
- commit e32301a
* Wed Apr  1 2015 dmueller@suse.com
- ARMv6: config: Reenable DWC2 host support
  We need the USB host controller support in order to have
  network on the Raspberry Pi, as the network is connected
  via USB.
- commit f54483c
* Tue Mar 31 2015 dmueller@suse.com
- ARM: config: Enable Stack Protector
- commit 0f06efd
* Tue Mar 31 2015 dmueller@suse.com
- ARMv6: config: Cleanup default config
  Previous updates enabled config options that do not make sense
  on ARMv6. ARMv6 default flavor is actually just a RPi1 kernel,
  so enabling platform support for hardware that is unavailable there
  and that conflicts with the Rpi drivers should not be done.
  This causes the kernel to boot again on a Rpi1.
- commit 1bc76eb
* Tue Mar 31 2015 jeffm@suse.com
- Update to 4.0-rc6.
- commit 3062c5b
* Fri Mar 27 2015 mmarek@suse.cz
- guards: Include the file name also in the "Not found" error
- commit 9b71e7b
* Fri Mar 27 2015 mmarek@suse.cz
- guards: Add support for an external filelist in --check mode
  This will allow us to run --check without a kernel-source.git work tree.
- commit 61c3df5
* Fri Mar 27 2015 mmarek@suse.cz
- guards: Simplify help text
- commit f0c085a
* Thu Mar 26 2015 jslaby@suse.cz
- Linux 3.19.3 (bsc#921313).
- Refresh patches.xen/xen3-patch-3.1.
- Delete
  patches.arch/x86-vdso-fix-a-reference-to-a-non-existing-instructi.patch.
- Delete
  patches.drivers/ALSA-hda-Fix-regression-of-HD-audio-controller-fallb.patch.
- commit f10e7fc
* Tue Mar 24 2015 jbeulich@suse.com
- Update Xen patches to 4.0-rc5.
- commit 7636f33
* Tue Mar 24 2015 dsterba@suse.cz
- config: disable SCSI_MQ_DEFAULT on all architectures and configs
  The scsi-mq feature lacks support for io schedulers right now.  This
  exhibits as performance drop for random RW workloads due to excessive
  seeking. The real benefit of scsi-mq comes with high-end and fast
  devices, the estimated impact on our users is low.
- commit 59a4160
* Tue Mar 24 2015 dsterba@suse.cz
- config: disable SCSI_MQ_DEFAULT on all architectures and configs
  The scsi-mq feature lacks support for io schedulers right now. This
  exhibits as performance drop for random RW workloads due to excessive
  seeking. The real benefit of scsi-mq comes with high-end and fast
  devices, the estimated impact on our users is low.
- commit d8856ce
* Tue Mar 24 2015 agraf@suse.de
- pci: Enable pci-host-generic support for ARM64 (bnc#911732).
- PCI/MSI: of: Allow msi_domain lookup using the PHB node
  (bnc#911732).
- PCI/MSI: Drop domain field from msi_controller (bnc#911732).
- irqchip: gicv3-its: Get rid of struct msi_controller
  (bnc#911732).
- irqchip: GICv2m: Get rid of struct msi_controller (bnc#911732).
- PCI/MSI: Let pci_msi_get_domain use struct device's msi_domain
  (bnc#911732).
- PCI/MSI: of: add support for OF-provided msi_domain
  (bnc#911732).
- PCI/MSI: add hooks to populate the msi_domain field
  (bnc#911732).
- device core: Introduce per-device MSI domain pointer
  (bnc#911732).
- commit 3583a4a
* Tue Mar 24 2015 agraf@suse.de
- Delete patches.arch/arm64-0012-generic-pci.patch.
- commit 6b01afd
* Tue Mar 24 2015 agraf@suse.de
- Refresh
  patches.arch/arm64-0010-KVM-ARM-Hack-to-enable-VGIC-mapping-on-64k-PAGE_SIZE.patch.
- commit 6c49399
* Mon Mar 23 2015 jeffm@suse.com
- config: disable CONFIG_ACPI_PROCFS_POWER (i386/x86_64) (boo#917728)
  CONFIG_ACPI_PROCFS_POWER is deprecated and should be disabled.
- commit 9eb6ba4
* Mon Mar 23 2015 jeffm@suse.com
- Update to 4.0-rc5.
- Eliminated 1 patch.
- Config changes:
  - ARM64:
  - CAN_XILINXCAN=m
- commit ecb5151
* Sat Mar 21 2015 dmueller@suse.com
- ARM64: config: Raise NR cpus to 64
  There is hardware that has more than 32 cores, so we would
  like to support them out of the box.
- commit 8434f2b
* Wed Mar 18 2015 jslaby@suse.cz
- Linux 3.19.2.
- commit f2f9797
* Wed Mar 18 2015 jbeulich@suse.com
- Update Xen patches to 4.0-rc4 and c/s 1283.
- config.conf: Re-enable Xen and PV configs.
- Update config files.
- commit 09cef55
* Mon Mar 16 2015 dmueller@suse.com
- ARM64: Update patch-mainline for A0-silicon support
- commit 5541c66
* Mon Mar 16 2015 jeffm@suse.com
- Update to 4.0-rc4.
- Config changes:
  - ppc/ppc64/ppc64le/armv7hl/arm64:
  - OF_OVERLAY=y (no functional change, the option was introduced to
    allow disabling of previously builtin behavior)
  - CONFIG_OF_RECONFIG_NOTIFIER_ERROR_INJECT=m
  - i386:
  - OF_OVERLAY=n
- commit 0067839
* Mon Mar 16 2015 jeffm@suse.com
- config: refresh armv7hl-vanilla config
  The armv7hl-vanilla config contained options not offered by the vanilla
  kernel, showing it hadn't been resynced.
- commit 1c9d3a1
* Mon Mar 16 2015 jeffm@suse.com
- config: update arm64-vanilla config
  The ARM64 update for 4.0-rc3 updated default, but not vanilla. This commit
  just syncs the changes.
- commit dc76fd5
* Sun Mar 15 2015 dmueller@suse.com
- ARM64: Adjust xkbe-a0 to Linux 4.0rc3
  Upstream commit df8a39defad4 (net: rename vlan_tx_* helpers since "tx"
  is misleading there) renamed vlan_tx_* helpers causing a build failure for
  xgbe. This commit resyncs with 4.0-rc3.
- commit 126fc64
* Sun Mar 15 2015 dmueller@suse.com
- ARM64: Fix support for ARMv7 userspace
- commit 86b157b
* Mon Mar  9 2015 dmueller@suse.com
- config: ARM64: Reenable configs for 4.0-rc3
  This mainly adds support for Exynos 7, Mediatek and
  Freescale's SoCs.
- commit d573f03
* Mon Mar  9 2015 dmueller@suse.com
- ARM64: Use 64k zero page protection like on other arches
  For cross-architecture compatibility, use the 64k MMAP min
  addr. The old value was nonsensical anyway since we switched to 64k
  page size, which means this change is effectively a NOOP in the 64k
  Pagesize flavor.
- commit d5c547f
* Mon Mar  9 2015 jeffm@suse.com
- config: disable FEC_MPC52xx on ppc
  List discussion indicates that the openSUSE kernel doesn't properly
  support Efika and that there aren't users of the hardware.
  These devices can only be enumerated using open firmware.
- commit 4a3e976
* Mon Mar  9 2015 tiwai@suse.de
- ALSA: hda - Fix regression of HD-audio controller fallback modes
  (bsc#921313).
- commit c0946e9
* Mon Mar  9 2015 jeffm@suse.com
- Update to 4.0-rc3.
- commit f264c86
* Sat Mar  7 2015 jeffm@suse.com
- config: disable SERIAL_XILINX_PS_UART on i386
  These devices can only be enumerated using open firmware.
- commit ee2b818
* Sat Mar  7 2015 jeffm@suse.com
- config: disable W1_MASTER_GPIO on i386, x86_64
  These devices can only be enumerated using open firmware.
- commit f84f577
* Sat Mar  7 2015 jeffm@suse.com
- config: disable VIRTIO_MMIO on i386, x86_64
  These devices can only be enumerated using open firmware.
- commit ff54725
* Sat Mar  7 2015 jeffm@suse.com
- config: disable MFD_TI_AM335X_TSCADC on non-ARM platforms
  These devices can only be enumerated using open firmware.
- commit 9ac8349
* Sat Mar  7 2015 jeffm@suse.com
- config: disable STMMAC_PLATFORM on non-ARM platforms
  These devices can only be enumerated using open firmware.
- commit f641fdf
* Sat Mar  7 2015 jeffm@suse.com
- config: disable TI_ST and RADIO_WL128X on i386, x86_64
  Can probably also be disabled on ppc*
  These devices can only be enumerated using open firmware.
- commit 90c2553
* Sat Mar  7 2015 jeffm@suse.com
- config: disable MMC_SDHCI_OF_ARASAN on i386
  Can probably also be disabled on ARM64
  These devices can only be enumerated using open firmware.
- commit 4ea5b44
* Sat Mar  7 2015 jeffm@suse.com
- config: disable PPS_CLIENT_GPIO on i386, x86_64
  These devices can only be enumerated using open firmware.
- commit b5f1d4c
* Sat Mar  7 2015 jeffm@suse.com
- config: disable MDIO_BUS_MUX_GPIO on i386
  These devices can only be enumerated using open firmware.
- commit 85bea9a
* Sat Mar  7 2015 jeffm@suse.com
- config: disable KS8851_MLL on i386, x86_64
  Can probably also be disabled on ppc, ppc64, ppc64le but I couldn't
  find a definitive list of platforms this hardware is used with.
  These devices can only be enumerated using open firmware.
- commit 9dc4b32
* Sat Mar  7 2015 jeffm@suse.com
- config: disable I2C_MPC on ppc64, ppc64le
  These devices can only be enumerated using open firmware.
- commit 1fb8e5a
* Sat Mar  7 2015 jeffm@suse.com
- config: disable GPIO_WATCHDOG on i386
  These devices can only be enumerated using open firmware.
- commit 46bdcd6
* Sat Mar  7 2015 jeffm@suse.com
- config: disable GPIO_SYSCON on i386
  These devices can only be enumerated using open firmware.
- commit 05f2a21
* Sat Mar  7 2015 jeffm@suse.com
- config: disable IR_GPIO_CIR on i386, x86_64
  These devices can only be enumerated using open firmware.
- commit feacf1d
* Sat Mar  7 2015 jeffm@suse.com
- config: disable GPIO_GRGPIO on i386, ppc, ppc64, ppc64le
  The hardware enabled by this driver is typically only found on LEON
  SPARC systems. Since it enables an IP library that could potentially
  be found on any embedded board, I've left it enabled for ARM and PPC.
- commit 6b22540
* Sat Mar  7 2015 jeffm@suse.com
- config: disable INPUT_GPIO_BEEPER on i386, x86_64
  These devices can only be enumerated using open firmware.
- commit b215566
* Sat Mar  7 2015 jeffm@suse.com
- config: disable GPIO_74XX_MMIO on i386
  These devices can only be enumerated using open firmware.
- commit ee3e4f4
* Sat Mar  7 2015 jeffm@suse.com
- config: disable SERIAL_FSL_LPUART on non-ARM platforms.
  This hardware is only found on Freescale ARM platforms.
- commit b43a527
* Sat Mar  7 2015 jslaby@suse.cz
- Linux 3.19.1.
- Refresh patches.xen/xen-x86-bzImage.
- commit a04cebc
* Sat Mar  7 2015 jeffm@suse.com
- config: disable ETHOC on i386, x86_64
  These devices can only be enumerated using open firmware.
- commit aed4e05
* Sat Mar  7 2015 jeffm@suse.com
- config: disable DW_WATCHDOG on i386, x86_64, ppc, ppc64, ppc64le
  This hardware used to be ARM-only but is now available on Xtensa, so
  we can disable it everywhere bug ARM.
- commit a4ffedf
* Sat Mar  7 2015 jeffm@suse.com
- config: disable MTD_DOCG3 on i386, x86_64, ppc64, ppc64le
  This generation of DiskOnChip is quite old and found on embedded platforms.
  It's probably ok to disable it for arm64 as well.
  These devices can only be enumerated using open firmware.
- commit d84f49b
* Sat Mar  7 2015 jeffm@suse.com
- config: disable SERIO_APBPS2 on i386
  The hardware enabled by this driver is typically only found on LEON
  SPARC systems. Since it enables an IP library that could potentially
  be found on any embedded board, I've left it enabled for ARM and PPC.
- commit 27b679d
* Sat Mar  7 2015 jeffm@suse.com
- config: disable APPLE_AIRPORT on ppc64le
  Apple Airport is only found on Apple ppc/ppc64 hardware.
- commit 77cf796
* Sat Mar  7 2015 jeffm@suse.com
- Update to 4.0-rc2.
- commit bdfe724
* Wed Mar  4 2015 matwey.kornilov@gmail.com
- config: armv7hl: Reenable for armv7hl
- commit 23602ae
* Tue Mar  3 2015 jslaby@suse.cz
- x86/vdso: fix a reference to a non-existing instruction.
- commit 584067b
* Tue Mar  3 2015 jeffm@suse.com
- config: revert changes to i386/pv
  The i386/pv config will be resynced when Xen is updated.
- commit c77a495
* Tue Mar  3 2015 jeffm@suse.com
- config: disable ALTERA_TSE on i386/x86_64
  These devices can only be enumerated using open firmware.
- commit 6506dc7
* Tue Mar  3 2015 jeffm@suse.com
- config: disable FB_OPENCORES on i386/x86_64
  These devices can only be enumerated using open firmware.
- commit 1c992f1
* Mon Mar  2 2015 jeffm@suse.com
- Update to 4.0-rc1.
- Eliminated 1 patch.
- Xen needs updating.
- ARM configs need updating.
- Config changes:
  - General:
  - RCU_KTHREAD_PRIO = 0 for default; 1 for desktop
  - X86_INTEL_QUARK=y (32-bit only)
  - X86_AMD_PLATFORM_DEVICE=y
  - ZSMALLOC_STAT=n
  - DEVMEM=y
  - DUMMY_CONSOLE_COLUMNS=80
  - DUMMY_CONSOLE_ROWS=25
  - FS_DAX=y
  - PSTORE_PMSG=n
  - F2FS_IO_TRACE=n
  - NFSD_PNFS=y
  - GDB_SCRIPTS=n (only installs in build dir)
  - LIVEPATCH=y
  - TEST_HEXDUMP=n
  - CRYPTO_USER_API_RNG=m
  - BLK_DEV_RAM_DAX=y
  - PM_DEVFREQ_EVENT=y
  - VIRTIO_PCI_LEGACY=y
  - Networking:
  - IEEE802154_SOCKET=m
  - NET_ACT_BPF=m
  - NET_ACT_CONNMARK=m
  - BT_SELFTEST=n
  - Networking drivers:
  - IXGBE_VXLAN=y
  - AMD_XGBE=m
  - AMD_XGBE_DCB=y
  - Input:
  - MOUSE_PS2_FOCALTECH=y
  - HID_BETOP_FF=m
  - Other drivers, enabled as modules:
  - TCG_CRB
  - I2C_DESIGNWARE_BAYTRAIL
  - SPI_DLN2
  - USB_ISP1760
  - LEDS_CLASS_FLASH
  - FB_SM7XX
  - USB_GSPCA_TOUPTEK
  - SND_USB_POD
  - SND_USB_PODHD
  - SND_USB_TONEPORT
  - SND_USB_VARIAX
  - Disabled drivers:
  - RTC_DRV_DS1685_FAMILY (found on SGI O2/Octane hardware)
  - ACPI-discoverable sensors drivers, enabled as modules:
  - MMA9551
  - MMA9553
  - KMX61
  - JSA1212
  - SX9500
  - x86
  - DEBUG_IMR_SELFTEST=n
  - zSeries:
  - MARCH_Z900
  - TUNE_DEFAULT
  - SCHED_TOPOLOGY=y (renamed from SCHED_BOOK)
  - Device-tree dependent drivers, all disabled:
  - MTD_NAND_HISI504
  - TI_CPSW_ALE
  - INPUT_E3X0_BUTTON
  - INPUT_TPS65218_PWRBUTTON
  - SERIAL_CONEXANT_DIGICOLOR
  - TCG_TIS_I2C_ST33
  - GPIO_XILINX
  - BATTERY_GAUGE_LTC2941
  - POWER_RESET_RESTART
  - MFD_DA9150
  - MFD_RT5033
  - DRM_PANEL_SIMPLE
  - DRM_PANEL_LD9040
  - DRM_PANEL_S6E8AA0
  - DRM_PANEL_SHARP_LQ101R1SX01
  - MMC_SDHCI_F_SDH30
  - RTC_DRV_ABB5ZES3
  - FB_TFT
  - COMMON_CLK_CDCE706
  - ASM9260_TIMER
  - IOMMU_IO_PGTABLE_LPAE
  - CC10001_ADC
  - QCOM_SPMI_VADC
  - IIO_SSP_SENSORHUB
  - CM3232
- commit d6b999d
* Tue Feb 24 2015 guillaume.gardet@free.fr
- config: armv6hl: Update and re-enable armv6 default config
  Please find an update from 3.18.0 to 3.19.0 for armv6 default config.
  It also enables armv6 default config again.
  [AF: Homogenized module selection, dropped Broadcom Kona support (ARMv7)]
  (cherry picked from commit 860fc5cd0552cd001cbb4ed0edbb9634748ae0eb)
- config: armv6hl: Update and re-enable armv6 default config
  Please find an update from 3.18.0 to 3.19.0 for armv6 default config.
  It also enables armv6 default config again.
  [AF: Homogenized module selection, dropped Broadcom Kona support (ARMv7)]
- commit f85c84c
* Mon Feb 16 2015 matwey.kornilov@gmail.com
- config: armv7hl: Temporarily disable CONFIG_PCIE_SPEAR13XX
  spear13xx pcie leads to kernel oopses in random places,
  so let's disable it until a proper solution to fix it is found.
  References: bko#92581
  (cherry picked from commit a26077781b14f8b6c48517927216eb5b923de54d)
- config: armv7hl: Temporarily disable CONFIG_PCIE_SPEAR13XX
  spear13xx pcie leads to kernel oopses in random places,
  so lets disable it until a proper solution to fix it is found.
  References: bko#92581
- commit 1133f88
* Fri Feb 13 2015 jdelvare@suse.de
- Update config files: disable CONFIG_I2C_SLAVE
  Disable CONFIG_I2C_SLAVE on x86 and ppc*. There is currently no known
  use case for this feature on these architectures, and it has a small
  build time and size cost.
- commit 9a477d7
* Tue Feb 10 2015 tiwai@suse.de
- fix a leak in bch_cached_dev_run() (bnc#910440).
- bcache: unregister reboot notifier when bcache fails to register
  a block device (bnc#910440).
- bcache: fix a livelock in btree lock (bnc#910440).
- bcache: [BUG] clear BCACHE_DEV_UNLINK_DONE flag when attaching
  a backing device (bnc#910440).
- bcache: Add a cond_resched() call to gc (bnc#910440).
- fix a leak in bch_cached_dev_run() (bnc#910440).
- bcache: unregister reboot notifier when bcache fails to register
  a block device (bnc#910440).
- bcache: fix a livelock in btree lock (bnc#910440).
- bcache: [BUG] clear BCACHE_DEV_UNLINK_DONE flag when attaching
  a backing device (bnc#910440).
- bcache: Add a cond_resched() call to gc (bnc#910440).
- commit 30e9ca2
* Tue Feb 10 2015 tiwai@suse.de
- vm: add VM_FAULT_SIGSEGV handling support for XEN (bnc#917060).
- commit 48f695c
* Tue Feb 10 2015 jbeulich@suse.com
- Update Xen patches to 3.19-final.
- commit 7ba6009
* Mon Feb  9 2015 jeffm@suse.com
- Update to 3.19-final.
- commit b47fe8e
* Fri Feb  6 2015 jslaby@suse.cz
- Linux 3.18.6.
- Delete patches.fixes/vm-add-VM_FAULT_SIGSEGV-handling-support.
- Delete
  patches.fixes/vm-make-stack-guard-page-errors-return-VM_FAULT_SIGS.
- commit ec2a744
* Thu Feb  5 2015 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Fix build if there is no *.crt file
- commit c5b1275
* Wed Feb  4 2015 jbeulich@suse.com
- Update Xen patches to 3.19-rc7 and c/s 1279.
- Update Xen config files.
- commit f6f5ce5
* Tue Feb  3 2015 jeffm@suse.com
- Update to 3.19-rc7.
- commit 7505c11
* Fri Jan 30 2015 mmarek@suse.cz
- rpm/constraints.in: Lower the requirement to 4 CPUs on POWER
- commit 9e50821
* Fri Jan 30 2015 tiwai@suse.de
- vm: make stack guard page errors return VM_FAULT_SIGSEGV rather
  than SIGBUS.
- vm: add VM_FAULT_SIGSEGV handling support.
- commit fe77e87
* Fri Jan 30 2015 jslaby@suse.cz
- Linux 3.18.5.
- Refresh patches.xen/xen3-auto-xen-kconfig.diff.
- Refresh patches.xen/xen3-patch-3.15.
- Update config files.
- commit f378da4
* Wed Jan 28 2015 jeffm@suse.com
- Update to 3.19-rc6.
- Config changes:
  - SENSORS_I5500=m (i386/x86_64)
- commit 5dca9d9
* Tue Jan 27 2015 jslaby@suse.cz
- Linux 3.18.4 (bnc#897736 bnc#905329 bnc#911356 bnc#911835).
- Delete
  patches.drivers/drm-i915-Don-t-call-intel_prepare_page_flip-multiple.
- Delete patches.drivers/drm-radeon-fix-sad_count-check-for-dce3.
- Delete patches.drivers/hp_accel-Add-support-for-HP-ZBook-15.
- Delete
  patches.fixes/media-uvc-Fix-destruction-order-in-uvc_delete.
- Update config files.
- commit abfc700
* Tue Jan 27 2015 jbeulich@suse.com
- rpm/package-descriptions: Describe kernel-pv (and correct kernel-ec2's).
- commit 6dd25c9
* Mon Jan 26 2015 mmarek@suse.cz
- DocBook: Do not exceed argument list limit.
- commit 6eae009
* Mon Jan 26 2015 mmarek@suse.cz
- rpm/kernel-docs.spec.in: Do not ignore errors from make
- commit 86ebfa7
* Sat Jan 24 2015 jdelvare@suse.de
- Update x86_64 config files: CONFIG_SENSORS_NCT6683=m
  The nct6683 driver is already enabled on i386 and history suggests
  that it not being enabled on x86_64 is by mistake.
- commit e31f652
* Fri Jan 23 2015 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Drop sparse from BuildRequires
- commit 9777c26
* Fri Jan 23 2015 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Update the comment about NO_BRP_STALE_LINK_ERROR
  There is no stale symlink in the installed system anymore, but there is
  one during build.
- commit e575cce
* Fri Jan 23 2015 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Own the modules directory in the devel
  package (bnc#910322)
- commit d89b963
* Thu Jan 22 2015 jbeulich@suse.com
- Add x86 PV config files.
- commit 297f762
* Thu Jan 22 2015 jbeulich@suse.com
- Update Xen patches to 3.19-rc5 and c/s 1276.
- config.conf: Re-enable Xen configs.
- Update config files.
- commit 9368e4c
* Wed Jan 21 2015 mmarek@suse.cz
- Fix Module.supported handling for external modules (bnc#905304).
- commit 26d68ed
* Wed Jan 21 2015 jeffm@suse.com
- Update to 3.19-rc5.
- Config changes:
  - I40E_FCOE=y
- commit 1548087
* Mon Jan 19 2015 jslaby@suse.cz
- Update patches.kernel.org/patch-3.18.1-2 (CVE-2014-8133
  bnc#906545 bnc#908163 bsc#909077).
  Add one more reference.
- commit c3e148f
* Sat Jan 17 2015 jslaby@suse.cz
- Linux 3.18.3 (bnc#908794).
- Delete
  patches.fixes/blk-mq-Fix-uninitialized-kobject-at-CPU-hotplugging.
- commit 390047f
* Fri Jan 16 2015 matwey.kornilov@gmail.com
- config: armv7hl: Update config files for 3.19-rc6
  [AF: Updated for -rc6, enabled some more default options,
    enabled/disabled lpae options, regenerated vanilla from default]
- commit a7bdd86
* Wed Jan 14 2015 agraf@suse.de
- Refresh patches.arch/arm64-0012-generic-pci.patch (fix PCI bridge support)
- commit b9cbcf4
* Wed Jan 14 2015 agraf@suse.de
- Refresh patches.arch/arm64-0039-generic-pci.patch  (fix PCI bridge support)
- commit 88366a3
* Mon Jan 12 2015 jeffm@suse.com
- Update to 3.19-rc4.
- Config changes:
  - KDB_DEFAULT_ENABLE=0x1 (default, no change)
- commit f688a05
* Mon Jan 12 2015 jeffm@suse.com
- config: fixed re-enabling of CFG80211_WEXT
- Note: CFG80211_WEXT was disabled in 3.19-rc1, not 3.17.
  * git describe and git name-rev show different things.
- IPW2200_DEBUG=y was set prior to 3.19-rc1, restore it
- Re-sync arm64 config to match pre-rc1 values.
- commit 79a899b
* Fri Jan  9 2015 jslaby@suse.cz
- Linux 3.18.2 (CVE-2014-8133 bnc#908163 bsc#909077).
- Delete
  patches.fixes/KEYS-Fix-stale-key-registration-at-error-path.
- Delete
  patches.fixes/x86-tls-validate-tls-entries-to-protect-espfix.patch.
- commit a393f37
* Thu Jan  8 2015 tiwai@suse.de
- Bluetooth: Add support for Broadcom BCM20702A0 variants firmware
  download (bnc#911311).
- commit 15c2753
* Thu Jan  8 2015 jeffm@suse.com
- Update to 3.19-rc3.
- Config changes are repairing fallout from the removal of
  wireless extensions in 3.17. They were restored in 3.19-rc3.
- commit 43d6953
* Thu Jan  8 2015 tiwai@suse.de
- drm/radeon: fix sad_count check for dce3 (bnc#911356).
- commit d0f80d0
* Tue Jan  6 2015 tiwai@suse.de
- drm/i915: Don't call intel_prepare_page_flip() multiple times
  on gen2-4 (bnc#911835).
- commit 946a5ed
* Tue Jan  6 2015 agraf@suse.de
- arm64: Enable DRM
- commit c00a333
* Mon Jan  5 2015 agraf@suse.de
- arm64: Disable CRC32 accelerator again, doesn't build
- commit c0e01e0
* Mon Jan  5 2015 agraf@suse.de
- arm64: Enable generic PHB driver (bnc#912061).
- arm64: Enable generic PHB driver (bnc#911732).
- commit 5452184
* Mon Jan  5 2015 agraf@suse.de
- Update config files for arm64
- commit 4c90d68
* Fri Jan  2 2015 dbueso@suse.de
- rpm/old-flavors: Obsolete kernel-bigsmp (fate#318083)
- commit c5abe0c
* Fri Jan  2 2015 mmarek@suse.cz
- patches.suse/supported-flag: fix mis-reported supported status (bnc#809493)
  Port fix from SLE12.
- commit 92db6d0
* Fri Jan  2 2015 mmarek@suse.cz
- Refresh patches.suse/supported-flag: fix TAINT_NO_SUPPORT handling on
  module load
  Port fix from SLE12.
- commit 47e6368
* Tue Dec 30 2014 jeffm@suse.com
- Update to 3.19-rc2.
- commit aa3360b
* Tue Dec 23 2014 matwey.kornilov@gmail.com
- config: Introduce vanilla configs for armv6l, armv7l and aarch64
- commit cd0d0f3
* Mon Dec 22 2014 jeffm@suse.com
- Update to 3.19-rc1.
- Eliminated 5 patches.
- Xen needs updating.
- ARM configs need updating.
- Config changes:
  - General
  - INIT_FALLBACK (y, default, consistent with old default)
  - PAGE_EXTENSION=n (overhead)
  - PAGE_OWNER=n (overhead)
  - Networking:
  - NET_FOU_IP_TUNNELS=y
  - NFT_REDIR=m
  - NFT_REDIR_IPV4=m
  - NFT_REDIR_IPV6=m
  - NET_DSA_HWMON=y
  - NET_ACT_VLAN=m
  - NET_SWITCHDEV=y (only impact is a slightly bigger ndo)
  - BT_BREDR=y
  - BT_LE=y
  - IPVLAN=m
  - NET_DSA_MV88E6352=m
  - ROCKER=m
  - BCMGENET=m
  - Driver options:
  - CONFIG_MAC80211_RC_MINSTREL_VHT=y
  - ATH9K_PCOEM=y
  - RTC_DRV_DS1374_WDT=y
  - INFINIBAND_ON_DEMAND_PAGING=y
  - SQUASHFS_LZ4=y
  - Drivers:
  - SCSI_AM53C974=m
  - SCSI_WD719X=m
  - KEYBOARD_CAP11XX=m
  - MOUSE_ELAN_I2C=m
  - TOUCHSCREEN_GOODIX=m
  - TOUCHSCREEN_ELAN=m
  - IPMI_SSIF=m
  - I2C_SLAVE=y (does nothing; only here for future additions)
  - GPIO_74XX_MMIO=m
  - SENSORS_NCT7802=m
  - MFD_DLN2=m
  - I2C_DLN2=m
  - GPIO_DLN2
  - IR_IGORPLUGUSB=m
  - DVB_SMIPCIE=m
  - DVB_MN88472=m
  - DVB_MN88473=m
  - VIDEO_SAA7191=n (staging/deprecated)
  - VIDEO_VIM2M=m
  - DRM_I2C_ADV7511=m
  - SND_OXFW=m
  - HID_PLANTRONICS=m
  - MMC_TOSHIBA_PCI=m
  - LEDS_LP8860=m
  - x86
  - X86_INTEL_MPX=y (default n, little kernel overhead for potential security gains)
  - RCU_KTHREAD_PRIO=1 (default)
  - X86_VSYSCALL_EMULATION=y
  - HSA_AMD=m
  - EDAC_AMD64=m
  - EDAC_AMD64_ERROR_INJECTION=y
  - ppc
  - OF_UNITTEST=n
  - IPMI_POWERNV=m
  - I2C_OPAL=m
  - RTC_DRV_OPAL=m
  - s390x
  - SCLP_ASYNC_ID=000000000 (default)
  - SoC
  - PINCTRL_CHERRYVIEW=n
  - ARM?: (all n)
  - PMIC
  - MFD_ATMEL_HLCDC
  - COMMON_CLK_XLNX_CLKWZRD
  - QCOM_SPMI_IADC
  - Mobile sensors: (all n)
  - SI7020
  - BMP280
- commit 85f0072
* Wed Dec 17 2014 bp@suse.de
- x86/tls: Validate TLS entries to protect espfix (bsc#909077,CVE-2014-8133).
- commit 5f2f35e
* Wed Dec 17 2014 jslaby@suse.cz
- Linux 3.18.1.
- Delete
  patches.drivers/ALSA-usb-audio-Don-t-resubmit-pending-URBs-at-MIDI-e.
- commit 0fdb00f
* Tue Dec 16 2014 tiwai@suse.de
- parport: parport_pc, do not remove parent devices early
  (bnc#856659).
- commit 161f750
* Sun Dec 14 2014 tiwai@suse.de
- blk-mq: Fix uninitialized kobject at CPU hotplugging
  (bnc#908794).
- commit b68f510
* Fri Dec 12 2014 jbeulich@suse.com
- Refresh Xen patches (adjustments for pv-ops builds and a huge
  memory DomU boot fix).
- commit 0510331
* Tue Dec  9 2014 jbeulich@suse.com
- Update Xen patches to 3.18-final.
- x86-64/MCE: flip CPU and bank numbers in log message.
- commit 2b473fc
* Tue Dec  9 2014 jeffm@suse.com
- Update to 3.18-final.
- commit fb05465
* Sun Dec  7 2014 jslaby@suse.cz
- Linux 3.17.6.
- commit 12b7bf1
* Sun Dec  7 2014 jslaby@suse.cz
- Linux 3.17.5 (bnc#904417).
- Refresh patches.xen/xen3-patch-2.6.18.
- Refresh patches.xen/xen3-patch-2.6.31.
- Delete
  patches.drivers/drm-radeon-report-disconnected-for-LVDS-eDP-with-PX.
- commit 8bebfb6
* Sat Dec  6 2014 tiwai@suse.de
- ALSA: usb-audio: Don't resubmit pending URBs at MIDI error
  recovery.
- commit a6e513d
* Fri Dec  5 2014 tiwai@suse.de
- drm: Implement O_NONBLOCK support on /dev/dri/cardN
  (bnc#904097).
- commit 1b14fe6
* Fri Dec  5 2014 tiwai@suse.de
- KEYS: Fix stale key registration at error path (bnc#908163).
- commit 7d9c8f3
* Fri Dec  5 2014 agraf@suse.de
- arm64: Enable 64k page size (bnc#908468)
- commit 088d59b
* Thu Dec  4 2014 agraf@suse.de
- ARMv7: Bump NR_CPUs to 16, the HIP04D01 has that many
- commit 9c41958
* Mon Dec  1 2014 jeffm@suse.com
- Update to 3.18-rc7.
- commit 58b7b67
* Mon Dec  1 2014 jbeulich@suse.com
- Update Xen config files (restore RTC_DRV_EFI).
- commit ab8d181
* Fri Nov 28 2014 jbeulich@suse.com
- Update Xen patches to 3.18-rc6 and c/s 1269.
- commit 7e21a29
* Thu Nov 27 2014 mmarek@suse.cz
- rpm/constraints.in: Require 10GB of disk space also on 32bit POWER
- commit 33a282b
* Wed Nov 26 2014 jeffm@suse.com
- Update to 3.18-rc6.
- commit 961dff7
* Wed Nov 26 2014 mmarek@suse.cz
- rpm/constraints.in: Require 10GB disk space on POWER
  A debuginfo build currently requires about 8.5 GB on POWER. Also,
  require at least 8 CPUs, so that builds do not get accidentally
  scheduled on slow machines.
- commit 596d9cf
* Tue Nov 25 2014 tiwai@suse.de
- drm/radeon: report disconnected for LVDS/eDP with PX if ddc
  fails (bnc#904417).
- commit 2d23787
* Sat Nov 22 2014 jslaby@suse.cz
- Linux 3.17.4 (bnc#665315 bnc#903748 bnc#904289).
- Refresh patches.xen/xen3-patch-3.17.
- Delete
  patches.drivers/0010-ALSA-hda-Add-mute-LED-control-for-Lenovo-Ideapad-Z56.patch.
- Delete
  patches.drivers/Input-synaptics-add-min-max-quirk-for-Lenovo-T440s.
- Delete patches.drivers/quirk-for-Lenovo-Yoga-3-no-rfkill-switch.
- commit d50009e
* Wed Nov 19 2014 jeffm@suse.com
- Update to 3.18-rc5.
- commit 2e1894b
* Fri Nov 14 2014 jslaby@suse.cz
- Linux 3.17.3 (bnc#900786).
- Refresh patches.xen/xen3-patch-2.6.24.
- Delete
  patches.fixes/iwlwifi-dvm-drop-non-VO-frames-when-flushing.
- commit 76fe48f
* Fri Nov 14 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Provide name-version-release for kgraft
  packages (bnc#901925)
- commit c9157ee
* Fri Nov 14 2014 agraf@suse.de
- PPC: Update config files: Enable HV KVM as module
- commit 0521fb3
* Thu Nov 13 2014 tiwai@suse.de
- hp_accel: Add support for HP ZBook 15 (bnc#905329).
- commit 44e7f88
* Thu Nov 13 2014 tiwai@suse.de
- ALSA: hda - Add mute LED control for Lenovo Ideapad Z560
  (bnc#665315).
- commit ed2f271
* Wed Nov 12 2014 tiwai@suse.de
- ALSA: hda/realtek - Change EAPD to verb control (bnc#905068).
- ALSA: hda/realtek - Restore default value for ALC668
  (bnc#905068).
- ALSA: hda/realtek - Update Initial AMP for EAPD control
  (bnc#905068).
- ALSA: hda/realtek - Update restore default value for ALC283
  (bnc#905068).
- ALSA: hda/realtek - Update restore default value for ALC282
  (bnc#905068).
- ALSA: hda/realtek - Use tables for batch COEF writes/updtes
  (bnc#905068).
- ALSA: hda/realtek - Add alc_update_coef*_idx() helper
  (bnc#905068).
- ALSA: hda/realtek - Use alc_write_coef_idx() in
  alc269_quanta_automake() (bnc#905068).
- ALSA: hda/realtek - Optimize alc888_coef_init() (bnc#905068).
- commit 757f42b
* Mon Nov 10 2014 jeffm@suse.com
- Update to 3.18-rc4.
- commit 1eac9b3
* Fri Nov  7 2014 tiwai@suse.de
- quirk for Lenovo Yoga 3: no rfkill switch (bnc#904289).
- commit bf63174
* Fri Nov  7 2014 tiwai@suse.de
- iwlwifi: dvm: drop non VO frames when flushing (bnc#900786).
- commit de638be
* Fri Nov  7 2014 tiwai@suse.de
- Input: synaptics - add min/max quirk for Lenovo T440s
  (bnc#903748).
- commit 8e9c18e
* Wed Nov  5 2014 tiwai@suse.de
- Delete patches.rpmify/chipidea-clean-up-dependencies (bnc#903986)
- commit 3788128
* Wed Nov  5 2014 tiwai@suse.de
- [media] uvc: Fix destruction order in uvc_delete() (bnc#897736).
- commit 2f29e54
* Wed Nov  5 2014 tiwai@suse.de
- Disable patches.rpmify/chipidea-clean-up-dependencies
  This rather causes a problem when building as a module.  If all builds
  fine, drop this later.
- commit 6b12ffb
* Tue Nov  4 2014 jbeulich@suse.com
- Update Xen patches to 3.18-rc3.
- config.conf: Re-enable Xen configs.
- Update config files.
- commit e706e91
* Mon Nov  3 2014 matwey.kornilov@gmail.com
- config: armv7hl: temporarily disable KEYSTONE_NAVIGATOR_QMSS
  KEYSTONE_NAVIGATOR_QMSS leads to the following module dependency cycle.
  Disable it until it will be fixed in upstream.
  [24907s] depmod: ERROR: Found 2 modules in dependency cycles!
  [24907s] depmod: ERROR: Cycle detected: knav_qmss_queue -> knav_qmss_acc -> knav_qmss_queue
- commit 5709b4c
* Mon Nov  3 2014 jeffm@suse.com
- netfilter: fix missing declaration of csum_ipv6_magic for
  bridge reject.
- commit a73bb9e
* Mon Nov  3 2014 jeffm@suse.com
- Update to 3.18-rc3.
- Eliminated 3 patches.
- commit d6cda9a
* Sun Nov  2 2014 agraf@suse.de
- Limit xgbe a0 driver to arm64
- commit 12cb573
* Sun Nov  2 2014 agraf@suse.de
- usb: Add support for Synopsis H20AHB EHCI host controller
  (bnc#902632).
- usb: fix hcd h20ahb driver depends (bnc#902632).
- KVM: ARM: Add "arm,gic-400" compatible support (bnc#902632).
- net/xgbe: Add A0 silicon support (bnc#902632).
- arm64: dts: Add X-Gene reboot driver dts node (bnc#902632).
- arm64: Select reboot driver for X-Gene platform (bnc#902632).
- arm64: Do not call enable PCI resources when specify
  PCI_PROBE_ONLY (bnc#902632).
- ARM/ARM64: arch-timer: fix arch_timer_probed logic (bnc#902632).
- Documentation: Restrict TSC test code to x86 (bnc#902632).
- KVM: ARM: Hack to enable VGIC mapping on 64k PAGE_SIZE kernels
  (bnc#902633).
- Update config files.
- commit 2d3b60c
* Thu Oct 30 2014 jslaby@suse.cz
- Linux 3.17.2.
- Delete
  patches.fixes/btrfs-0001-revert-race-free-update-of-commit-root-for-ro-.patch.
- commit 1afb260
* Thu Oct 30 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Fix including the secure boot cert in /etc/uefi/certs
- commit 72255c9
* Wed Oct 29 2014 jslaby@suse.cz
- Input: psmouse - add support for detecting FocalTech PS/2
  touchpads (bnc#897112).
- Input: psmouse - add psmouse_matches_pnp_id helper function
  (bnc#897112).
- commit d944251
* Wed Oct 29 2014 jslaby@suse.cz
- Delete patches.fixes/input-add-acer-aspire-5710-to-nomux.patch.
  It is in 3.17 already, so it is applied twice.
- commit 14a333d
* Tue Oct 28 2014 tiwai@suse.de
- Split kernel-docs-pdf and kernel-docs-html subpackages
  They'll contain PDF and HTML documents generated from kernel source,
  respectively.  kernel-docs still keeps man pages and basic documents
  in root directory.
- commit 4fa7b81
* Mon Oct 27 2014 jeffm@suse.com
- Update to 3.18-rc2.
- Config changes:
  * ACPI_THERMAL_REL=m
  * DA9063_WATCHDOG=m
  * INT340X_THERMAL=m
  * OVERLAYFS_FS=m (vanilla only, we've been carrying these patches)
  * PWM_LPSS_PCI=m
  * PWM_LPSS_PLATFORM=m
  * TCM_USER=m
  * THERMAL_GOV_BANG_BANG=y
- commit 44afd6d
* Fri Oct 24 2014 jeffm@suse.com
- vdso: don't require 64-bit math in standalone test.
- commit e58d2f6
* Fri Oct 24 2014 jeffm@suse.com
- Refresh patches.fixes/dm-table-switch-to-readonly.
- commit afa7428
* Fri Oct 24 2014 matwey.kornilov@gmail.com
- config: armv6hl: Compile KGDB serial console into kernel
  A serial console is the major communication for ARM devices.
  Having CONFIG_KGDB_SERIAL_CONSOLE=m makes it impossible to debug the kernel
  at early boot stages.
- commit e34532c
* Fri Oct 24 2014 matwey.kornilov@gmail.com
- config: armv7hl: Compile KGDB serial console into kernel
  A serial console is the major communication for ARM devices.
  Having CONFIG_KGDB_SERIAL_CONSOLE=m makes it impossible to debug the kernel
  at early boot stages.
- commit 18c982d
* Fri Oct 24 2014 matwey.kornilov@gmail.com
- config: armv7hl: Disable CONFIG_USB_MUSB_TUSB6010
  TUSB6010 is not used by any of our JeOSes*, but introduces issues
  with USB on BeagleBone (and all other boards utilizing musb_hdrc).
  The way to resolve the issues is currently unknown, so temporarily
  disable it.
  See for details: http://marc.info/?l=linux-usb&m=141088564307331&w=2
- commit fb5877e
* Fri Oct 24 2014 jeffm@suse.com
- patches.fixes/dm-table-switch-to-readonly: fix incomplete merge
- commit 2c7dd5c
* Fri Oct 24 2014 agraf@suse.de
- ARM: Update config files: Move closer to x86_64 config
- commit 0f35e83
* Fri Oct 24 2014 afaerber@suse.de
- config: arm64: Update to v3.18-rc1
  Generic options as x86_64/armv7hl.
  Enabled PCI, enabling lots of devices.
  When in doubt, left miscellaneous drivers disabled.
- commit 83baa8a
* Fri Oct 24 2014 afaerber@suse.de
- config: armv6hl: Update to v3.18-rc1
  Generic options as for x86_64/armv7hl.
  When in doubt, disabled SoC level and PMIC drivers.
- commit 10e9bcb
* Fri Oct 24 2014 afaerber@suse.de
- config: armv7hl: Update to v3.18-rc1
  Generic options like x86_64.
  Meson6 and BCM SoCs for default only.
- commit c8b0df9
* Thu Oct 23 2014 jeffm@suse.com
- Update to 3.18-rc1
- Eliminated 6 patches.
- ARM is disabled.
- Xen is disabled.
- Config changes:
  - Generic config options:
  * TASKS_RCU=n (default)
  * ADVISE_SYSCALLS=y (default)
  * MODULE_COMPRESS=n (default)
  * DISABLE_DEV_COREDUMP=n (default)
  * MTD_SPI_NOR_USE_4K_SECTORS=y (default)
  * SCSI_MQ_DEFAULT=y
  * SCHED_STACK_END_CHECK=y (good protection, may need to reevaluate)
  * HMC_DRV=m
  * DEVFREQ_GOV_SIMPLE_ONDEMAND=m
  * DEVFREQ_GOV_PERFORMANCE=m
  * DEVFREQ_GOV_POWERSAVE=m
  * DEVFREQ_GOV_USERSPACE=m
  * CPUFREQ_DT=n (default)
  - Security:
  * INTEGRITY=y
  - INTEGRITY_SIGNATURE=y
  - INTEGRITY_ASYMMETRIC_KEYS=y
  - INTEGRITY_AUDIT=y
  * CRYPTO_MCRYPTD=m
  * CRYPTO_SHA1_MB=m (x86_64)
  - Networking options:
  * NET_FOU=m
  * GENEVE=m
  * OPENVSWITCH_GENEVE=y
  * TCP_CONG_DCTCP=m
  * NFT_MASQ=m
  * IP_SET_HASH_MAC=m
  * IP_VS_FO=m
  * NF_REJECT_IPV4=y
  * NF_REJECT_IPV6=
  * NFT_MASQ_IPV4=m
  * NFT_MASQ_IPV6=m
  * CAN_M_CAN=m
  - New modules:
  * NET_DSA_MV88E6171=m
  * NET_DSA_BCM_SF2=m
  * FM10K=m
  * - FM10K_VXLAN=y
  * QCA7000=m
  * IWLWIFI_UAPSD=n (default, possible interop problems)
  * RTL8192EE=m
  * RTL8821AE=m
  * TOUCHSCREEN_AR1021_I2C=m
  * INPUT_DRV260X_HAPTICS=m
  * INPUT_DRV2667_HAPTICS=m
  * SERIAL_8250_FINTEK=m
  * HID_PENMOUNT=m
  * IR_HIX5HD2=m
  * DVB_USB_DVBSKY=m
  * USB_HACKRF=m
  * VIDEO_TW68=m
  * VIDEO_SAA7134_GO7007=m
  * DVB_PT3=m
  * USB_LED_TRIG=y
  * LEDS_SYSCON=y
  * BMC150_ACCEL=m
  * VIDEO_PCI_SKELETON=n
  * VIDEO_VIVID=m
  * POWER_RESET_GPIO_RESTART=n (default)
  * POWER_RESET_LTC2952=n
  * POWER_RESET_SYSCON=n
  * ATH9K_DYNACK=n (experimental)
  * ATH9K_CHANNEL_CONTEXT=y (needed for multi-channel concurrency)
  - New options specific to ARM (I think, all disabled):
  * MFD_HI6421_PMIC
  * MFD_RK808
  * MFD_RN5T618
  * SOC_TI
  * EXTCON_RT8973A
  * TI_ADC128S052
  * MAX5821
  * BMG160
  * AL3320A
  * GPIO_DWAPB
  * GPIO_MCP23S08
  - x86/x86_64:
  * IOSF_MBI_DEBUG=n (default)
  - Power:
  * GENERIC_CPU=y (ppc64)
  * POWER7_CPU=y (ppc64le)
  * CXL=m
  - System Z:
  * UPROBE_EVENT=y
- commit ab4cc2f
* Wed Oct 22 2014 tiwai@suse.de
- Use fop for creating PDF files in kernel-docs package
  As some files still cannot be built with the default backend.
- commit 0de03e2
* Wed Oct 22 2014 tiwai@suse.de
- Fix build of PDF files in kernel-docs package
  Double the spaces for tex, and fix buildrequires for docbook.
- commit 9e1f511
* Mon Oct 20 2014 tiwai@suse.de
- Enable some IIO drivers for xen flavors too (bnc#898828)
- commit 6c9b613
* Mon Oct 20 2014 agraf@suse.de
- Delete patches.arch/cubox-configuration.patch.
  - cubox should be used via device tree now
- commit 2a9b81b
* Mon Oct 20 2014 tiwai@suse.de
- Enable some IIO drivers on x86 for Tablet sensors (bnc#898828)
  Only a limited number of drivers are enabled as of now.  If more other
  device-specific drivers are needed, enable appropriately later.
- commit e3b6d24
* Sun Oct 19 2014 dsterba@suse.cz
- Revert "Btrfs: race free update of commit root for ro snapshots"
- commit fd16010
* Sun Oct 19 2014 dsterba@suse.cz
- Revert "Btrfs: race free update of commit root for ro snapshots"
- commit 5c4d099
* Fri Oct 17 2014 jbeulich@suse.com
- Update Xen patches to 3.17.1.
- commit e3f9aac
* Wed Oct 15 2014 jslaby@suse.cz
- Linux 3.17.1.
- commit 16cdf1f
* Thu Oct  9 2014 jeffm@suse.com
- block: copy bi_vcnt in __bio_clone_fast (boo#888259).
- commit c467423
* Thu Oct  9 2014 jeffm@suse.com
- block: copy bi_vcnt in __bio_clone_fast (boo#888259).
- commit 263fe49
* Tue Oct  7 2014 jbeulich@suse.com
- Revert "supported.conf: i2c-core -> i2core." - the respective
  upstream change got reverted too.
  This reverts commit 602eb759ffd78c04efb82a041167718d98180ffd.
- commit afa08f0
* Tue Oct  7 2014 jbeulich@suse.com
- Update Xen patches to 3.17-final and c/s 1266.
- commit 28bdf1b
* Mon Oct  6 2014 jeffm@suse.com
- Update to 3.17-final.
- commit ba887ef
* Mon Oct  6 2014 jack@suse.cz
- Refresh patches.suse/ovl01-vfs-add-i_op-dentry_open.patch.
- commit c1c43b8
* Mon Oct  6 2014 jack@suse.cz
  Removing RICHACL support since it never went upstream and noone seems
  to really care (bnc#892834)
- Delete
  patches.suse/0001-vfs-Hooks-for-more-fine-grained-directory-permission.patch.
- Delete
  patches.suse/0002-vfs-Add-generic-IS_ACL-test-for-acl-support.patch.
- Delete
  patches.suse/0003-vfs-Add-IS_RICHACL-test-for-richacl-support.patch.
- Delete
  patches.suse/0004-richacl-In-memory-representation-and-helper-function.patch.
- Delete
  patches.suse/0005-richacl-Permission-mapping-functions.patch.
- Delete
  patches.suse/0006-richacl-Compute-maximum-file-masks-from-an-acl.patch.
- Delete
  patches.suse/0007-richacl-Update-the-file-masks-in-chmod.patch.
- Delete
  patches.suse/0008-richacl-Permission-check-algorithm.patch.
- Delete
  patches.suse/0009-richacl-Helper-functions-for-implementing-richacl-in.patch.
- Delete patches.suse/0010-richacl-Create-time-inheritance.patch.
- Delete
  patches.suse/0011-richacl-Check-if-an-acl-is-equivalent-to-a-file-mode.patch.
- Delete patches.suse/0012-richacl-Automatic-Inheritance.patch.
- Delete
  patches.suse/0013-richacl-Restrict-access-check-algorithm.patch.
- Delete patches.suse/0014-richacl-xattr-mapping-functions.patch.
- Delete
  patches.suse/0016-ext4-Implement-richacl-support-in-ext4.patch.
- commit 81acd03
* Mon Oct  6 2014 jack@suse.cz
- Update
  patches.fixes/xfs-mark-all-internal-workqueues-as-freezable.patch
  (bnc#899785).
- commit 951f215
* Mon Oct  6 2014 jack@suse.cz
- xfs: mark all internal workqueues as freezable.
- commit ba6c1f6
* Mon Oct  6 2014 jslaby@suse.cz
- Linux 3.16.4.
- commit 7a8842b
* Mon Sep 29 2014 jeffm@suse.com
- Update to 3.17-rc7.
- commit 6304463
* Thu Sep 25 2014 jbeulich@suse.com
- patches.suse/stack-unwind: Reduce the number of cases where
  hitting broken/missing unwind information would result in a full
  but predictably pointless linear scan of the FDEs. Some cosmetic
  cleanup.
- commit 8a52bcb
* Mon Sep 22 2014 jeffm@suse.com
- Update to 3.17-rc6.
- commit 811b3a2
* Mon Sep 22 2014 jbeulich@suse.com
- patches.arch/x86_64-unwind-annotations: Fix patch format (as reported
  by Luis Rodriguez).
- commit f35848e
* Thu Sep 18 2014 jbeulich@suse.com
- Update EC2 config files again (adding DEBUG_INFO_DWARF4).
- commit 82404e9
* Thu Sep 18 2014 jbeulich@suse.com
- supported.conf: i2c-core -> i2core.
- commit 602eb75
* Thu Sep 18 2014 jbeulich@suse.com
- Refresh patches.xen/xen3-patch-3.17-rc5 (fix build issue on native).
- commit 000c18b
* Wed Sep 17 2014 jslaby@suse.cz
- Linux 3.16.3 (bnc#890096).
- Delete
  patches.fixes/reiserfs-fix-corruption-introduced-by-balance_leaf-refactor.
- Delete patches.fixes/rtsx_usb-export-device-table.
- Update config files.
  Set CONFIG_SMS_SIANO_DEBUGFS=n as it is in master.
- commit d2bbe7f
* Wed Sep 17 2014 jbeulich@suse.com
- Update EC2 config files (re-enable DEBUG_INFO).
- commit c7796ab
* Wed Sep 17 2014 jbeulich@suse.com
- Update Xen patches to 3.17-rc5.
- config.conf: Re-enable Xen configs.
- Update config files.
- commit 7069df5
* Wed Sep 17 2014 jeffm@suse.com
- blk-merge: fix blk_recount_segments (bnc#888259).
- commit 5fca623
* Tue Sep 16 2014 jdelvare@suse.de
- Update s390x config files: disable CONFIG_EXTCON_SM5502
  Enabling CONFIG_EXTCON_SM5502 broke the build, because this option
  should depend on CONFIG_I2C which is not enabled on s390x. So disable
  CONFIG_EXTCON_SM5502 on s390x, and also disable CONFIG_EXTCON as
  there is no point in enabling it when no extcon device driver is
  selected.
- commit f48cb05
* Mon Sep 15 2014 jeffm@suse.com
- Update to 3.17-rc5.
- Config changes:
  - NAT config option splitout, no real change:
  - CONFIG_IP6_NF_NAT=m
  - CONFIG_IP_NF_NAT=m
  - CONFIG_NETFILTER_XT_NAT=m
  - CONFIG_NF_NAT_H323=m
  - CONFIG_NF_NAT_IPV4=m
  - CONFIG_NF_NAT_IPV6=m
  - CONFIG_NF_NAT_PPTP=m
  - CONFIG_NF_NAT_PROTO_GRE=m
  - CONFIG_NF_NAT_SNMP_BASIC=m
- commit 5a3d027
* Sun Sep 14 2014 jdelvare@suse.de
- Update s390x config files: Disable CONFIG_WATCHDOG_NOWAYOUT
  It's already disabled on all other architectures for a long time and
  has been causing problems on s390x (bnc#756585, bnc#895103.)
- commit 04827b4
* Tue Sep  9 2014 agraf@suse.de
- ARM: Update config files: Enable DRM
- commit 066bdc8
* Tue Sep  9 2014 matwey.kornilov@gmail.com
- config: armv7hl/default: Disable DMA for MUSB
  Hi, this is both for stable and master.
  An issue is the following. We can not have multiple DMA modes in the same kernel due to current musb design.
  So, it will work only for specific hardware (OMAP DMA). Current configuration leads to OOPS at BeaglBone Black (CPI41 DMA which is disabled), because it tries to use wrong DMA functions (from OMAP DMA).
  The fairest way to fix it is to disable DMA for all hardware until fix in upstream.
  [agraf: copy changes to lpae flavor as well]
- commit 957d74e
* Mon Sep  8 2014 jeffm@suse.com
- Update to 3.17-rc4.
- No config changes.
- commit 9c66470
* Mon Sep  8 2014 agraf@suse.de
- kernel-obs-build: Force load kernel modules
  - fixes QEMU kiwi builds
- commit 9a27fc1
* Mon Sep  8 2014 agraf@suse.de
- rpm/kernel-obs-build.spec.in: Enable 32bit ARM builds
- commit 3ccdab2
* Sun Sep  7 2014 agraf@suse.de
- ARM: Update config files.
  - armv7: Increase CMA size to 64MB
  - arm64: Switch to 4k pages, enables KVM on more systems and 32bit compat
- commit 62283c7
* Sun Sep  7 2014 jslaby@suse.cz
- Linux 3.16.2 (bko#81111 bnc#887046 bnc#889790).
- Update config files.
- Refresh patches.xen/xen-x86-EFI.
- Refresh patches.xen/xen-x86-bzImage.
- Refresh patches.xen/xen3-auto-common.diff.
- Refresh patches.xen/xen3-patch-2.6.37.
- Delete
  patches.fixes/Btrfs-Fix-memory-corruption-by-ulist_add_merge-on-32.
- Delete patches.fixes/drm-omapdrm-fix-compiler-errors.
- Delete
  patches.fixes/nfs-nfs3_list_one_acl-check-get_acl-result-with-is_err_or_null.
- Delete
  patches.suse/btrfs-0003-read-lock-extent-buffer-while-walking-backrefs.patch.
- Delete
  patches.suse/btrfs-0006-fix-compressed-write-corruption-on-enospc.patch.
- Delete
  patches.suse/btrfs-0008-fix-csum-tree-corruption-duplicate-and-outdate.patch.
- Delete
  patches.suse/btrfs-0033-fix-task-hang-under-heavy-compressed-write.patch.
- commit dcee397
* Sat Sep  6 2014 dmueller@suse.com
- config: armv7hl/lpae: Reenable support for Hugepages
  This was apparently accidentally disabled, but we need
  hugepages support for improved performance and stability
  of the KVM build workers.
- commit 3d06ff1
* Fri Sep  5 2014 agraf@suse.de
- rpm/kernel-binary.spec.in: Always build zImage for ARM
- commit 14e56cc
* Wed Sep  3 2014 mmarek@suse.cz
- rpm/kernel-source.spec.in: Create a kernel-macros package with the KMP macros
  This package does not have multiversion(kernel) and is not built in the
  - rt tree (bnc#867595).
- commit 9b6a6fe
* Wed Sep  3 2014 mmarek@suse.cz
- rpm/kernel-source.spec.in: Install doc files in a versioned directory (bnc#867595)
- commit deb25bc
* Tue Sep  2 2014 jeffm@suse.com
- Update to 3.17-rc3.
- Config changes:
  - x86_64: KEXEC_FILE=y
- commit 1149eb3
* Mon Sep  1 2014 agraf@suse.de
- ARM: Update config files: Disable NFC, it results in endless depmod loops
- commit c64eeb2
* Thu Aug 28 2014 matwey.kornilov@gmail.com
- config: armv7hl/default: Disable pcie-spear13xx and gpio-zynq
  This is for master (Kernel:HEAD) to fix build:
  [30000s] ERROR: "dw_pcie_host_init" [drivers/pci/host/pcie-spear13xx.ko] undefined!
  [30000s] ERROR: "dw_handle_msi_irq" [drivers/pci/host/pcie-spear13xx.ko] undefined!
  [30000s] ERROR: "dw_pcie_msi_init" [drivers/pci/host/pcie-spear13xx.ko] undefined!
  [30000s] ERROR: "dw_pcie_cfg_write" [drivers/pci/host/pcie-spear13xx.ko] undefined!
  [30000s] ERROR: "dw_pcie_cfg_read" [drivers/pci/host/pcie-spear13xx.ko] undefined!
  [30000s] ERROR: "dw_pcie_setup_rc" [drivers/pci/host/pcie-spear13xx.ko] undefined!
  [30000s] ERROR: "dw_pcie_link_up" [drivers/pci/host/pcie-spear13xx.ko] undefined!
  [30003s] ERROR: "handle_fasteoi_irq" [drivers/gpio/gpio-zynq.ko] undefined!
- commit f6ce720
* Wed Aug 27 2014 jslaby@suse.cz
- Update config files.
  Turn off udev firmware loading as udev does not provide this service
  anymore and it causes delays. This kernel on older distros still
  should load the fw on its own. (bnc#891645)
- commit 2873b40
* Wed Aug 27 2014 mmarek@suse.cz
- rpm/config.sh Use the same repository setup as the master branch
- commit 90bc0f1
* Wed Aug 27 2014 jeffm@suse.com
- Update to 3.17-rc2.
- Config changes:
  - PCI_DRA7XX=n on ARM
  - I2C_ACPI renamed to ACPI_I2C_OPREGION.
- commit 8f730c5
* Tue Aug 26 2014 jslaby@suse.cz
- rpm/config.sh: build against factory
- commit 768ed24
* Tue Aug 26 2014 dsterba@suse.cz
- Btrfs stable updates.
  Pending or future 3.16.y fixes
- Btrfs: read lock extent buffer while walking backrefs.
- Btrfs: fix compressed write corruption on enospc.
- Btrfs: fix csum tree corruption, duplicate and outdated
  checksums.
- Btrfs: fill_holes: Fix slot number passed to hole_mergeable()
  call.
- Btrfs: fix wrong write range for filemap_fdatawrite_range().
- Btrfs: fix wrong extent mapping for DirectIO.
- btrfs: Return right extent when fiemap gives unaligned offset
  and len.
- Btrfs: ensure tmpfile inode is always persisted with link
  count of 0.
- Btrfs: don't monopolize a core when evicting inode.
- Btrfs: fix task hang under heavy compressed write.
- Refresh
  patches.fixes/Btrfs-Fix-memory-corruption-by-ulist_add_merge-on-32.
- commit c40eb71
* Tue Aug 26 2014 schwab@suse.de
- config: arm64/default: reenable ARM64_CRYPTO
- commit 9768fa4
* Mon Aug 25 2014 agraf@suse.de
- Update armv6hl config file
- commit 2d13fa5
* Mon Aug 25 2014 agraf@suse.de
- Update armv7l config files
- commit e915f04
* Mon Aug 25 2014 agraf@suse.de
- Update arm64 config file
- commit 90dba99
* Fri Aug 22 2014 jeffm@suse.com
- config: disable COMMON_CLK_QCOM on non-ARM architectures
- commit 901b82f
* Fri Aug 22 2014 jeffm@suse.com
- Update to 3.17-rc1
- Eliminated 8 patches.
- ARM is disabled.
- Xen is disabled.
- Config changes:
  - Generic config options:
  * LOG_CPU_MAX_BUF_SHIFT=15 (32kb, only used with ncpus > 64)
  * KEXEC_VERIFY_SIG=y (needed for secure boot to not get our keys revoked)
  * FW_LOADER_USER_HELPER_FALLBACK=y (we use udev)
  * MESSAGE_LOGLEVEL_DEFAULT=4 (default)
  * DEBUG_INFO_SPLIT=n (would be nice to do =y, but do our tools support it?)
  * DEBUG_INFO_DWARF4=y
  * TEST_RHASHTABLE=n
  * TEST_FIRMWARE=n
  * TEST_UDELAY=n
  * FENCE_TRACE=n
  * GLOB_SELFTEST=n
  * CONFIG_SPI=y
  - USB_MSI2500 depends on SPI
  - Every other SPI driver is disabled
  - New modules:
  * NF_LOG_ARP=m
  * NF_LOG_IPV4=m
  * NF_LOG_IPV6=m
  * NFT_BRIDGE_REJECT=m
  * NF_LOG_BRIDGE=m
  * 6LOWPAN=m
  * TABLET_SERIAL_WACOM4=m
  * I2C_ACPI=y
  * W1_SLAVE_DS2406=m
  * SENSORS_POWR1220=m
  * SENSORS_TPS40422=m
  * SENSORS_TMP103=m
  * IR_XMP_DECODER=m
  * USB_MSI2500=m
  * USB_AIRSPY=m
  * VIDEO_SOLO6X10=m
  * HID_GT683R=m
  * HID_LENOVO=m
  * USB_LINK_LAYER_TEST=m
  * EDAC_IE31200=m
  * RTC_DRV_PCF85063=m
  * MFD_MAX8907=m
  * VIDEO_SOLO6X10=m
  * TOSHIBA_HAPS=m
  * EXTCON_SM5502=m
  * PHY_ST_SPEAR1310_MIPHY=m
  * PHY_ST_SPEAR1340_MIPHY=m
  * THUNDERBOLT=m
  * CRYPTO_DRBG_MENU=m
  - CRYPTO_DRBG_HMAC=y
  - CRYPTO_DRBG_HASH=y
  - CRYPTO_DRBG_CTR=y
  * CRYPTO_DEV_QAT_DH895xCC=m
  * CRYPTO_DES3_EDE_X86_64=m
  * INTEL_MIC_BUS=m
  * INTEL_MIC_X100_DMA=m
  * UNISYS_VISORUTIL=m
  - UNISYS_VISORCHANNEL=m
  - UNISYS_VISORCHIPSET=m
  - UNISYS_CHANNELSTUB=m
  - UNISYS_UISLIB=m
  - UNISYS_VIRTPCI=m
  - UNISYS_VIRTHBA=m
  - ppc64/ppc64le:
  * SENSORS_IBMPOWERNV=m
  * KVM_BOOK3S_64_HV=m
  * CMA_DEBUG=n
  * CMA_AREAS=7 (default)
  - s390x:
  * IRQ_DOMAIN_DEBUG=n
- commit 7627acb
* Thu Aug 21 2014 tiwai@suse.de
- Btrfs: Fix memory corruption by ulist_add_merge() on 32bit arch
  (bnc#887046).
- commit b1e2a41
* Thu Aug 21 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Fix the version variables in the generated
  Makefile (bnc#892973)
- commit 8331f47
* Wed Aug 20 2014 mmarek@suse.cz
- rpm/compress-vmlinux.sh: Do not duplicate the job of brp-99-compress-vmlinux
- commit e561498
* Wed Aug 20 2014 afaerber@suse.de
- config: arm64: Enable RTC_DRV_HID_SENSOR_TIME
  For consistency across ARM configs.
  This drags in IIO. For consistency, in turn use:
  CONFIG_IIO_SIMPLE_DUMMY=m
  CONFIG_HID_SENSOR_IIO_TRIGGER=m
  CONFIG_IIO_PERIODIC_RTC_TRIGGER=m
  CONFIG_IIO_INTERRUPT_TRIGGER=m
  CONFIG_IIO_SYSFS_TRIGGER=m
  CONFIG_IIO_BUFFER=y
  CONFIG_IIO_KFIFO_BUF=m
  CONFIG_HID_SENSOR_*=m
- commit 7a6e5f7
* Wed Aug 20 2014 afaerber@suse.de
- config: armv6hl: Re-enable DWC2 USB support
  The config update/cleanup for v3.16-rc3 mistakenly disabled USB_DWC2,
  which is needed for the Raspberry Pi.
  Fixes: d2f49e165ca3 ("config: armv6hl: Update config for 3.16-rc3")
- commit cc9f241
* Wed Aug 20 2014 afaerber@suse.de
- config: ARM: Change RTC drivers to built-in
  Consistently do not build RTC drivers as modules. This fixes subtle
  differences between armv7hl default and lpae flavors and avoids any
  timing-related driver initialization issues.
  To make RTC_DRV_88PM80X built-in, make MFD_88PM800 built-in, too.
  To make RTC_DRV_PM8XXX built-in, make MFD_PM8921_CORE built-in, too.
- commit cf526c8
* Mon Aug 18 2014 mmarek@suse.cz
- rpm/config.sh: Drop the ARM repo, it is covered by the ports repo
- commit 84ffa90
* Mon Aug 18 2014 schwab@suse.de
- rpm/kernel-binary.spec.in: Fix missing quotes around %%build_flavor
  %%build_flavor can be an arbitrary string, so it needs to be quoted for
  string comparison.
- commit 0134440
* Mon Aug 18 2014 dvaleev@suse.com
- rpm/kernel-obs-build.spec.in: Use dracut for SLE12
- commit ec64eaf
* Mon Aug 18 2014 afaerber@suse.de
- config: armv6hl: Enable DMA_BCM2835
  Only bcm2835 option missing.
- commit 1fd2cdd
* Mon Aug 18 2014 afaerber@suse.de
- config: armv7hl: Enable DWMAC_SUNXI for lpae flavor as well
  Without this, the Cubietruck has no network in LPAE mode.
- commit 4f16280
* Sun Aug 17 2014 jslaby@suse.cz
- Linux 3.16.1.
- commit 9353bcb
* Wed Aug 13 2014 tiwai@suse.de
- Revert "config: armv7hl: Disable OMAP DRM"
  This reverts commit f92487dbd7a305531e4cc54c41609b8f77a1bc30.
  The previous commit should fix the build error of omapdrm.
- commit 07174c1
* Wed Aug 13 2014 tiwai@suse.de
- drm: omapdrm: fix compiler errors.
- commit ee3abc8
* Wed Aug 13 2014 afaerber@suse.de
- config: armv7hl: Disable OMAP DRM
  To avoid errors such as:
  ../drivers/gpu/drm/omapdrm/omap_plane.c: In function 'omap_plane_pre_apply':
  ../drivers/gpu/drm/omapdrm/omap_plane.c:145:2: error: format '%%x' expects argument of type 'unsigned int', but argument 5 has type 'dma_addr_t' [-Werror=format=]
    DBG("%%d,%%d %%08x %%08x", info->pos_x, info->pos_y,
    ^
  ../drivers/gpu/drm/omapdrm/omap_plane.c:145:2: error: format '%%x' expects argument of type 'unsigned int', but argument 6 has type 'dma_addr_t' [-Werror=format=]
  cc1: all warnings being treated as errors
  disable OMAP DRM for now.
  Two patches were sent upstream by Matwey V. Kornilov but didn't find
  their way into v3.16. Once patches are applied, revert this commit.
- commit f92487d
* Wed Aug 13 2014 afaerber@suse.de
- config: arm64: Disable ARM64 crypto extensions
  To avoid build errors such as:
  ld: cannot find arch/arm64/crypto/aes-glue-ce.o: No such file or directory
  ../scripts/Makefile.build:411: recipe for target 'arch/arm64/crypto/aes-ce-blk.o' failed
  disable support for ARM64 crypto extensions for now.
  A patch was submitted upstream by Andreas Schwab but didn't make it into
  v3.16. Once that is available, this commit should be reverted.
- commit 5f99cfd
* Tue Aug 12 2014 schwab@suse.de
- config: arm64/default: make rtc-pl03[01] built-in
- commit 1b1d9da
* Fri Aug  8 2014 jeffm@suse.com
- rtsx_usb: export device table (bnc#890096).
- commit a29135e
* Fri Aug  8 2014 tiwai@suse.de
- Delete patches.drivers/drm-cirrus-Use-16bpp-as-default (bnc#890599).
- commit 820d92f
* Wed Aug  6 2014 jbeulich@suse.com
- Update Xen patches to 3.16-final.
- vscsi: support larger transfer sizes (bnc#774818).
- commit 0e31675
* Tue Aug  5 2014 jeffm@suse.com
- nfs: nfs3_list_one_acl(): check get_acl() result with
  IS_ERR_OR_NULL (bko#81111 bnc#889790).
- commit 258e3b0
* Tue Aug  5 2014 jeffm@suse.com
- nfs: nfs3_list_one_acl(): check get_acl() result with
  IS_ERR_OR_NULL (bko#81111 bnc#889790).
- commit c485b2b
* Tue Aug  5 2014 jeffm@suse.com
- reiserfs: fix corruption introduced by balance_leaf refactor.
- commit 37d2234
* Mon Aug  4 2014 jeffm@suse.com
- config: disable CONFIG_PPC_PS3 on ppc64le
  The PS3 hardware is big-endian.
- commit a9046ed
* Mon Aug  4 2014 jeffm@suse.com
- config: resync vanilla configs (no actual changes)
- commit 2821f4c
* Mon Aug  4 2014 jeffm@suse.com
- Update to 3.16.
- commit bf5b385
* Fri Aug  1 2014 jslaby@suse.cz
- Linux 3.15.8.
- Refresh patches.suse/stack-unwind.
- commit 1bbc06d
* Thu Jul 31 2014 jkosina@suse.cz
- Refresh patches.fixes/input-add-acer-aspire-5710-to-nomux.patch: update
  upstream reference.
- commit 7690e04
* Wed Jul 30 2014 jdelvare@suse.de
- Revert "config: disable USB_UAS (bnc#888069)."
  This reverts commit f509af67eb3a98665e0134eaadb91e93420d9e04. The uas
  driver works fine since kernel v3.15, the problem was that the
  module was blacklisted so it would not load when needed.
- commit 9b5a5f0
* Wed Jul 30 2014 jbeulich@suse.com
- Update Xen patches to 3.16-rc7 and c/s 1263.
- netbk: Don't destroy the netdev until the vif is shut down
  (bnc#881008).
- commit a2720a7
* Tue Jul 29 2014 jeffm@suse.com
- config: disable USB_UAS (bnc#888069).
  uas is already blacklisted in /etc/modprobe.d/50-blacklist.conf as
  being hopelessly broken, but there are parts of usb-storage that are
  ifdef'd around it being configured at all. Let's disable it completely.
- commit f509af6
* Tue Jul 29 2014 jeffm@suse.com
- Update to 3.16-rc7.
- commit 47ebc04
* Mon Jul 28 2014 jslaby@suse.cz
- Linux 3.15.7 (bnc#879071).
- Delete
  patches.fixes/don-t-trigger-congestion-wait-on-dirty-but-not-write.patch.
- Update config files.
- commit 972d9a6
* Mon Jul 28 2014 schwab@suse.de
- config: arm64/default: increase LOG_BUF_SHIFT to 18
- commit f45208d
* Mon Jul 28 2014 lpechacek@suse.cz
- doc/README.SUSE: update Solid Driver team contacts
- commit a90946c
* Thu Jul 24 2014 jdelvare@suse.de
- Update config files: disable CONFIG_STE_MODEM_RPROC
  I was told by Dmitry Tarnyagin and Linus Walleij that there exists no
  public hardware that needs this driver, so there is no point in
  building it and shipping it.
- commit 85b815c
* Mon Jul 21 2014 jslaby@suse.cz
- Don't trigger congestion wait on dirty-but-not-writeout pages
  (bnc#879071).
- commit edc5ddf
* Mon Jul 21 2014 jeffm@suse.com
- config: sync vanilla configs
- commit a0523f2
* Mon Jul 21 2014 jeffm@suse.com
- Update to 3.16-rc6.
- Eliminated 1 patch.
- commit 2736eea
* Mon Jul 21 2014 jdelvare@suse.de
- Update armv7hl config files for 3.16-rc5
  New driver CONFIG_USB_EHCI_MSM=m.
- commit f1230bd
* Fri Jul 18 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Do not sign firmware files (bnc#867199)
- commit 38f105d
* Fri Jul 18 2014 jslaby@suse.cz
- Linux 3.15.6.
- commit fdb2dde
* Mon Jul 14 2014 jeffm@suse.de
- Update to 3.16-rc5.
- Eliminated 1 patch.
- commit e709184
* Fri Jul 11 2014 jdelvare@suse.de
- Update ppc config files: Disable ChromeOS drivers
  No Chromebook is based on PowerPC so these drivers are useless on ppc.
- commit aa23827
* Thu Jul 10 2014 jslaby@suse.cz
- Update patches.kernel.org/patch-3.15.4-5 (bnc#878489 bnc#882648
  bnc#883750).
- Delete
  patches.fixes/xhci-Use-correct-SLOT-ID-when-handling-a-reset-devic.patch.
  bah, one should run sequence_patch after rebase.
- commit 01d2774
* Wed Jul  9 2014 mmarek@suse.cz
- rpm/package-descriptions: Drop descriptions for dropped flavors
- commit aa68ae6
* Wed Jul  9 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in, rpm/post(un).sh: Drop checks for dropped archs/flavors
- commit bd6afed
* Wed Jul  9 2014 jslaby@suse.cz
- Linux 3.15.5 (bnc#882648 bnc#883750).
- Refresh patches.xen/xen3-patch-3.6.
- Delete
  patches.drivers/drm-i915-HD-audio-Don-t-continue-probing-when-nomode.
- Delete
  patches.fixes/cifs-fix-broken-pathnames-with-mapchars.patch.
- commit b151807
* Wed Jul  9 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: No scriptlets in kernel-zfcpdump
  The kernel should not be added to the bootloader nor are there any KMPs.
- commit bcca34b
* Mon Jul  7 2014 jslaby@suse.cz
- xhci: Use correct SLOT ID when handling a reset device command
  (bnc#878489).
- commit 2b59ae6
* Mon Jul  7 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Delete the build-id links created by vdso_install
- commit ca040af
* Mon Jul  7 2014 jeffm@suse.com
- Update to 3.16-rc4.
- commit 45467d6
* Mon Jul  7 2014 jslaby@suse.cz
- Linux 3.15.4.
- commit ca33e5b
* Sun Jul  6 2014 afaerber@suse.de
- config: armv7hl: Update configs for 3.16-rc3
  * Samsung Exynos is now in default flavor, drop exynos flavor
  * Enable Freescale/Xilinx for default flavor only
  * Enable Qualcomm/LSI for both default and lpae flavors
  * Enable Allwinner A20+ in lpae flavor, A10+ in default flavor
  * Enable Hisilicon Hi3xxx in default flavor
  * Enable Renesas RZ/A in default flavor
  * Enable big.LITTLE switcher module
  * Enable PCI for Freescale/Marvell/Nvidia/Samsung
  but keep device drivers to minimum, as known boards are mini PCIe only
  * Build in some more serial drivers for console use
  * Enable some missing USB media device driver modules
  * Disable OMAP4 V4L as it cannot be built as module (Matwey K.)
- commit ca6193e
* Sun Jul  6 2014 afaerber@suse.de
- config: arm64: Update config for 3.16-rc3
- commit 28b0756
* Sun Jul  6 2014 afaerber@suse.de
- config: armv6hl: Update config for 3.16-rc3
- commit d2f49e1
* Fri Jul  4 2014 jdelvare@suse.de
- Update config files: Disable CONFIG_DRM_I2C_NXP_TDA998X
  Disable the TDA998x driver in all flavors where is not needed.
- commit 267d4c1
* Fri Jul  4 2014 mmarek@suse.cz
- kbuild: Do not print the build directory with make -s.
- commit 6bf8303
* Thu Jul  3 2014 jbeulich@suse.com
- Update Xen patches to 3.16-rc3 and c/s 1261.
- config.conf: Re-enable Xen configs.
- Update x86 config files.
- commit 56ffa43
* Wed Jul  2 2014 jeffm@suse.com
- Delete
  patches.fixes/drm-msm-replace-type-of-paddr-to-uint32_t.patch.
- commit 29c1c05
* Wed Jul  2 2014 jeffm@suse.com
- Update to 3.16-rc3.
- Eliminated 1 patch.
- commit d86449f
* Tue Jul  1 2014 jdelvare@suse.de
- net: fix circular dependency in of_mdio code.
- commit 66576dd
* Tue Jul  1 2014 jdelvare@suse.de
- drm/msm: Replace type of paddr to uint32_t.
  This fixes the build on armv7l.
- commit d43d97e
* Tue Jul  1 2014 jslaby@suse.cz
- Linux 3.15.3.
- Refresh patches.xen/xen3-auto-xen-kconfig.diff.
- Refresh patches.xen/xen3-patch-2.6.37.
- Update config files.
- commit 42bf625
* Mon Jun 30 2014 schwab@suse.de
- rpm/kernel-obs-build.spec.in: add support for aarch64
  Use Image for kernel_name on aarch64 and add virtio_mmio to KERNEL_MODULES.
- commit 6024dc9
* Fri Jun 27 2014 mmarek@suse.cz
- rpm/compress-vmlinux.sh: Compress vmlinux after find-debuginfo.sh (bnc#884459)
- commit 381a192
* Fri Jun 27 2014 jslaby@suse.cz
- Linux 3.15.2.
- commit fb7c781
* Thu Jun 26 2014 mmarek@suse.cz
- rpm/old-flavors: Obsolete kernel-trace-base by kernel-default
  (bnc#884364)
- commit 568f3cc
* Thu Jun 26 2014 mmarek@suse.cz
- rpm/old-flavors: Explicitly list subpackages to obsolete
- commit 5595ce2
* Wed Jun 25 2014 jbeulich@suse.com
- patches.fixes/bridge-module-get-put.patch,
  patches.suse/stack-unwind: Update Patch-mainline tag.
- commit a0f93ad
* Tue Jun 24 2014 jeffm@suse.com
- config: disable X86_GOLDFISH
  It seems to be built-in and generates loads of messages like:
  genirq: Flags mismatch irq 4. 00000000 (serial) vs. 00000080 (goldfish_pdev_bus)
- commit 37599aa
* Tue Jun 24 2014 jeffm@suse.com
- patches.suse/stack-unwind: VSYSCALL_START replaced with VSYSCALL_ADDR.
- commit f5ee8e7
* Tue Jun 24 2014 jeffm@suse.de
- Update to 3.16-rc2.
- Config changes:
  - Generic config options:
  * RANDOMIZE_BASE=n (default n)
  - With only 9 bits of entropy on 64-bit systems, is it worthwhile?
  - System z:
  * DIAG288_WATCHDOG=m
  - New options specific to ARM (I think), all disabled:
  * I2C_RK3X (SoC)
- commit f93db59
* Tue Jun 24 2014 ddiss@suse.de
- Refresh patch-mainline tags
  patches.fixes/cifs-Do-not-send-ClientGUID-on-SMB2.02-dialect.patch
  patches.fixes/cifs-Set-client-guid-on-per-connection-basis.patch
- commit 9b8b77a
* Mon Jun 23 2014 jslaby@suse.cz
- asus-wmi: Set WAPF to 4 for Asus X550CA (bnc#882234).
- commit 7d71861
* Mon Jun 23 2014 mmarek@suse.cz
- rpm/post.sh: Also check for grub2 config
- commit 0844541
* Mon Jun 23 2014 mmarek@suse.cz
- Port ppc64le packaging fixes from 'SLE12' to 'packaging'
- commit c233eb3
* Mon Jun 23 2014 ddiss@suse.de
- fs/cifs: Fix broken pathnames with mapchars (bnc#883750).
- commit 44c0fc3
* Mon Jun 23 2014 jdelvare@suse.de
- Update config files: Enable Realtek RTL8723AU support
  This wireless network chipset is found in hybrid notebooks/tablets
  such as the first Lenovo Yoga 13.
- commit 0cf7afd
* Tue Jun 17 2014 jslaby@suse.cz
- Linux 3.15.1.
- commit fb8e7ed
* Mon Jun 16 2014 jeffm@suse.de
- Update to 3.16-rc1.
- Eliminated 10 patches.
- ARM is disabled.
- Xen is disabled.
- Config changes:
  - Generic config options:
  * UEVENT_HELPER=y (default y)
  - It should be obsolete - needs review
  * SGETMASK_SYSCALL=y/n
  - default varies by architecture, used default
  * DEBUG_PI_LIST=n (default n)
  * TRACEPOINT_BENCHMARK=n (default n)
  - Only needed if developing tracepoint infrastructure
  * TEST_BPF=n (default n)
  - New options for existing drivers:
  * QLCNIC_HWMON=y (default y)
  * ISDN_CAPI_CAPIDRV_VERBOSE=y (helpful messages, cost only in capi.ko)
  - New modules:
  * SERIAL_SC16IS7XX (i2c)
  * SENSORS_SHTC1 (i2c)
  * USB_GSPCA_DTCS033 (usb)
  * SND_BCD2000 (firewire)
  * SND_FIREWORKS (firewire)
  * SND_BEBOB (firewire)
  * HID_RMI (usb)
  * MMC_USDHI6ROL0 (usb)
  * MMC_REALTEK_USB (usb)
  * MEMSTICK_REALTEK_USB (usb)
  * R8192EE (pci)
  * INPUT_GPIO_BEEPER (generic gpio)
  * NFT_BRIDGE_META (netfilter)
  * CAN_GS_USB (USB)
  * MTD_SPI_NOR (SPI)
  * AMD_XGBE (PCI)
  - x86/x86_64:
  * DELL_SMO8800=m
  * SENSORS_NCT6683=m (found on Intel DQ87PG motherboards)
  * INTEL_SOC_DTS_THERMAL=m
  * X86_GOLDFISH=y (platform driver, used for virtual Android development)
  - KEYBOARD_GOLDFISH_EVENTS=m
  - GOLDFISH_TTY=m
  - BATTERY_GOLDFISH=m
  - MMC_GOLDFISH=m
  - GOLDFISH_AUDIO=m
  - MTD_GOLDFISH_NAND=m
  - GOLDFISH_PIPE=m
  * CRYPTO_SKEIN=n (default n)
  - staging, only available on 64-bit x86 - usefulness?)
  * CRYPTO_THREEFISH=n (same)
  * I2C_CROS_EC_TUNNEL=m (also available on ARM)
  * X86_16BIT=y (default y, required for wine, minimal runtime savings)
  - ppc64le:
  * VIRTUALIZATION=y
  - KVM_BOOK3S_64=m
  - KVM_BOOK3S_64_PR=m
  - KVM_XICS=y
  - New options specific to ARM (I think), all disabled:
  * NFC_ST21NFCA (datasheet says intended for mobile phone use)
  * USB_DWC2
  * SYSTEMPORT
  * KEYBOARD_OMAP4
  * PINCTRL_APQ8064
  * PINCTRL_IPQ8064
  * GENERIC_CPUFREQ_CPU0
  * RTC_DRV_XGENE
  * MFD_AXP20X
- commit 6ff907a
* Mon Jun 16 2014 tiwai@suse.de
- drm/i915, HD-audio: Don't continue probing when nomodeset is
  given (bnc#882648).
- commit cc07b60
* Mon Jun 16 2014 jdelvare@suse.de
- Update config files: Disable CONFIG_8723AU_P2P
  Disable this as it is reported to be totally broken and can cause
  a kernel oops.
- commit a014268
* Fri Jun 13 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Build in a subdirectory of the source tree
  So that the build can use relative paths.
- commit 8eb070a
* Tue Jun 10 2014 jbeulich@suse.com
- swiotlb: don't assume PA 0 is invalid (bnc#865882).
- Update Xen patches to 3.15 final.
- Update x86-64 Xen config files.
- commit 0a9fc1a
* Tue Jun 10 2014 jslaby@suse.cz
- Update config files.
  Disable the reverted CONFIG_ACPI_PROCFS_POWER. Nobody seems to
  complain, so do not enable it.
- commit 0592a75
* Tue Jun 10 2014 jslaby@suse.cz
- Linux 3.14.6 (bnc#880613).
- Delete
  patches.drivers/ALSA-hda-Fix-onboard-audio-on-Intel-H97-Z97-chipsets.
- commit f0d0e23
* Mon Jun  9 2014 jeffm@suse.de
- Update to 3.15.
- commit 91a9a36
* Thu Jun  5 2014 mmarek@suse.cz
- rpm/package-descriptions: kernel-vmi is gone
- rpm/mkspec: Obsolete $flavor-{devel,extra} $flavor-base is obsolete
  (bnc#881490)
- rpm/kernel-module-subpackage: Obsolete -trace KMPs (bnc#881490)
- rpm/old-flavors: Obsolete also kernel-trace-base (bnc#881490)
- commit 38d4d09
* Thu Jun  5 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Do not require hmaccalc on 13.1 and earlier
- commit d7a84f7
* Wed Jun  4 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Allow find-debuginfo.sh to create vmlinux.debug
- commit 9b3c48f
* Wed Jun  4 2014 jslaby@suse.cz
- Linux 3.14.5.
- commit 3ee48e0
* Mon Jun  2 2014 tiwai@suse.de
- usb: musb: tusb6010: Use musb->tusb_revision instead of
  tusb_get_revision call (bnc#872715).
- usb: musb: tusb6010: Add tusb_revision to struct musb to store
  the revision (bnc#872715).
- commit 6141be1
* Mon Jun  2 2014 jeffm@suse.de
- Update to 3.15-rc8.
- commit 93f605c
* Mon Jun  2 2014 mmarek@suse.cz
- Obsolete kernel-trace by kernel-default
- commit 1eb3f59
* Mon Jun  2 2014 jdelvare@suse.de
- Update config files: Disable CONFIG_XO15_EBOOK
  The xo15-ebook driver is useless without the rest of OLPC support. So
  I left it enabled only in i386/default and i386/vanilla.
- commit 9694fd3
* Fri May 30 2014 tiwai@suse.de
- ALSA: hda - Fix onboard audio on Intel H97/Z97 chipsets
  (bnc#880613).
- commit 0de0f93
* Wed May 28 2014 jdelvare@suse.de
- Update config files: Disable gpio-fan and ntc_thermistor drivers
  Disable the gpio-fan and ntc_thermistor hwmon drivers on all
  architectures where they are not used.
- commit 96f5b60
* Wed May 28 2014 jbeulich@suse.com
- Update Xen patches to 3.15-rc7.
- commit f8382bf
* Tue May 27 2014 jeffm@suse.de
- Update to 3.15-rc7.
- Eliminated 1 patch.
- Config changes:
  - CX_ECAT=m (default n) for i386/x86_64
  - The vendor supplying this hardware only uses 32/64-bit Atom CPUs.
    This may need to be revisited if the hardware extends to different
    architectures (ARM, probably).
  - SENSORS_NTC_THERMISTOR=m (default n)
  - Sensor chip that could be found essentially anywhere.
- commit e9c45a3
* Mon May 26 2014 ddiss@suse.de
- cifs: fix client guid reuse logic
  Client guid reuse across multiple protocol versions causes mount
  failures against Windows 2012 servers (bnc#879932).
- patches.fixes/cifs-Set-client-guid-on-per-connection-basis.patch
- patches.fixes/cifs-Do-not-send-ClientGUID-on-SMB2.02-dialect.patch
- commit 289f0e9
* Fri May 23 2014 jeffm@suse.de
- config: sync vanilla configs for 3.15-rc6.
- commit acf7dab
* Fri May 23 2014 jeffm@suse.de
- Update to 3.15-rc6.
- Config changes:
  - ACPI_PROCFS_POWER=y (default n)
  - Should eventually be =n once userspace tools have been audited.
- commit d2be7e3
* Fri May 23 2014 jdelvare@suse.de
- Update ppc config files: Disable SH_MOBILE media drivers
  These are useless on PowerPC.
- commit cacd723
* Fri May 23 2014 ddiss@suse.de
- Update config files: enable CONFIG_CIFS_SMB2
  cifs.ko is currently built with support for the base SMB1/CIFS dialect
  only. SMB1/CIFS support can be disabled in Windows 8.1 and Windows
  Server 2012 R2, and is completely unsupported with the Microsoft Azure
  File service, leaving cifs.ko users unable to access files on such
  servers without this change (fate#317480).
- commit 837860b
* Fri May 23 2014 jdelvare@suse.de
- Update config files: Disable remaining R-CAR drivers
  These drivers are useless except on arm/shmobile.
- commit 2dd69e8
* Wed May 21 2014 jdelvare@suse.de
- Fix a typo in config/ppc/vanilla, sorry
- commit cc68f12
* Wed May 21 2014 jdelvare@suse.de
- Update config files: Disable unused RTC platform drivers
- commit 85c0b8b
* Wed May 21 2014 jdelvare@suse.de
- Update config files: Disable the rtc-moxart driver
  This driver is only needed on Moxa ART systems, which we do not
  support.
- commit 9939e8f
* Tue May 20 2014 jbeulich@suse.com
- supported.conf: Take care of a few driver renames/splits/etc.
- commit ed5e591
* Tue May 20 2014 jbeulich@suse.com
- Update Xen config files: Set compatibility level back to 4.1
  (bnc#851338).
- commit 22da852
* Mon May 19 2014 jdelvare@suse.de
- Update armv7hl/default config file: CONFIG_DRM_PTN3460=y
  Align on what exynos has, in anticipation of both files being
  merged someday.
- commit 8ba853c
* Mon May 19 2014 jdelvare@suse.de
- Update config files: Disable DRM_PTN3460
  Currently it's only needed on arm/exynos.
- commit 6f380e7
* Mon May 19 2014 jdelvare@suse.de
- Update armv7hl/exynos config file: CONFIG_DRM_PTN3460=y
  DRM_EXYNOS_DP depends on DRM_PTN3460, and we have the former built-in,
  so the latter must be built-in as well. Otherwise we get a linker
  failure like:
  .../linux-3.15-rc5/drivers/gpu/drm/exynos/exynos_dp_core.c:1004:
  undefined reference to `ptn3460_init'
- commit bb0a6e6
* Fri May 16 2014 jdelvare@suse.de
- Update config files: Disable all EG20T drivers except on i386
  EG20T (aka Topcliff PCH) is a chipset for 32-bit x86 processors, so
  we only need these drivers on i386.
- commit 923c7d2
* Fri May 16 2014 mhocko@suse.cz
- memcg: fix swapcache charge from kernel thread context (bnc#878306).
- commit 8eaaed7
* Fri May 16 2014 jdelvare@suse.de
- Update arm64 config file to fix the build
- commit beb76a8
* Fri May 16 2014 afaerber@suse.de
- config: armv6hl: Update config to 3.15-rc5
- commit 15546e3
* Fri May 16 2014 afaerber@suse.de
- config: armv7hl: Update configs to 3.15-rc5
- commit de0d16f
* Thu May 15 2014 jdelvare@suse.de
- Update armv7hl/lpae config file: Enable SERIAL_TEGRA
  Despite what the Kconfig text says, the serial-tegra driver works on
  all Tegra platforms.
- commit 222a09f
* Thu May 15 2014 jdelvare@suse.de
- Update ppc64le config files: Disable DA903x support completely
  It makes no sense to support some sub-drivers and not the rest.
- commit 269e033
* Thu May 15 2014 duwe@suse.de
- Update config files:
  i386/x86_64/ppc64/ppc64le disable:
  timeriomem-rng
  pwm-pca9685
  unsupported RTC drivers
  ssd1307fb/da903x_bl
- commit 7725871
* Wed May 14 2014 afaerber@suse.de
- config: arm64: Update config for 3.15
- commit 2d96bf1
* Wed May 14 2014 jbeulich@suse.com
- Update Xen patches to 3.15-rc5.
- privcmd: actually batch hypercalls for batch ioctls.
- Refresh patches.xen/xen-blkfront-indirect (bnc#876786).
- config.conf: Re-enable Xen configs.
- Update x86 config files.
- commit 9ebd57d
* Wed May 14 2014 jbeulich@suse.com
- Refresh patches.suse/stack-unwind (dump_trace_unwind() can be static).
- commit 47a05b6
* Tue May 13 2014 jdelvare@suse.de
- Update ec2 config files: Disable CAN support
  It was enabled by accident.
- commit 4f49dd9
* Tue May 13 2014 jslaby@suse.cz
- Linux 3.14.4 (bnc#871252 bnc#875690 CVE-2014-0196).
- Refresh patches.xen/xen-pcpu.
- Delete
  patches.fixes/n_tty-Fix-n_tty_write-crash-when-echoing-in-raw-mode.patch.
- commit bebeb6f
* Tue May 13 2014 jbeulich@suse.com
- patches.suse/stack-unwind: Drop bogus (redundant) asmlinkage from
  unwind_init_running() definition.
- commit d2673c3
* Mon May 12 2014 tiwai@suse.de
- pvpanic: Set high notifier priority (bnc#875220).
- commit da0842c
* Mon May 12 2014 tiwai@suse.de
- fbcon: Clean up fbcon data in fb_info on FB_EVENT_FB_UNBIND
  with 0 fbs (bnc#875687).
- commit b8d699a
* Mon May 12 2014 jeffm@suse.de
- Update to 3.15-rc5.
- Eliminated 2 patches.
- Config changes:
  - CAN_C_CAN_STRICT_FRAME_ORDERING=n (default)
- commit 7f2c6bf
* Mon May 12 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Do not keep debug symbols in vmlinux-*.gz
  (bnc#877267)
- commit f928d60
* Wed May  7 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Package .vmlinuz-*.hmac as well
- commit 3375bd7
* Wed May  7 2014 jdelvare@suse.de
- Update x86 config files: Disable unused CAN drivers
  Disable platform, grcan and tscan1 CAN drivers. Disable ISA and EG20T
  CAN drivers on x86_64. These are believed to be useless, and will
  only be enabled upon explicit request.
- commit dab25a2
* Wed May  7 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Exclude /boot/symtypes* from the base/main package
  Also, get rid of the comparison of the base and devel filelist.
- commit f1e303f
* Wed May  7 2014 tiwai@suse.de
- ALSA: hda - Add dock pin setups for Thinkpad T440 (bnc#876699).
- commit efc8676
* Wed May  7 2014 tiwai@suse.de
- ALSA: hda - Add dock pin setups for Thinkpad T440 (bnc#876699).
- commit 8292525
* Tue May  6 2014 jslaby@suse.cz
- Linux 3.14.3.
- commit 2a280a3
* Tue May  6 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Fix packaging of vmlinux debuginfo
  (bnc#875946)
  Add the uncompressed vmlinux image as ghost file to the main package, so
  that the vmlinux debuginfo generated by rpm natively and put into the
  right package.
- commit 26b7a64
* Tue May  6 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Simplify filelist for files in /boot
- commit ef040ff
* Mon May  5 2014 mmarek@suse.cz
- Enable CONFIG_INTEL_TXT on i586 as well (fate#311820, fate#311962,
  bnc#707666, bnc#875575)
- commit 403ada2
* Mon May  5 2014 jslaby@suse.cz
- Refresh
  patches.fixes/n_tty-Fix-n_tty_write-crash-when-echoing-in-raw-mode.patch.
  Add commit SHA
- commit 4f0c42a
* Mon May  5 2014 jslaby@suse.cz
- n_tty: Fix n_tty_write crash when echoing in raw mode
  (bnc#871252 bnc#875690 CVE-2014-0196).
- commit e72b790
* Tue Apr 29 2014 guillaume.gardet@oliseo.fr
- Re-eanble ARM kernel in config.conf file and update all ARM configs:
  * config/arm64/default:
  - Add SATA/PATA support
  - Add voltage and regulator support
  * config/armv6hl/default:
  - Add external I2C controllers
  - Add usermode SPI driver
  * config/armv7hl/default:
  - Add I2C support for Tegra SoC
  - Add external I2C controllers
  - Add SPI, GPIO and watchdog support to Davinci/Keystone SoC
  - Add RTC driver for Tegra and sunxi SoC
  - Enhance nVidia Tegra support with MFD_NVEC and KEYBOARD_TEGRA
  - Add OMAP4 video input support
  - Add IR receiver
  - Add iMX HDMI support
  - Add Serial support for Tegra SoC
  * config/armv7hl/exynos:
  - Trivial update
  * config/armv7hl/lpae:
  - Add I2C support for Tegra SoC
  - Add external I2C controllers
  - Add SPI, GPIO and watchdog support to Davinci/Keystone SoC
  - Remove unused Terga20/Tegra30 SPI support
  - Add RTC driver for Tegra and sunxi SoC
  - Enhance nVidia Tegra supprt with MFD_NVEC and KEYBOARD_TEGRA
  - Add IR receiver
  - Add iMX HDMI support
- commit fcd7b3d
* Tue Apr 29 2014 jeffm@suse.com
- Update to 3.15-rc3.
- commit 62b5593
* Tue Apr 29 2014 jeffm@suse.com
- config: sync PCI changes to s390x/vanilla
- commit 807a685
* Tue Apr 29 2014 jdelvare@suse.de
- Update arm config files: Enable all USB-to-serial drivers
  Specifically, enable USB_SERIAL_WISHBONE, USB_SERIAL_MXUPORT and
  USB_SERIAL_QT2 on all arm flavors.
- commit 589f44f
* Tue Apr 29 2014 jdelvare@suse.de
- Update arm64 config file: Disabled 3 unneeded drivers
  Align the arm64 config file with the rest of the config files:
  CONFIG_ATMEL_SSC is not set
  CONFIG_FB_TMIO is not set
  CONFIG_FB_GOLDFISH is not set
- commit aaf60ce
* Tue Apr 29 2014 jdelvare@suse.de
- Update config files: Enable CONFIG_USB_SERIAL_SIMPLE
  This is a unified driver replacing several drivers we were shipping
  so far, so we should ship it too.
- commit 0d558c9
* Tue Apr 29 2014 mmarek@suse.cz
- Enable CONFIG_INTEL_TXT on x86_64 (fate#311820, fate#311962,
  bnc#707666, bnc#875575)
- commit 8f9c4ac
* Mon Apr 28 2014 jeffm@suse.com
- unwind: remove check for vdso32 compat range.
  This fixes a build failure introduced in 3.15-rc1.
- commit 66cfb7b
* Mon Apr 28 2014 mmarek@suse.cz
- rpm/kernel-obs-build.spec.in: Require only perl-Bootloader
- commit 573fc1b
* Mon Apr 28 2014 mmarek@suse.cz
- rpm/kernel-obs-qa.spec.in: Use per-flavor path for the logfile
- commit 717e968
* Mon Apr 28 2014 jeffm@suse.com
- powerpc: export flush_icache_range.
- commit f47acdb
* Sun Apr 27 2014 jeffm@suse.com
- s390: enable PCI to match SLE12 kernel configs
- PCI=y
- HOTPLUG_PCI=y
- HOTPLUG_PCI_S390=y
- PCI_IOV=y
- INFINIBAND=m
- INFINIBAND_USER_ACCESS=m
- MLX4_INFINIBAND=m
- MLX4_EN=m
- RDS_RDMA=m
  New devices since 3.12:
- MLX5_CORE=m
- MLX5_INFINIBAND=m
- SUNRPC_XPRT_RDMA_CLIENT=m
- SUNRPC_XPRT_RDMA=m
- SUNRPC_XPRT_RDMA_SERVER=m
- All others defaulted to No.
- commit ae2780e
* Sun Apr 27 2014 jeffm@suse.com
- s390: add slab.h for kzalloc/kfree.
- commit 7e349ea
* Sun Apr 27 2014 jeffm@suse.com
- patches.suse/ovl05-overlay-filesystem.patch: fix vfs_rename call due to changed prototype
- commit 0a26d0b
* Sun Apr 27 2014 jeffm@suse.de
- Update to 3.15-rc2.
- Config changes:
  - Generic config options:
  * IPMI_SI_PROBE_DEFAULTS=y (default=n)
  - older hardware only works with boot option
  - New options specific to ARM:
  * PINCTRL_BCM281XX=n (default)
- commit c35b255
* Sun Apr 27 2014 jeffm@suse.de
- Update to 3.15-rc1.
- Xen is disabled.
- ARM is disabled.
- Eliminated 3 patches.
- Config changes:
  - Generic config options:
  * USELIB=y (default) - only used for libc5 users, do we care?
  * SYSFS_SYSCALL=y (default) - libc doesn't even supported it anymore,
  do we care?
  * ACPI_REDUCED_HARDWARE_ONLY=n (default)
  * CGROUP_NET_PRIO=y (new feature, do we want it?)
  * LOCK_TORTURE_TEST=n (default)
  * EVM=n (default)
  - New options for existing drivers:
  * BATMAN_ADV_MCAST=y (default=n) -- optimization w/ better reliability
  * BT_6LOWPAN=y (default=n) -- new feature
  * MTD_UBI_BLOCK=n (default -- do we even care about UBI?)
  * ZRAM_LZ4_COMPRESS=y (new feature)
  * BE2NET_VXLAN=y (default)
  * MLX4_EN_VXLAN=y (default)
  * QLCNIC_VXLAN=y (default=n) - enabled for other drivers
  * IWLWIFI_BCAST_FILTERING=n (default)
  - New modules:
  * IP_SET_HASH_IPMARK
  * INTEL_MEI_TXE
  * DM_ERA
  * ALTERA_TSE
  * RTL8723BE
  * RSI_91X
  - RSI_DEBUGFS=n
  - RSI_SDIO=m
  - RSI_USB=m
  * INPUT_PWM_BEEPER
  * SENSORS_LTC2945
  * SENSORS_LTC4222
  * SENSORS_LTC4260
  * SENSORS_ADC128D818
  * MFD_RTSX_USB
  * IR_SHARP_DECODER
  * IR_IMG
  - IR_IMG_RAW=n (documented as performance degrading and for debugging)
  - IR_IMG_NEC=y
  - IR_IMG_JVC=y
  - IR_IMG_SONY=y
  - IR_IMG_SHARP=y
  - IR_IMG_SANYO=y
  * DRM_PTN3460
  * USB_UAS
  * DVB_RTL2832_SDR (USB)
  * ALIENWARE_WMI
  * PWM_LPSS
  * SUNRPC_XPRT_RDMA_CLIENT=m (default)
  * SUNRPC_XPRT_RDMA_SERVER=m (default)
  - x86_64:
  * EFI_MIXED=n (default) -- do we use a bootloader that can support it?
  - ppc/ppc64le:
  * HV_PERF_CTRS=y (default)
  * POWERNV_CPUFREQ=y (default)
  - Probably ARM but looks generic, all modules:
  * SPMI
  * GPIO_DWAPB
  * HID_CP2112
  * MFD_TPS65218
  * GPIO_SYSCON (depends on MFD_SYSCON, which looks to be only used by ARM)
  - New options specific to ARM (I think), all disabled:
  * IMX_THERMAL
  * AHCI_IMX
  * PWM_FSL_FTM
  * OMAP_CONTROL_PHY
  * PHY_SAMSUNG_USB2
  * FSL_EDMA
  * XILINX_WATCHDOG
  * GS_FPGABOOT
  * BCMGENET
  * SXGBE_ETH
  * MFD_BCM590XX
  * BCM7XXX_PHY
  - New options specific to tablets, all disabled:
  * INPUT_SOC_BUTTON_ARRAY (windows tablet)
  * R8723AU (Lenovo Yogi)
  - Other weird hardware:
  * CONFIG_MCB=n (specific to MEN Mikroelektronik FGPA devices)
  - Changes undocumented here were changed automatically.
- commit c0815d2
* Sun Apr 27 2014 jslaby@suse.cz
- Linux 3.14.2.
- commit 91d5ef4
* Thu Apr 24 2014 jdelvare@suse.de
- Update config files: Disable CONFIG_NFC on s390x and ppc64le
  NFC support makes little sense on server-class hardware.
- commit 5cbf723
* Thu Apr 24 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Do not store the buildroot in the .hmac file
- commit ce5bd7a
* Thu Apr 24 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Add hmaccalc to buildrequires
- commit 9cca2fa
* Wed Apr 23 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Generate a hmac singature for the kernel
  (fate#316930, bnc#856310)
- commit 2659f6f
* Wed Apr 23 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Drop conditionals for -kdump and -ps3
- commit 01fab08
* Wed Apr 23 2014 adrian@suse.de
- require kernel-obs-build
  It must be also configured as VMinstall, but is a build requires
  as well to avoid that qa and build package build parallel after kernel-default
  or kernel-xen have changed.
- commit 7a16a4e
* Wed Apr 23 2014 adrian@suse.de
- improve error logging in case the kernel module could not get loaded
- commit 3811667
* Wed Apr 23 2014 adrian@suse.de
- add block device modules for xen kernel-obs-build image
- commit 04fbb81
* Wed Apr 23 2014 jdelvare@suse.de
- Update arm64 config file
  I'm an idiot :-(
- commit 6e9f0a1
* Wed Apr 23 2014 jdelvare@suse.de
- Update arm64 config file: Disable CONFIG_IIO
  It is disabled in all other non-ARM configuration files.
- commit 8cbbb4c
* Tue Apr 22 2014 jdelvare@suse.de
- Update arm64 config file: Disable CONFIG_RTC_DRV_HID_SENSOR_TIME
  It forcibly selects CONFIG_IIO, which we don't want.
- commit 9afef89
* Tue Apr 15 2014 jdelvare@suse.de
- Update arm config files: Disable Cadence network drivers
  Disable ARM_AT91_ETHER in all arm config files, it is only needed on
  Atmel AT91 which we don't support.
  CONFIG_MACB is useful on armv6hl/default (for ARCH_PICOXCELL) and
  armv7hl/default (for ARCH_ZYNQ.) Disable it in all other config files.
- commit 43063d0
* Tue Apr 15 2014 jdelvare@suse.de
- Disable CONFIG_NET_CADENCE on non-ARM
- commit 00acb46
* Tue Apr 15 2014 guillaume.gardet@opensuse.org
- Update armv7hl configs
  * config/armv7hl/default :
  - Switch CONFIG_PHYLIB from =m to =y (fix Ethernet on iMX6 boards)
  - Enable CONFIG_USB_DWC3* to add USB3 support for keystone SoC only
  - Enable CONFIG_USB_CHIPIDEA* to add USB support for iMX boards
  * config/armv7hl/exynos :
  - Enable CONFIG_USB_DWC3* to add USB3 support for Exynos SoC only
  * config/armv7hl/lpae :
  - Switch CONFIG_PHYLIB from =m to =y (fix Ethernet on iMX6 boards)
  - Enable CONFIG_USB_DWC3* to add USB3 support for keystone boards
  - Enable CONFIG_USB_CHIPIDEA* to add USB support for iMX boards
- commit 4337939
* Mon Apr 14 2014 mmarek@suse.cz
- Add kernel-obs-qa-xen.spec
- commit f73cebd
* Mon Apr 14 2014 jslaby@suse.cz
- Update config files.
- commit 13cc815
* Mon Apr 14 2014 jslaby@suse.cz
- Linux 3.14.1.
- commit 117c27b
* Fri Apr 11 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Only sign the kernel on x86_64
- commit e0d4304
* Thu Apr 10 2014 jeffm@suse.com
- config: eliminate trace flavor
  With the tracing options synced to the other flavors, we can eliminate
  the trace flavor entirely.
  This implicitly disables the following options that used to be set
  in the trace flavors:
  IRQSOFF_TRACER: carries a substantial runtime overhead
  MMIOTRACE: really only needed for driver development
  FTRACE_SELFTEST: introduces noticible delays during boot
  FTRACE_STARTUP_TEST: introduces noticible delays during tracer startup
- commit 8020846
* Thu Apr 10 2014 jeffm@suse.com
- config: sync RING_BUFFER_BENCHMARK=m on s390x configs
  It is enabled as a module on every other config.
- commit 0b42220
* Thu Apr 10 2014 jeffm@suse.com
- config: enable STACK_TRACER on all flavors
  It carries no runtime overhead when disabled (and it is by default).
- commit fea9446
* Thu Apr 10 2014 jeffm@suse.com
- config: enable FTRACE_SYSCALLS on all flavor files
  It incurs no runtime overhead other than a few KB of memory.
- commit 3427d84
* Thu Apr 10 2014 jeffm@suse.com
- config: enable SCHED_TRACER on all flavors
  It doesn't have any runtime overhead except for a few KB of memory.
- commit 9125183
* Thu Apr 10 2014 jeffm@suse.com
- config: enable ftrace features on all flavors
  We enable the following function tracing options:
- FUNCTION_TRACER
- DYNAMIC_FTRACE
- FUNCTION_PROFILER
- FUNCTION_GRAPH_TRACER
  With dynamic ftrace, there is very little runtime overhead.
  FUNCTION_GRAPH_TRACER is disabled only on ARM because it enables
  frame pointers there, so there is a real runtime cost even when it
  is disabled.
- commit ce4047b
* Thu Apr 10 2014 mmarek@suse.cz
- Generate kernel-obs-*.spec from templates
- commit b2e5f7c
* Wed Apr  9 2014 jdelvare@suse.de
- Update debug config files: enable TTY_PRINTK
  Enabled only in debug kernels for now, as it can't be modular yet.
  Once it can be built as a module, we can enable it in other flavors
  as well.
- commit 043a9a9
* Tue Apr  8 2014 jdelvare@suse.de
- Update arm64 config file: disable CONFIG_USB_DWC3_KEYSTONE
  This driver is only needed on Texas Instruments Keystone2 platforms.
- commit 4e4e502
* Tue Apr  8 2014 jdelvare@suse.de
- Update ppc config files: disble HW_RANDOM_ATMEL
  This driver is only needed on Atmel AT91 systems.
- commit 2cac896
* Tue Apr  8 2014 jdelvare@suse.de
- Update arm/exynos config file: disable AHCI_IMX
  This driver is only used on Freescale i.MX systems so it isn't needed
  on Exynos.
- commit 45d6387
* Tue Apr  8 2014 jdelvare@suse.de
- Update arm config files: Disable exynos support
  Disable exynos support in all non-exynos configuration files, as we
  have a dedicated kernel flavor for exynos.
- commit c65cb20
* Fri Apr  4 2014 mmarek@suse.cz
- rpm/kernel-module-subpackage: Regenerated the initrd in %%posttrans
  (fate#313506)
- commit c0b6219
* Fri Apr  4 2014 jbeulich@suse.com
- Refresh Xen patches (bnc#870874, bnc#871827).
- commit 00dd4e3
* Fri Apr  4 2014 jdelvare@suse.de
- Update x86_64 config files: disable CONFIG_SBC8360_WDT
  The sbc8360 driver is for a Socket 370-based single-board computer,
  so it's useless on x86-64.
- commit 47efdd9
* Fri Apr  4 2014 adrian@suse.de
- fix building initrd for SLE 12
  It does provided and load the critical kernel modules
  for building some kiwi images and cross architecture
  builds like used for aarch64.
  The kernel-obs-build.spec still contains the bits to allow
  to use it also for SLE 11.
- commit e9868b7
* Thu Apr  3 2014 guillaume.gardet@oliseo.fr
- Refresh patches.rpmify/chipidea-clean-up-dependencies
  Replace OF_DEVICE by OF (OF_DEVICE does not exist anymore.)
- commit 299b9cd
* Thu Apr  3 2014 duwe@suse.de
- Refresh patches.suse/pstore-backend-autoaction.
  Fix valid gcc warnings about an unitialised return code
  and printf format problems.
- commit 73e63e4
* Thu Apr  3 2014 jdelvare@suse.de
- Update config files: disable all of Timberdale support
  Timberdale is a companion chip for Atom CPUs in embedded in-car
  infotainment systems. We don't need that in openSUSE, really.
- commit 47e54c8
* Wed Apr  2 2014 jdelvare@suse.de
- Update config files: disable CONFIG_I2C_SI470X
  I2C access to the SI470X radio chip is only needed on embedded systems
  so it makes no sense to enable it in most of our kernel configuration
  files.
- commit b60e271
* Wed Apr  2 2014 jbeulich@suse.com
- Refresh patches.xen/xen3-patch-3.7 (fix another AR build issue).
- commit 59b27eb
* Wed Apr  2 2014 jdelvare@suse.de
- Update config files: re-enable twofish crypto support
  Software twofish crypto support was disabled in several architectures
  since openSUSE 10.3. For i386 and x86_64 it was on purpose, because
  hardware-accelerated alternatives exist. However for all other
  architectures it was by accident.
  Re-enable software twofish crypto support in all configuration files,
  to guarantee that at least one implementation is always available,
  (bnc#871325).
- commit 8f37fd4
* Wed Apr  2 2014 mmarek@suse.cz
- rpm/kernel-syms.spec.in: Require pesign-obs-integration for signing KMPs
- commit e68d5fc
* Tue Apr  1 2014 jslaby@suse.cz
- Delete patches.arch/arm-omap3isp.patch.
  superseded by 31036441d785359999e45bf410c778f64ffcab64
- commit fd18f9e
* Tue Apr  1 2014 ohering@suse.de
- Fix typo in netfront, in type check of unplug code
- commit 6623a43
* Tue Apr  1 2014 jdelvare@suse.de
- Update config files: disable CONFIG_TOUCHSCREEN_W90X900
  The w90p910_ts driver only makes sense on the W90x900 architecture,
  which we do not support.
- commit 4ebef59
* Tue Apr  1 2014 jbeulich@suse.com
- Update Xen patches to 3.14-final and c/s 1256.
- blkback: allow using indirect request segment descriptors
  (fate#316871).
- blkfront: allow using indirect request segment descriptors
  (fate#316871).
- commit fbd23cd
* Tue Apr  1 2014 jdelvare@suse.de
- Update config files: CONFIG_HID_BATTERY_STRENGTH=y
  CONFIG_HID_BATTERY_STRENGTH was already enabled on i386, x86_64 and
  most of arm. Enable this feature on all other architectures which can
  benefit from it.
- commit aec4432
* Mon Mar 31 2014 jeffm@suse.de
- Update to 3.14.
- commit 5795bd9
* Fri Mar 28 2014 jdelvare@suse.de
- Update i386/desktop config file: enable CONFIG_RCU_FAST_NO_HZ
  All other x86 kernels have CONFIG_RCU_FAST_NO_HZ enabled so the
  i386/desktop kernel should too.
- commit 05ea8f5
* Fri Mar 28 2014 jdelvare@suse.de
- Update ppc config files: adjust filesystems modularity
  Build reiserfs, fat and vfat support as modules as we do on every
  other architecture. Also align the reiserfs debugging features on
  x86_64.
- commit 0985b71
* Wed Mar 26 2014 jdelvare@suse.de
- Update ec2 config files: disable HID device drivers
  I don't think the HID drivers for non-standard keyboards and mice
  are needed at all on EC2.
- commit 9fdef61
* Tue Mar 25 2014 jeffm@suse.com
- Update to 3.14-rc8.
- commit b356c6a
* Tue Mar 25 2014 jdelvare@suse.de
- Update x86 config files: enable CONFIG_HID_BATTERY_STRENGTH
  Looks like a cool feature to support on desktop systems. As it has
  to be built-in, I'm only enabling it on x86 for now, because I don't
  know for sure how useful it would be on other architectures. Feel
  free to enable on any other architecture where it would be useful.
- commit 1edfe71
* Tue Mar 25 2014 jdelvare@suse.de
- Update ec2 config files: disable CONFIG_INPUT_FF_MEMLESS
  This helper module is useless on EC2.
- commit c2808f3
* Tue Mar 25 2014 jdelvare@suse.de
- Update i386 config files: Modularize all HID device drivers
  HID device drivers are modularized in all config files except arm*
  and desktop, so i386/pae, i386/trace and i386/xen should do the same.
- commit 3c2834b
* Tue Mar 25 2014 jdelvare@suse.de
- Update i386 config files: CONFIG_HID=y
  Align the CONFIG_HID setting of the i386/debug, i386/default and
  i386/vanilla config files with what is done in every other config
  file (but s390x and ec2.)
- commit 177a262
* Mon Mar 24 2014 jdelvare@suse.de
- Refresh patches.suse/kconfig-automate-kernel-desktop.
  Options CGROUPS and CGROUP_SCHED are no longer disabled in desktop
  kernel.
- commit 148e111
* Mon Mar 24 2014 jslaby@suse.cz
- Linux 3.13.7.
- Refresh patches.xen/xen3-auto-common.diff.
- Delete patches.arch/ppc64le-ibmveth.patch.
- commit a68bc7c
* Thu Mar 20 2014 jdelvare@suse.de
- Update s390x config files: disable CONFIG_INPUT_FF_MEMLESS
  It was set by mistake, obviously.
- commit 89fa272
* Wed Mar 19 2014 tiwai@suse.de
- Enable Socketcan again for i386 and x86_64 (bnc#858607)
- commit d1f1027
* Tue Mar 18 2014 jdelvare@suse.de
- Update vanilla config files: enable console rotation
  It's enabled in all other kernel flavors so it should be enabled in
  vanilla too.
- commit 1384611
* Tue Mar 18 2014 jdelvare@suse.de
- config: set CONFIG_X86_INTEL_LPSS in trace and vanilla
  Trying to keep the trace and vanilla kernels in sync with default.
- commit 09e4895
* Tue Mar 18 2014 jdelvare@suse.de
- Align the x86_64 debug config file on the default config
  For real this time.
- commit 0b5593a
* Mon Mar 17 2014 jeffm@suse.de
- Update to 3.14-rc7.
- Eliminated 1 patch.
- commit 56ad46a
* Mon Mar 17 2014 jdelvare@suse.de
- Align the x86_64 debug config file on the default config
  This makes it much easier to validate that the debug config file only
  diverges from default by debug and testing options.
- commit 37f104e
* Mon Mar 17 2014 jdelvare@suse.de
- config.conf: ia64 is history
- Delete config/ia64/debug.
- Delete config/ia64/default.
- Delete config/ia64/trace.
- Delete config/ia64/vanilla.
- commit 9e606b5
* Mon Mar 17 2014 tiwai@suse.de
- Enable CONFIG_IRDA_FAST_RR=y (bnc#860502)
- commit 0509ce5
* Mon Mar 17 2014 tiwai@suse.de
- Enable CONFIG_IRDA_FAST_RR=y (bnc#860502)
- commit 3659420
* Sat Mar 15 2014 jdelvare@suse.de
- Update x86_64 config files: Disable AMD Elan SC520 drivers
  The AMD Elan SC520 is a 32-bit x86 processor, related drivers are
  useless on other architectures.
- commit e5b4397
* Sat Mar 15 2014 jdelvare@suse.de
- Update x86_64 and ia64 config files: Disable SC1200 drivers
  The SC1200 is a SoC based on the Geode GX1 32-bit x86 processor, so
  its drivers are useless on other architectures.
- commit 1058f71
* Fri Mar 14 2014 jdelvare@suse.de
- Update config files: Restore CONFIG_THERMAL_HWMON
  Setting CONFIG_THERMAL=y in commit e60ddcfe had the side effect of
  disabling CONFIG_THERMAL_HWMON in many configs that didn't have
  CONFIG_HWMON=y. So revert that change in all affected config files.
  Sorry for overlooking that originally.
- commit b197f4a
* Fri Mar 14 2014 jdelvare@suse.de
- Update config files: Drop all Geode-related drivers
  The Geode was a 32-bit x86 CPU, so all drivers for its companion
  chips (CS55xx) are useless on other architectures. Same for OT200
  drivers, as the Bachmann OT200 device was based on a Geode CPU.
- commit 0bdb147
* Fri Mar 14 2014 jdelvare@suse.de
- Update arm and ppc config files: Drop OLPC-related driver
  OLPC drivers are only useful on i386.
- commit c98f904
* Thu Mar 13 2014 jdelvare@suse.de
- Update debug config files: mac80211 debug options
  Enable all mac80211 debug options in all debug kernel flavors.
- commit 855178e
* Wed Mar 12 2014 guillaume.gardet@opensuse.org
- config: Fix version string for armv7hl/lpae
- commit d1a7ba5
* Wed Mar 12 2014 guillaume.gardet@opensuse.org
- ARM: Re-enable and update configs
- commit d73f266
* Tue Mar 11 2014 jbeulich@suse.com
- Update Xen patches to 3.14-rc6.
- commit cc55130
* Mon Mar 10 2014 jeffm@suse.com
- Update to 3.14-rc6.
- commit e9d20d4
* Fri Mar  7 2014 mmarek@suse.cz
- rpm/mkspec: Generate a per-architecture per-package _constraints file
- commit 65a07f7
* Fri Mar  7 2014 mmarek@suse.cz
- rpm/mkspec: Remove dead code
- commit 3fc95f5
* Fri Mar  7 2014 jslaby@suse.cz
- Linux 3.13.6.
- commit 4727218
* Thu Mar  6 2014 jdelvare@suse.de
- Update config files: CONFIG_THERMAL=y
  The generic thermal module is used by several ACPI components
  (processor, fan, thermal and video) and a few other drivers. So
  in practice it will end up being loaded on almost all systems
  which support ACPI. It is small so build it into the kernel to
  improve boot speed on all ACPI-enabled architectures (i386,
  x86_64 and ia64.)
- commit e60ddcf
* Wed Mar  5 2014 jeffm@suse.com
- Update to 3.14-rc5.
- commit 4126853
* Tue Mar  4 2014 jdelvare@suse.de
- Update ppc64le config files: disable STE_MODEM_RPROC
  Disable config option STE_MODEM_RPROC on all ppc64le flavors, because
  it draws dependencies which aren't available on ppc64le:
  warning: (REMOTEPROC && RPMSG) selects VIRTUALIZATION which has unmet direct dependencies (!CPU_LITTLE_ENDIAN)
- commit 712ca17
* Sat Mar  1 2014 jslaby@suse.cz
- rpc_pipe: fix cleanup of dummy gssd directory when notification
  fails (bnc#866437).
- sunrpc: add an "info" file for the dummy gssd pipe (bnc#866437).
- rpc_pipe: remove the clntXX dir if creating the pipe fails
  (bnc#866437).
- nfs: check if gssd is running before attempting to use krb5i
  auth in SETCLIENTID call (bnc#866437).
- sunrpc: replace sunrpc_net->gssd_running flag with a more
  reliable check (bnc#866437).
- sunrpc: create a new dummy pipe for gssd to hold open
  (bnc#866437).
- commit 5bb4797
* Sat Mar  1 2014 mmarek@suse.cz
- rpm/mkspec: Fix whitespace in NoSource lines
- commit 6320617
* Sat Mar  1 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Do not zero modules.dep before using it
  (bnc#866075)
- commit b67b660
* Fri Feb 28 2014 jdelvare@suse.de
- Update config files: modularize BLK_DEV_MD, disable MD_AUTODETECT
  Michal Marek says:
  I think that the reason why BLK_DEV_MD is built in is
  config MD_AUTODETECT
    bool "Autodetect RAID arrays during kernel boot"
    depends on BLK_DEV_MD=y
  but since we compile the raid presonalities as modules, this cannot
  work. Also, we use the initrd even in the trivial cases, so why bother
  about root-on-md.
- commit db76347
* Fri Feb 28 2014 jdelvare@suse.de
- Update config files.
  Modularize the following helper drivers:
  INET_LRO, NET_CLS_CGROUP, DNS_RESOLVER
  They had to be built-in before due to dependencies, but this is no
  longer the case, so we can modularize them again.
- commit a970646
* Fri Feb 28 2014 jdelvare@suse.de
- Update x86 config files: CONFIG_X86_MSR=m
  The msr driver creates /dev/cpu/*/msr through which you can poke
  at all the MSRs if you have CAP_SYS_RAWIO. We prefer to be able
  to remove that module if it is not needed.
- commit 9e6b04a
* Fri Feb 28 2014 mmarek@suse.cz
- rpm/kernel-obs-build.spec: Drop useless ExclusiveArch statement
- commit 5cdf1da
* Fri Feb 28 2014 guillaume.gardet@oliseo.fr
- config: Update armv7/exynos
- Add sound support
- Add I2C/SPI support
- commit 93b38ce
* Fri Feb 28 2014 tiwai@suse.de
- ALSA: hda/sigmatel - Allow auto-switching for dock line-in of
  HP laptops (bnc#866100).
- commit 6367fe8
* Fri Feb 28 2014 jdelvare@suse.de
- Update config files: CONFIG_ISO9660_FS=m
  There is no good reason why isofs would be built into the kernel.
  Most systems don't need it after installation, and reportedly
  mkinitrd etc. can deal with it as a module just fine.
- commit 3dd8a1a
* Tue Feb 25 2014 jdelvare@suse.de
- Update config files: CONFIG_AUTOFS4_FS=y
  systemd requires autofs, so autofs4.ko will always be loaded on boot.
  For performance reasons, it makes sense to build it into the kernel
  (bnc#863771).
- commit 70247d1
* Tue Feb 25 2014 jbeulich@suse.com
- Update Xen patches to 3.14-rc4 and c/s 1252.
- privcmd: allow preempting long running user-mode originating
  hypercalls (bnc#861093).
- config.conf: Re-enable Xen configs.
- Update x86 config files.
- scripts/check-cvs-add: Disable config checking for now.
- commit d5aea30
* Mon Feb 24 2014 tiwai@suse.de
- Obsolete compat-wireless, rts5229 and rts_pstor KMPs
  These are found in SLE11-SP3, now replaced with the upstream drivers.
- commit 37738dd
* Mon Feb 24 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Do not obsolete ocfs2-kmp (bnc#865259)865259
- commit c8661b5
* Mon Feb 24 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Obsolete the -base package from SLE11 (bnc#865096)
- commit 3f926c3
* Mon Feb 24 2014 jeffm@suse.com
- config: disable PINCTRL_MSM and PINCTRL_MSM8X4
  These options were enable accidentally during the 3.14-rc1 update for
  just the i386/default config.
- commit 2ded0ed
* Mon Feb 24 2014 jeffm@suse.com
- Update to 3.14-rc4.
- Eliminated 1 patch.
- commit 16d4242
* Sun Feb 23 2014 jslaby@suse.cz
- Linux 3.13.5.
- commit 4e9ddcc
* Thu Feb 20 2014 jslaby@suse.cz
- Linux 3.13.4.
- commit 6eda950
* Wed Feb 19 2014 jeffm@suse.com
- dmraid45: removed driver.
  This functionality should be offered by the dmraid driver.
- commit 9a83d77
* Tue Feb 18 2014 mszeredi@suse.cz
- cifs: ensure that uncached writes handle unmapped areas
  correctly (bnc#864025 CVE-2014-00691).
- commit 79c42c5
* Mon Feb 17 2014 jeffm@suse.com
- config: CONFIG_BCM_KONA_USB2_PHY=n on s390
- commit f30c873
* Mon Feb 17 2014 jeffm@suse.com
- acpi: Complete fix for thinkpad RSDT blacklist
- commit 2e62bb9
* Mon Feb 17 2014 jeffm@suse.com
- Update to 3.14-rc3.
- commit 058f759
* Mon Feb 17 2014 jeffm@suse.com
- dmraid45: updated to use new bvec iterators.
- commit 9e25806
* Mon Feb 17 2014 jeffm@suse.com
- acpi: Updated acpi=rsdt dmi blacklist to new variable name.
- commit 4bd9031
* Mon Feb 17 2014 jeffm@suse.com
- Update vanilla config files.
- commit b49cb75
* Fri Feb 14 2014 mmarek@suse.cz
- rpm/kernel-obs-build.spec: Do not mount /sys, the build script does it
- commit f11b02a
* Fri Feb 14 2014 jdelvare@suse.de
- Update config files: Disable TS5500-specific drivers
  These drivers are useless without TS5500 board support: mtd-ts5500,
  gpio-ts5500 and max197.
- commit 2a03456
* Fri Feb 14 2014 jslaby@suse.cz
- Linux 3.13.3 (bnc#799216).
- Refresh patches.xen/xen-x86-EFI.
- Refresh patches.xen/xen3-patch-3.12.
- Delete
  patches.drivers/drm-cirrus-Correct-register-values-for-16bpp.
- Update config files.
- commit d6e2c2f
* Thu Feb 13 2014 dvaleev@suse.de
- rpm/kernel-obs-build.spec: Fix for ppc64le
- commit 50c4205
* Wed Feb 12 2014 mq@suse.cz
- Scripts: .nosrc.rpm should contain only the specfile (bnc #639379)
- commit afe62e0
* Wed Feb 12 2014 jdelvare@suse.de
- Drop outdated comment
- commit 65bab82
* Wed Feb 12 2014 jbeulich@suse.com
- Refresh patches.xen/xen3-patch-3.13 (fix net{back,front} checksum setup).
- commit a23672f
* Wed Feb 12 2014 lpechacek@suse.cz
- doc/README.PATCH-POLICY.SUSE: updated links
- commit ac58062
* Tue Feb 11 2014 mmarek@suse.cz
- Delete unused patches.arch/ppc64le-fix-copytofrom.patch
- commit ce3dbc3
* Tue Feb 11 2014 tiwai@suse.de
- drm/cirrus: Fix cirrus drm driver for fbdev + qemu (bnc#856760).
- commit ee73224
* Tue Feb 11 2014 mq@suse.cz
- Spec: zeroing modules.dep to get identical builds among different machines
- commit a1c5879
* Tue Feb 11 2014 mmarek@suse.cz
- rpm/guards: Report which config file has problem in --check mode
- commit b39543d
* Mon Feb 10 2014 jeffm@suse.com
- Updated patch headers for 3.14-rc2.
- commit d0ea44a
* Mon Feb 10 2014 jeffm@suse.com
- Update to 3.14-rc2.
- Eliminated 1 patch.
- commit a5ab7bf
* Mon Feb 10 2014 jslaby@suse.cz
- rpm/config.sh: switch to building against 13.1
- commit b59b809
* Mon Feb 10 2014 mmarek@suse.cz
- doc/README.SUSE: Update to match the current package layout
- commit f357abb
* Mon Feb 10 2014 mmarek@suse.cz
- Add the README.SUSE file to the packaging branch
- commit 11905ea
* Thu Feb  6 2014 jslaby@suse.cz
- Linux 3.13.2 (bnc#860993 CVE-2014-0038).
- Delete patches.fixes/compat_sys_recvmmsg-x32-fix.patch.
- Refresh patches.xen/xen3-patch-2.6.37.
- Refresh patches.xen/xen3-patch-3.10.
- commit 7e6b5de
* Wed Feb  5 2014 mmarek@suse.cz
- Change also BuildRequires from module-init-tools to modutils
- commit f650166
* Tue Feb  4 2014 jeffm@suse.com
- Updated patch headers for 3.14-rc1.
- commit 967bc40
* Tue Feb  4 2014 jeffm@suse.com
- Update to 3.14-rc1.
- 19 patches eliminated.
- Xen is disabled.
- ARM is disabled.
- commit 691c6b1
* Fri Jan 31 2014 adrian@suse.de
- avoid double /sys mounts for kernel-obs-build, OBS is doing this meanwhile
- commit 3ea39a4
* Thu Jan 30 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Require 'modutils' also in the subpackages
- commit 91f0a2e
* Thu Jan 30 2014 mmarek@suse.cz
- Reformat the spec files to what the buildservice expects
- commit 0b9e9a1
* Wed Jan 29 2014 bp@suse.de
- compat_sys_recvmmsg X32 fix (bnc#860993 CVE-2014-0038).
- commit b4ff60b
* Wed Jan 29 2014 jslaby@suse.cz
- Linux 3.13.1.
- commit 01e2360
* Mon Jan 27 2014 mmarek@suse.cz
- rpm/kernel-source.spec.in: Add README.PATCH-POLICY.SUSE as source file
- commit 9c9ce61
* Mon Jan 27 2014 mmarek@suse.cz
- Drop the _constraints file, we are using the prjconf setting for now
- commit a0aa890
* Fri Jan 24 2014 jbeulich@suse.com
- Refresh Xen patches (fix PV driver build).
- commit d9213ce
* Thu Jan 23 2014 jkosina@suse.cz
- floppy: bail out in open() if drive is not responding to block0
  read (bnc#773058).
- commit 1d92189
* Wed Jan 22 2014 jbeulich@suse.com
- Update Xen patched to 3.13-final and c/s 1248.
- Update EC2 config files (restore CONFIG_DEBUG_INFO).
- commit a770ad7
* Tue Jan 21 2014 jeffm@suse.de
- Update to 3.13.
- commit ff46e6a
* Mon Jan 20 2014 jslaby@suse.cz
- Linux 3.12.8.
- commit 2caf20a
* Fri Jan 17 2014 ohering@suse.de
- xen: pv-on-hvm: skip initialization of emulated devices
  (fate#311487).
- commit f011587
* Fri Jan 17 2014 tiwai@suse.de
- ACPI: Blacklist Win8 OSI for some HP laptop 2013 models
  (bnc#856294).
- commit 0223704
* Fri Jan 17 2014 mmarek@suse.cz
- Revert "rpm/config.sh: Drop the ARM and PPC repositories"
  This was actually wrong, the ports repository is broken.
- commit a983897
* Fri Jan 17 2014 mmarek@suse.cz
- rpm/config.sh: Drop the ARM and PPC repositories
  The architectures are provided by the ports repository
- commit 96b9cec
* Tue Jan 14 2014 mmarek@suse.cz
- rpm/kernel-source.spec.in: Require kernel-devel%%variant
- commit 810ea41
* Tue Jan 14 2014 mhocko@suse.cz
- Delete patches.fixes/remount-no-shrink-dcache.
  the optimization is no longer needed because dcache_lock is long
  gone and replaced by RCU (see b5c84bf6f6 fs: dcache remove
  dcache_lock and others).
- commit 0092763
* Tue Jan 14 2014 mhocko@suse.cz
- Delete patches.fixes/oom-warning.
  The additional warning message is not worth carrying. Highorder
  or atomic allocations which are expected to fail should use
  __GFP_NOWARN to not pollute logs with allocation failures which are
  acceptable.
- commit c07fd34
* Tue Jan 14 2014 mhocko@suse.cz
- Update config files.
  Disable CONFIG_MEMCG_SWAP_ENABLED because it got enabled by accident.
  The CONFIG_MEMCG_SWAP is enabled but the accounting has to be explicitly
  allowed by swap_account=1 kernel command line parameter
- commit 402a841
* Mon Jan 13 2014 jeffm@suse.com
- Update to 3.13-rc8.
- commit 44ad2a9
* Mon Jan 13 2014 jslaby@suse.cz
- efifb: prevent null-deref when iterating dmi_list (bnc#858404).
- commit 78b11e9
* Sat Jan 11 2014 ohering@suse.de
- hv: set guest os id (bnc#814005).
- commit e3d0b5d
* Fri Jan 10 2014 mmarek@suse.cz
- rpm/mkspec: Fix for older Perl
- commit ecf021e
* Fri Jan 10 2014 mmarek@suse.cz
- rpm/mkspec: Add .changes file for kernel-obs-*.spec as well
- commit bd3c299
* Fri Jan 10 2014 ro@suse.de
- rpm/kernel-obs-build.spec: Fix building in chroot instead of Xen
- commit 57e89b6
* Fri Jan 10 2014 jslaby@suse.cz
- Linux 3.12.7.
- commit 2424219
* Thu Jan  9 2014 jdelvare@suse.de
- Disable CONFIG_MODULE_FORCE_UNLOAD (bnc#857673)
  Forcing module unloading can't lead to anything good. If reference
  counting is wrong then it should be fixed. If the reference count is
  right and a regular (unforced) unloading doesn't work, then a forced
  unloading can only lead to chaos and ultimately a kernel crash.
- commit 3d57f73
* Thu Jan  9 2014 afaerber@suse.de
- config: armv6hl: Extend default config for Raspberry Pi
  Enable CONFIG_FB_SIMPLE as that's what U-Boot exposes in DT.
- commit c7b8797
* Wed Jan  8 2014 afaerber@suse.de
- config: armv6hl: Extend default config for Raspberry Pi
  Activate CONFIG_ARM_ATAG_DTB_COMPAT for it to receive U-Boot bootargs.
  Enable BCM2835_{I2C,WDT}, MMC_SDHCI_BCM2835, USB_HCD_BCMA as modules.
- commit 57a2f1c
* Wed Jan  8 2014 jbeulich@suse.com
- Update Xen patches to 3.13-rc7 and c/s 1245.
- netback: bump tx queue length (bnc#849404).
- config.conf: Re-enable Xen configs.
- Update config files.
- commit 0e71aa4
* Tue Jan  7 2014 agraf@suse.de
- Delete config/armv7hl/cubox.
- commit 85bdaf6
* Mon Jan  6 2014 jeffm@suse.com
- Update to 3.13-rc7.
- Eliminated 1 patch.
- commit fed42b5
* Mon Jan  6 2014 jdelvare@suse.de
- Disable CONFIG_I2C_VIA in config/x86_64/desktop too
- commit febc20c
* Mon Jan  6 2014 jdelvare@suse.de
- Disable CONFIG_I2C_VIA, no 64-bit system would need it
- commit 95d3d3d
* Fri Jan  3 2014 mmarek@suse.cz
- Switch to linux-*.tar.xz
- commit 27d9f61
* Fri Jan  3 2014 mmarek@suse.cz
- Add support for linux-*.tar.xz to the spec files
- commit d12c880
* Thu Jan  2 2014 agraf@suse.de
- ARM: Reenable and update configs
- commit 0d77ece
* Thu Jan  2 2014 jeffm@suse.de
- Update to 3.13-rc6.
- commit 63236e5
* Thu Dec 26 2013 jeffm@suse.de
- Update to 3.13-rc5.
- Eliminated 3 patches.
- commit 7127d5f
* Mon Dec 23 2013 dvaleev@suse.com
- Run add_vmlinux for ppc64le
- commit ae96e26
* Mon Dec 23 2013 agraf@suse.de
- ibmveth: Fix more little endian issues.
- powerpc: Don't return to BE mode when we are already there.
- powerpc: Add hack to make ppc64le work on hosts without ILE.
- powerpc: Add relocation code for fixups.
- powerpc: Add global exports for all interrupt vectors.
- commit 3d0a348
* Sat Dec 21 2013 jeffm@suse.de
- Update to 3.13-rc4.
- ppc64le/vanilla appears to have not been resynced when copied.
- commit 82b44e7
* Sat Dec 21 2013 jslaby@suse.cz
- Linux 3.12.6.
- Update config files.
- commit 080d0df
* Fri Dec 20 2013 agraf@suse.de
- Update config files: Disable relocation on ppc64le (it's broken)
- commit fbe0eb5
* Thu Dec 19 2013 agraf@suse.de
- Update config files: Disable kvm for ppc64le (not implemented upstream)
- commit 7fa2dfd
* Thu Dec 19 2013 agraf@suse.de
- powerpc: PTRACE_PEEKUSR always returns FPR0.
- commit c9829ea
* Thu Dec 19 2013 agraf@suse.de
- PPC: Build only vmlinux target.
- commit 04c2cde
* Thu Dec 19 2013 agraf@suse.de
- powerpc: Make 64-bit non-VMX __copy_tofrom_user bi-endian.
- commit 0044320
* Thu Dec 19 2013 agraf@suse.de
- Add ppc64le support (configs are a copy of the ppc64 ones with LE enabled)
- commit d86dbed
* Thu Dec 19 2013 agraf@suse.de
- sched: Remove PREEMPT_NEED_RESCHED from generic code.  (fixes ppc)
- commit 605502a
* Thu Dec 19 2013 agraf@suse.de
- Disable 32-on-64 ptrace patch, it breaks for ppc64le
- commit a943cf8
* Thu Dec 19 2013 agraf@suse.de
- Update config files
  - remove epapr bytechan interface, we don't support booke
- commit 68ab0ab
* Wed Dec 18 2013 tiwai@suse.de
- Disable simplefb and x86 sysfb due to breakage (bnc#855821)
- commit 3848a14
* Wed Dec 18 2013 adrian@suse.de
- Add kernel-obs-build to use the distribution kernel within OBS VM builds.
  Add kernel-obs-qa to test that the kernel is booting within OBS VMs. It may run also further tests later on.
- commit e9cfd5c
* Tue Dec 17 2013 mmarek@suse.cz
- Port module signing changes from SLE11-SP3 (fate#314508)
- commit 8a264a3
* Mon Dec 16 2013 ohering@suse.de
- fbmem: really support wildcard video=options for all fbdev
  drivers.
- commit 5b170d7
* Mon Dec 16 2013 ohering@suse.de
- Delete
  patches.suse/suse-hv-Drivers-hv-util-Fix-a-bug-in-util-version-negotiatio.patch.
- commit b3125ee
* Mon Dec 16 2013 jkosina@suse.cz
- doc/README.PATCH-POLICY.SUSE: add patch policy / best practices document
- commit 60893d6
* Fri Dec 13 2013 tiwai@suse.de
- Add missing CONFIG_PINCTRL_SINGLE kconfig setups
- commit 39ea148
* Thu Dec 12 2013 jdelvare@suse.de
- config.conf: s390 is history
- Delete config/s390/s390.
- Delete config/s390/trace.
- Delete config/s390/vanilla.
- commit 2bf5161
* Thu Dec 12 2013 jdelvare@suse.de
- Delete patches.suse/ida-remove-warning-dump-stack.patch.
  Already included since kernel 3.11 (WARN calls dump_stack.)
- commit 8e04564
* Thu Dec 12 2013 jslaby@suse.cz
- Linux 3.12.5.
- commit 48b587a
* Wed Dec 11 2013 jdelvare@suse.de
- rpm/guards: Spelling fix
- commit 2e074cb
* Wed Dec 11 2013 jdelvare@suse.de
- rpm/guards: Delete dead code
- commit 98077a9
* Wed Dec 11 2013 jdelvare@suse.de
- rpm/guards: Typo fix from upstream
- commit ce654f8
* Wed Dec 11 2013 stefan.bruens@rwth-aachen.de
- config: set CONFIG_X86_INTEL_LPSS and CONFIG_I2C_DESIGNWARE_PLATFORM
  Enable INTEL LPSS (Low Power SubSystem) for LynxPoint chipsets (bnc#849125)
  and DesignWare (platform) i2c bus driver (bnc#849338).
  The DesignWare i2c driver depends on the clock subsystem.
- commit 3a6fe23
* Tue Dec 10 2013 jslaby@suse.cz
- Linux 3.12.4.
- Refresh patches.suse/connector-read-mostly.
- Refresh patches.xen/xen3-auto-common.diff.
- commit 87dc4f5
* Mon Dec  9 2013 hare@suse.de
- Delete patches.suse/scsi-error-test-unit-ready-timeout:
  Superseded by commit 0816c9251a7180383bb7811e1a1545f7b78e5374.
- commit 44df1ce
* Mon Dec  9 2013 hare@suse.de
- iscsi_target: race condition on shutdown (bnc#850072).
- commit c4710fd
* Sun Dec  8 2013 jeffm@suse.com
- Update to 3.13-rc3.
- commit 82b4383
* Fri Dec  6 2013 mmarek@suse.cz
- rpm/kernel-source.spec.in: Add the OBS _constraints file as source
- commit 17282e4
* Wed Dec  4 2013 jslaby@suse.cz
- Linux 3.12.3.
- Refresh
  patches.suse/0001-vfs-Hooks-for-more-fine-grained-directory-permission.patch.
- commit f37dca6
* Wed Dec  4 2013 jeffm@suse.de
- config: enable CONFIG_EXPERT
  3.10 introduced Kconfig rules that automatically builds in
  uncommon HID drivers if EXPERT is not set.
  This commit does not introduce any other config changes.
- commit 30a8773
* Wed Dec  4 2013 jeffm@suse.com
- README: Update to document typical patch naming
- commit d2a2470
* Wed Dec  4 2013 tiwai@suse.de
- config: CONFIG_CHECKPOINT_RESTORE=y and CONFIG_MEM_SOFT_DIRTY=y on x86_64
- commit d99342f
* Mon Dec  2 2013 jeffm@suse.com
- Revert "init: define console_initcall when built as a module."
  This reverts commit 9eb723d9911b941e71381831812b7c7bd17d24f3.
- commit c172b07
* Mon Dec  2 2013 jeffm@suse.com
- init: define console_initcall when built as a module.
- commit 9eb723d
* Mon Dec  2 2013 jeffm@suse.com
- overlayfs: update for 3.13 delegated_inode API changes.
- commit 3d88c7f
* Mon Dec  2 2013 jeffm@suse.com
- Update to 3.13-rc2.
  - Eliminated 1 patch.
- commit 75ac3c3
* Fri Nov 29 2013 jslaby@suse.cz
- Linux 3.12.2.
- Refresh patches.xen/xen3-patch-2.6.29.
- Delete
  patches.suse/btrfs-relocate-csums-properly-with-prealloc-extents.patch.
- commit 3b81e61
* Fri Nov 29 2013 tiwai@suse.de
- Build mei and mei_me as modules (bnc#852656)
- commit 1a570dd
* Thu Nov 28 2013 jdelvare@suse.de
- supported.conf: dd drivers/hwmon/smsc47b397
  That one is very simple and reliable and found in a number of
  enterprise-grade workstations. I believe it would make sense to support
  it.
- commit 3a2ac9d
* Wed Nov 27 2013 duwe@suse.de
- pstore: automatically dump and clean dmesg entries
  (fate#315232).
- Update config files.
- commit 9525160
* Tue Nov 26 2013 agraf@suse.de
- omapdrm: fix compile with dma_addr_t > u32.
- commit 611f4eb
* Sat Nov 23 2013 jeffm@suse.com
- Update to 3.13-rc1.
- Eliminated 7 patches.
- Xen is disabled.
- ARM needs config updates.
- commit 2dfdca4
* Thu Nov 21 2013 guillaume.gardet@oliseo.fr
- Add USB PHY support (needed to get USB and Ethernet working on beagle and panda boards) Add CONFIG_PINCTRL_SINGLE=y to be able to use Device tree (at least for beagle and panda boards) Add ARM SoC sound support Add SPI bus support Add user-space access to I2C and SPI
- commit b3c966e
* Thu Nov 21 2013 guillaume.gardet@oliseo.fr
- Set CONFIG_GPIO_TWL4030 as built-in (instead of module) as a requirement to boot on SD card on beagleboard xM
- commit 5b7fb61
* Thu Nov 21 2013 jslaby@suse.cz
- Linux 3.12.1.
- commit 1e06fbe
* Wed Nov 20 2013 jslaby@suse.cz
- Update config files (fate#315172).
- commit a0984ed
* Wed Nov 20 2013 jslaby@suse.cz
- x86/dumpstack: Fix printk_address for direct addresses
  (bnc#845621).
- Refresh patches.suse/stack-unwind.
- Refresh patches.xen/xen-x86_64-dump-user-pgt.
- commit ce55b22
* Tue Nov 19 2013 jbohac@suse.cz
- supported.conf: marked net/netfilter/xt_set as supported (bnc#851066)
  xt_set should have been enabled together with the ip_set modules in
  fate#313309
- commit c2e046e
* Sat Nov 16 2013 jeffm@suse.com
- config: build uncommon HID drivers as modules
- commit 92db3f1
* Sat Nov 16 2013 jeffm@suse.com
- config: sync HID=y on x86_64/debug config
- commit 2437d0f
* Tue Nov 12 2013 jdelvare@suse.de
- armv6hl, armv7hl: Update config files.
  Set CONFIG_BATMAN_ADV_BLA=y as all other kernel configuration files
  have.
- commit e7c00d8
* Fri Nov  8 2013 jdelvare@suse.de
- Update config files:
  * CONFIG_BATMAN_ADV_NC=y, because other BATMAN_ADV options are all
  enabled so why not this one.
  * CONFIG_GPIO_SCH=m, CONFIG_GPIO_PCH=m, because we support all other
  features of these pieces of hardware.
  * CONFIG_INTEL_POWERCLAMP=m, because this small driver might be
  useful in specific cases, and there's no obvious reason not to
  include it.
- commit 79e7a03
* Thu Nov  7 2013 jbeulich@suse.com
- Update Xen patches to 3.12-final.
- commit ec28986
* Wed Nov  6 2013 duwe@suse.de
- fate#316581: CONFIG_IBM_BSR y -> m
- commit f5eba64
* Mon Nov  4 2013 jslaby@suse.cz
- Delete patches.kernel.org/patch-3.11.1.
- commit ec24572
* Mon Nov  4 2013 jeffm@suse.com
- Update config files.
- commit f7c27a2
* Mon Nov  4 2013 jeffm@suse.com
- Update to 3.12-final.
- commit bd2bcf1
* Mon Nov  4 2013 jeffm@suse.com
- Refresh
  patches.suse/btrfs-add-ability-to-query-change-feature-bits-online-ioctl.
- commit a58c8c5
* Mon Nov  4 2013 jeffm@suse.com
- Refresh patches.suse/btrfs-add-tracing-for-failed-reservations.
- Refresh patches.suse/btrfs-publish-allocation-data-in-sysfs.
  - No code change: missing 'quilt add' caused a chunk to be
    in the wrong patch.
- commit 0346b5c
* Wed Oct 30 2013 tiwai@suse.de
- ALSA: hda - Add extra chmap for 2.1 outputs on ASUS laptops
  (bnc#846531).
- commit 5fe5110
* Wed Oct 30 2013 tiwai@suse.de
- ALSA: hda - Add a fixup for ASUS N76VZ (bnc#846529).
- commit c8ca4fb
* Tue Oct 29 2013 jbeulich@suse.com
- Update Xen patches to 3.12-rc7 and c/s 1240.
- commit 49141ff
* Mon Oct 28 2013 jeffm@suse.de
- Update to 3.12-rc7.
- commit c59f68d
* Tue Oct 22 2013 jeffm@suse.com
- nouveau: Fix race with fence signaling (bnc#844177).
- commit db1113e
* Tue Oct 22 2013 jeffm@suse.com
- btrfs: add ioctl to export size of global metadata reservation.
- btrfs: add tracing for failed reservations.
- btrfs: publish allocation data in sysfs.
- btrfs: publish device membership in sysfs.
- btrfs: publish fs label in sysfs.
- btrfs: publish per-super attributes in sysfs.
- btrfs: publish per-super features in sysfs.
- btrfs: publish supported featured in sysfs.
- btrfs: publish unknown feature bits in sysfs.
- kobject: export kobj_sysfs_ops.
- Refresh
  patches.suse/btrfs-add-ability-to-change-features-via-sysfs.
- Refresh
  patches.suse/btrfs-use-feature-attributes-to-print-names-in-errors.
- Delete
  patches.suse/btrfs-add-per-super-attribute-publishing-to-sysfs.
- Delete
  patches.suse/btrfs-add-publishing-of-unknown-features-in-sysfs.
- Delete patches.suse/btrfs-export-supported-featured-to-sysfs.
- Delete patches.suse/btrfs-publish-per-super-features-to-sysfs.
- Delete patches.suse/introduce-kobj_completion.
- commit 28f62b4
* Mon Oct 21 2013 jeffm@suse.com
- Update to 3.12-rc6.
- commit 7244867
* Fri Oct 18 2013 jslaby@suse.cz
- Linux 3.11.6 (bnc#841645).
- Delete patches.drivers/ALSA-hda-Add-fixup-for-ASUS-N56VZ.
- commit 9ca6827
* Wed Oct 16 2013 jbeulich@suse.com
- Update x86 Xen config files (RTC_DRV_EFI=y).
- commit ac42dba
* Wed Oct 16 2013 jbeulich@suse.com
- Update Xen patches to 3.12-rc5.
- config.conf: Re-enable Xen configs.
- Update config files.
- Delete patches.xen/xen3-010-acpi_initrd_override_tables.patch.
- commit 8673f3f
* Tue Oct 15 2013 oneukum@suse.de
- sha256_ssse3: also test for BMI2 (bnc#842459).
- commit 243990f
* Mon Oct 14 2013 jeffm@suse.com
- config: enable HAVE_BOOTMEM_INFO_NODE on ppc64 to match 3.11.5 (vanilla)
- commit 53efb9c
* Mon Oct 14 2013 jeffm@suse.com
- config: enable HAVE_BOOTMEM_INFO_NODE on ppc64 to match 3.11.5
- commit 22f9877
* Mon Oct 14 2013 jeffm@suse.com
- btrfs: Fix creation of per-super sysfs directories when using multiple
  subvolumes (bnc#845774)
- commit adcee6c
* Mon Oct 14 2013 jeffm@suse.com
- btrfs: Fix creation of per-super sysfs directories when using multiple
  subvolumes (bnc#845774).
- commit 0801062
* Mon Oct 14 2013 jeffm@suse.com
- Update to 3.12-rc5.
- commit 6c5465f
* Mon Oct 14 2013 oneukum@suse.de
- sha256_ssse3: also test for BMI2 (bnc#842459).
- commit 626459d
* Mon Oct 14 2013 jslaby@suse.cz
- Linux 3.11.5.
- Delete
  patches.suse/btrfs-0005-reset-ret-in-record_one_backref.patch.
- Delete
  patches.suse/btrfs-0010-change-how-we-queue-blocks-for-backref-checkin.patch.
- Delete
  patches.suse/btrfs-0022-skip-subvol-entries-when-checking-if-we-ve-cre.patch.
- Delete
  patches.suse/btrfs-0033-remove-ourselves-from-the-cluster-list-under-l.patch.
- commit c00734a
* Fri Oct 11 2013 jeffm@suse.com
- Update to 3.12-rc4.
- commit 8fdbb19
* Fri Oct 11 2013 tiwai@suse.de
- drm/i915: Undo the PIPEA quirk for i845 (bnc#845503).
- commit e401a74
* Tue Oct  8 2013 tiwai@suse.de
- ALSA: hda - Add fixup for ASUS N56VZ (bnc#841645).
- commit 9f1b1d6
* Mon Oct  7 2013 jack@suse.cz
- supported.conf: Update support info
- commit fe619b0
* Sat Oct  5 2013 jslaby@suse.cz
- Linux 3.11.4.
- commit 40d7ca3
* Fri Oct  4 2013 bp@suse.de
- supported.conf: Remove IOMMU v2
  This is only needed for HSA.
- commit 1d0217b
* Fri Oct  4 2013 bp@suse.de
- supported.conf: Add a bunch of AMD-specific drivers to the list
  + sb_edac which people wanted since SLE11-SP2.
- commit 942c03a
* Fri Oct  4 2013 bpoirier@suse.de
- supported.conf: update for network related modules
  based on FATE#313655
  +		drivers/net/ethernet/intel/i40e/i40e
  vhost_net depends on vhost
  +		drivers/vhost/vhost
  nf_nat is now nf_nat_ipv4, _ipv6 was introduced in v3.7
  - net/ipv4/netfilter/nf_nat
  +		net/ipv4/netfilter/nf_nat_ipv4
  +		net/ipv6/netfilter/nf_nat_ipv6
  based on the rationale that we already package `ss` and support inet_diag:
  +		net/ipv4/udp_diag
  +		net/netlink/netlink_diag
  +		net/packet/af_packet_diag
  +		net/unix/unix_diag
- commit 07a54e6
* Fri Oct  4 2013 mmarek@suse.cz
- supported.conf: Add newly requested drivers
- commit 199c169
* Fri Oct  4 2013 mmarek@suse.cz
- supported.conf: More updates from SLE11-SP3
- commit 45bc81a
* Fri Oct  4 2013 mmarek@suse.cz
- rpm/split-modules: Check module support only if the -extra package is requested
- commit add86bf
* Fri Oct  4 2013 mmarek@suse.cz
- rpm/split-modules: Remove unused options
- commit 3736315
* Fri Oct  4 2013 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Fix creating the kernel-*-extra package
  CONFIG_ENTERPRISE_SUPPORT has been renamed to CONFIG_SUSE_KERNEL_SUPPORTED
- commit 9e5b6fe
* Fri Oct  4 2013 mmarek@suse.cz
- supported.conf: Copy some missing changes from SLE11-SP3
- commit fdeb1a7
* Fri Oct  4 2013 mmarek@suse.cz
- supported.conf: Remove the kernel/ prefix from module paths.
- commit 9649d9f
* Fri Oct  4 2013 mmarek@suse.cz
- modpost: Allow wildcards in the Module.supported file.
- commit a464383
* Fri Oct  4 2013 mmarek@suse.cz
- modpost: Fix matching of dashes and underscores in Module.supported (bnc#719090).
- commit cab1abc
* Thu Oct  3 2013 mmarek@suse.cz
- Enable CONFIG_DRM_QXL and mark qxl.ko as supported (fate#316469)
- commit acad9db
* Wed Oct  2 2013 jslaby@suse.cz
- Linux 3.11.3.
- Refresh patches.xen/xen3-patch-3.4.
- commit 485f0d1
* Tue Oct  1 2013 jeffm@suse.com
- Update to 3.12-rc3.
- commit e5ef0d0
* Tue Oct  1 2013 mmarek@suse.cz
- Disable CONFIG_FB_TMIO (Sharp Zaurus) on non-arm configs.
- commit 977b235
* Tue Oct  1 2013 mmarek@suse.cz
- Disable CONFIG_FB_GEODE, as the individual GEODE options are already disabled
- commit d10fe5f
* Mon Sep 30 2013 mmarek@suse.cz
- Always include the git commit in KOTD builds
  This allows us not to set it explicitly in builds submitted to the
  official distribution (bnc#821612, bnc#824171).
- commit a80e5ef
* Mon Sep 30 2013 mmarek@suse.cz
- Do not build udlfb, to avoid conflict with udl (fate#316407)
- commit 678681d
* Mon Sep 30 2013 mmarek@suse.cz
- Disable fb drivers that have been blacklisted for a long time
  via /etc/modprobe.d/50-blacklist.conf.
- commit b34e737
* Mon Sep 30 2013 dsterba@suse.cz
- Btrfs: relocate csums properly with prealloc extents.
- commit 6cf855e
* Mon Sep 30 2013 dsterba@suse.cz
- Btrfs: relocate csums properly with prealloc extents.
- commit cb5d5b5
* Sat Sep 28 2013 ohering@suse.de
- Refresh
  patches.suse/suse-hv-X86-Hyper-V-Get-the-local-APIC-timer-frequency-from-.patch.
  actually assign the divide result to hv_lapic_frequency
- commit 420e19b
* Sat Sep 28 2013 ohering@suse.de
- Refresh
  patches.suse/suse-hv-X86-Hyper-V-Get-the-local-APIC-timer-frequency-from-.patch.
  actually assign the divide result to hv_lapic_frequency
- commit 9e0a852
* Fri Sep 27 2013 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Add obsolete KMPs from sle11-sp1
- commit 221133c
* Fri Sep 27 2013 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Make sure that all KMP obsoletes are
  versioned (bnc#821465).
- commit d802bf2
* Fri Sep 27 2013 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Provide obsoleted KMPs (bnc#753353)
- commit f5449e6
* Fri Sep 27 2013 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Remove unversioned provides/obsoletes
  for packages that were only seen in openSUSE releases up to 11.0.
  (bnc#821465).
- commit 7e1f4b6
* Fri Sep 27 2013 jeffm@suse.com
- config: disable FB_UDL in favor of DRM_UDL (bnc#836782).
- commit 68c5865
* Fri Sep 27 2013 ohering@suse.de
- Refresh
  patches.suse/suse-hv-X86-Hyper-V-Get-the-local-APIC-timer-frequency-from-.patch.
- commit 83e7e53
* Fri Sep 27 2013 ohering@suse.de
- Refresh
  patches.suse/suse-hv-X86-Hyper-V-Get-the-local-APIC-timer-frequency-from-.patch.
- commit ff1e29f
* Fri Sep 27 2013 ohering@suse.de
- X86: Hyper-V: Get the local APIC timer frequency from the
  hypervisor.
- commit 4f400e1
* Fri Sep 27 2013 ohering@suse.de
- Input: add a driver to support Hyper-V synthetic keyboard
  (fate#315887).
- Update config files.
- commit 7affb28
* Fri Sep 27 2013 ohering@suse.de
- X86: Hyper-V: Get the local APIC timer frequency from the
  hypervisor.
- commit ca351ea
* Fri Sep 27 2013 ohering@suse.de
- Input: add a driver to support Hyper-V synthetic keyboard
  (fate#315887).
- Update config files.
- commit 0b0a3fa
* Fri Sep 27 2013 jeffm@suse.com
- config: disable DGAP on s390
  It requires ioremap, which isn't available on s390. It's a staging
  driver anyway.
- commit cf0bc41
* Fri Sep 27 2013 mmarek@suse.cz
- rpm/old-flavors, rpm/mkspec: Add version information to obsolete
  flavors (bnc#821465).
- rpm/kernel-binary.spec.in: Move the xenpae obsolete to the
  old-flavors file.
- commit 25c1b0d
* Fri Sep 27 2013 mmarek@suse.cz
- rpm/old-flavors: Convert the old-packages.conf file to a flat
  list.
- rpm/mkspec: Adjust.
- rpm/old-packages.conf: Delete.
- commit 4037e16
* Fri Sep 27 2013 mmarek@suse.cz
- rpm/old-packages.conf: Drop bogus obsoletes for "smp" (bnc#821465)
- commit 50c4c23
* Fri Sep 27 2013 jslaby@suse.cz
- README.BRANCH: fix typo
- commit 4c1fc5a
* Fri Sep 27 2013 jslaby@suse.cz
- Linux 3.11.2.
- Refresh patches.xen/pci-guestdev.
- Refresh patches.xen/xen3-patch-2.6.27.
- Delete
  patches.rpmify/powerpc-add-missing-include-to-book3s_xics-c.
- commit d1e8a21
* Fri Sep 27 2013 jdelvare@suse.de
- config/*/debug: Enable FSCACHE_DEBUG and CACHEFILES_DEBUG.
- commit 5068fbc
* Thu Sep 26 2013 rgoldwyn@suse.com
- rpm/kernel-binary.spec.in: Remove Obsoletes ocfs2-kmp
  This is done to enable install of ocfs2-kmp-* alongwith the
  kernel until the patches are reviewed.
- commit 9d2b4ca
* Thu Sep 26 2013 jeffm@suse.com
- config.conf: Re-enable s390x and ia64 configs
- commit 954d4c1
* Thu Sep 26 2013 jeffm@suse.com
- config.conf: Re-enable s390x and ia64 configs
- commit adb564f
* Thu Sep 26 2013 jeffm@suse.com
- patches.rpmify/documentation-fix-bad-merge-with-tmpfile-documentation:
  Updated Patch-mainline
- commit a1513a8
* Thu Sep 26 2013 jdelvare@suse.de
- Build gpio-ucb1400 as a module
- commit 68bb010
* Thu Sep 26 2013 jdelvare@suse.de
- Build gpio-ucb1400 as a module
- commit fc372c0
* Thu Sep 26 2013 mmarek@suse.cz
- Update README.BRANCH
- commit 4d432eb
* Wed Sep 25 2013 dsterba@suse.cz
- Disable patches.suse/btrfs-0034-optimize-key-searches-in-btrfs_search_slot.patch
- commit e74b2a8
* Wed Sep 25 2013 agraf@suse.de
- ARM: Update config files: Use lpae for multiarch, exynos for LPAE exynos5
- commit 957e65c
* Wed Sep 25 2013 agraf@suse.de
- Clean up ARM patches:
- Refresh patches.arch/arm-arndale-dma.patch.
- Delete patches.arch/arm-exynos-nosparse.patch.
- Delete
  patches.arch/arm-xen-0001-arm-introduce-psci_smp_ops.patch.
- Delete
  patches.arch/arm-xen-0002-ARM-Enable-selection-of-SMP-operations-at-boot-time.patch.
- Delete
  patches.arch/arm-xen-0006-xen-arm-disable-cpuidle-when-linux-is-running-as-dom.patch.
- Delete
  patches.arch/arm-xen-0007-arm-choose-debug-uncompress.h-include-when-uncompres.patch.
- Delete
  patches.arch/arm-xen-0008-xen-arm-enable-PV-control-for-ARM.patch.
- commit 1cdc83d
* Wed Sep 25 2013 agraf@suse.de
- config.conf:
- Update config files for ARM on 3.12.
- commit 2503bec
* Tue Sep 24 2013 trenn@suse.de
- Delete patches.arch/010-acpi_initrd_override_tables.patch.
  This old one alone broke acpi initrd override -> delete it.
- commit a75f081
* Tue Sep 24 2013 jeffm@suse.com
- lustre/lloop: don't change the logical size for the queue.
- commit 4a2006a
* Tue Sep 24 2013 jeffm@suse.com
- Update to 3.12-rc2.
- Eliminated 3 patches.
- commit d7d9943
* Tue Sep 24 2013 jeffm@suse.com
- Update to 3.12-rc1.
- Eliminated 42 patches.
- Xen is disabled.
- ARM is disabled.
- commit c58d853
* Mon Sep 23 2013 jeffm@suse.com
- patches.suse/btrfs-add-per-super-attribute-publishing-to-sysfs: Fix issue where
  the error case would still attempt to create sysfs dir.
- commit 129c02b
* Fri Sep 20 2013 jslaby@suse.cz
- power_supply: Prevent suspend until power supply events are
  processed (bnc#841596).
- commit 11b28da
* Wed Sep 18 2013 duwe@suse.de
- Increase NR_CPUS on ppc64 to 2048 (fate#315438)
- commit 8a38aef
* Tue Sep 17 2013 jslaby@suse.cz
- Update config files.
  Fix ZSWAP on vanillas.
- commit da42424
* Tue Sep 17 2013 jeffm@suse.com
- scripts/sequence-patch.sh: Fix for Xen detection with --vanilla
  When we hit the limit code to handle $SKIP_XEN and there aren't
  any Xen patches to apply anyway, we'll fail because LIMIT is unset.
- commit 1d7b879
* Tue Sep 17 2013 jeffm@suse.com
- scripts/tar-up.sh: Disable Xen patches when Xen configs are disabled
  Similar to the change for scripts/sequence-patch.sh, this change
  disables the Xen patches with +noxen in series.conf when creating
  the kernel-source package.
- commit 3104a04
* Tue Sep 17 2013 jeffm@suse.com
- scripts/sequence-patch.sh: Skip Xen patches when Xen configs are disabled.
  When updating the base kernel version, the Xen patches must be updated
  separately. This allows us to skip the Xen patches until they're resynced
  just by disabling the configs.
- commit d9673e9
* Tue Sep 17 2013 jeffm@suse.com
- btrfs: use feature attribute names to print better error
  messages.
- btrfs: add ability to change features via sysfs.
- btrfs: add publishing of unknown features in sysfs.
- btrfs: publish per-super features to sysfs.
- btrfs: add per-super attributes to sysfs.
- btrfs: export supported featured to sysfs.
- kobject: introduce kobj_completion.
- btrfs: add ioctls to query/change feature bits online.
- btrfs: use btrfs_commit_transaction when setting fslabel.
- commit 7e40f1e
* Tue Sep 17 2013 jeffm@suse.com
- config: Update missing ZSWAP configs.
- commit 85bd223
* Mon Sep 16 2013 dsterba@suse.cz
- Btrfs: optimize key searches in btrfs_search_slot.
- Btrfs: remove ourselves from the cluster list under lock.
- Btrfs: do not clear our orphan item runtime flag on eexist.
- Btrfs: fix printing of non NULL terminated string.
- Btrfs: fix memory leak of orphan block rsv.
- Btrfs: don't miss inode ref items in BTRFS_IOC_INO_LOOKUP.
- Btrfs: add missing error code to BTRFS_IOC_INO_LOOKUP handler.
- Btrfs: move btrfs_free_qgroup_config() out of spin_lock and
  fix comments.
- Btrfs: fix oops when writing dirty qgroups to disk.
- Btrfs: fix heavy delalloc related deadlock.
- Btrfs: fix the error handling wrt orphan items.
- Btrfs: don't allow a subvol to be deleted if it is the default
  subovl.
- Btrfs: skip subvol entries when checking if we've created a
  dir already.
- Btrfs: fix possible memory leak in find_parent_nodes().
- Btrfs: return ENOSPC when target space is full.
- Btrfs: don't ignore errors from btrfs_run_delayed_items.
- Btrfs: fix inode leak on kmalloc failure in tree-log.c.
- Btrfs: stop using GFP_ATOMIC when allocating rewind ebs.
- Btrfs: deal with enomem in the rewind path.
- Btrfs: check our parent dir when doing a compare send.
- Btrfs: handle errors when doing slow caching.
- Btrfs: add missing error handling to read_tree_block.
- Btrfs: add missing error check to find_parent_nodes.
- Btrfs: don't bug_on when we fail when cleaning up transactions.
- Btrfs: change how we queue blocks for backref checking.
- Btrfs: add missing mounting options in btrfs_show_options().
- Btrfs: use u64 for subvolid when parsing mount options.
- Btrfs: don't bother autodefragging if our root is going away.
- Btrfs: cleanup reloc roots properly on error.
- Btrfs: reset ret in record_one_backref.
- btrfs: fix get set label blocking against balance.
- Btrfs: set qgroup_ulist to be null after calling ulist_free().
- Btrfs: add missing error checks to add_data_references.
- Btrfs: Release uuid_mutex for shrink during device delete.
- commit ded2bc7
* Sat Sep 14 2013 jslaby@suse.cz
- Linux 3.11.1.
- commit 1383321
* Thu Sep 12 2013 jeffm@suse.com
- config: Enable CONFIG_ZSWAP (bnc#839064).
  It's built-in but a no-op without zswap.enabled=1 on the kernel
  command line.
- commit 1441e59
* Thu Sep 12 2013 jeffm@suse.com
- Update
  patches.fixes/reiserfs-locking-handle-nested-locks-properly.
- Update
  patches.fixes/reiserfs-locking-push-write-lock-out-of-xattr-code.
- Update
  patches.fixes/reiserfs-locking-release-lock-around-quota-operations.
- commit fd0a178
* Fri Sep  6 2013 rgoldwyn@suse.de
- Update config files to enable GFS DLM locking.
- commit 712cff0
* Thu Sep  5 2013 ohering@suse.de
- Drivers: hv: util: Fix a bug in util version negotiation code
  (bnc#838346).
- commit 938aca5
* Wed Sep  4 2013 jbeulich@suse.com
- Update Xen patches to final 3.11.
- commit e71a103
* Tue Sep  3 2013 jeffm@suse.com
- Update to 3.11-final.
- commit 7561c6f
* Thu Aug 29 2013 jslaby@suse.cz
- Linux 3.10.10.
- commit 8038aea
* Tue Aug 27 2013 jeffm@suse.com
- rpm/kernel-docs.spec.in: Fix missing whitespace error in description
- commit 280c88e
* Tue Aug 27 2013 jeffm@suse.com
- Update to 3.11-rc7.
- commit 99e1318
* Wed Aug 21 2013 jbeulich@suse.com
- Update Xen patches to 3.11-rc6.
- commit 7ee85be
* Wed Aug 21 2013 jslaby@suse.cz
- Linux 3.10.9.
- commit a0841e3
* Wed Aug 21 2013 jslaby@suse.cz
- Linux 3.10.8.
- commit e77e7a7
* Mon Aug 19 2013 jeffm@suse.com
- Update to 3.11-rc6.
- commit b474038
* Thu Aug 15 2013 jbeulich@suse.com
- Update Xen patches to 3.11-rc5.
- config.conf: Re-enable Xen configs
- Delete patches.xen/xen-sections.
- commit adcd98b
* Thu Aug 15 2013 jslaby@suse.cz
- Linux 3.10.7.
- commit 771dec3
* Tue Aug 13 2013 guillaume.gardet@oliseo.fr
- config: update armv6 default config to multi-arch armv6
- commit 25b5917
* Mon Aug 12 2013 jeffm@suse.com
- Update to 3.11-rc5.
- commit c33c981
* Mon Aug 12 2013 jslaby@suse.cz
- Linux 3.10.6.
- commit bd99dce
* Sun Aug 11 2013 jslaby@suse.cz
- Update config files.
  Enable acpi pci hotplug again.
- commit f2022c3
* Thu Aug  8 2013 guillaume.gardet@oliseo.fr
- arm: update default config for 3.11.0-rc4
- Add sound modules
- Add TI wifi modules
- commit 448a93c
* Thu Aug  8 2013 dmueller@suse.com
- config/arm: update and reenable ARM64 config
- commit 327e5fc
* Thu Aug  8 2013 dmueller@suse.com
- Reenable ARMv6/ARMv7 configs
- commit 461df98
* Wed Aug  7 2013 jeffm@suse.com
- config: disable RCU_USER_QS
  RCU_USER_QS is used for hacking on debugging the full dynticks model,
  which we've disabled.
- commit 910e01d
* Mon Aug  5 2013 jeffm@suse.com
- reiserfs: locking, release lock around quota operations
  (bnc#815320).
- reiserfs: locking, handle nested locks properly (bnc#815320).
- reiserfs: locking, push write lock out of xattr code
  (bnc#815320).
- commit 01695c8
* Mon Aug  5 2013 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Avoid hardcoded runtime dependency on
  module-init-tools.
- commit 2889cef
* Mon Aug  5 2013 jeffm@suse.com
- Update to 3.11-rc4.
- commit 38e9077
* Sun Aug  4 2013 jslaby@suse.cz
- Linux 3.10.5 (bnc#829539 bnc#830492).
- Delete
  patches.fixes/drm-i915-Fix-write-read-race-with-multiple-rings.patch.
- Delete
  patches.fixes/drm-i915-correctly-restore-fences-with-objects-attac.patch.
- Delete
  patches.suse/suse-hv-Drivers-hv-balloon-Do-not-post-pressure-status-if-in.patch.
- Delete
  patches.suse/suse-hv-Drivers-hv-balloon-Fix-a-bug-in-the-hot-add-code.patch.
- commit 4e0ffc2
* Tue Jul 30 2013 jslaby@suse.cz
- Delete patches.drivers/elousb.patch.
- Delete patches.kernel.org/patch-3.10.1-2.
  They are both obsolete.
- commit e924b54
* Mon Jul 29 2013 jeffm@suse.com
- Update to 3.11-rc3.
- Eliminated 3 patches.
- commit c0a4742
* Mon Jul 29 2013 jslaby@suse.cz
- Linux 3.10.4.
- Refresh patches.suse/no-frame-pointer-select.
- commit d58862b
* Fri Jul 26 2013 jslaby@suse.cz
- Linux 3.10.3 (bnc#802347 bnc#830492).
- Delete
  patches.fixes/drm-i915-Only-clear-write-domains-after-a-successful.patch.
- Delete
  patches.fixes/drm-nouveau-use-vmalloc-for-pgt-allocation.patch.
- Delete
  patches.kernel.org/revert-cpufreq-Fix-cpufreq-regression-after-suspend-.patch.
- commit ec6c1d9
* Thu Jul 25 2013 jeffm@suse.com
- btrfs: check index in extent_buffer_page.
- commit 15eacb9
* Thu Jul 25 2013 jdelvare@suse.de
- Hu, OK, RapidIO can't be fully modularized on PPC (yet.)
- commit 4c2611f
* Thu Jul 25 2013 jdelvare@suse.de
- Update config files: build RapidIO support as modules
- commit 1c6c425
* Thu Jul 25 2013 jeffm@suse.com
- rpm/kernel-binary.spec.in: Obsolete microcode_ctl
  The kernel can request CPU microcode itself now and microcode_ctl is
  no longer required.
- commit 43e5ff5
* Thu Jul 25 2013 jeffm@suse.com
- config: enable early CPU microcode loading.
- commit 0911270
* Wed Jul 24 2013 jeffm@suse.com
- btrfs: fall back to global reservation when removing subvolumes.
- commit 026dc43
* Wed Jul 24 2013 jslaby@suse.cz
- drm/i915: correctly restore fences with objects attached
  (bnc#830492).
- commit 49a8c47
* Tue Jul 23 2013 jeffm@suse.com
- config: disable USB_CHIPIDEA
- commit 00cdcf9
* Tue Jul 23 2013 jeffm@suse.com
- Refresh patches.suse/dmraid45-api-updates.
- commit 8e1fa8b
* Tue Jul 23 2013 jeffm@suse.com
- Refresh patches.suse/ovl05-overlay-filesystem.patch.
- commit 27c899f
* Tue Jul 23 2013 jeffm@suse.com
- Update to 3.11-rc2.
- Eliminated 1 patch.
- commit f6f5941
* Mon Jul 22 2013 jslaby@suse.cz
- Refresh
  patches.arch/arm-xen-0001-arm-introduce-psci_smp_ops.patch.
- Refresh
  patches.arch/arm-xen-0002-ARM-Enable-selection-of-SMP-operations-at-boot-time.patch.
  Update usptream status.
- commit 17cddd7
* Mon Jul 22 2013 jslaby@suse.cz
- Linux 3.10.2.
- Delete
  patches.arch/arm-xen-0003-ARM-let-the-ASID-allocator-handle-suspended-animatio.patch.
- Delete
  patches.arch/arm-xen-0004-ARM-prevent-risks-of-out-of-bound-access-in-ASID-all.patch.
- Delete
  patches.arch/arm-xen-0005-ARM-Cortex-A15-fix-erratum-798181-implementation.patch.
- commit 16a6c33
* Mon Jul 22 2013 jslaby@suse.cz
- drm/i915: Only clear write-domains after a successful wait-seqno
  (bnc#830492).
- drm/i915: Fix write-read race with multiple rings (bnc#830492).
- commit d76b800
* Fri Jul 19 2013 ohering@suse.de
- Drivers: hv: balloon: Do not post pressure status if interrupted
  (bnc#829539).
- Drivers: hv: balloon: Fix a bug in the hot-add code
  (bnc#829539).
- Drivers: hv: util: Fix a bug in version negotiation code for
  util services (bnc#828714).
- commit 0cd5432
* Thu Jul 18 2013 jbeulich@suse.com
- Refresh patches.xen/xen3-patch-3.7 (bnc#804198).
- commit 123639e
* Tue Jul 16 2013 jslaby@suse.cz
- Refresh patches.drivers/elousb.patch.
- commit abd0978
* Tue Jul 16 2013 jslaby@suse.cz
- drm/nouveau: use vmalloc for pgt allocation (bnc#802347).
- commit 114f846
* Tue Jul 16 2013 jeffm@suse.com
- Updated patch-mainline headers.
- commit ba04848
* Tue Jul 16 2013 jeffm@suse.com
- Update to 3.10-rc1.
- Eliminated 13 patches.
- Xen needs updating and is disabled.
- commit 8ffe6ba
* Tue Jul 16 2013 jeffm@suse.com
- config: revert NO_HZ_FULL=y to NO_HZ_IDLE=y (bnc#826946)
  NO_HZ_FULL mode was introduced in v3.10 but still has some
  problems to be worked out. Most notably are issues with
  CPU accounting and how it interacts with power states.
  We'll re-enable it when it's been proven to be stable.
- commit 80c46a2
* Mon Jul 15 2013 jbeulich@suse.com
- Refresh Xen patches (bnc#814211, bnc#826374).
- commit 56bb9c2
* Mon Jul 15 2013 jslaby@suse.cz
- Revert "cpufreq: Fix cpufreq regression after suspend/resume".
- commit 3bcd588
* Sun Jul 14 2013 jslaby@suse.cz
- Linux 3.10.1.
- commit 062e800
* Mon Jul  8 2013 mmarek@suse.cz
- Require 14GB of free space in the buildservice
- commit e7a8371
* Mon Jul  8 2013 jdelvare@suse.de
- patches.suse/ida-remove-warning-dump-stack.patch: Add upstream commit ID
- commit 4fa2dc2
* Sat Jul  6 2013 agraf@suse.de
- ARM: Enable xen for lpae target
- arm: introduce psci_smp_ops.
- ARM: Enable selection of SMP operations at boot time.
- ARM: let the ASID allocator handle suspended animation.
- ARM: prevent risks of out-of-bound access in ASID allocator.
- ARM: Cortex-A15: fix erratum 798181 implementation.
- xen/arm: disable cpuidle when linux is running as dom0.
- arm: choose debug/uncompress.h include when uncompress debug
  is disabled.
- xen/arm: enable PV control for ARM.
- Update config files.
- Refresh patches.xen/xen3-fixup-xen.
- commit 5c7a1e8
* Fri Jul  5 2013 agraf@suse.de
- MMC: Exynos: Add module alias for dw mmc.
- commit 182d5ca
* Wed Jul  3 2013 agraf@suse.de
- ARM: Enable Arndale board with LPAE config
- ARM: EXYNOS: Set 64-bit DMA mask for EXYNOS5250.
- usb: phy: Fix phy-samsung-usb when built as module.
- USB: ehci-s5p: Fix phy reset.
- ARM: Update config files: Make LPAE Exynos only until Multiarch comes
- commit c521db7
* Tue Jul  2 2013 jbeulich@suse.com
- Update Xen patches to 3.10-final.
- commit c5ad3f9
* Mon Jul  1 2013 jeffm@suse.com
- Update to 3.10-final.
- commit f080c74
* Sat Jun 29 2013 dmueller@suse.com
- arm: cubox, use timer initialization directly in the machine descriptor
  Now that the only field in struct sys_timer is .init, delete the struct,
  and replace the machine descriptor .timer field with the
  initialization function itself.
- commit d522780
* Sat Jun 29 2013 dmueller@suse.com
- arm: add and reenable armv6hl
  We've recently decided to remove the softfp
  targets from the openSUSE ARM portfolio. Add
  a armv6hl default kernel flavor and remove
  traces of armv5tel.
- commit 51c5edf
* Fri Jun 28 2013 jslaby@suse.cz
- Linux 3.9.8.
- commit f3348a8
* Thu Jun 27 2013 mszeredi@suse.cz
- Refresh patches.suse/ovl02-vfs-export-do_splice_direct-to-modules.patch.
- Refresh patches.suse/ovl05-overlay-filesystem.patch.
- commit 0e47df9
* Thu Jun 27 2013 mszeredi@suse.cz
- Revert "overlayfs: api: do_splice_direct has changed."
  This reverts commit 6cbfbd0e38cefde22aef0daf8be435a26aa840f7.
  This does not work as new_file->f_pos will not get updated so the file position
  will never advance.
- commit 93bc660
* Thu Jun 27 2013 jeffm@suse.com
- overlayfs: api: do_splice_direct has changed.
- commit 6cbfbd0
* Thu Jun 27 2013 guillaume.gardet@oliseo.fr
- arm: build lpae kernel as zImage
- commit d8f6242
* Wed Jun 26 2013 jeffm@suse.com
- Update to 3.10-rc7.
- Eliminated 1 patch.
- commit 888aa58
* Wed Jun 26 2013 dmueller@suse.com
- arm: fix cubox build by reverting removal of mach-types
- commit ff0165e
* Fri Jun 21 2013 jbeulich@suse.com
- Update Xen patches to 3.10-rc6 and c/s 1235.
- commit 20cc894
* Thu Jun 20 2013 jslaby@suse.cz
- Linux 3.9.7.
- Update config files.
- commit fccf19c
* Mon Jun 17 2013 jeffm@suse.com
- config: update vanilla configs for -rc6.
- commit ca41cec
* Mon Jun 17 2013 jeffm@suse.com
- Update to 3.10-rc6.
- commit dbed8c7
* Thu Jun 13 2013 jslaby@suse.cz
- Linux 3.9.6.
- Refresh patches.xen/xen3-patch-3.8.
- commit 8ead728
* Tue Jun 11 2013 dmueller@suse.com
- arm: topology: export cpu_topology
- commit e3dca27
* Mon Jun 10 2013 dmueller@suse.com
- Update and reenable armv7hl configs
- commit 2d22236
* Mon Jun 10 2013 jeffm@suse.com
- Update to 3.10-rc5.
- commit 1ce1338
* Mon Jun 10 2013 schwab@suse.de
- Update arm64/default and reenable it
- commit 4d0acbd
* Sun Jun  9 2013 jslaby@suse.cz
- Linux 3.9.5.
- Refresh patches.xen/xen3-fixup-xen.
- Refresh patches.xen/xen3-patch-2.6.39.
- Delete
  patches.fixes/reiserfs-fix-deadlock-with-nfs-racing-on-create-lookup.
- commit 08531e3
* Wed Jun  5 2013 jeffm@suse.com
- powerpc: add missing include to book3s_xics.c.
- commit fc06ef7
* Wed Jun  5 2013 jbeulich@suse.com
- Update Xen patches to 3.10-rc4.
- use vCPU time info registration to support vread_pvclock().
- Delete patches.xen/xen-netback-nr-irqs.
- config.conf: Re-enable Xen flavors.
- Update x86 config files.
- commit 4967b19
* Wed Jun  5 2013 jbeulich@suse.com
- Refresh and re-enable patches.arch/x86_64-unwind-annotations.
- commit 8f640b2
* Wed Jun  5 2013 mszeredi@suse.cz
- Refreshed overlayfs patches
- commit 0c856a9
* Mon Jun  3 2013 jeffm@suse.com
- Update to 3.10-rc4.
- Eliminated 4 patches.
- commit b3d0118
* Mon Jun  3 2013 jeffm@suse.com
- vtime: Use consistent clocks among nohz accounting.
- commit 731983f
* Fri May 31 2013 jeffm@suse.com
- reiserfs: fix spurious multiple-fill in reiserfs_readdir_dentry
  (bnc#822722).
- commit 244eade
* Fri May 31 2013 jeffm@suse.com
- reiserfs: fix problems with chowning setuid file w/ xattrs
  (bnc#790920).
- commit 951bebc
* Fri May 31 2013 jeffm@suse.com
- iscsi-target: fix heap buffer overflow on error (CVE-2013-2850,
  bnc#821560).
- commit 0799911
* Wed May 29 2013 jdelvare@suse.de
- Update config files: Modularize HID drivers
  Modularize all HID drivers which can easily be. Some couldn't due to
  weird Kconfig dependencies.
- commit 02ccd70
* Wed May 29 2013 jdelvare@suse.de
- Update config files: disable RADIO_SI476X
  RADIO_SI476X selects SND_SOC_SI476X, which depends on SND_SOC which we do
  not have.
- commit e75c4a8
* Tue May 28 2013 jeffm@suse.com
- Update to 3.10-rc3.
- 2 patches eliminated.
- commit b74ef38
* Fri May 24 2013 jslaby@suse.cz
- Linux 3.9.4.
- Delete
  patches.kernel.org/x86-Fix-bit-corruption-at-CPU-resume-time.patch.
- commit 51bf0ff
* Wed May 22 2013 jslaby@suse.cz
- Refresh
  patches.fixes/misdn-add-support-for-group-membership-check.
  Let's use the new UID/GID API.
- commit 17413bd
* Wed May 22 2013 jeffm@suse.com
- Remove unused 3.9-stable patches.
- commit d28ac96
* Wed May 22 2013 jslaby@suse.cz
- x86: Fix bit corruption at CPU resume time.
- commit 06ad9d8
* Wed May 22 2013 jeffm@suse.com
- config: remove sparc64 configs
  The sparc64 configs have been completely unmaintained for two years.
  If someone wants to resurrect support, we'll accept patches.
- commit 17364b5
* Wed May 22 2013 jeffm@suse.com
- sparc64: revert accidental changes during the 3.9-rc2 update
- commit b120c5a
* Wed May 22 2013 schwab@suse.de
- Update group-source-files.pl to handle symlink to directory
  Also add arch/[^/]+/boot/dts/include/dt-bindings to the list of devel
  files and avoid listing README.SUSE twice.
- commit af248e4
* Tue May 21 2013 jeffm@suse.com
- Update to 3.10-rc2.
- commit e454a38
* Mon May 20 2013 jslaby@suse.cz
- Linux 3.9.3.
- Update config files.
- Refresh patches.xen/xen3-patch-2.6.21.
- Refresh patches.xen/xen3-patch-2.6.24.
- Refresh patches.xen/xen3-patch-2.6.36.
- commit 00c4cdd
* Fri May 17 2013 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Avoid duplicates in the certifiate list.
- commit 9d687ad
* Fri May 17 2013 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Do an exit 0 at the end of each scriptlet
  (bnc#809617).
- commit 7d1a48f
* Thu May 16 2013 mmarek@suse.cz
- rpm/config.sh: Use openSUSE:Factory:{ARM,PowerPC}
  The openSUSE:Factory/ports repository does not work.
- commit 756ee56
* Thu May 16 2013 jdelvare@suse.de
- Update config files: CONFIG_ZSMALLOC=y
  Zsmalloc support can no longer be built as a module, so change
  CONFIG_ZSMALLOC=m to =y in all configuration files to fix the build.
- commit 861551b
* Tue May 14 2013 jeffm@suse.com
- Update to 3.10-rc1.
- Eliminated 10 patches.
- Xen is disabled.
- ARM configs are disabled pending updates.
- In-kernel Bootsplash has been removed.
- EXT4 rich acls are re-enabled after having the index officially reserved.
- commit 0ead2af
* Tue May 14 2013 jdelvare@suse.de
- Change CONFIG_OF_MDIO from y to m as needed
  Fix build after my previous commit, OF_MDIO depends on PHYLIB so when
  turning the latter into a module I should have done so with the former
  as well.
- commit 7e7365d
* Tue May 14 2013 jdelvare@suse.de
- Update config files : build PHYLIB as a module.
  All but armv7hl/cubox: make PHYLIB modular. Most systems don't
  need it, and it registers a mdio_bus driver. As a side effect,
  we have to disable PHY emulation support, as it is only availble
  when PHYLIB is built-in. This driver is rather weird anyway and
  hopefully no system we want to support needs it, so it should be
  OK.
  - CONFIG_PHYLIB=m
  - CONFIG_FIXED_PHY=n
- commit 49e25f5
* Sun May 12 2013 jslaby@suse.cz
- Linux 3.9.2.
- commit 7bb3aa9
* Fri May 10 2013 jbeulich@suse.com
- Update Xen patches to 3.9.1 and c/s 1231.
- commit 0eb4d0d
* Wed May  8 2013 jslaby@suse.cz
- Linux 3.9.1.
- Delete patches.arch/arm-highbank-sata.patch.
- commit 733bf04
* Wed May  8 2013 jslaby@suse.cz
- Refresh patches.rpmify/ptp-pch-depends-on-x86.
  Update upstream status -- it was rejected.
- commit 4173967
* Wed May  8 2013 neilb@suse.de
- Delete
  patches.fixes/nfsd-06-sunrpc-cache-retry-cache-lookups-that-return-ETIMEDO.patch.
  Patchset went upstream around about
  commit f16b6e8d838b2e2bb4561201311c66ac02ad67df
  in a form that didn't need this patch.
- commit 226d6be
* Wed May  8 2013 neilb@suse.de
- Delete patches.fixes/nfs-connect-timeout.
  Problem fixed upstream by
  commit 3ed5e2a2c394df4e03a680842c2d07a8680f133b
  Author: Trond Myklebust <Trond.Myklebust@netapp.com>
  Date:   Mon Mar 4 17:29:33 2013 -0500
    SUNRPC: Report network/connection errors correctly for SOFTCONN rpc tasks
- commit afa0a59
* Tue May  7 2013 dmueller@suse.com
- Fix -devel package for armv7hl
  armv7hl kernel flavors in the non-multiplatform configuration
  (which is the default for our openSUSE 12.3 release), needs
  more header files from the machine specific directories to
  be included in kernel-devel.
- commit 882120e
* Tue May  7 2013 jslaby@suse.cz
- Delete patches.fixes/nfs-adaptive-readdir-plus.
  Superseded by d69ee9b85541a69a1092f5da675bd23256dc62af.
- commit f35dac6
* Tue May  7 2013 jslaby@suse.cz
- Delete
  patches.fixes/fs-partitions-efi-c-corrupted-guid-partition-tables-can-cause-kernel-oops.
  Superseded by 3eb8e74ec72736b9b9d728bad30484ec89c91dde.
- commit 7838036
* Tue May  7 2013 jslaby@suse.cz
- Delete
  patches.fixes/ia64-configure-HAVE_UNSTABLE_SCHED_CLOCK-for-SGI_SN.patch.
  Superseded by 0773a6cf673316440999752e23f8c3d4f85e48b9.
- commit 36f8ff4
* Mon May  6 2013 jeffm@suse.com
- config.conf: disable s390 support for openSUSE kernels
  There is no community project to build openSUSE on s390 so we don't need
  to waste resources building the kernel for it.
- commit 5e6ccae
* Mon May  6 2013 jdelvare@suse.de
- S390: Disable CONFIG_PHYLIB on 32-bit kernels
  libphy depends on irq code which is only available on 64-bit S390,
  so disable it on 32-bit kernels.
- commit dd79db9
* Sun May  5 2013 jdelvare@suse.de
- idr: Print a stack dump after ida_remove warning
  (http://lists.opensuse.org/opensuse-kernel/2013-04/msg00102.html).
- commit 4c487a5
* Sun May  5 2013 jdelvare@suse.de
- Update config files: enable CC_STACKPROTECTOR
  All other major Linux distributions are building their kernel
  with -fstack-protector, so do the same. See the discussion at:
  http://lists.opensuse.org/opensuse-kernel/2012-06/msg00088.html
  http://lists.opensuse.org/opensuse-kernel/2012-07/msg00000.html
  http://lists.opensuse.org/opensuse-kernel/2013-05/msg00013.html
  - CONFIG_CC_STACKPROTECTOR=y
- commit fc6f988
* Sat May  4 2013 mmarek@suse.cz
- rpm/config.sh: Drop the ARM repository in Kernel:HEAD
  Use the "ports" repository of openSUSE:Factory instead.
- commit 6fc0bd5
* Fri May  3 2013 mmarek@suse.cz
- rpm/mkspec: Stop generating the get_release_number.sh file
  It was only needed for the old KOTD.
- commit ee71b69
* Thu May  2 2013 mmarek@suse.cz
- rpm/kernel-spec-macros: Properly handle KOTD release numbers with
  .g<commit> suffix
- commit ccb20c3
* Thu May  2 2013 mmarek@suse.cz
- rpm/kernel-spec-macros: Drop the %%release_num macro
  We no longer put the -rcX tag into the release string.
- commit b88e78f
* Tue Apr 30 2013 jeffm@suse.de
- Update to 3.9-final.
- commit b4b0bc4
* Mon Apr 29 2013 agraf@suse.de
- Fix highbank sata proc_name.
- commit 1c2686d
* Mon Apr 29 2013 jslaby@suse.cz
- TTY: fix atime/mtime regression (bnc#815745).
- commit 5e42670
* Fri Apr 26 2013 jbeulich@suse.com
- Update Xen patches to 3.9-rc8 and c/s 1229.
- commit dd1fbd8
* Fri Apr 26 2013 jslaby@suse.cz
- efi: Export efi_query_variable_store() for efivars.ko
  (bnc#815170).
- commit 02dfd8e
* Fri Apr 26 2013 jslaby@suse.cz
- Update config files.
- commit 25b8212
* Fri Apr 26 2013 jslaby@suse.cz
- x86/Kconfig: Make EFI select UCS2_STRING (bnc#815170).
- Refresh patches.xen/xen-x86-EFI.
- Refresh patches.xen/xen3-auto-xen-kconfig.diff.
- commit ae13122
* Fri Apr 26 2013 jslaby@suse.cz
- Linux 3.8.9.
- commit 3f8cfc6
* Wed Apr 24 2013 jeffm@suse.com
- config: disable SCSI_UFSHCD on s390/x
  It depends on PCI and can be re-enabled when PCI is enabled
  on s390/x. I expect eventually another module will be added to use
  a different bus technology so adding a depends PCI on SCSI_UFSHCD
  won't really help.
- commit 754e58e
* Wed Apr 24 2013 jeffm@suse.com
- patches.arch/ppc-prom-nodisplay.patch: Fix build failure.
  Commit 3bf3dbf8 (Update to 3.9-rc2) missed removing an
  instance of the now-gone RELOC macro, causing build failures.
- commit 674c7b1
* Wed Apr 24 2013 jeffm@suse.com
- Update to 3.9-rc8.
  Eliminated 2 patches.
- commit a86daba
* Wed Apr 24 2013 mmarek@suse.cz
- rpm/macros.kernel-source: Fix the -c option if -n is not given
- commit d704806
* Wed Apr 24 2013 jslaby@suse.cz
- x86,efi: Implement efi_no_storage_paranoia parameter
  (bnc#815170).
- efi: Distinguish between "remaining space" and actually used
  space (bnc#815170).
- x86,efi: Check max_size only if it is non-zero (bnc#815170).
- efi: Pass boot services variable info to runtime code
  (bnc#815170).
- Move utf16 functions to kernel core and rename (bnc#815170).
- x86, efivars: firmware bug workarounds should be in platform
  code (bnc#815170).
- commit e166324
* Thu Apr 18 2013 mmarek@suse.cz
- Remove set -x and set +e statements in KMP scripts
- commit 5575c3c
* Wed Apr 17 2013 jslaby@suse.cz
- Linux 3.8.8.
- commit 193f348
* Fri Apr 12 2013 agraf@suse.de
- cpuidle: calxeda: disable power gating by default.
- commit 1f54900
* Fri Apr 12 2013 jslaby@suse.cz
- Linux 3.8.7.
- Refresh patches.xen/pci-guestdev.
- Delete patches.arch/arm-fix-build-ux500-module.diff.
- commit 9785c05
* Thu Apr 11 2013 sleep_walker@suse.cz
- Enable FRAMEBUFFER_CONSOLE_ROTATION in our kernels
  More and more monitors have insane aspect ratio and can be better used when
  rotated. This may help when X.org is not running and for boot.
- commit f592a19
* Tue Apr  9 2013 jeffm@suse.com
- Refresh patches.xen/xen3-patch-3.9-rc5.
  Previous commit removed a move of a variable declaration to an ifdef section.
- commit 372aad5
* Tue Apr  9 2013 jeffm@suse.com
- Update to 3.9-rc6.
  Eliminated 1 patch.
- commit 68d380d
* Tue Apr  9 2013 agraf@suse.de
- Refresh patches.arch/arm-fec.patch.
- commit 41b3194
* Tue Apr  9 2013 agraf@suse.de
- ARM: cache-l2x0: fix masking of RTL revision numbering and
  set_debug init.
- commit bd5dc17
* Mon Apr  8 2013 tiwai@suse.de
- Refresh patches.suse/SUSE-bootsplash.
  Fix bootsplash breakage due to stable fix (bnc#813963)
- commit 5d7fc50
* Mon Apr  8 2013 agraf@suse.de
- ARM: Exynos: Update config files: Use DRM instead of FB
- commit 7e7c136
* Sun Apr  7 2013 agraf@suse.de
- ARM: DMA: PL330: Add check if device tree compatible.
- commit 73c94ff
* Sun Apr  7 2013 agraf@suse.de
- ARM: exynos: only use device tree when it exists.
- commit afed1f3
* Sun Apr  7 2013 agraf@suse.de
- rpm/package-descriptions: add lpae config for ARM
- ARM: Update config files (fix default, split out lpae).
- ARM: xen: Add missing define.
- config.conf: add lpae config for ARM
- rpm/package-descriptions: add lpae config for ARM
- commit 958fe54
* Fri Apr  5 2013 jslaby@suse.cz
- Linux 3.8.6.
- Refresh patches.xen/xen3-fixup-xen.
- Refresh patches.xen/xen3-patch-3.1.
- Refresh patches.xen/xen3-patch-3.7.
- commit 713918b
* Fri Apr  5 2013 jbeulich@suse.com
- Update Xen patches to 3.9-rc5.
- config.conf: Re-enable Xen configs.
- Update config files.
- commit 0100be6
* Fri Apr  5 2013 jdelvare@suse.de
- Update config files: enable ViperBoard drivers
  All kernels which include core (MFD) support for the ViperBoard
  should also include the actual drivers for its functions:
  - CONFIG_I2C_VIPERBOARD=m
  - CONFIG_GPIO_VIPERBOARD=m
- commit 688764f
* Fri Apr  5 2013 jdelvare@suse.de
- Update config files: disable UCB1400 on all but ARM
  Currently UCB1400 is only used on ARM OMAP systems, and part of the
  code is dead code that can't even be modularized.
  - CONFIG_UCB1400_CORE=n
  - CONFIG_TOUCHSCREEN_UCB1400=n
  - CONFIG_GPIO_UCB1400=n
- commit c81a0de
* Thu Apr  4 2013 jslaby@suse.cz
- drm/nouveau: Fix typo in init_idx_addr_latched() (bnc#800686).
- commit 6c8af4a
* Wed Apr  3 2013 jeffm@suse.com
- Update to 3.9-rc5.
  EFI_VARS_PSTORE is disabled. It is potentially useful but can brick
  certain models of notebooks. Until it's been confirmed as safe, we
  should keep this disabled.
- commit 7fd0ea3
* Sat Mar 30 2013 jdelvare@suse.de
- Update config files: Build DSA drivers as modules
  DSA drivers can be built as modules since kernel v3.3, so do that:
  - CONFIG_NET_DSA=m
  - CONFIG_NET_DSA_MV88E6XXX=m
  - CONFIG_NET_DSA_MV88E6060=m
  - CONFIG_NET_DSA_MV88E6131=m
  - CONFIG_NET_DSA_MV88E6123_61_65=m
- commit ab03c84
* Fri Mar 29 2013 jdelvare@suse.de
- Update config file config/sparc64/default: drop X86-only GPIO drivers
- commit 931180e
* Fri Mar 29 2013 jeffm@suse.com
- config: enable GPIO_[PS]CH, disable INTEL_MID_DMAC
- commit 46bdeb9
* Fri Mar 29 2013 jdelvare@suse.de
- Update config files: CONFIG_I2C_COMPAT
  Disable compatibility with lm-sensors <= 3.1.1, version 3.1.2 was
  released 3 years ago.
- commit c1b3c2d
* Thu Mar 28 2013 jslaby@suse.cz
- Linux 3.8.5 (bnc#808829,CVE-2013-0913).
- Delete
  patches.drivers/drm-i915-bounds-check-execbuffer-relocation-count.
- Update config files.
- commit acb103a
* Wed Mar 27 2013 mmarek@suse.cz
- rpm/kernel-cert-subpackage: Fix description and summary.
- commit a4cd5e1
* Tue Mar 26 2013 agraf@suse.de
- Delete config/armv7hl/u8500.
- commit b9fe3d9
* Mon Mar 25 2013 jeffm@suse.com
- Updated to 3.9-rc4.
  Eliminated 2 patches.
- commit 894fec7
* Sat Mar 23 2013 jslaby@suse.cz
- rpm/config.sh: build against 12.3
- commit 20fc41c
* Sat Mar 23 2013 jslaby@suse.cz
- Linux 3.8.4.
- commit a14294f
* Thu Mar 21 2013 agraf@suse.de
- SMDKV310: Fix compilation.
- commit cf345eb
* Thu Mar 21 2013 agraf@suse.de
- ARM: FEC: Fix module compilation.
- ARM: kvm: fix IOMMU dependency check.
- omap3isp: fix miscompile.
- VT8500: fix miscompile in clk driver.
- config.conf: Remove imx51 and omap2plus, reenable arm
- Update config files.
- Delete config/armv7hl/imx51.
- Delete config/armv7hl/omap2plus.
- commit 7d60e2d
* Mon Mar 18 2013 jeffm@suse.com
- Update to 3.9-rc3.
- 2 patches were eliminated
  CONFIG_EXPERIMENTAL was eliminated, so I've updated the Xen patches for
  that. DMRAID45 and Rich ACLs also needed updating.
- commit 228c5dd
* Mon Mar 18 2013 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Fix sed command with multiple certificates
- commit 59405a2
* Fri Mar 15 2013 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Install the used certificates below
  /etc/uefi/certs (fate#314507).
- commit 19b4300
* Fri Mar 15 2013 mmarek@suse.cz
- rpm/kernel-cert-subpackage: Make the template work with multiple
  certificates.
- commit 3bf5898
* Fri Mar 15 2013 jslaby@suse.cz
- Linux 3.8.3 (bnc#804367 bnc#806966).
- Refresh patches.xen/xen3-fixup-xen.
- Refresh patches.xen/xen3-patch-2.6.23.
- Refresh patches.xen/xen3-patch-2.6.34.
- Delete
  patches.fixes/e1000e-fix-pci-device-enable-counter-balance.patch.
- Delete
  patches.fixes/revert-USB-EHCI-remove-ASS-PSS-polling-timeout.patch.
- Delete
  patches.suse/suse-hv-Drivers-scsi-storvsc-Initialize-the-sglist.patch.
- commit 1ca6928
* Thu Mar 14 2013 jeffm@suse.com
- Updated to 3.9-rc2.
- Eliminated 52 patches.
- Xen is disabled.
- ARM configs need updating and are disabled.
- commit 3bf3dbf
* Thu Mar 14 2013 jeffm@suse.com
- Updated Patch-mainline headers for HyperV patches.
- commit 2e0d7a5
* Thu Mar 14 2013 jeffm@suse.com
- supported-flag: clean up patches and merge into one
  The config option is renamed to CONFIG_SUSE_KERNEL_SUPPORTED and
  the text has been updated to reflect that SUSE is no longer a
  unit of Novell.
- commit 7761647
* Thu Mar 14 2013 tiwai@suse.de
- drm/i915: bounds check execbuffer relocation count
  (bnc#808829,CVE-2013-0913).
- commit 72202f0
* Wed Mar 13 2013 jeffm@suse.com
- config: disabled CONFIG_SPI and CONFIG_IIO on non-ARM architectures
  These devices are found almost entirely on embedded platforms and
  end up adding hundreds of drivers for hardware that most users won't
  have. On systems using them, they are more likely to be embedded
  systems that should probably have a specialized kernel anyway.
- commit 33d736f
* Wed Mar 13 2013 jeffm@suse.com
- Updated patch-mainline for patches.rpmify/apm-honor-config_apm_cpu_idle-n
- commit 1008856
* Tue Mar 12 2013 ohering@suse.de
- Drivers: hv: balloon: Do not request completion notification
  (fate#314663).
- commit 6b249cb
* Tue Mar 12 2013 jslaby@suse.cz
- e1000e: fix runtime power management transitions (bnc#806966).
- e1000e: fix pci-device enable-counter balance (bnc#806966).
- e1000e: fix accessing to suspended device (bnc#806966).
- commit 48a333b
* Mon Mar 11 2013 rw@suse.de
- supported.conf: add drivers/s390/block/scm_block
  (fate#314095, bnc#807237)
- commit 09836cb
* Sun Mar 10 2013 mmarek@suse.cz
- KMP: Add -c <cert> option to the %%kernel_module_package macro
  This produces an -ueficert subpackage that imports the certificate into
  the MokList when installed (fate#314511)
- commit d8f177c
* Fri Mar  8 2013 mmarek@suse.cz
- KMP: Add the -kmp suffix inside the subpackage definition
- commit 7c6395d
* Tue Mar  5 2013 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Do not require new mkinitrd in kernel-vanilla
- commit 26431d8
* Tue Mar  5 2013 jbeulich@suse.com
- Update Xen patches to 3.8.2 and c/s 1226.
- commit eee1405
* Tue Mar  5 2013 jdelvare@suse.de
- gpio-ich: Fix ichx_gpio_check_available() return what callers expect.
  Conflicts:
  series.conf
- commit 051149b
* Mon Mar  4 2013 tiwai@suse.de
- Refresh patches.suse/SUSE-bootsplash-mgadrmfb-workaround.
  Add the same w/a for ast and cirrus KMS, too (bnc#806990).
- commit 0422575
* Mon Mar  4 2013 jslaby@suse.cz
- Linux 3.8.2 (bnc#802153).
- Delete patches.arch/009-acpi_initrd_override_tables.patch.
- Delete
  patches.fixes/quota-autoload-the-quota_v2-module-for-qfmt_vfs_v1-quota-format.
- commit 3611cf6
* Fri Mar  1 2013 tiwai@suse.de
- Fix broken VT1 output with mgadrmfb (bnc#806990).
- commit 0934989
* Fri Mar  1 2013 jslaby@suse.cz
- PCI/PM: Clear state_saved during suspend (bnc#806966).
- commit cdd289b
* Thu Feb 28 2013 agraf@suse.de
- Add AArch64 support
- commit 09220ef
* Thu Feb 28 2013 jslaby@suse.cz
- Update config files.
- commit 9ad7236
* Thu Feb 28 2013 jslaby@suse.cz
- Linux 3.8.1.
- Refresh patches.xen/xen3-patch-2.6.31.
- Delete
  patches.suse/suse-hv-register-clocksource-only-if-its-adverti.patch.
- commit 0c01cac
* Thu Feb 28 2013 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Copy kernel signing changes from 12.3 to the
  packaging branch
- commit 59d2acf
* Thu Feb 28 2013 mmarek@suse.cz
- rpm/kernel-binary.spec.in: 'bc' is required since v3.9-rc1
- commit 4a9a926
* Thu Feb 28 2013 mmarek@suse.cz
- Copy packaging changes from master to the packaging branch
- commit dd227e2
* Wed Feb 27 2013 jslaby@suse.cz
- Refresh patches.drivers/elousb.patch.
- commit 4687d79
* Tue Feb 26 2013 agraf@suse.de
- ARM: Update config files: Drop mmap min addr to at most 32k
- commit db497a6
* Tue Feb 26 2013 agraf@suse.de
- ARM: default: Update config file: Compile RTC drivers =y
- commit dfccf37
* Tue Feb 26 2013 aj@suse.de
- Mention Linux 3.x as well
- commit 3d86a6c
* Mon Feb 25 2013 jslaby@suse.cz
- TTY: do not update atime/mtime on read/write (bnc#797175
  CVE-2013-0160).
- commit 821f03c
* Thu Feb 21 2013 ohering@suse.de
- Drivers: hv: balloon: Execute hot-add code in a separate context
  (fate#314663).
- Drivers: hv: balloon: Execute balloon inflation in a separate
  context (fate#314663).
- commit 2c746be
* Thu Feb 21 2013 ohering@suse.de
- Drivers: hv: vmbus: Handle channel rescind message correctly
  (fate#314665).
- commit bd98cf4
* Thu Feb 21 2013 jbeulich@suse.com
- update Xen patches to 3.8 final and c/s 1224
- add symbols to hypercall stubs
- commit 88b4228
* Wed Feb 20 2013 jslaby@suse.cz
- Delete patches.drivers/x86_acpi_cpufreq_autoload.patch.
  Substituted by efa17194581bdfca0986dabc178908bd7c21ba00 upstream.
- commit a060c45
* Wed Feb 20 2013 trenn@suse.de
- Disable efi pstore by default (bnc#804482).
- commit 5986b31
* Wed Feb 20 2013 jeffm@suse.com
- config: disable ACPI_BGRT on ia64
  bgrt_image is only defined on x86.
- commit e252f7f
* Wed Feb 20 2013 jeffm@suse.com
- config: disable ACPI_INITRD_TABLE_OVERRIDE on ia64
  It requires max_low_pfn_mapped, which is x86 only.
- commit 9901a64
* Wed Feb 20 2013 jeffm@suse.com
- Update to 3.8-final.
- commit c9c649c
* Tue Feb 19 2013 jslaby@suse.cz
- Revert "USB: EHCI: remove ASS/PSS polling timeout" (bnc#804367).
- commit 83cb8d1
* Tue Feb 19 2013 jslaby@suse.cz
- drm/nouveau/vm: fix memory corruption when pgt allocation fails
  (bnc#802347).
- commit e224175
* Sun Feb 17 2013 jslaby@suse.cz
- Linux 3.7.9.
- commit c6b8d60
* Sun Feb 17 2013 ohering@suse.de
- video: Add Hyper-V Synthetic Video Frame Buffer Driver
- Update config files.
- commit f3ee42f
* Thu Feb 14 2013 jslaby@suse.cz
- Linux 3.7.8.
- Delete
  patches.fixes/revert-iwlwifi-fix-the-reclaimed-packet-tracking-upon-flush-queue.
- commit 59f2b98
* Wed Feb 13 2013 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Only sign the x86_64 kernels
- commit d55bd47
* Tue Feb 12 2013 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Add needssslcertforbuild, so that the project
  certificate is available when signing the kernel.
- commit f4f3306
* Tue Feb 12 2013 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Sign vmlinuz in the buildservice
- commit b13c7b4
* Mon Feb 11 2013 jslaby@suse.cz
- Linux 3.7.7.
- commit 67ebb60
* Mon Feb 11 2013 ohering@suse.de
- Drivers: hv: balloon: Prevent the host from ballooning the
  guest too low.
- Drivers: hv: balloon: Add a parameter to delay pressure
  reporting.
- commit 77e8d63
* Mon Feb 11 2013 ohering@suse.de
- Drivers: hv: balloon: Prevent the host from ballooning the
  guest too low.
- Drivers: hv: balloon: Add a parameter to delay pressure
  reporting.
- Drivers: hv: balloon: Make adjustments to the pressure report.
- commit 31ecddc
* Mon Feb 11 2013 jeffm@suse.de
- Update to 3.8-rc7.
  Eliminated 1 patch.
- commit 82fec2f
* Wed Feb  6 2013 jbeulich@suse.com
- Refresh.
- commit 1001e0b
* Wed Feb  6 2013 jbeulich@suse.com
- xen-pciback: rate limit error messages from
  xen_pcibk_enable_msi{,x}() (CVE-2013-0231 XSA-43 bnc#801178).
- Update Xen patches to 3.8-rc6 and c/s 1222.
- commit e6b44d3
* Wed Feb  6 2013 ohering@suse.de
- Drivers: hv: Bind all vmbus interrupts to the boot CPU
  (fate#314665).
- Drivers: hv: vmbus: Use the new infrastructure for delivering
  VMBUS interrupts (fate#314665).
- Delete patches.suse/suse-hv-fate314665-force-win2008.patch.
- commit 444d3d1
* Tue Feb  5 2013 ohering@suse.de
- X86: Handle Hyper-V vmbus interrupts as special hypervisor
  interrupts (fate#314665).
- hv: deliver vmbus interrupts to all vcpus
- Refresh patches.xen/xen3-patch-2.6.23.
- Refresh patches.xen/xen3-patch-2.6.27.
- commit 3a682f8
* Tue Feb  5 2013 ohering@suse.de
- X86: Add a check to catch Xen emulation of Hyper-V
  (fate#314665).
- commit 3f41db6
* Tue Feb  5 2013 jeffm@suse.com
- quota: autoload the quota_v2 module for QFMT_VFS_V1 quota format
  (bnc#802153).
- commit bdeb401
* Tue Feb  5 2013 jeffm@suse.com
- quota: autoload the quota_v2 module for QFMT_VFS_V1 quota format
  (bnc#802153).
- commit ecd48c7
* Tue Feb  5 2013 jbeulich@suse.com
- Update Xen patches to 3.7.6 and c/s 1222.
- xen-pciback: rate limit error messages from
  xen_pcibk_enable_msi{,x}() (CVE-2013-0231 XSA-43 bnc#801178).
- commit ffecceb
* Mon Feb  4 2013 jeffm@suse.com
- Revert "iwlwifi: fix the reclaimed packet tracking upon
  flush queue".
- commit 8f91af5
* Mon Feb  4 2013 jslaby@suse.cz
- Linux 3.7.6 (bnc#800701).
- Update config files.
- Delete patches.drivers/alsa-hda-001-Fix-non-snoop-page-handling.
- commit bcd9d42
* Sun Feb  3 2013 jeffm@suse.com
- Update to 3.8-rc6.
- commit afa3941
* Thu Jan 31 2013 tiwai@suse.de
- drm/cirrus: Use 16bpp as default (bnc#799216).
- drm/cirrus: Correct register values for 16bpp (bnc#799216).
  Conflicts:
  series.conf
- drm/cirrus: Use 16bpp as default (bnc#799216).
- drm/cirrus: Correct register values for 16bpp (bnc#799216).
- commit 86d0404
* Wed Jan 30 2013 ohering@suse.de
- scsi: storvsc: avoid usage of WRITE_SAME.
- Drivers: scsi: storvsc: Initialize the sglist.
- Drivers: hv: Execute shutdown in a thread context.
- commit 133b379
* Wed Jan 30 2013 jeffm@suse.com
- ptp: PTP_1588_CLOCK_PCH depends on x86.
- commit 99fbe25
* Wed Jan 30 2013 ohering@suse.de
- scsi: storvsc: avoid usage of WRITE_SAME.
- Drivers: scsi: storvsc: Initialize the sglist.
- Drivers: hv: Execute shutdown in a thread context.
- commit 1b6d4ef
* Wed Jan 30 2013 jeffm@suse.com
- config: disable CONFIG_MVMDIO on s390/x
  CONFIG_MVMDIO is only used by a few ARM SoCs, so we don't need to build
  it everywhere else. Not sure why s390 got skipped in the previous commit.
- commit f0b494a
* Wed Jan 30 2013 jeffm@suse.com
- config: disable CONFIG_MVMDIO on non-ARM arches
  CONFIG_MVMDIO is only used by a few ARM SoCs, so we don't need to build
  it everywhere else.
- commit 2bf6fb1
* Wed Jan 30 2013 jbeulich@suse.com
- Update Xen patches to 3.8-rc5 and c/s 1218.
- commit 36b617a
* Wed Jan 30 2013 tiwai@suse.de
- ALSA: hda - Fix non-snoop page handling (bnc#800701).
- commit 9969bb3
* Wed Jan 30 2013 jbeulich@suse.com
- Comment out patches.drivers/x86_acpi_cpufreq_autoload.patch as
  conflicting with 3.8.-rc5. Refresh patches.xen/xen3-auto-common.diff.
- commit 737e677
* Wed Jan 30 2013 jeffm@suse.com
- Update to 3.8-rc5.
  Eliminated 4 patches.
- commit e8b3b53
* Tue Jan 29 2013 jeffm@suse.com
- sysctl: Fixed vm.dirty_ratio sysctl name for desktop flavors
- commit 3d41dfd
* Mon Jan 28 2013 mmarek@suse.cz
- rpm/config.sh: Update buildservice projects.
- commit d9a9e6d
* Mon Jan 28 2013 mmarek@suse.cz
- rpm/config.sh: Update $IBS_PROJECT_ARM
- commit 3e873c5
* Mon Jan 28 2013 ohering@suse.de
- Drivers: hv: balloon: Make adjustments to the pressure report.
- commit 2ae0171
* Mon Jan 28 2013 ohering@suse.de
- Drivers: hv: balloon: Make adjustments to the pressure report.
- commit 3c7bac7
* Mon Jan 28 2013 jslaby@suse.cz
- Linux 3.7.5 (bnc#756085).
- Refresh patches.suse/stack-unwind.
- Refresh patches.xen/xen3-auto-common.diff.
- Delete patches.drivers/x86_acpi_cpufreq_autoload.patch.
- commit 236d8d7
* Thu Jan 24 2013 jeffm@suse.com
- Updated to 3.8-rc2.
  Eliminated 1 patch.
- commit e466109
* Tue Jan 22 2013 jslaby@suse.cz
- Linux 3.7.4.
- commit 7f4460e
* Mon Jan 21 2013 agraf@suse.de
- ARM: fix imx usb driver build issue.
- commit 4f2d1a3
* Sun Jan 20 2013 agraf@suse.de
- Delete config/armv7hl/highbank (included in default now)
- commit c0e90d8
* Sun Jan 20 2013 agraf@suse.de
- ARM: Default: Update config file (enable multiarch)
- commit 8a5d039
* Sat Jan 19 2013 agraf@suse.de
- Delete config/armv7hl/tegra
- commit b63dfab
* Sat Jan 19 2013 agraf@suse.de
- ARM: IMX51: Update config file (enable drm)
- commit 8e98c0c
* Sat Jan 19 2013 agraf@suse.de
- ARM: IX51: Update config file (enable drm)
- commit e2d2446
* Sat Jan 19 2013 agraf@suse.de
- ARM: Exynos: Update config file
- commit e83ffaa
* Sat Jan 19 2013 agraf@suse.de
- ARM: Exynos: Update config file (set drm+video =y)
- commit 7904ca2
* Sat Jan 19 2013 agraf@suse.de
- staging/omapdrm: garbage collect OMAP_DSS_DISPLAY_SUSPENDED.
- OMAP: Fix missing usb.h include.
- OMAP: Fix missing cm3xxx.h include.
- commit c3f4aa6
* Sat Jan 19 2013 agraf@suse.de
- ARM: use zImage for "default" flavor
- commit 0d71552
* Thu Jan 17 2013 jslaby@suse.cz
- Linux 3.7.3.
- Refresh
  patches.suse/0016-ext4-Implement-richacl-support-in-ext4.patch.
- commit 9f86828
* Tue Jan 15 2013 dmueller@suse.com
- Fix build of omap2plus kernel
- commit 48790e9
* Tue Jan 15 2013 dmueller@suse.com
- reenable armv7hl configs
- commit a996303
* Tue Jan 15 2013 ohering@suse.de
- hyperv: force vmbus interrupts to cpu 0. (instead of forcing ws2008 during vmbus negotiation.)
- hyperv: force vmbus interrupts to cpu 0.
  (instead of forcing ws2008 during vmbus negotiation.)
- commit a5459d4
* Tue Jan 15 2013 ohering@suse.de
- x86: Hyper-V: register clocksource only if its advertised (bnc#792500).
- x86: Hyper-V: register clocksource only if its advertised
  (bnc#792500).
- commit 2c26304
* Tue Jan 15 2013 jbeulich@suse.com
- Update Xen patches to 3.8-rc3.
- config.conf: Re-enable Xen flavors.
- Update x86 config files.
- commit 4de2e49
* Fri Jan 11 2013 jslaby@suse.cz
- Linux 3.7.2.
- commit d62551b
* Thu Jan 10 2013 jeffm@suse.com
- Update to 3.8-rc3.
- commit 7ce28dd
* Thu Jan 10 2013 dmueller@suse.com
- config: update armv5tel config for 3.8-rc2
- commit df5a66e
* Mon Jan  7 2013 ohering@suse.de
- hyperv: force ws2008 during vmbus negotiation.
- force ws2008 during vmbus negotiation.
- commit b93e5a2
* Fri Jan  4 2013 jeffm@suse.com
- staging/sb105x: remove asm/segment.h dependency.
- commit 473afce
* Thu Jan  3 2013 jeffm@suse.com
- config: Update vanilla configs.
- commit 0d2a457
* Thu Jan  3 2013 jeffm@suse.com
- Updated to 3.8-rc2.
- commit 79d206a
* Thu Dec 27 2012 jslaby@suse.cz
- drm/i915: TLB invalidation with MI_FLUSH_DW requires a post-sync
  op v3 (bnc#795963).
- commit db55aa9
* Tue Dec 25 2012 jeffm@suse.com
- Updated to 3.8-rc1.
- Eliminated 13 patches.
- Xen is disabled.
- ARM configs need updating.
- ext4 richacls are disabled until the upstream index can be reserved.
- commit a952042
* Tue Dec 18 2012 jbeulich@suse.com
- Update Xen patches to 3.7.1 and c/s 1213.
- commit 756a7d4
* Mon Dec 17 2012 jslaby@suse.cz
- Linux 3.7.1.
- Delete patches.rpmify/ezusb-add-dependency-to-usb.
- commit 7c5f8a6
* Wed Dec 12 2012 jeffm@suse.com
- ezusb: add dependency to USB.
  This prevents build failures by making it depend on the value of CONFIG_USB.
  Commit 36e0f0bd did this for architectures other than ARM manually.
- commit b89db5d
* Tue Dec 11 2012 ohering@suse.de
- Drivers: hv: balloon: Fix a memory leak.
- commit 26cdad5
* Tue Dec 11 2012 jeffm@suse.com
- Update to 3.7-final.
- commit 1771a73
* Tue Dec 11 2012 ohering@suse.de
- Update patch headers for fate314663 and fate314665 changes
- commit 44044f1
* Tue Dec 11 2012 jack@suse.cz
- Disable ext3 driver in all kernels and use ext4 driver instead. Eventually
  ext3 will be removed upstream so let's do the transition.
- commit dadc8ea
* Mon Dec 10 2012 jslaby@suse.cz
- Linux 3.6.10.
- Refresh patches.xen/xen3-patch-3.4.
- commit cfa7c19
* Fri Dec  7 2012 guillaume.gardet@oliseo.fr
- Update omap2plus (armv7) config: Enable TWL* USB drivers
- commit 28c09f5
* Fri Dec  7 2012 jbeulich@suse.com
- rpm/kernel-binary.spec.in: Conditionalize the use of vmlinuz instead
  of bzImage for Xen flavors.
- commit 713a73c
* Fri Dec  7 2012 jbeulich@suse.com
- Update Xen config files (enable XEN_BZIMAGE and EFI_STUB).
- commit d1ec1be
* Fri Dec  7 2012 jbeulich@suse.com
- Update Xen patches to 3.7-rc7 and c/s 1211.
- allow non-pv-ops kernel to be built as bzImage.
- commit 2a7feb8
* Thu Dec  6 2012 ohering@suse.de
- fate#314663 hyper-v memory ballooning support
- mm: Export a function to get vm committed memory.
- Drivers: hv: Add Hyper-V balloon driver.
- Drivers: hv: balloon: Fix a bug in the definition of struct
  dm_info_msg.
- Update config files.
  fate#314665 hyper-v: Update the Vmbus protocol
- Drivers: hv: Implement routines for read side signaling
  optimization.
- Drivers: hv: Add state to manage batched reading.
- Drivers: hv: Turn off batched reading for util drivers.
- Drivers: hv: Optimize signaling in the read path.
- Drivers: hv: Optimize the signaling on the write path.
- Drivers: hv: Get rid of hv_get_ringbuffer_interrupt_mask().
- Drivers: hv: Support handling multiple VMBUS versions.
- Drivers: hv: Update the ring buffer structure to match win8
  functionality.
- Drivers: hv: Extend/modify vmbus_channel_offer_channel for
  win7 and beyond.
- Drivers: hv: Save and export negotiated vmbus version.
- Drivers: hv: Change the signature for hv_signal_event().
- Drivers: hv: Change the signature of vmbus_set_event().
- Drivers: hv: Move vmbus version definitions to hyperv.h.
- Drivers: hv: Manage signaling state on a per-connection basis.
- Drivers: hv: Cleanup vmbus_set_event() to support win7 and
  beyond.
- Drivers: hv: Setup a mapping for Hyper-V's notion cpu ID.
- Drivers: hv: Add state to manage incoming channel interrupt
  load.
- Drivers: hv: Modify the interrupt handling code to support
  win8 and beyond.
- Drivers: hv: Add code to distribute channel interrupt load.
- Drivers: hv: Get rid of the unused global signaling state.
- Drivers: hv: Get rid of unnecessary request for offers.
- Drivers: hv: Manage event tasklets on per-cpu basis.
- Drivers: hv: Handle vmbus interrupts concurrently on all cpus.
- Drivers: hv: Add a check to deal with spurious interrupts.
- Drivers: hv: Enable protocol negotiation with win8 hosts.
- Drivers: hv: Implement flow management on the send side.
- Drivers: hv: Capture the host build information.
- Drivers: hv: Cleanup and consolidate reporting of build/version
  info.
- commit 4fccd03
* Wed Dec  5 2012 jeffm@suse.com
- Update to 3.7-rc8.
- Delete patches.rpmify/net-fix-build-failure-in-xilinx.
- commit 76b3d92
* Tue Dec  4 2012 ohering@suse.de
- add splash=black option to bootsplash code,
  to keep a black background, useful for remote access to VMs
  (bnc#773487)
- commit c060ae1
* Tue Dec  4 2012 jslaby@suse.cz
- Linux 3.6.9.
- commit 9966a2e
* Tue Nov 27 2012 jslaby@suse.cz
- Linux 3.6.8.
- commit 6fb821e
* Fri Nov 23 2012 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Do not remove fillup from the buildsystem
  (bnc#781327)
- commit 841d864
* Tue Nov 20 2012 jeffm@suse.com
- net: fix build failure in xilinx.
- commit 28be621
* Tue Nov 20 2012 sjayaraman@suse.com
- Update config files. Enable CONFIG_SMB2 to 'y'.
- commit 25bdfaf
* Mon Nov 19 2012 jeffm@suse.com
- Update to 3.7-rc6.
- commit daac70a
* Sun Nov 18 2012 jslaby@suse.cz
- rpm/config.sh: build against 12.2
  It should fix the firmware build problem.
- commit d760411
* Sun Nov 18 2012 jslaby@suse.cz
- Linux 3.6.7.
- commit 2bc3b09
* Fri Nov 16 2012 mmarek@suse.cz
- rpm/config.sh: Set projects for ARM
- commit 55bac79
* Thu Nov 15 2012 jbeulich@suse.com
- Refresh patches.xen/xen3-patch-3.7-rc3 (fix FPU handling related
  crash in context switch code).
- commit bb1d12d
* Wed Nov 14 2012 jbeulich@novell.com
- Update to 3.7-rc5.
- Update Xen patches additionally to c/s 1204:
- commit d5de9cf
* Tue Nov  6 2012 jeffm@suse.com
- config: sync x86_64 configs for NR_UARTS
  This commit sets both CONFIG_SERIAL_8250_RUNTIME_UARTS and
  CONFIG_SERIAL_8250_NR_UARTS to 32.
- commit ddf88e6
* Tue Nov  6 2012 jeffm@suse.com
- Delete patches.arch/s390-remove-kvm-para.patch.
- commit f759e1e
* Tue Nov  6 2012 jeffm@suse.com
- config: sync ppc64 configs for LIB80211, NET_SDA_MV*
  This commit changes the following options to be modular:
  LIB80211
  NET_DSA_MV88E6XXX
  NET_DSA_MV88E6060
- commit caa5a52
* Tue Nov  6 2012 jeffm@suse.com
- config: sync ppc64/debug with ppc64/default
  The debug config should be identical to default with the exception of
  the debug options. This patch brings ppc64/debug in line with ppc64/default
  with the exception of a few things that are modular in debug that should
  also be modular in default.
- commit b981fcd
* Tue Nov  6 2012 jeffm@suse.com
- config: sync kvm options between ppc64 flavors.
- commit 8a389d5
* Tue Nov  6 2012 jeffm@suse.com
- config: disable HW_RANDOM_AMD on ppc64
  This chip is only on AMD hardware and an old ppc64 eval board. We can skip
  it on ppc64.
- commit 03001a4
* Tue Nov  6 2012 jeffm@suse.com
- config: Eliminate unused ppc/ppc64 configs.
  The history of the ppc/ppc64 configs is a convoluted one that started
  before the kernel source could support multiple machine types with a
  single image and before there was a usable 64-bit userspace.
  In the subsequent years, the powerpc code has been unified and we've
  released a 64-bit powerpc userspace. The "default" and "ppc64" configs
  on ppc64 are essentially identical and just waste space. The "ppc64"
  config on 32-bit ppc address a long since unnecessary corner case. Users
  who still want a 32-bit userspace with a 64-bit kernel can install and
  update it themselves using the 64-bit repository like i386/x86_64 users
  can do.
  This commit can be summarized thusly:
  rm config/ppc/ppc64
  rm config/ppc/ps3 (already unused)
  mv config/ppc64/ppc64 config/ppc64/default
- commit a9cc3d5
* Tue Nov  6 2012 guillaume.gardet@oliseo.fr
- Add kernel-versatile description
- commit 5424cf2
* Tue Nov  6 2012 guillaume.gardet@oliseo.fr
- Enable armv5 in arch-symbols
- commit 401de81
* Tue Nov  6 2012 jslaby@suse.cz
- Linux 3.6.6.
- commit 9d1e567
* Mon Nov  5 2012 jeffm@suse.com
- config: sync vanilla flavor with default flavor for each platform
  The vanilla configs have drifted away from the default configuration
  for each platform. This patch brings them back in sync.
- commit 8d4661f
* Mon Nov  5 2012 jeffm@suse.com
- config: -ec2 still had CONFIG_ENTERPRISE_SUPPORT enabled.
- commit 9907c37
* Mon Nov  5 2012 jeffm@suse.com
- Updated to 3.7-rc4.
  Eliminated 1 patch.
- commit 5168053
* Mon Nov  5 2012 jbeulich@novell.com
- Refresh patches.xen/xen3-patch-3.7-rc3 (make "unmodified drivers" build again).
- commit 5feff7e
* Fri Nov  2 2012 jbeulich@novell.com
- Update Xen patches to 3.7-rc3 and c/s 1202.
- extend base interfaces to support multi-page rings for
  frontend/backend communication.
- blkback: allow using multiple page frontend communication ring.
- blkfront: allow using multiple page backend communication ring.
- ACPI: Store valid ACPI tables passed via early initrd in
  reserved memblock areas.
- ACPI: Fix build when disabled.
- ACPI: Cleanup acpi_initrd_override declaration and remove
  ifdefs.
- config.conf: Re-enable Xen configs.
- Update x86 config files.
- Delete patches.xen/xen3-acpi_override_2_2.patch.
- commit f042386
* Fri Nov  2 2012 jbeulich@novell.com
- Refresh patches.xen/xen-x86-EFI (fix build after update to 3.4.17).
- commit 483130a
* Wed Oct 31 2012 jslaby@suse.cz
- Linux 3.6.5.
- commit cefb3b0
* Wed Oct 31 2012 guillaume.gardet@oliseo.fr
- Add support to armv5 versatile kernel
- commit 99d34f3
* Wed Oct 31 2012 jeffm@suse.com
- Update to 3.7-rc3.
- commit 48e5027
* Tue Oct 30 2012 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Require coreutils in kernel-*-devel (bnc#783615)
- commit 2520563
* Tue Oct 30 2012 agraf@suse.de
- ARM: Update config files: Fix vexpress (default) config
- commit be072b4
* Sun Oct 28 2012 jslaby@suse.cz
- Linux 3.6.4.
- commit 0a37c3b
* Thu Oct 25 2012 hare@suse.de
- Fixup kvm for s390.
- commit 503388b
* Tue Oct 23 2012 agraf@suse.de
- ARM: Update config files: Exynos: Disable 8bit sd mode to support wifi
- commit 336ead7
* Mon Oct 22 2012 agraf@suse.de
- Revert "disable non-compiling irrelevant I2C module"
- commit d5a21c5
* Mon Oct 22 2012 agraf@suse.de
- thermal: exynos: Fix wrong name of MODULE_DEVICE_TABLE.
- commit 8e108ab
* Mon Oct 22 2012 agraf@suse.de
- ARM: Update config files.
- commit 565b450
* Mon Oct 22 2012 agraf@suse.de
- Refresh patches.arch/arm-exynos-nosparse.patch.
- commit 55fbf60
* Mon Oct 22 2012 agraf@suse.de
- ARM: Update config files.
- commit 118f2f9
* Mon Oct 22 2012 agraf@suse.de
- ARM: Exynos: Fix MMC driver
- ARM: Exynos: Update configs
- commit 37a1704
* Mon Oct 22 2012 jeffm@suse.com
- config: change CONFIG_USB_EZUSB_FX2 to module
- commit 36e0f0b
* Mon Oct 22 2012 jeffm@suse.com
- Actually use kthread_run in crasher.ko.
  The previous commit was incomplete.
- commit b8b35ae
* Mon Oct 22 2012 jeffm@suse.com
- crasher: use kthread_run() instead of kernel_thread().
  Linux 3.7-rc2 no longer exports kernel_thread on all architectures.
- commit f17d925
* Mon Oct 22 2012 jeffm@suse.com
- Updated to 3.7-rc2.
- commit e00a663
* Mon Oct 22 2012 agraf@suse.de
- ARM: Update config files: Exynos: Enable gfx and highmem
- commit e8b3bd9
* Sun Oct 21 2012 jslaby@suse.cz
- Linux 3.6.3.
- Refresh patches.xen/xen3-fixup-xen.
- Refresh patches.xen/xen3-patch-2.6.23.
- Refresh patches.xen/xen3-patch-3.2.
- Refresh patches.xen/xen3-patch-3.6.
- Delete patches.fixes/hv-storvsc-reset-wait.patch.
- Delete
  patches.rpmify/x86-kbuild-archscripts-depends-on-scripts_basic.
- commit cfee26b
* Thu Oct 18 2012 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Use a macro instead of /etc/IGNORE-KABI-BADNESS
- commit 19e7e54
* Thu Oct 18 2012 agraf@suse.de
- ARM: Update config files: Fix exynos uart
- commit 1b4b5c5
* Thu Oct 18 2012 trenn@suse.de
- Cleanup ACPI table override patches with latest x86-tip commits
  and proper git-xy: meta tags:
- lib: Add early cpio decoder.
- x86, acpi: Introduce x86 arch specific arch_reserve_mem_area()
  for e820 handling.
- ACPI: Store valid ACPI tables passed via early initrd in
  reserved memblock areas.
- ACPI: Implement physical address table override.
- ACPI: Create acpi_table_taint() function to avoid code
  duplication.
- ACPI: Document ACPI table overriding via initrd.
- ACPI: Fix build when disabled.
- X86 ACPI: Use #ifdef not #if for CONFIG_X86 check.
- ACPI: Overriding ACPI tables via initrd only works with
  an initrd.
- ACPI: Cleanup acpi_initrd_override declaration and remove
  ifdefs.
- Delete patches.arch/acpi_fix_custom_method_acc.patch.
- Delete patches.arch/acpi_override_2_2.patch.
- Delete patches.arch/acpi_override_documentation.
- Delete patches.arch/acpi_override_introduce_taint_func.patch.
- Delete patches.arch/acpi_physical_override.patch.
- Delete patches.arch/lib_earlycpio.patch.
- Delete patches.arch/x86_introduce_reserve_mem_area.patch.
- commit c45da8f
* Wed Oct 17 2012 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Also check for /etc/IGNORE-KABI-BADNESS file
  This allows to control the kabi checker from outside of the package.
- commit 0a0900c
* Wed Oct 17 2012 jeffm@suse.com
- Update to 3.7-rc1.
- Eliminated 38 patches.
- Xen is disabled.
- ARM configs need updating.
- Module signing is disabled until the build infrastructure can support it.
- commit fce087a
* Sat Oct 13 2012 jslaby@suse.cz
- x86/kbuild: archscripts depends on scripts_basic.
- commit 007718d
* Sat Oct 13 2012 jslaby@suse.cz
- Linux 3.6.2.
- commit 798d597
* Thu Oct 11 2012 guillaume.gardet@oliseo.fr
- ARM (omap2plus) : re-enable OMAP DRM module
- commit 379798d
* Wed Oct 10 2012 jslaby@suse.cz
- Delete
  patches.suse/msft-hv-0394-tools-hv-Fix-file-handle-leak.patch.
- Delete
  patches.suse/msft-hv-0395-tools-hv-Fix-exit-error-code.patch.
- Delete
  patches.suse/msft-hv-0396-tools-hv-Check-for-read-write-errors.patch.
  These are in 3.6.1.
- commit 2a321c4
* Mon Oct  8 2012 dmueller@suse.com
- Remove noncompiling modules
- commit b7cdd5a
* Mon Oct  8 2012 agraf@suse.de
- ARM: Update config files: Exynos: Enable serial console
- commit a8d41ec
* Sun Oct  7 2012 jslaby@suse.cz
- Linux 3.6.1.
- commit 1f7626a
* Thu Oct  4 2012 ohering@suse.de
- rpm/kernel-binary.spec.in: enable Conflicts for
  apparmor, udev and lvm2 also for vanilla kernel
- commit a24206f
* Thu Oct  4 2012 ohering@suse.de
- rpm/kernel-binary.spec.in: add Conflicht: hyper-v < 4
  to make sure the daemon is in sync with the kernel
  (bnc#770763 , fate#314441)
- commit 86f9ba3
* Thu Oct  4 2012 jbeulich@novell.com
- Update Xen patches to 3.6-final and c/s 1197.
- Update Xen config files.
- commit 338be2c
* Thu Oct  4 2012 ohering@suse.de
- Hyper-V KVP IP injection (fate#31441)
- hyperv: Add comments for the extended buffer after RNDIS message.
- Drivers: hv: Cleanup the guest ID computation.
- Drivers: hv: vmbus: Use the standard format string to format
  GUIDs.
- Drivers: hv: Add KVP definitions for IP address injection.
- Drivers: hv: kvp: Cleanup error handling in KVP.
- Drivers: hv: Explicitly size elements of protocol structures.
- Drivers: hv: kvp: Support the new IP injection messages.
- Tools: hv: Prepare to expand kvp_get_ip_address() functionality.
- Tools: hv: Further refactor kvp_get_ip_address().
- Tools: hv: Gather address family information.
- Tools: hv: Gather subnet information.
- Tools: hv: Represent the ipv6 mask using CIDR notation.
- Tools: hv: Gather ipv[4,6] gateway information.
- hv: fail the probing immediately when we are not in hyperv
  platform.
- hv: vmbus_drv: detect hyperv through x86_hyper.
- Tools: hv: Get rid of some unused variables.
- Tools: hv: Correctly type string variables.
- Tools: hv: Add an example script to retrieve DNS entries.
- Tools: hv: Gather DNS information.
- Drivers: hv: kvp: Copy the address family information.
- Tools: hv: Add an example script to retrieve dhcp state.
- Tools: hv: Gather DHCP information.
- Tools: hv: Add an example script to configure an interface.
- Tools: hv: Implement the KVP verb - KVP_OP_SET_IP_INFO.
- Tools: hv: Rename the function kvp_get_ip_address().
- Tools: hv: Implement the KVP verb - KVP_OP_GET_IP_INFO.
- tools/hv: Fix file handle leak.
- tools/hv: Fix exit() error code.
- tools/hv: Check for read/write errors.
- tools/hv: Parse /etc/os-release.
- hyperv: Fix the max_xfer_size in RNDIS initialization.
- hyperv: Fix the missing return value in
  rndis_filter_set_packet_filter().
- hyperv: Fix page buffer handling in rndis_filter_send_request().
- hyperv: Remove extra allocated space for recv_pkt_list elements.
- hyperv: Report actual status in receive completion packet.
- hyperv: Add buffer for extended info after the RNDIS response
  message.
- Delete
  patches.suse/suse-hv-Cleanup-the-guest-ID-computation.patch.
- commit 08d283b
* Mon Oct  1 2012 agraf@suse.de
- ARM: Update config files: Exynos: Disable broken config options
- commit 8d7f8ab
* Mon Oct  1 2012 agraf@suse.de
- ARM: Update config files: Exynos: disable VFIO
- commit 80abd68
* Mon Oct  1 2012 jeffm@suse.com
- Update to 3.6-final.
- commit 6066894
* Sat Sep 29 2012 dmueller@suse.com
- ARM/u5800: Fix build of ux500 driver
- commit 0ea37a0
* Sat Sep 29 2012 dmueller@suse.com
- disable non-compiling irrelevant I2C module
- commit 0ba9bac
* Sat Sep 29 2012 dmueller@suse.com
- ARM/tegra: Remove optional parts to fix build
- commit d729a16
* Sat Sep 29 2012 dmueller@suse.com
- ARM: enable zcache support
- commit 17b147b
* Sat Sep 29 2012 dmueller@suse.com
- ARM/cubox: set cachefilesd to module
- commit c1fb243
* Fri Sep 28 2012 trenn@suse.de
- Remove old patchset to override ACPI tables via initrd.
  Also remove a stale xen patch related to that.
- Delete
  patches.arch/acpi_implement_overriding_of_arbitrary_acpi_tables_via_initrd.patch.
- Delete
  patches.arch/acpica_fix_wrongly_mapped_acpi_table_header_when_overriding_via_initrd.patch.
- Delete
  patches.arch/acpica_introduce_acpi_os_phys_table_override_function.patch.
- Delete
  patches.xen/xen3-acpi_implement_overriding_of_arbitrary_acpi_tables_via_initrd.patch.
- commit dd8f1b0
* Fri Sep 28 2012 trenn@suse.de
- Refresh patches.arch/acpi_override_2_2.patch.
- commit 80dcdb8
* Fri Sep 28 2012 mszeredi@suse.cz
- Update config files to enable building overlayfs as a module.
- commit 42f70e6
* Fri Sep 28 2012 trenn@suse.de
- Update config files.
  Enable ACPI table override capability via initrd for
  all i386/x86_64 flavors:
  +CONFIG_ACPI_INITRD_TABLE_OVERRIDE=y
- commit 08721cc
* Fri Sep 28 2012 trenn@suse.de
- ACPI: Only allow users with CAP_SYS_RAWIO rights to overwrite
  ACPI funcs at runtime.
- ACPI: Document ACPI table overriding via initrd.
- ACPI: Create acpi_table_taint() function to avoid code
  duplication.
- ACPI: Implement physical address table override.
- ACPI: Store valid ACPI tables passed via early initrd in
  reserved memblock areas.
- X86 ACPI: Introduce x86 arch specific arch_reserve_mem_area()
  for e820 handling.
- lib: Add early cpio decoder.
- commit dfdfcd3
* Fri Sep 28 2012 mszeredi@suse.cz
- overlayfs: copy up i_uid/i_gid from the underlying inode.
- ovl: switch to __inode_permission().
- vfs: export __inode_permission() to modules.
- overlayfs: create new inode in ovl_link.
- overlayfs: fix possible leak in ovl_new_inode.
- fs: limit filesystem stacking depth.
- overlay: overlay filesystem documentation.
- overlayfs: implement show_options.
- overlayfs: add statfs support.
- overlay filesystem.
- vfs: introduce clone_private_mount().
- vfs: export do_splice_direct() to modules.
- vfs: add i_op->dentry_open().
- commit f3e02da
* Thu Sep 27 2012 agraf@suse.de
- Update config files: Disable JTAG HVC, when enabled the kernel hangs on access
- commit cdf0705
* Tue Sep 25 2012 jeffm@suse.com
- Update to 3.6-rc7.
  Eliminated one patch.
- commit 91c0ddc
* Tue Sep 25 2012 mmarek@suse.cz
- Delete scripts/config.sh, rpm/config.sh has all the needed information
- commit 06c7ff0
* Mon Sep 24 2012 bpoirier@suse.de
- net: do not disable sg for packets requiring no checksum
  (bnc#774859).
- commit f1a1fe2
* Fri Sep 21 2012 bpoirier@suse.de
- af_netlink: force credentials passing [CVE-2012-3520]
  (bnc#776925 CVE-2012-3520).
  Conflicts:
  series.conf
- commit 644e37d
* Fri Sep 21 2012 jslaby@suse.cz
- cgroup: mark subsystems with broken hierarchy support and
  whine if cgroups are nested for them (bnc#781134).
- commit dbeda53
* Fri Sep 21 2012 bpoirier@suse.de
- tcp: Apply device TSO segment limit earlier (bnc#774523
  CVE-2012-3412).
- sfc: Fix maximum number of TSO segments and minimum TX queue
  size (bnc#774523 CVE-2012-3412).
- net: Allow driver to limit number of GSO segments per skb
  (bnc#774523 CVE-2012-3412).
- commit 1908f74
* Thu Sep 20 2012 jeffm@suse.com
- x86/kbuild: archscripts depends on scripts_basic.
  patches.rpmify/makefile-fix-scripts_basic-archscripts-build-order is
  now obsolete.
- commit 33eb1e6
* Wed Sep 19 2012 jeffm@suse.com
- Makefile: Fix scripts_basic / archscripts build order.
- commit 65590b3
* Wed Sep 19 2012 agraf@suse.de
- Delete patches.arch/arm-phys-offset.patch.
- commit 50837bd
* Mon Sep 17 2012 jeffm@suse.com
- Update to 3.6-rc6.
- Eliminated 1 patch.
  patches.arch/arm-phys-offset.patch needs review.
- commit d6432fe
* Sat Sep 15 2012 jslaby@suse.cz
- rpm/kernel-binary.spec.in: avoid fixdep compilation error
  Let's see if it helps.
- commit c618b7c
* Sat Sep 15 2012 jslaby@suse.cz
- Linux 3.5.4.
- Refresh patches.suse/scsi-error-test-unit-ready-timeout.
- Delete
  patches.fixes/i2c-busses-fix-build-error-if-config_i2c_designware_platform-y-config_i2c_design.
- Update config files.
- commit a925c74
* Tue Sep 11 2012 dmueller@suse.com
- (ARM/tegra) remove non-building module from config
- commit 4cdd491
* Tue Sep 11 2012 jeffm@suse.com
- config: disabled MFD drivers that aren't buildable as modules
  This allows MFD_CORE to be modular on all arch/flavors except for
  ARM and the non-PAE flavors on i386, since it's used with the OLPC XO-1.
- commit ff91de4
* Mon Sep 10 2012 jeffm@suse.com
- Update to 3.6-rc5.
- commit 11b8e7e
* Mon Sep 10 2012 jbeulich@novell.com
- patches.arch/s390-message-catalog.diff: Properly handle pr_cont() and fold
  in the below two trivial fixes.
- Delete patches.arch/s390-message-catalog-fix.diff.
- Delete patches.arch/s390-message-catalog-perl-fix.diff.
- Refresh patches.arch/kmsg-fix-parameter-limitations.
- commit 71b4cc3
* Fri Sep  7 2012 dmueller@suse.com
- fix build of imx51 flavor by removing irrelevant drivers
- commit 7ea6615
* Fri Sep  7 2012 dmueller@suse.com
- remove drivers that do not exist and do not build on ARM (default)
- commit 2319db4
* Thu Sep  6 2012 ohering@suse.de
- Refresh
  patches.suse/suse-hv-identify-virtual-pc-in-ata_piix.patch.
- commit fb4b7f9
* Thu Sep  6 2012 ohering@suse.de
- identify Virtual PC guests in ata_piix (bnc#737532).
- commit 13500ed
* Thu Sep  6 2012 mmarek@suse.cz
- rpm/package-descriptions: Fix typo
- commit c08c34b
* Thu Sep  6 2012 jbeulich@novell.com
- Update Xen patches to 3.6-rc4 and c/s 1188.
- config.conf: Re-enable Xen configs.
- Update x86 config files.
- commit 4cdebd8
* Tue Sep  4 2012 jeffm@suse.com
- Update to 3.6-rc4.
- Eliminated one patch.
- commit 9fe3afb
* Tue Sep  4 2012 mmarek@suse.cz
- Disable CONFIG_KMSG_IDS on s390x, because it is currently broken
- commit c1db24a
* Mon Sep  3 2012 jslaby@suse.cz
- Update config files. (vanilla ones)
- commit ca19bfb
* Fri Aug 31 2012 dmueller@suse.com
- ARM(omap2plus): Remove optional parts that don't compile
- commit 77105c2
* Fri Aug 31 2012 jslaby@suse.cz
- i2c/busses: Fix build error if CONFIG_I2C_DESIGNWARE_PLATFORM=y
  && CONFIG_I2C_DESIGN.
- Delete
  patches.fixes/i2c-busses-fix-build-error-if-config_i2c_designware_platform-y-config_i2c_design.
  Move it to rpmify, so that vanilla builds fine too.
- commit 0217ad5
* Thu Aug 30 2012 agraf@suse.de
- Update config files: Add highbank (forgot in last patch)
- commit e86b000
* Thu Aug 30 2012 agraf@suse.de
- config.conf: Enable ARM
- Update ARM config files.
- Add highbank definition
- commit 835e93d
* Thu Aug 30 2012 mmarek@suse.cz
- rpm/kernel-module-subpackage: Provide name-kmp = %%version in KMPs
  This allows userspace packages to require a specific version of a KMP,
  wothout worrying about the _k<kernel version> suffix.
- commit caaaa9a
* Tue Aug 28 2012 jeffm@suse.com
- config: Update -vanilla for ChipIdea fix
- commit c45f0ac
* Tue Aug 28 2012 jeffm@suse.com
- chipidea: Allow user to select PCI/IMX options.
  This allows us to disable the ChipIdea IMX code on powerpc,
  where it was causing build problems.
- commit 278cad2
* Tue Aug 28 2012 jeffm@suse.com
- config: Disable EXYNOS_VIDEO and HW_RANDOM_EXYNOS on all configs except exynos
  This hardware is only found on the Samsung EXYNOS boards.
- commit 429a008
* Mon Aug 27 2012 jeffm@suse.com
- Revert "clk.h: Fix shim ifdef guard (HAVE_CLK -> COMMON_CLK)."
  This reverts commit 54e1c0025e4757174d8d648e8224bf74009b3c2b.
  The issue is either an incomplete clk API on powerpc or clk_devm needs
  to be made generic. Discussion continues upstream.
- commit 8c9a4e9
* Mon Aug 27 2012 jeffm@suse.com
- clk.h: Fix shim ifdef guard (HAVE_CLK -> COMMON_CLK).
  This fixes the clk_devm_get build failures on ppc.
- commit 54e1c00
* Mon Aug 27 2012 jeffm@suse.com
- Update to 3.6-rc3.
- commit 0a688a0
* Mon Aug 27 2012 jslaby@suse.cz
- Linux 3.5.3.
- commit ffb9fbd
* Tue Aug 21 2012 jeffm@suse.com
- config: update vanilla configs for 3.6-rc2.
- commit e0fa472
* Fri Aug 17 2012 jeffm@suse.com
- Update to 3.6-rc2.
  - Eliminated 1 patch.
- commit 71963b0
* Wed Aug 15 2012 jslaby@suse.cz
- Fuck, this time maybe
- commit 4904750
* Wed Aug 15 2012 jslaby@suse.cz
- Linux 3.5.2.
- commit 2af8a27
* Fri Aug 10 2012 jeffm@suse.com
- printk: Fix calculation of length used to discard records.
- commit cd6596b
* Fri Aug 10 2012 mmarek@suse.cz
- Revert "rpm/config.sh: really build against openSUSE:12.1 also in the ibs"
  This reverts commit daed3d92. SUSE:openSUSE:12.1:Update:Test does not
  exist, which broke automatic builds. scripts/osc_wrapper is now updated
  to fall back to openSUSE.org:$OBS_PROJECT if IBS_PROJECT is not set.
- commit 370c9f4
* Thu Aug  9 2012 jslaby@suse.cz
- rpm/config.sh: really build against openSUSE:12.1 also in the ibs
- commit daed3d9
* Thu Aug  9 2012 jslaby@suse.cz
- ubifs: remove __DATE__ and __TIME__.
- commit 6702208
* Thu Aug  9 2012 jslaby@suse.cz
- Refresh
  patches.drivers/ALSA-hda-Fix-mute-LED-GPIO-setup-for-HP-Mini-210.
  Update git-commit tag.
- commit f3a1eba
* Thu Aug  9 2012 jslaby@suse.cz
- Linux 3.5.1.
- Delete
  patches.drivers/ALSA-hda-Fix-mute-LED-GPIO-initialization-for-IDT-co.
- Delete
  patches.drivers/ALSA-hda-Fix-mute-LED-GPIO-setup-for-HP-Mini-210.
- Delete
  patches.drivers/ALSA-hda-Fix-polarity-of-mute-LED-on-HP-Mini-210.
- commit d21661b
* Thu Aug  9 2012 jeffm@suse.com
- Update to 3.6-rc2. - Eliminated 2 patches.
- commit b073c66
* Thu Aug  9 2012 jeffm@suse.com
- reiserfs: fix deadlock with nfs racing on create/lookup
  (bnc#762693).
- commit 5b2dce3
* Thu Aug  9 2012 mmarek@suse.cz
- Delete patches.suse/s390-Kerntypes.diff until we get an updated version.
- commit 78f2edc
* Thu Aug  9 2012 mmarek@suse.cz
- Disable CONFIG_DRM_NOUVEAU on ia64 due to build errors
- commit 38e08ef
* Wed Aug  8 2012 mmarek@suse.cz
- Update config files to fix build.
- commit 9c9630c
* Wed Aug  8 2012 dmueller@suse.com
- config: enable various ARM errata workarounds to improve stability
- commit 4e28647
* Tue Aug  7 2012 mmarek@suse.cz
- rpm/config.sh: Build against openSUSE:12.1 also in the ibs
- commit 954867f
* Mon Aug  6 2012 tiwai@suse.de
- ASoC: omap: Add missing modules aliases to get sound working
  on omap devices.
- commit cbda3c2
* Fri Aug  3 2012 jeffm@suse.com
- Updated and re-enabled DMRAID45.
- commit 6b8bedd
* Fri Aug  3 2012 jeffm@suse.com
- Updated and re-enabled richacl support.
- commit 001594d
* Fri Aug  3 2012 jeffm@suse.com
- Update to 3.6-rc1.
  - Eliminated 11 patches.
  - Rich ACLs are disabled.
  - Xen is disabled.
  - ARM is disabled.
  - DMRAID45 is disabled.
- commit 5807d6b
* Fri Aug  3 2012 jeffm@suse.com
- i2c/busses: Fix build error if CONFIG_I2C_DESIGNWARE_PLATFORM=y
  && CONFIG_I2C_DESIGN.
- commit 3bec42b
* Fri Aug  3 2012 jeffm@suse.com
- reiserfs: fix deadlocks with quotas.
- commit 77ba55a
* Wed Aug  1 2012 jbeulich@novell.com
- Refresh Xen patches (fixing a major bug in the most recent Xen commit).
- commit 5df2b91
* Wed Aug  1 2012 jbeulich@novell.com
- Refresh patches.suse/stack-unwind (to work with older tool chains).
- commit 30e4ab0
* Tue Jul 31 2012 jeffm@suse.com
- rpm/kernel-binary.spec.in: Add dependency on mkinitrd >= 2.7.1 (bnc#773559).
- commit 2f75710
* Tue Jul 31 2012 tiwai@suse.de
- ALSA: hda - Fix mute-LED GPIO initialization for IDT codecs
  (bnc#772923).
- ALSA: hda - Fix polarity of mute LED on HP Mini 210
  (bnc#772923).
- commit f3c90ee
* Mon Jul 30 2012 jeffm@suse.com
- Update config files: HID_GENERIC=y where USBHID=y (bnc#773559).
  On flavors where USBHID is built-in statically, we want HID_GENERIC to
  be built statically as well. This, notably, includes i386/x86_64's desktop
  flavors.
- commit 6d995bc
* Mon Jul 30 2012 jeffm@suse.com
- Synced configs after commit 940e57e2 (Delete patches.drivers/input-Add-LED-support-to-Synaptics-device.)
- commit 104f550
* Mon Jul 30 2012 dmueller@suse.com
- Enable RTL8150 for omap2plus
  Generic USB Network device that also works fine on ARM, so enable it
- commit 400dcb7
* Mon Jul 30 2012 ohering@suse.de
- Drivers: hv: Cleanup the guest ID computation.
- hyperv: Add a check for ring_size value.
- hyperv: Add error handling to rndis_filter_device_add().
- Drivers: hv: Change the hex constant to a decimal constant.
- hyperv: Add support for setting MAC from within guests.
- commit 73d4430
* Fri Jul 27 2012 trenn@suse.de
- ACPI: Only count valid srat memory structures (bnc#757888).
- ACPI: Untangle a return statement for better readability
  (bnc#757888).
- commit 876d6b9
* Fri Jul 27 2012 tiwai@suse.de
- Refresh patches.suse/SUSE-bootsplash.
  Fix wrong vfree() (bnc#773406)
- commit a637a16
* Thu Jul 26 2012 tiwai@suse.de
- Delete patches.drivers/input-Add-LED-support-to-Synaptics-device.
  This feature was dropped from 12.2/FACTORY packages due to instability
  (bnc#768506,bnc#765524)
- commit 940e57e
* Thu Jul 26 2012 tiwai@suse.de
- ALSA: hda - Fix mute-LED GPIO setup for HP Mini 210
  (bnc#772923).
- commit 0ac6c27
* Thu Jul 26 2012 jeffm@suse.com
- Enabled patches.fixes/brcmsmac-firmware.
- commit 4ed5cb4
* Thu Jul 26 2012 jeffm@suse.com
- brcmsmac: document firmware dependencies (bnc#733148).
- commit f489263
* Wed Jul 25 2012 jbeulich@novell.com
- Update Xen patches to 3.5-final and c/s 1184.
- Delete patches.xen/xen3-apei_allow_drivers_access_nvs_ram.patch.
- commit 341366d
* Tue Jul 24 2012 jeffm@suse.com
- Update to 3.5-final.
  patches.suse/dm-raid45-26-Nov-2009.patch needs updating to new kmsg
  interface but, since powerpc isn't officially supported by opensuse, the
  update can happen later.
- commit fb9c50b
* Mon Jul 23 2012 jbeulich@novell.com
- patches.suse/no-frame-pointer-select: Update mainline tag.
- commit 4e207cd
* Fri Jul 20 2012 jslaby@suse.cz
- Linux 3.4.6.
- patches.xen/xen3-patch-3.3:
- Delete
  patches.fixes/acpica_fix_null_pointer_in_repair_code.patch.
- commit 3689ec0
* Fri Jul 20 2012 dsterba@suse.cz
- btrfs: do not update atime for RO snapshots (FATE#306586).
- commit 2073e27
* Wed Jul 18 2012 ohering@suse.de
- Delete patches.suse/led_classdev.sysfs-name.patch.
  All valid changes in this patch were merged into 2.6.32-rc3
  The remaining change to default-on LED trigger changed the name
  from default-on to default::on, which is wrong.
- commit 13b12c9
* Wed Jul 18 2012 ohering@suse.de
- Delete patches.suse/led_classdev.sysfs-name.patch.
  All valid changes in this patch were merged into 2.6.32-rc3
  The remaining change to default-on LED trigger changed the name
  from default-on to default::on, which is wrong.
- commit a2f36dc
* Tue Jul 17 2012 tiwai@suse.de
- Refresh patches.drivers/input-Add-LED-support-to-Synaptics-device.
  Fix a typo in the capability bit check (bnc#768506).
- commit 66cae25
* Tue Jul 17 2012 jslaby@suse.cz
- Linux 3.4.5.
- Refresh patches.fixes/bridge-module-get-put.patch.
- Delete patches.fixes/acpi_quirk_cover_all_timer_overrides.patch.
- Delete
  patches.fixes/fujitsu_amilo_v2030_timeroverride_quirk.patch.
- Delete
  patches.fixes/mm-correctly-synchronize-rss-counters-at-exit-exec.patch.
- Delete
  patches.fixes/nfs-force-the-legacy-idmapper-to-be-single-threaded.
- Delete
  patches.fixes/udf-Avoid-run-away-loop-when-partition-table-length-.patch.
- Delete patches.fixes/udf-Fortify-loading-of-sparing-table.patch.
- Delete
  patches.fixes/udf-Use-ret-instead-of-abusing-i-in-udf_load_logical.patch.
- commit 5bbda10
* Mon Jul 16 2012 jeffm@suse.com
- Updated to 3.5-rc7.
- Eliminated 1 patch.
- commit 58a8fc5
* Fri Jul 13 2012 neilb@suse.de
- Update config files.
  Updates vanilla config files to include NFS_DEBUG implied by SUNRPC_DEBUG
- commit f36b6ed
* Fri Jul 13 2012 neilb@suse.de
- Update config files.
  Update 'vanilla' configs for SUNRPC_DEBUG
- commit 7749430
* Fri Jul 13 2012 neilb@suse.de
- Update config files.
  Add new option SUNRPC_DEBUG.  This functionality was previously
  always on, and is needed by "rpcdebug" to enable tracing.
  We often ask customers to enable this to analyse NFS issues.
- commit a0aa02e
* Fri Jul 13 2012 neilb@suse.de
- Update config files.
  Add SUNRPC_DEBUG - a new option for functionality that was
  previously always present.
  Without this, "rpcdebug" doesn't work.
  We often request customers enable this to analyse problems.
- commit b4fa24f
* Thu Jul 12 2012 mmarek@suse.cz
- Update vanilla config files.
- commit a0c6b82
* Thu Jul 12 2012 agraf@suse.de
- ARM: Add PM support for OMAP4460 (fixes instability issues)
- commit 9149272
* Tue Jul 10 2012 jeffm@suse.com
- Enable VMWGFX as module (bnc#769534).
  This option affects GNOME performance in VMware virtual machines.
- commit 8442da0
* Tue Jul 10 2012 jeffm@suse.com
- Enable VMWGFX as module (bnc#769534).
  This option affects GNOME performance in VMware virtual machines.
- commit 0998ae0
* Tue Jul 10 2012 agraf@suse.de
- Refresh patches.arch/arm-omap-drm-fix-global-buffer.patch: typo
- commit 65dce23
* Tue Jul 10 2012 agraf@suse.de
- Refresh patches.arch/arm-omap-drm-fix-global-buffer.patch: Fix OMAP3
- commit 6df2baf
* Tue Jul 10 2012 agraf@suse.de
- ARM: OMAP: Update config files: Enable status LED
- commit afc95c8
* Mon Jul  9 2012 jeffm@suse.com
- Updated to 3.5-rc6.
- Eliminated 1 patch.
- commit 93575a7
* Mon Jul  9 2012 jeffm@suse.com
- coretemp-xen: Fix usage of X86_FEATURE_DTS -> X86_FEATURE_DTHERM
  Upstream commit 4ad33411308596f2f918603509729922a1ec4411 renamed _DTS to
  _DTHERM, so fix its usage in the Xen driver.
- commit 1732d37
* Mon Jul  9 2012 sjayaraman@suse.com
- Update config files: CONFIG_CIFS_FSCACHE=y.
- commit 72cd989
* Mon Jul  9 2012 sjayaraman@suse.com
- Update config files: CONFIG_CIFS_FSCACHE=m.
- commit cdced94
* Mon Jul  9 2012 jeffm@suse.com
- Updated to 3.5-rc5.
- Eliminated 2 patches.
- commit ec675c6
* Sat Jul  7 2012 agraf@suse.de
- ARM: OMAP: dss: GLOBAL_BUFFER hack.
- commit d70ee95
* Thu Jul  5 2012 agraf@suse.de
- Update config files: use PR KVM on ppc/ppc64
- commit c902ea5
* Wed Jul  4 2012 hare@suse.de
- mach-dove: define TIMER_PHYS_BASE.
- Update config files.
- commit 0ea0e05
* Wed Jul  4 2012 agraf@suse.de
- Update config files.
- commit 97411e1
* Wed Jul  4 2012 agraf@suse.de
- Remove non-ARM and Samsung specific CMA patches, we only need the framework for OMAP
- commit a9a5b39
* Wed Jul  4 2012 trenn@suse.de
- Fix NULL pointer derference in acpi_ns_check_object_type()
  (kernel bug 44171).
- commit 10f1915
* Wed Jul  4 2012 trenn@suse.de
- Fix NULL pointer derference in acpi_ns_check_object_type()
  (kernel bug 44171).
- commit 36cf667
* Wed Jul  4 2012 trenn@suse.de
- Delete patches.arch/dell_latitude_e6xxx_e5xxx__fix_reboot.patch.
- Delete patches.drivers/apei_allow_drivers_access_nvs_ram.patch.
- commit c6e9e42
* Wed Jul  4 2012 trenn@suse.de
- Delete patches.arch/acpi_fix_fadt_32_bit_zero_length.patch.
- Delete patches.suse/acpi_osi_sle11_ident.patch.
- commit d8799fb
* Tue Jul  3 2012 agraf@suse.de
- Update config files for CMA
- commit 2b3ec9b
* Tue Jul  3 2012 agraf@suse.de
- ARM: backport CMA framework (required for omapdrm)
- commit d0c4392
* Tue Jul  3 2012 jack@suse.cz
- udf: Fortify loading of sparing table (bnc#769784).
- udf: Avoid run away loop when partition table length is
  corrupted (bnc#769784).
- udf: Use 'ret' instead of abusing 'i' in udf_load_logicalvol()
  (bnc#769784).
- commit 48e23e1
* Tue Jul  3 2012 agraf@suse.de
- omap2+: add drm device for the new Xorg driver.
- omap2+: Revert "mmc: omap_hsmmc: Enable Auto CMD12".
- omap2+: Revert "Fix OMAP EHCI suspend/resume failure (i693)".
- omap2+: add drm device for the new Xorg driver.
- commit babe620
* Mon Jul  2 2012 trenn@suse.de
- ACPI: Make acpi_skip_timer_override cover all source_irq==0
  cases (bnc#676068).
- ACPI: Add a quirk for "AMILO PRO V2030" to ignore the timer
  overriding (bnc#676068).
- Refresh patches.xen/xen3-patch-2.6.27.
- commit ce6a9c8
* Mon Jul  2 2012 dsterba@suse.cz
- btrfs: allow cross-subvolume file clone (bnc#698540).
- btrfs: use correct device for maps (bnc#672923 bnc#769545).
- btrfs: allow cross-subvolume file clone (bnc#698540).
- btrfs: use correct device for maps (bnc#672923 bnc#769545).
- commit 25d8571
* Wed Jun 27 2012 jbeulich@novell.com
- Update Xen patches to c/s 1182.
- Update Xen and EC2 config files.
- commit 1f9dec5
* Tue Jun 26 2012 vojtech@suse.com
- Update post.sh to make the RT kernel default in the bootloader
  after installation.
- commit 3c10ce7
* Tue Jun 26 2012 guillaume.gardet@oliseo.fr
- Update omap2plus (ARM) config
- commit 466b846
* Mon Jun 25 2012 jeffm@suse.com
- Updated Patch-mainline for patches.fixes/mm-correctly-synchronize-rss-counters-at-exit-exec.patch.
- commit d022daf
* Mon Jun 25 2012 jeffm@suse.com
- Updated to 3.5-rc4.
- Eliminated 1 patch.
- commit 65cee14
* Mon Jun 25 2012 jeffm@suse.com
- NFS: Force the legacy idmapper to be single threaded
  (bnc#766514).
- commit b73cb98
* Mon Jun 25 2012 jslaby@suse.cz
- Linux 3.4.4.
- Refresh patches.xen/xen3-patch-2.6.35.
- commit 25f83ba
* Sun Jun 24 2012 awafaa@opensuse.org
- Add support for Samsung Exynos SoC
- commit 81fc687
* Sun Jun 24 2012 awafaa@opensuse.org
- Update configs for cubox/default/imx51/tegra/u8500
- commit 65b18f1
* Tue Jun 19 2012 jbeulich@novell.com
- Update Xen patches to 3.5-rc3 and c/s 1182.
- Update x86 config files.
- Delete patches.xen/add-console-use-vt.
- commit d11f278
* Mon Jun 18 2012 jeffm@suse.com
- Fixed up post-3.5-merge conflicts.
- patches.drivers/mach-dove-Fixup-ge00-initialisation.patch.
- patches.drivers/spi-orion-convert-to-new-infrastructure.patch.
- commit 7a3a50c
* Mon Jun 18 2012 jeffm@suse.com
- Updated to 3.5-rc3.
- commit 3ee859e
* Mon Jun 18 2012 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Revert "Add provides and make most obsoletes
  versioned." (commit e3023c7). This change is wrong, the packages have
  their own versioning schemes.
- commit 29957f5
* Mon Jun 18 2012 jbeulich@novell.com
- Delete patches.xen/frontswap-config.
- Delete patches.xen/frontswap-core.
- Delete patches.xen/frontswap-header.
- Delete patches.xen/frontswap-hooks.
- commit cb6120e
* Mon Jun 18 2012 jbeulich@novell.com
- Refresh an re-enable patches.arch/x86_64-unwind-annotations.
- commit 9ed2387
* Sun Jun 17 2012 jslaby@suse.cz
- Linux 3.4.3.
- Delete patches.suse/suse-hv-pata_piix-ignore-disks.patch.
- commit 76639c2
* Fri Jun 15 2012 mhocko@suse.cz
- mm: correctly synchronize rss-counters at exit/exec (bnc#767152).
- commit d161b60
* Thu Jun 14 2012 jeffm@suse.com
- CONFIG_RTC_DRV_CMOS=y on all x86/x86_64 flavors (bnc#755525).
  When rtc_cmos is module, hctosys fails to set the clock on boot, issuing
  ominious error messages to the console.
- commit cddcbe7
* Thu Jun 14 2012 jbeulich@novell.com
- Update x86 config files (ATA_PIIX=m, bnc#766284).
- commit 8677f43
* Thu Jun 14 2012 tiwai@suse.de
- Refresh patches.drivers/input-Add-LED-support-to-Synaptics-device.
  Add product ID 0x84 that may have the LED support (bnc#764339)
- commit 6e5a834
* Wed Jun 13 2012 hare@suse.de
- Rediff patch
- patches.drivers/mach-dove-Fixup-ge00-initialisation.patch:
  Rediff after backport from upstream.
- commit fa58c5e
* Wed Jun 13 2012 hare@suse.de
- Fixup patch to apply
- patches.drivers/spi-orion-convert-to-new-infrastructure.patch
  backported from upstream.
- commit 2507393
* Wed Jun 13 2012 hare@suse.de
- Add SolidRun Cubox configuration
- Update config files.
- Add separate cubox configuration.
- mach-dove: Fixup ge00 initialisation.
- spi-orion: convert to new infrastructure.
- config.conf: Add cubox configuration
- rpm/package-descriptions: Add cubox description
- commit bfddec4
* Mon Jun 11 2012 jeffm@suse.com
- Update to 3.5-rc2.
  - Xen needs update.
  - ARM needs update.
  - Eliminated 13 patches.
- commit 3f461b1
* Sat Jun  9 2012 jslaby@suse.cz
- Linux 3.4.2.
- commit 16fc260
* Fri Jun  8 2012 tiwai@suse.de
- Refresh patches.drivers/input-Add-LED-support-to-Synaptics-device.
  Use depends instead of reverse selection for avoiding the inconsitent
  Kconfig state.
- commit 316d77d
* Wed Jun  6 2012 tiwai@suse.de
- Refresh patches.drivers/input-Add-LED-support-to-Synaptics-device.
  Fix the detection of LED on the recent HP laptops (bnc#765524)
- commit 27c3276
* Tue Jun  5 2012 ohering@suse.de
- usb/net: rndis: merge command codes.
  only net/hyperv part
- usb/net: rndis: remove ambigous status codes.
  only net/hyperv part
- usb/net: rndis: break out <linux/rndis.h> defines.
  only net/hyperv part
- net/hyperv: Add flow control based on hi/low watermark.
- hv: fix return type of hv_post_message().
- Drivers: hv: util: Properly handle version negotiations.
- Drivers: hv: Get rid of an unnecessary check in vmbus_prep_negotiate_resp().
- HID: hyperv: Set the hid drvdata correctly.
- HID: hid-hyperv: Do not use hid_parse_report() directly.
- commit cfebefe
* Mon Jun  4 2012 jslaby@suse.cz
- Linux 3.4.1.
- commit 4415495
* Mon Jun  4 2012 tiwai@suse.de
- Update config files: Use CONFIG_SND_HDA_INPUT_BEEP=1 instead of 2
  The mode 2 was an ugly hack and shouldn't have been set, but it was so
  changed since some time ago.
- commit 695549b
* Mon Jun  4 2012 ohering@suse.de
- [SCSI] storvsc: Properly handle errors from the host
  (bnc#747404).
- Delete patches.suse/suse-hv-storvsc-ignore-ata_16.patch.
- commit ad28e23
* Fri Jun  1 2012 tiwai@suse.de
- Update config files: Use CONFIG_SND_HDA_INPUT_BEEP=1 instead of 2
  The mode 2 was an ugly hack and shouldn't have been set, but it was so
  changed since some time ago...
- commit 86629f1
* Fri Jun  1 2012 guillaume.gardet@oliseo.fr
- Update ARM configs
- commit 550ef37
* Thu May 31 2012 ohering@suse.de
- replace our version of this patch with upstream variant:
  ata_piix: defer disks to the Hyper-V drivers by default
  libata: add a host flag to ignore detected ATA devices.
- commit bf70e35
* Wed May 30 2012 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Own the right -kdump initrd (bnc#764500)
- commit 5c85db8
* Tue May 29 2012 mhocko@suse.cz
- Refresh
  patches.apparmor/apparmor-compatibility-patch-for-v5-network-control.
  Fix a compile error due to anonymous union initialization not supported
  by earlier gcc versions (<4.6.x).
- commit 790f341
* Tue May 29 2012 jbeulich@novell.com
- Update Xen config files (XEN_SPINLOCK_ACQUIRE_NESTING=1).
- commit d03820c
* Fri May 25 2012 jeffm@suse.com
- Renamed armv7l to armv7hl, following %%_cpu_target convention.
- commit 64b97cd
* Wed May 23 2012 jbeulich@novell.com
- Update Xen patches to 3.4-final and c/s 1177.
- commit a3c5f2c
* Tue May 22 2012 trenn@suse.de
- X86 acpi_cpufreq: Do not use request_module for autoloading
  (bnc#756085).
- Refresh patches.xen/xen3-auto-common.diff.
- patches.xen/xen3-patch-3.3:
- commit caf270e
* Mon May 21 2012 jslaby@suse.cz
- Let's build against 12.1
  Otherwise we are getting build errors.
- commit 6966f52
* Mon May 21 2012 jeffm@suse.com
- Update to 3.4-final.
- commit 91b2c6e
* Tue May 15 2012 agraf@suse.de
- Update config files: ppc64: use PR instead of HV KVM which is usable by more people
- commit 5e7640a
* Tue May 15 2012 jeffm@suse.com
- Make CRYPTO_CRC32C modular (bnc#762344)
  It was pulled in =y via CEPH_LIB=y, so we change the
  following options to =m:
- CONFIG_CEPH_LIB
- CONFIG_CRYPTO_CRC32C
- CONFIG_LIBCRC32C
  Making it modular allows the Intel-optimized crc32c implementation
  to be loaded, improving performance of things like btrfs.
- commit d569763
* Mon May 14 2012 jeffm@suse.com
- Disabled more Intel embedded drivers.
  Disabled:
- CONFIG_GPIO_LANGWELL
- CONFIG_GPIO_PCH
- CONFIG_GPIO_SCH
- commit f554d8b
* Mon May 14 2012 jeffm@suse.com
- USB storage on -desktop should be modular.
- commit 9331d48
* Mon May 14 2012 jeffm@suse.com
- Disabled more testing options.
  Disables:
  - CONFIG_TEST_POWER
  - CONFIG_VIDEO_MEM2MEM_TESTDEV
- commit ef1f4ca
* Mon May 14 2012 jeffm@suse.com
- Update to 3.4-rc7.
  - Eliminated 1 patch.
- commit 4cd9e9b
* Sun May 13 2012 jslaby@suse.cz
- Linux 3.3.6.
- commit a4363bf
* Wed May  9 2012 jeffm@suse.com
- geodefb: Depend on X86_32.
  Disables:
- CONFIG_FB_GEODE_GX1
- CONFIG_FB_GEODE_GX
- CONFIG_FB_GEODE_LX
- CONFIG_FB_GEODE
- commit 1f260fb
* Wed May  9 2012 jeffm@suse.com
- Disabled testing config options on !debug
- CONFIG_CRYPTO_TEST
- CONFIG_DMATEST
- CONFIG_RTC_DRV_TEST
- commit d7c9a65
* Wed May  9 2012 guillaume.gardet@opensuse.org
- Update ARM configs
- commit aac8787
* Tue May  8 2012 jbeulich@novell.com
- Update Xen patches to 3.4-rc6.
- commit 8ed7ef0
* Mon May  7 2012 jslaby@suse.cz
- Linux 3.3.5.
- commit a8d8330
* Mon May  7 2012 jeffm@suse.com
- IA32 emulation: Fix build problem for modular ia32 a.out
  support. (Xen version)
- commit 1c19c30
* Mon May  7 2012 jeffm@suse.com
- IA32 emulation: Fix build problem for modular ia32 a.out
  support.
- commit ad06d7d
* Mon May  7 2012 jeffm@suse.com
- Update to 3.4-rc6.
  - Eliminated 2 patches.
- commit 749ea8f
* Sat May  5 2012 jeffm@suse.com
- Disabled MMC_TEST (bnc#760077).
- commit c36bb06
* Fri May  4 2012 jeffm@suse.com
- sysctl/defaults: kernel.hung_task_timeout -> kernel.hung_task_timeout_secs (bnc#700174)
- commit 94b5c35
* Thu May  3 2012 guillaume.gardet@opensuse.org
- Update config/armv7l/omap2plus
- commit db627f7
* Wed May  2 2012 jeffm@suse.com
- patches.drivers/ehea-modinfo.patch: Updated patch-mainline for submission.
- commit e0eb735
* Wed May  2 2012 jeffm@suse.com
- omap-usb-host: include <plat/cpu.h>.
- commit 4d1394a
* Wed May  2 2012 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Do not require distribution-release
  during build.
- commit 3cd703f
* Wed May  2 2012 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Depend on distribution-release, so that
  the grub entry has correct title (bnc#757565).
- commit 30145a4
* Mon Apr 30 2012 jeffm@suse.com
- Updated and re-enabled armv7l.
  Thanks to Guillaume GARDET <guillaume.gardet@opensuse.org>
- commit d5a693e
* Mon Apr 30 2012 neilb@suse.de
- Update config files.
  Add CONFIG options for NFSv4v1 support.
  bnc#730444
- commit bd05821
* Mon Apr 30 2012 jeffm@suse.com
- Update to 3.4-rc5.
- commit e4e6b33
* Fri Apr 27 2012 jslaby@suse.cz
- Linux 3.3.4.
- commit d42fe44
* Fri Apr 27 2012 jeffm@suse.com
- Disabled more Moorestown/Medfield drivers.
  Specific options disabled:
  I2C_INTEL_MID
  CONFIG_SFI
  MTD_NAND_DENALI
  SERIAL_MRST_MAX3110
  DRM_GMA600
  SPI_DW_MID_DMA
  APDS9802ALS
- commit 9a9ecdf
* Thu Apr 26 2012 jeffm@suse.com
- Disabled DECNet and ARCNet.
  Specific config options disabled:
  CONFIG_ARCNET
  CONFIG_ARCNET_1051
  CONFIG_ARCNET_1201
  CONFIG_ARCNET_CAP
  CONFIG_ARCNET_COM20020_CS
  CONFIG_ARCNET_COM20020
  CONFIG_ARCNET_COM20020_PCI
  CONFIG_ARCNET_COM90xxIO
  CONFIG_ARCNET_COM90xx
  CONFIG_ARCNET_RAW
  CONFIG_ARCNET_RIM_I
  CONFIG_DECNET
  CONFIG_DECNET_NF_GRABULATOR
- commit 272dd14
* Thu Apr 26 2012 jeffm@suse.com
- Disabled embedded hardware on all architectures except armv7l.
  Regulator drivers, except those needed by Via vx885/875 and OLPC
  are disabled.  IIO drivers are disabled.  SPI drivers are disabled.
  Drivers used only with Intel Medfield or Moorestown have been disabled.
  Specific options disabled:
  CONFIG_AD2S1200, CONFIG_AD2S1210, CONFIG_AD2S90, CONFIG_AD5064,
  CONFIG_AD5360, CONFIG_AD5380, CONFIG_AD5421, CONFIG_AD5446, CONFIG_AD5504,
  CONFIG_AD5624R_SPI, CONFIG_AD5686, CONFIG_AD5764, CONFIG_AD5791,
  CONFIG_AD5930, CONFIG_AD5933, CONFIG_AD7150, CONFIG_AD7152, CONFIG_AD7192,
  CONFIG_AD7280, CONFIG_AD7291, CONFIG_AD7298, CONFIG_AD7476,
  CONFIG_AD7606_IFACE_PARALLEL, CONFIG_AD7606_IFACE_SPI, CONFIG_AD7606,
  CONFIG_AD7746, CONFIG_AD7780, CONFIG_AD7793, CONFIG_AD7816, CONFIG_AD7887,
  CONFIG_AD799X, CONFIG_AD799X_RING_BUFFER, CONFIG_AD9832, CONFIG_AD9834,
  CONFIG_AD9850, CONFIG_AD9852, CONFIG_AD9910, CONFIG_AD9951,
  CONFIG_ADE7753, CONFIG_ADE7754, CONFIG_ADE7758, CONFIG_ADE7759,
  CONFIG_ADE7854_I2C, CONFIG_ADE7854, CONFIG_ADE7854_SPI, CONFIG_ADIS16060,
  CONFIG_ADIS16080, CONFIG_ADIS16130, CONFIG_ADIS16201, CONFIG_ADIS16203,
  CONFIG_ADIS16204, CONFIG_ADIS16209, CONFIG_ADIS16220, CONFIG_ADIS16240,
  CONFIG_ADIS16260, CONFIG_ADIS16400, CONFIG_ADT7310, CONFIG_ADT7316_I2C,
  CONFIG_ADT7316, CONFIG_ADT7316_SPI, CONFIG_ADT7410, CONFIG_ADXRS450,
  CONFIG_BACKLIGHT_WM831X, CONFIG_CAN_JANZ_ICAN3, CONFIG_FB_SM501,
  CONFIG_GPIO_JANZ_TTL, CONFIG_GPIO_RDC321X, CONFIG_GPIO_STMPE,
  CONFIG_GPIO_TIMBERDALE, CONFIG_GPIO_WM831X, CONFIG_IIO_BUFFER,
  CONFIG_IIO_CONSUMERS_PER_TRIGGER=2, CONFIG_IIO_GPIO_TRIGGER,
  CONFIG_IIO_KFIFO_BUF, CONFIG_IIO, CONFIG_IIO_PERIODIC_RTC_TRIGGER,
  CONFIG_IIO_SIMPLE_DUMMY, CONFIG_IIO_ST_HWMON, CONFIG_IIO_SW_RING,
  CONFIG_IIO_SYSFS_TRIGGER, CONFIG_IIO_TRIGGER,
  CONFIG_INPUT_MC13783_PWRBUTTON, CONFIG_INPUT_WM831X_ON,
  CONFIG_KEYBOARD_STMPE, CONFIG_KXSD9, CONFIG_LEDS_MC13783,
  CONFIG_LEDS_REGULATOR, CONFIG_LEDS_WM831X_STATUS,
  CONFIG_LIS3L02DQ_BUF_KFIFO, CONFIG_LIS3L02DQ, CONFIG_MAX1363,
  CONFIG_MAX1363_RING_BUFFER, CONFIG_MAX517, CONFIG_MFD_CORE,
  CONFIG_MFD_JANZ_CMODIO, CONFIG_MFD_MC13783, CONFIG_MFD_MC13XXX,
  CONFIG_MFD_RDC321X, CONFIG_MFD_SM501_GPIO, CONFIG_MFD_SM501,
  CONFIG_MFD_STMPE, CONFIG_MFD_TIMBERDALE, CONFIG_MFD_TPS65217,
  CONFIG_MFD_WM831X_SPI, CONFIG_MFD_WM831X, CONFIG_MFD_WM8400,
  CONFIG_RADIO_TIMBERDALE, CONFIG_REGMAP_I2C, CONFIG_REGMAP_SPI,
  CONFIG_REGMAP, CONFIG_REGULATOR_AD5398, CONFIG_REGULATOR_DA903X,
  CONFIG_REGULATOR_DEBUG, CONFIG_REGULATOR_DUMMY,
  CONFIG_REGULATOR_FIXED_VOLTAGE, CONFIG_REGULATOR_GPIO,
  CONFIG_REGULATOR_ISL6271A, CONFIG_REGULATOR_LP3971,
  CONFIG_REGULATOR_LP3972, CONFIG_REGULATOR_MAX1586,
  CONFIG_REGULATOR_MAX8649, CONFIG_REGULATOR_MAX8660,
  CONFIG_REGULATOR_MAX8952, CONFIG_REGULATOR_MC13783,
  CONFIG_REGULATOR_MC13892, CONFIG_REGULATOR_MC13XXX_CORE,
  CONFIG_REGULATOR_PCAP, CONFIG_REGULATOR_TPS6105X,
  CONFIG_REGULATOR_TPS62360, CONFIG_REGULATOR_TPS65023,
  CONFIG_REGULATOR_TPS6507X, CONFIG_REGULATOR_TPS65217,
  CONFIG_REGULATOR_TPS6524X, CONFIG_REGULATOR_USERSPACE_CONSUMER,
  CONFIG_REGULATOR_VIRTUAL_CONSUMER, CONFIG_REGULATOR_WM831X,
  CONFIG_REGULATOR_WM8400, CONFIG_REGULATOR, CONFIG_RFKILL_REGULATOR,
  CONFIG_RTC_DRV_MC13XXX, CONFIG_RTC_DRV_WM831X, CONFIG_SCA3000,
  CONFIG_SENSORS_AK8975, CONFIG_SENSORS_HMC5843, CONFIG_SENSORS_ISL29018,
  CONFIG_SENSORS_MC13783_ADC, CONFIG_SENSORS_TSL2563, CONFIG_SENSORS_WM831X,
  CONFIG_SERIAL_MFD_HSU, CONFIG_SERIAL_UARTLITE, CONFIG_STMPE_I2C,
  CONFIG_STMPE_SPI, CONFIG_TOUCHSCREEN_MC13783, CONFIG_TOUCHSCREEN_STMPE,
  CONFIG_TOUCHSCREEN_WM831X, CONFIG_TPS6105X, CONFIG_TSL2583,
  CONFIG_WM831X_BACKUP, CONFIG_WM831X_POWER, CONFIG_WM831X_WATCHDOG
- commit 0f27f25
* Thu Apr 26 2012 jeffm@suse.com
- Disabled CONFIG_COPS and CONFIG_LTPC: Ancient ISA LocalTalk hardware.
- commit 43b6598
* Wed Apr 25 2012 jeffm@suse.com
- dl2k: Tighten ioctl permissions (bnc#758813).
- commit 8d00242
* Wed Apr 25 2012 jeffm@suse.com
- Update to 3.4-rc4.
- commit 37113a8
* Mon Apr 23 2012 jslaby@suse.cz
- Linux 3.3.3.
- Delete
  patches.suse/btrfs-REVERT-increase-the-global-block-reserve-estim.patch.
- commit 739b98b
* Sun Apr 22 2012 jeffm@suse.com
- Update config files: Merged omap2plus changes.
- commit f0e2149
* Fri Apr 20 2012 jbeulich@novell.com
- Update Xen patches to 3.4-rc3 and c/s 1172.
- config.conf: Re-enabled Xen configs.
- Update config files.
- commit 9f943f6
* Tue Apr 17 2012 jeffm@suse.com
- Update to 3.4-rc3.
  - Eliminated 1 patch.
- commit 2fde7e0
* Fri Apr 13 2012 jslaby@suse.cz
- Linux 3.3.2.
- Delete
  patches.fixes/revert-ath9k-fix-going-to-full-sleep-on-PS-idle.patch.
- commit addbdfa
* Fri Apr 13 2012 jbeulich@novell.com
- Drivers: scsi: storvsc: Account for in-transit packets in the
  RESET path.
- commit 4c1e258
* Mon Apr  9 2012 jeffm@suse.com
- Update to 3.4-rc2.
- commit 976094f
* Sat Apr  7 2012 jslaby@suse.cz
- Revert "ath9k: fix going to full-sleep on PS idle" (bnc#756013).
- commit c31d1b5
* Fri Apr  6 2012 jeffm@suse.com
- Update AppArmor for 3.4.
  - apparmor: Add "profiles" list to sysfs.
- commit 59517ac
* Thu Apr  5 2012 jeffm@suse.com
- Update richacl patchset for 3.4.
- commit f13764e
* Thu Apr  5 2012 jeffm@suse.com
- Updated to 3.4-rc1.
  - Eliminated 121 patches.
  - Xen is unavailable.
  - ACPI overrides are unavailable.
  - AppArmor network feature are unavailable.
- commit 3ac7e79
* Thu Apr  5 2012 jeffm@suse.de
- Updated patch headers
- commit 09c9338
* Tue Apr  3 2012 ohering@suse.de
- Drivers: scsi: storvsc: Properly handle errors from the host
  (bnc#747404).
- commit 2f7920e
* Tue Apr  3 2012 jslaby@suse.cz
- Linux 3.3.1.
- Delete
  patches.drivers/drm-i915-suspend-fbdev-device-around-suspend-hiberna.
- Delete
  patches.fixes/net-fix-a-potential-rcu_read_lock-imbalance-in-rt6_fill_node.
- commit efec235
* Mon Apr  2 2012 jeffm@suse.de
- armv7l: Disable CONFIG_TOUCHSCREEN_EGALAX on default and u8500 due to missing infrastructure.
- commit b614c98
* Mon Apr  2 2012 jslaby@suse.cz
- samsung-laptop: make the dmi check less strict (bnc#746695).
- commit 170a6a2
* Fri Mar 30 2012 tiwai@suse.de
- drm/i915: suspend fbdev device around suspend/hibernate
  (bnc#732908).
- commit 028c29f
* Wed Mar 28 2012 jeffm@suse.com
- net: fix a potential rcu_read_lock() imbalance in
  rt6_fill_node() (bnc#754186).
- commit 8d5a9e4
* Mon Mar 26 2012 ohering@suse.de
- net/hyperv: Fix the code handling tx busy.
- Tools: hv: Support enumeration from all the pools.
- Tools: hv: Fully support the new KVP verbs in the user level
  daemon.
- Drivers: hv: Support the newly introduced KVP messages in
  the driver.
- Drivers: hv: Add new message types to enhance KVP.
- net/hyperv: Add support for vlan trunking from guests.
- net/hyperv: Fix data corruption in rndis_filter_receive().
- drivers: hv: Increase the number of VCPUs supported in the
  guest.
- drivers: hv: kvp: Cleanup the kernel/user protocol.
- tools: hv: Use hyperv.h to get the KVP definitions.
- drivers: hv: Cleanup the kvp related state in hyperv.h.
- net/hyperv: Remove the unnecessary memset in
  rndis_filter_send().
- net/hyperv: Correct the assignment in netvsc_recv_callback().
- net/hyperv: Convert camel cased variables in rndis_filter.c
  to lower cases.
- drivers: hv: kvp: Move the contents of hv_kvp.h to hyperv.h.
- drivers: hv: kvp: Add/cleanup connector defines.
- drivers: hv: Get rid of some unnecessary code.
- commit 78acc3b
* Sat Mar 24 2012 dsterba@suse.cz
- Revert "Btrfs: increase the global block reserve estimates"
- commit 7e9dd21
* Sat Mar 24 2012 dsterba@suse.cz
- Refresh patches.suse/btrfs-handle-EIO.
- Refresh
  patches.suse/btrfs-volumes-schedule_bio-should-return-void.
- commit d97ade6
* Fri Mar 23 2012 jbeulich@novell.com
- Update Xen patches to 3.3 final and c/s 1165.
- commit 6c5f5ef
* Thu Mar 22 2012 jeffm@suse.com
- Update config files: Disable CONFIG_INTEL_IOMMU_DEFAULT_ON (bnc#740102 and others)
- commit b244b17
* Thu Mar 22 2012 jeffm@suse.de
- Update config files: Disabled CONFIG_COMPAT_BRK and CONFIG_COMPAT_VDSO (FATE#313171)
- commit 990b059
* Wed Mar 21 2012 meissner@suse.de
- rpm: include crtsavres.o on ppc
- commit 854a031
* Mon Mar 19 2012 jeffm@suse.com
- Update vanilla config files.
- commit bd476d4
* Mon Mar 19 2012 jslaby@suse.cz
- Update (vanilla) config files.
- commit 55a0a56
* Mon Mar 19 2012 jslaby@suse.cz
- Delete
  patches.arch/acpi_ec_provide_non_interrupt_mode_boot_param.patch.
- Delete patches.arch/dell_optiplex_990_fix_reboot.patch.
- Delete
  patches.drivers/alsa-hda-0004-Add-missing-static-ADC-tables-for-ALC269-qu.
- Delete patches.drivers/libata-unlock-hpa-by-default.
- Delete patches.fixes/scsi-add-tgps-setting.
- Delete patches.fixes/scsi-dh-rdac-add-stk.
- Delete patches.suse/dm-mpath-evaluate-request-result-and-sense.
- Delete patches.suse/richacl-fix.
  Remove unused patches.
- commit 2cbabfe
* Mon Mar 19 2012 jeffm@suse.com
- Update to 3.3-final.
- commit a9ab64a
* Fri Mar 16 2012 ohering@suse.de
- Update bugnumber patches.suse/sd_init.mark_majors_busy.patch (bnc#744658).
- commit e60f2c3
* Tue Mar 13 2012 jslaby@suse.cz
- Linux 3.2.10.
- Delete
  patches.fixes/media-staging-lirc_serial-Do-not-assume-error-codes-.patch.
- Delete
  patches.fixes/media-staging-lirc_serial-Free-resources-on-failure-.patch.
- commit 614ed04
* Mon Mar 12 2012 jslaby@suse.cz
- staging: lirc_serial: Free resources on failure paths of
  lirc_serial_probe() (bnc#750106).
- staging: lirc_serial: Do not assume error codes returned by
  request_irq() (bnc#750106).
- commit 4bff877
* Mon Mar 12 2012 jbeulich@novell.com
- Update Xen patches to 3.3-rc7 and c/s 1163.
- commit 0054c83
* Mon Mar 12 2012 ohering@suse.de
- Staging: hv: storvsc: Cleanup some comments.
- Staging: hv: storvsc: Cleanup storvsc_probe().
- Staging: hv: storvsc: Cleanup storvsc_queuecommand().
- Staging: hv: storvsc: Introduce defines for srb status codes.
- Staging: hv: storvsc: Cleanup storvsc_host_reset_handler().
- Staging: hv: storvsc: Move and cleanup storvsc_remove().
- Staging: hv: storvsc: Add a comment to explain life-cycle
  management.
- Staging: hv: storvsc: Get rid of the on_io_completion in
  hv_storvsc_request.
- Staging: hv: storvsc: Rename the context field in
  hv_storvsc_request.
- Staging: hv: storvsc: Miscellaneous cleanup of storvsc driver.
- Staging: hv: storvsc: Cleanup the code for generating protocol
  version.
- Staging: hv: storvsc: Cleanup some protocol related constants.
- Staging: hv: storvsc: Get rid of some unused defines.
- Staging: hv: storvsc: Consolidate the request structure.
- Staging: hv: storvsc: Consolidate all the wire protocol
  definitions.
- Staging: hv: storvsc: Move the storage driver out of the
  staging area.
- Rename patches.suse/staging-hv-pata_piix-ignore-disks.patch to
  patches.suse/suse-hv-pata_piix-ignore-disks.patch
- commit 7487199
* Mon Mar 12 2012 jeffm@suse.com
- Update to 3.3-rc7.
- commit 81a18ea
* Sun Mar 11 2012 jeffm@suse.com
- btrfs: Handle EIO.
- btrfs: add varargs to btrfs_error.
- btrfs: Remove BUG_ON from __finish_chunk_alloc().
- btrfs: Remove BUG_ON from __btrfs_alloc_chunk().
- btrfs: Don't BUG_ON insert errors in btrfs_alloc_dev_extent().
- btrfs: Go readonly on tree errors in balance_level.
- btrfs: Don't BUG_ON errors from update_ref_for_cow().
- btrfs: Go readonly on bad extent refs in update_ref_for_cow().
- btrfs: Don't BUG_ON errors in __finish_chunk_alloc().
- btrfs: Don't BUG_ON kzalloc error in btrfs_lookup_csums_range().
- btrfs: Don't BUG_ON() errors in update_ref_for_cow().
- btrfs: Don't BUG_ON errors from btrfs_create_subvol_root().
- btrfs: btrfs_drop_snapshot should return int.
- brfs: split extent_state ops.
- btrfs: drop gfp_t from lock_extent.
- btrfs: scrub functions should return void.
- btrfs: btrfs_set_item_key_safe should BUG on error and return
  void.
- btrfs: Add extent_state alloc/free tracing.
- btrfs: btrfs_destroy_pending_snapshots should return void.
- btrfs: btrfs_destroy_ordered_extents should return void.
- btrfs: btrfs_destroy_ordered_operations should return void.
- btrfs: del_fs_roots should return void.
- btrfs: btrfs_free_fs_root should return void.
- btrfs: btrfs_add_ordered_sum should return void.
- btrfs: btrfs_add_ordered_operation should return void.
- btrfs: btrfs_run_ordered_operations should return void.
- btrfs: btrfs_wait_ordered_range should return void.
- btrfs: btrfs_wait_ordered_extents should return void.
- btrfs: __btrfs_remove_ordered_extent should return void.
- btrfs: btrfs_put_ordered_extent should return void.
- btrfs: update_inline_extent_backref should return void.
- btrfs: copy_for_split should return void.
- btrfs: end_compressed_writeback should return void.
- btrfs: btrfs_extend_item should return void.
- btrfs: btrfs_truncate_item should return void.
- btrfs: add_delayed_data_ref should return void.
- btrfs: add_delayed_tree_ref should return void.
- btrfs: add_delayed_ref_head should return void.
- btrfs: insert_ptr should return void.
- btrfs: del_ptr should return void.
- btrfs: setup_items_for_insert should return void.
- btrfs: fixup_low_keys should return void.
- btrfs: __add_reloc_root error push-up.
- btrfs: ->submit_bio_hook error push-up.
- btrfs: Factor out tree->ops->merge_bio_hook call.
- btrfs: Simplify btrfs_submit_bio_hook.
- btrfs: Fix kfree of member instead of structure.
- btrfs: setup_inline_extent_backref should return void.
- btrfs: btrfs_set_block_group_rw should return void.
- btrfs: btrfs_prepare_extent_commit should return void.
- btrfs: btrfs_destroy_delalloc_inodes should return void.
- btrfs: __setup_root should return void.
- btrfs: btrfs_invalidate_inodes should return void.
- btrfs: btrfs_init_compress should return void.
- btrfs: wait_for_writer should return void.
- btrfs: btrfs_end_log_trans should return void.
- btrfs: btrfs_requeue_work should return void.
- btrfs: btrfs_stop_workers should return void.
- btrfs: run_ordered_completions should return void.
- btrfs: fill_device_from_item should return void.
- btrfs: schedule_bio should return void.
- btrfs: btrfs_close_extra_devices should return void.
- btrfs: run_scheduled_bios should return void.
- btrfs: btrfs_cleanup_fs_uuids should return void.
- btrfs: clear_extent_buffer_dirty should return void.
- btrfs: check_page_writeback should return void.
- btrfs: check_page_locked should return void.
- btrfs: check_page_uptodate should return void.
- btrfs: __unlock_for_delalloc should return void.
- btrfs: wait_extent_bit should return void.
- btrfs: wait_on_state should return void.
- btrfs: btrfs_update_root error push-up.
- btrfs: find_and_setup_root error push-up.
- btrfs: Remove set bits return from clear_extent_bit.
- btrfs: avoid NULL deref in btrfs_reserve_extent with
  DEBUG_ENOSPC.
- btrfs: clean_tree_block should panic on observed memory
  corruption and return void.
- btrfs: btrfs_tree_{,un}lock should return void.
- btrfs: Simplify btrfs_insert_root.
- btrfs: Panic on bad rbtree operations.
- btrfs: Catch locking failures in {set,clear,convert}_extent_bit.
- btrfs: Add btrfs_panic().
- commit fd31baf
* Fri Mar  9 2012 ohering@suse.de
- mark busy sd majors as allocated (bug#744658).
- commit b2a640b
* Thu Mar  8 2012 mmarek@suse.cz
- Fix vanilla config files.
- commit b343c8a
* Thu Mar  8 2012 mmarek@suse.cz
- Delete patches.rpmify/nvme-broken, nvme builds again on 32bit.
- commit d60272f
* Thu Mar  8 2012 jbeulich@novell.com
- patches.suse/crasher-26.diff: Eliminate build warnings.
- commit 67c3c8d
* Thu Mar  8 2012 agraf@suse.de
- armv7l: config: omap: disable HDMI output (breaks build)
- commit 6a871bd
* Tue Mar  6 2012 agraf@suse.de
- armv7l: omap2plus: Enable TIDSPBRIDGE and SND codecs
- commit 0d8ec4d
* Mon Mar  5 2012 jeffm@suse.com
- Refresh patches.xen/xen3-fixup-arch-x86.
- commit f4b95ae
* Mon Mar  5 2012 jeffm@suse.com
- Update to 3.3-rc6. Previous commit was configs.
- commit 639167f
* Mon Mar  5 2012 jeffm@suse.com
- Update to 3.3-rc6.
- commit ebec13a
* Sun Mar  4 2012 jslaby@suse.cz
- Update config files.
  Enable RT2800USB_RT35XX and RT2800USB_RT53XX.
- commit 2c205b4
* Sun Mar  4 2012 jslaby@suse.cz
- Update config files.
  Enable RT2800USB_RT35XX and RT2800USB_RT53XX.
- commit adb37b7
* Thu Mar  1 2012 jslaby@suse.cz
- xen3-patch-3.2.7-8
  Make xen build again.
- commit ba1cb50
* Thu Mar  1 2012 jslaby@suse.cz
- Linux 3.2.9.
- Refresh patches.xen/xen3-fixup-arch-x86.
- commit 82a8603
* Wed Feb 29 2012 jbeulich@novell.com
- Update Xen patches to 3.3-rc5 and c/s 1157.
- config.conf: Re-enable Xen configs.
- Update config files.
- commit f225622
* Tue Feb 28 2012 jslaby@suse.cz
- Linux 3.2.8.
  XEN is broken. The XEN-generated backport patch does not apply
  cleanly. So leaving XEN as is, until this is fixed in master. Then the
  same fix will be ported here.
- commit 2bcad53
* Mon Feb 27 2012 jeffm@suse.com
- Updated to 3.3-rc5.
- commit 0b7f048
* Sun Feb 26 2012 jslaby@suse.cz
- Revert "Disable 3.2.5"
  This reverts commit 6d12c9d00ec52d1d6745a08935b3f10870cbc58d.
  It works now.
- commit 91fa3bc
* Wed Feb 22 2012 jslaby@suse.cz
- Disable 3.2.5
  I lost my ps/2 keyboard and touchpad.
- commit 6d12c9d
* Tue Feb 21 2012 jslaby@suse.cz
- Linux 3.2.5.
- Refresh patches.kernel.org/patch-3.2.5-6.
- commit 9d01b21
* Tue Feb 21 2012 jslaby@suse.cz
- Linux 3.2.7.
- commit 3d38d11
* Sun Feb 19 2012 jeffm@suse.com
- Updated to 3.3-rc4.
- commit 8831dca
* Mon Feb 13 2012 jslaby@suse.cz
- Linux 3.2.6.
- Delete
  patches.fixes/PM-Hibernate-Fix-s2disk-regression-related-to-freezi.patch.
- commit 264e0d4
* Mon Feb 13 2012 trenn@suse.de
- cpufreq/gx: Fix the compile error.
- commit 4ba1d8b
* Mon Feb 13 2012 jslaby@suse.cz
- Update config files.
  Enable brcm80211 wireless driver.
- commit 70a4760
* Mon Feb 13 2012 mmarek@suse.cz
- nvme: Mark as broken on x86_32.
- commit 28ad576
* Sun Feb 12 2012 trenn@suse.de
- Add driver auto probing for x86 features v4
  (http://lists.opensuse.org/opensuse-kernel/2011-11/msg00075.html).
- x86/cpu: Fix overrun check in arch_print_cpu_modalias()
  (http://lists.opensuse.org/opensuse-kernel/2011-11/msg00075.html).
- crypto: Add support for x86 cpuid
  auto loading for x86 crypto drivers
  (http://lists.opensuse.org/opensuse-kernel/2011-11/msg00075.html).
- x86/cpu: Clean up modalias feature matching
  (http://lists.opensuse.org/opensuse-kernel/2011-11/msg00075.html).
- intel-idle: convert to x86_cpu_id auto probing
  (http://lists.opensuse.org/opensuse-kernel/2011-11/msg00075.html).
- intel_idle: Fix ID for Nehalem-EX Xeon in device ID table
  (http://lists.opensuse.org/opensuse-kernel/2011-11/msg00075.html).
- HWMON: Convert via-cputemp to x86 cpuid autoprobing
  (http://lists.opensuse.org/opensuse-kernel/2011-11/msg00075.html).
- powernow-k7: Fix CPU family number
  (http://lists.opensuse.org/opensuse-kernel/2011-11/msg00075.html).
- ACPI: Load acpi-cpufreq from processor driver automatically
  (http://lists.opensuse.org/opensuse-kernel/2011-11/msg00075.html).
- intel_idle: Revert change of auto_demotion_flags for Nehalem
  (http://lists.opensuse.org/opensuse-kernel/2011-11/msg00075.html).
- HWMON: Convert coretemp to x86 cpuid autoprobing
  (http://lists.opensuse.org/opensuse-kernel/2011-11/msg00075.html).
- powernow-k6: Really enable auto-loading
  (http://lists.opensuse.org/opensuse-kernel/2011-11/msg00075.html).
- X86: Introduce HW-Pstate scattered cpuid feature
  (http://lists.opensuse.org/opensuse-kernel/2011-11/msg00075.html).
- cpufreq: Add support for x86 cpuinfo auto loading v4
  (http://lists.opensuse.org/opensuse-kernel/2011-11/msg00075.html).
- x86: autoload microcode driver on Intel and AMD systems v2
  (http://lists.opensuse.org/opensuse-kernel/2011-11/msg00075.html).
- CPU: Introduce ARCH_HAS_CPU_AUTOPROBE and X86 parts
  (http://lists.opensuse.org/opensuse-kernel/2011-11/msg00075.html).
- ACPI: remove duplicated lines of merging
  problems with acpi_processor_start
  (http://lists.opensuse.org/opensuse-kernel/2011-11/msg00075.html).
- Update config files.
- commit 6efe9b5
* Fri Feb 10 2012 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Build x86 packages as i686, except for
  - default (bnc#745632). KMPs are still built as i586.
- commit 88a632b
* Thu Feb  9 2012 jeffm@suse.com
- Update to 3.3-rc3.
- commit 07ec27c
* Thu Feb  9 2012 agraf@suse.de
- armv7l: Update config files.
- commit d223353
* Thu Feb  9 2012 agraf@suse.de
- armv7l: config: integrate bmwiedemann's updates to make it usable
- commit 76d12ed
* Tue Feb  7 2012 jeffm@suse.com
- Update vanilla config files.
- commit fd3673f
* Tue Feb  7 2012 jeffm@suse.com
- Update to 3.3-rc2.
  - Eliminated 5 patches.
  - Xen is disabled.
- commit d017ea1
* Sat Feb  4 2012 jslaby@suse.cz
- Linux 3.2.4.
- commit 484affb
* Sat Feb  4 2012 jslaby@suse.cz
- Linux 3.2.3.
- commit 9c66f44
* Thu Feb  2 2012 jslaby@suse.cz
- Refresh
  patches.fixes/PM-Hibernate-Fix-s2disk-regression-related-to-freezi.patch.
- commit 763a147
* Mon Jan 30 2012 jslaby@suse.cz
- Do not build with the patch yet. It needs more work.
- commit 1101381
* Mon Jan 30 2012 jslaby@suse.cz
- PM / Hibernate: Fix s2disk regression related to freezing
  workqueues (bnc#743952).
- commit 6f37dda
* Sun Jan 29 2012 jslaby@suse.cz
- Delete patches.fixes/proc-mem-security-fix.
  Fix build error caused by merge of master branch.
- commit 62fc2fa
* Thu Jan 26 2012 jslaby@suse.cz
- Linux 3.2.2.
- Refresh patches.xen/xen3-fixup-xen.
- Refresh patches.xen/xen3-patch-2.6.24.
- Refresh patches.xen/xen3-patch-2.6.28.
- patches.xen/xen3-patch-2.6.39:
- Delete patches.arch/acpi_srat-pxm-rev-ia64.patch.
- Delete patches.arch/acpi_srat-pxm-rev-store.patch.
- Delete patches.arch/acpi_srat-pxm-rev-x86-64.patch.
- Delete
  patches.fixes/intel_idle_fix_mwait_leave_zero_kvm_issue.patch.
- commit 387c074
* Wed Jan 25 2012 dkukawka@suse.de
- fix NULL pointer dereference in DSS2 VENC sysfs debug attr on OMAP4.
- commit 2206a5c
* Wed Jan 25 2012 mmarek@suse.cz
- proc: clean up and fix /proc/<pid>/mem handling (bnc#742279,
  CVE-2012-0056).
- commit 4fb112d
* Tue Jan 17 2012 trenn@suse.de
- Delete patches.fixes/intel_idle_add_flush_tlb_param.patch.
- Delete patches.fixes/intel_idle_lapic_param.patch.
- commit e18e852
* Tue Jan 17 2012 agraf@suse.de
- KVM: PPC: Add HPT preallocator.
- KVM: PPC: Convert RMA allocation into generic code.
- commit a6da6a5
* Fri Jan 13 2012 agraf@suse.de
- ARM: Update config files: Enable highmem everywhere
- commit 4522c1c
* Fri Jan 13 2012 tiwai@suse.de
- Refresh patches.suse/SUSE-bootsplash.
- add a proper support for Xen fb (bnc#739020);
- fix the bootsplash-verbose switch race (bnc#734213)
- commit 6f3d77f
* Fri Jan 13 2012 jslaby@suse.cz
- Linux 3.2.1.
- Delete
  patches.fixes/reiserfs-force-inode-evictions-before-umount-to-avoid-crash.
- commit 38ed2a2
* Wed Jan 11 2012 jbeulich@novell.com
- patches.suse/stack-unwind: Fix more 2.6.29 merge problems plus a glue code problem.
- commit 9166360
* Mon Jan  9 2012 mmarek@suse.cz
- Set CONFIG_LOCALVERSION for armv7l/u8500.
- commit dde56d0
* Fri Jan  6 2012 awafaa@opensuse.org
- add support for ST-Ericsson Nova based SoCs
- commit 06d2b6e
* Fri Jan  6 2012 jbeulich@novell.com
- Update Xen patches to 3.2-final and c/s 1140.
- commit 917dd7e
* Thu Jan  5 2012 jeffm@suse.com
- Update to 3.2-final.
- commit 778e265
* Wed Jan  4 2012 jslaby@suse.cz
- Revert "- btrfs: use correct device for maps (bnc#672923)."
  This reverts commit 7e6bd95918d9b297d628b36d4b029da7cc335ca5.
  We mauy break kABI here and use the cleaner version :).
- commit 897def2
* Wed Jan  4 2012 jslaby@suse.cz
- Linux 3.1.7.
- commit 587be3b
* Mon Jan  2 2012 jeffm@suse.com
- Updated to 3.2-rc7.
- commit f458508
* Mon Jan  2 2012 dsterba@suse.cz
- btrfs: use correct device for maps (bnc#672923).
- Delete
  patches.suse/0001-vfs-allow-proc-pid-maps-to-return-a-custom-device.patch.
- Delete
  patches.suse/0002-btrfs-Introduce-btrfs_get_maps_dev.patch.
- commit 7e6bd95
* Mon Jan  2 2012 mhocko@suse.cz
- Update
  patches.fixes/oom-thaw-threads-if-oom-killed-thread-is-frozen-befo.patch
  (bnc#718831).
- commit 05b6faf
* Fri Dec 30 2011 bpoirier@suse.de
- net: Add a flow_cache_flush_deferred function (bnc#737624).
- commit 69bd36b
* Mon Dec 26 2011 jslaby@suse.cz
- sound: ratelimit sound debug prints.
- commit 441798f
* Mon Dec 26 2011 jslaby@suse.cz
- Linux 3.1.6.
- Revert "clocksource: Avoid selecting mult values that might
  overflow when adjusted".
- Revert "inet: add a redirect generation id in inetpeer".
- Delete
  patches.fixes/hfs-fix-hfs_find_init-sb-ext_tree-null-ptr-oops.patch.
- Delete
  patches.fixes/mm-Ensure-that-pfn_valid-is-called-once-per-pagebloc.patch.
- Linux 3.1.6.
- Delete
  patches.fixes/hfs-fix-hfs_find_init-sb-ext_tree-null-ptr-oops.patch.
- Delete
  patches.fixes/mm-Ensure-that-pfn_valid-is-called-once-per-pagebloc.patch.
- commit 2f8a8c2
* Thu Dec 22 2011 jeffm@suse.com
- Update config files.
- CONFIG_X86_INTEL_MID -> CONFIG_X86_WANT_INTEL_MID
- commit c4246bf
* Wed Dec 21 2011 jbeulich@novell.com
- Update Xen patches to 3.2-rc6 and c/s 1133.
- kexec: properly handle pCPU hotplug.
- x86: pCPU handling.
- commit cbe54a1
* Tue Dec 20 2011 dsterba@suse.cz
- Btrfs: fix wrong i_size when truncating a file to a larger size
  (FATE#306586).
- Btrfs: fix wrong disk space information of the files
  (FATE#306586).
- Btrfs: fix inaccurate available space on raid0 profile
  (FATE#306586).
- btrfs: keep orphans for subvolume deletion (FATE#306586).
- Btrfs: fix ctime update of on-disk inode (FATE#306586).
- Btrfs: add a cond_resched() into the worker loop (FATE#306586).
- BTRFS: Establish i_ops before calling d_instantiate
  (FATE#306586).
- Btrfs: deal with NULL srv_rsv in the delalloc inode reservation
  code (FATE#306586).
- Btrfs: fix num_workers_starting bug and other bugs in async
  thread (FATE#306586).
- Btrfs: deal with enospc from dirtying inodes properly
  (FATE#306586).
- Btrfs: fix how we do delalloc reservations and how we free
  reservations on error (FATE#306586).
- Btrfs: fix leaked space in truncate (FATE#306586).
- Btrfs: don't panic if orphan item already exists (FATE#306586).
- Btrfs: only set cache_generation if we setup the block group
  (FATE#306586).
- Btrfs: unplug every once and a while (FATE#306586).
- btrfs: lock and disable irq during space alloc (FATE#306586
  bnc#730103).
- Refresh
  patches.suse/btrfs-8014-add-new-ioctl-to-determine-size-of-compressed-.patch.
- Delete
  patches.suse/btrfs-0901-fix-num_workers_starting-bug-and-other-bugs-in.patch.
- Delete
  patches.suse/btrfs-0902-deal-with-enospc-from-dirtying-inodes-properly.patch.
- Delete
  patches.suse/btrfs-0903-fix-how-we-do-delalloc-reservations-and-how-we.patch.
- Delete
  patches.suse/btrfs-0904-fix-leaked-space-in-truncate.patch.
- Delete
  patches.suse/btrfs-0905-only-set-cache_generation-if-we-setup-the-bloc.patch.
- Delete
  patches.suse/btrfs-0906-don-t-panic-if-orphan-item-already-exists.patch.
- Delete
  patches.suse/btrfs-8027-fix-ctime-update-of-on-disk-inode.patch.
- Delete
  patches.suse/btrfs-8028-fix-wrong-disk-space-information-of-the-files.patch.
- Delete
  patches.suse/btrfs-8029-fix-wrong-i_size-when-truncating-a-file-to-a-l.patch.
- Delete
  patches.suse/btrfs-8030-fix-inaccurate-available-space-on-raid0-profil.patch.
- commit e3967f3
* Tue Dec 20 2011 jeffm@suse.com
- Update to 3.2-rc6.
  - Eliminated 1 patch.
- commit d5a489e
* Tue Dec 20 2011 trenn@suse.de
- These should all be mainline in some form:
- Delete
  patches.arch/implement_stop_machine_from_offline_cpu.patch.
- Delete patches.arch/kill-__stop_machine.patch.
- Delete patches.arch/reorganize_stop_cpus.patch.
- Delete patches.arch/use_stop_machine_for_mtrr_rendezvous.patch.
- commit 78eb159
* Sun Dec 18 2011 aj@suse.de
- rpm/kernel-source.rpmlintrc: The hidden files are fine, silence rpmlint.
- commit a7813dd
* Fri Dec 16 2011 aj@suse.de
- rpm/kernel-binary.spec.in: Add provides and make most obsoletes versioned.
  This silences rpmlint warnings.
- commit e3023c7
* Thu Dec 15 2011 dsterba@suse.cz
- Btrfs: fix inaccurate available space on raid0 profile
  (FATE#306586).
- Btrfs: fix wrong i_size when truncating a file to a larger size
  (FATE#306586).
- Btrfs: fix wrong disk space information of the files
  (FATE#306586).
- Btrfs: fix ctime update of on-disk inode (FATE#306586).
- Btrfs: fix possible deadlock when opening a seed device
  (FATE#306586).
- Btrfs: update global block_rsv when creating a new block group
  (FATE#306586).
- btrfs: workaround for cleaner deadlock (FATE#306586).
- Btrfs: don't panic if orphan item already exists (FATE#306586).
- Btrfs: only set cache_generation if we setup the block group
  (FATE#306586).
- commit 5341000
* Wed Dec 14 2011 dsterba@suse.cz
- btrfs: Introduce btrfs_get_maps_dev() (bnc#672923).
- vfs: allow /proc/pid/maps to return a custom device
  (bnc#672923).
- Btrfs: make lzo the default compression scheme (FATE#306586).
- btrfs: add new ioctl to determine size of compressed file
  (FATE#306586).
- Sector Size check during Mount (FATE#306586 bnc#724620).
- Btrfs: rewrite btrfs_trim_block_group() (FATE#306586).
- btrfs: allow cross-subvolume file clone (bnc#698540).
- Btrfs: fix leaked space in truncate (FATE#306586).
- Btrfs: fix how we do delalloc reservations and how we free
  reservations on error (FATE#306586).
- Btrfs: deal with enospc from dirtying inodes properly
  (FATE#306586).
- Btrfs: fix num_workers_starting bug and other bugs in async
  thread (FATE#306586).
- Btrfs: add allocator tracepoints (FATE#306586).
- Btrfs: fix btrfs_end_bio to deal with write errors to a single
  mirror (FATE#306586).
- Btrfs: drop spin lock when memory alloc fails (FATE#306586).
- Btrfs: check if the to-be-added device is writable
  (FATE#306586).
- Btrfs: try cluster but don't advance in search list
  (FATE#306586).
- Btrfs: try to allocate from cluster even at LOOP_NO_EMPTY_SIZE
  (FATE#306586).
- Btrfs: fix meta data raid-repair merge problem (FATE#306586).
- Btrfs: skip allocation attempt from empty cluster (FATE#306586).
- Btrfs: skip block groups without enough space for a cluster
  (FATE#306586).
- Btrfs: start search for new cluster at the beginning
  (FATE#306586).
- Btrfs: reset cluster's max_size when creating bitmap
  (FATE#306586).
- Btrfs: initialize new bitmaps' list (FATE#306586).
- Btrfs: fix oops when calling statfs on readonly device
  (FATE#306586).
- Btrfs: Don't error on resizing FS to same size (FATE#306586).
- Btrfs: fix deadlock on metadata reservation when evicting a
  inode (FATE#306586).
- btrfs scrub: handle -ENOMEM from init_ipath() (FATE#306586).
- Btrfs: remove free-space-cache.c WARN during log replay
  (FATE#306586).
- Btrfs: sectorsize align offsets in fiemap (FATE#306586).
- Btrfs: clear pages dirty for io and set them extent mapped
  (FATE#306586).
- Btrfs: wait on caching if we're loading the free space cache
  (FATE#306586).
- Btrfs: prefix resize related printks with btrfs: (FATE#306586).
- btrfs: fix stat blocks accounting (FATE#306586).
- Btrfs: avoid unnecessary bitmap search for cluster setup
  (FATE#306586).
- Btrfs: fix to search one more bitmap for cluster setup
  (FATE#306586).
- btrfs: mirror_num should be int, not u64 (FATE#306586).
- btrfs: Fix up 32/64-bit compatibility for new ioctls
  (FATE#306586).
- Btrfs: fix barrier flushes (FATE#306586).
- Btrfs: fix tree corruption after multi-thread snapshots and
  inode_cache flush (FATE#306586).
- btrfs: rename the option to nospace_cache (FATE#306586).
- Btrfs: handle bio_add_page failure gracefully in scrub
  (FATE#306586).
- Btrfs: fix deadlock caused by the race between relocation
  (FATE#306586).
- Btrfs: only map pages if we know we need them when reading
  the space cache (FATE#306586).
- Btrfs: fix orphan backref nodes (FATE#306586).
- Btrfs: Abstract similar code for btrfs_block_rsv_add{, _noflush}
  (FATE#306586).
- Btrfs: fix unreleased path in btrfs_orphan_cleanup()
  (FATE#306586).
- Btrfs: fix no reserved space for writing out inode cache
  (FATE#306586).
- Btrfs: fix nocow when deleting the item (FATE#306586).
- Btrfs: tweak the delayed inode reservations again (FATE#306586).
- Btrfs: rework error handling in btrfs_mount() (FATE#306586).
- Btrfs: close devices on all error paths in open_ctree()
  (FATE#306586).
- Btrfs: avoid null dereference and leaks when bailing from
  open_ctree() (FATE#306586).
- Btrfs: fix subvol_name leak on error in btrfs_mount()
  (FATE#306586).
- Btrfs: fix memory leak in btrfs_parse_early_options()
  (FATE#306586).
- Btrfs: fix our reservations for updating an inode when
  completing io (FATE#306586).
- Btrfs: fix oops on NULL trans handle in btrfs_truncate
  (FATE#306586).
- btrfs: fix double-free 'tree_root' in 'btrfs_mount()'
  (FATE#306586).
- Btrfs: check for a null fs root when writing to the backup
  root log (FATE#306586).
- Btrfs: fix race during transaction joins (FATE#306586).
- Btrfs: fix a potential btrfs_bio leak on scrub fixups
  (FATE#306586).
- Btrfs: stop leaking btrfs_bios on readahead (FATE#306586).
- Btrfs: stop the readahead threads on failed mount (FATE#306586).
- Btrfs: fix extent_buffer leak in the metadata IO error handling
  (FATE#306586).
- Btrfs: fix the new inspection ioctls for 32 bit compat
  (FATE#306586).
- btrfs: integrating raid-repair and scrub-fixup-nodatasum
  (FATE#306586).
- btrfs: Moved repair code from inode.c to extent_io.c
  (FATE#306586).
- btrfs: Put mirror_num in bi_bdev (FATE#306586).
- btrfs: Do not use bio->bi_bdev after submission (FATE#306586).
- btrfs: btrfs_multi_bio replaced with btrfs_bio (FATE#306586).
- btrfs: new ioctls to do logical->inode and inode->path resolving
  (FATE#306586).
- btrfs scrub: add fixup code for errors on nodatasum files
  (FATE#306586).
- btrfs scrub: use int for mirror_num, not u64 (FATE#306586).
- btrfs: add mirror_num to extent_read_full_page (FATE#306586).
- btrfs scrub: bugfix: mirror_num off by one (FATE#306586).
- btrfs scrub: print paths of corrupted files (FATE#306586).
- btrfs scrub: added unverified_errors (FATE#306586).
- btrfs: added helper functions to iterate backrefs (FATE#306586).
- btrfs: use readahead API for scrub (FATE#306586).
- btrfs: hooks for readahead (FATE#306586).
- btrfs: initial readahead code and prototypes (FATE#306586).
- btrfs: state information for readahead (FATE#306586).
- btrfs: add READAHEAD extent buffer flag (FATE#306586).
- btrfs: add an extra wait mode to read_extent_buffer_pages
  (FATE#306586).
- Btrfs: fix delayed insertion reservation (FATE#306586).
- Btrfs: ClearPageError during writepage and clean_tree_block
  (FATE#306586).
- Btrfs: be smarter about committing the transaction in
  reserve_metadata_bytes (FATE#306586).
- Btrfs: make a delayed_block_rsv for the delayed item insertion
  (FATE#306586).
- Btrfs: add a log of past tree roots (FATE#306586).
- btrfs: separate superblock items out of fs_info (FATE#306586).
- Btrfs: use the global reserve when truncating the free space
  cache inode (FATE#306586).
- Btrfs: release metadata from global reserve if we have to
  fallback for unlink (FATE#306586).
- Btrfs: make sure to flush queued bios if write_cache_pages waits
  (FATE#306586).
- Btrfs: fix extent pinning bugs in the tree log (FATE#306586).
- Btrfs: make sure btrfs_remove_free_space doesn't leak EAGAIN
  (FATE#306586).
- Btrfs: don't wait as long for more batches during SSD log commit
  (FATE#306586).
- btrfs: ratelimit WARN_ON in use_block_rsv (FATE#306586).
- btrfs: do not allow mounting non-subvolumes via subvol option
  (FATE#306586).
- Btrfs: close all bdevs on mount failure (FATE#306586).
- Btrfs: fix a bug when opening seed devices (FATE#306586).
- btrfs: fix oops on failure path (FATE#306586).
- Btrfs: fix race between multi-task space allocation and caching
  space (FATE#306586).
- Btrfs: fix return value of btrfs_get_acl() (FATE#306586).
- Btrfs: pass the correct root to lookup_free_space_inode()
  (FATE#306586).
- Btrfs: do not set EXTENT_DIRTY along with EXTENT_DELALLOC
  (FATE#306586).
- Btrfs: fix direct-io vs nodatacow (FATE#306586).
- Btrfs: remove BUG_ON() in compress_file_range() (FATE#306586).
- Btrfs: fix array bound checking (FATE#306586).
- btrfs: return EINVAL if start > total_bytes in fitrim ioctl
  (FATE#306586).
- Btrfs: honor extent thresh during defragmentation (FATE#306586).
- btrfs: trivial fix, a potential memory leak in
  btrfs_parse_early_options() (FATE#306586).
- Btrfs: fix wrong max_to_defrag in btrfs_defrag_file()
  (FATE#306586).
- Btrfs: use i_size_read() in btrfs_defrag_file() (FATE#306586).
- Btrfs: fix defragmentation regression (FATE#306586).
- btrfs: fix memory leak in btrfs_defrag_file (FATE#306586).
- btrfs: check file extent backref offset underflow (FATE#306586).
- Btrfs: don't flush the cache inode before writing it
  (FATE#306586).
- Btrfs: if we have a lot of pinned space, commit the transaction
  (FATE#306586).
- Btrfs: seperate out btrfs_block_rsv_check out into 2 different
  functions (FATE#306586).
- Btrfs: reserve some space for an orphan item when unlinking
  (FATE#306586).
- Btrfs: release trans metadata bytes before flushing delayed refs
  (FATE#306586).
- Btrfs: allow shrink_delalloc flush the needed reclaimed pages
  (FATE#306586).
- Btrfs: wait for ordered extents if we're in trouble when
  shrinking delalloc (FATE#306586).
- Btrfs: don't check bytes_pinned to determine if we should
  commit the transaction (FATE#306586).
- Btrfs: fix regression in re-setting a large xattr (FATE#306586).
- Btrfs: fix the amount of space reserved for unlink
  (FATE#306586).
- Btrfs: wait for ordered extents if we didn't reclaim enough
  (FATE#306586).
- Btrfs: inline checksums into the disk free space cache
  (FATE#306586).
- Btrfs: take overflow into account in reserving space
  (FATE#306586).
- Btrfs: check the return value of filemap_write_and_wait in
  the space cache (FATE#306586).
- Btrfs: add a io_ctl struct and helpers for dealing with the
  space cache (FATE#306586).
- Btrfs: don't skip writing out a empty block groups cache
  (FATE#306586).
- Btrfs: introduce mount option no_space_cache (FATE#306586).
- Btrfs: only inherit btrfs specific flags when creating files
  (FATE#306586).
- Btrfs: allow us to overcommit our enospc reservations
  (FATE#306586).
- Btrfs: break out of orphan cleanup if we can't make progress
  (FATE#306586).
- Btrfs: use the global reserve as a backup for deleting inodes
  (FATE#306586).
- Btrfs: stop using write_one_page (FATE#306586).
- Btrfs: introduce convert_extent_bit (FATE#306586).
- Btrfs: check unused against how much space we actually want
  (FATE#306586).
- Btrfs: fix orphan cleanup regression (FATE#306586).
- Btrfs: use the inode's mapping mask for allocating pages
  (FATE#306586).
- Btrfs: delay iput when deleting a block group (FATE#306586).
- Btrfs: make sure to unset trans->block_rsv before running
  delayed refs (FATE#306586).
- Btrfs: stop passing a trans handle all around the reservation
  code (FATE#306586).
- Btrfs: don't get the block_rsv in btrfs_free_tree_block
  (FATE#306586).
- Btrfs: use the transactions block_rsv for the csum root
  (FATE#306586).
- Btrfs: handle enospc accounting for free space inodes
  (FATE#306586).
- Btrfs: put the block group cache after we commit the super
  (FATE#306586).
- Btrfs: set truncate block rsv's size (FATE#306586).
- Btrfs: don't increase the block_rsv's size when emergency
  allocating space (FATE#306586).
- Btrfs: fix space leak when we fail to make an allocation
  (FATE#306586).
- Btrfs: fix call to btrfs_search_slot in free space cache
  (FATE#306586).
- Btrfs: allow callers to specify if flushing can occur for
  btrfs_block_rsv_check (FATE#306586).
- Btrfs: reduce the amount of space needed for truncates
  (FATE#306586).
- Btrfs: only reserve space in fallocate if we have to do a
  preallocate (FATE#306586).
- Btrfs: kill btrfs_truncate_reserve_metadata (FATE#306586).
- Btrfs: optimize how we account for space in truncate
  (FATE#306586).
- Btrfs: don't try to commit in btrfs_block_rsv_check
  (FATE#306586).
- Btrfs: kill unused parts of block_rsv (FATE#306586).
- Btrfs: ratelimit the generation printk for the free space cache
  (FATE#306586).
- Btrfs: fix how we reserve space for deleting inodes
  (FATE#306586).
- Btrfs: kill the durable block rsv stuff (FATE#306586).
- Btrfs: kill the orphan space calculation for snapshots
  (FATE#306586).
- Btrfs: calculate checksum space correctly (FATE#306586).
- Btrfs: skip looking for delalloc if we don't have
  - >fill_delalloc (FATE#306586).
- Btrfs: use bytes_may_use for all ENOSPC reservations
  (FATE#306586).
- Btrfs: fix how we mount subvol=<whatever> (FATE#306586).
- Btrfs: use d_obtain_alias when mounting subvol/subvolid
  (FATE#306586).
- Btrfs: kill reserved_bytes in inode (FATE#306586).
- Btrfs: move stuff around in btrfs_inode to get better packing
  (FATE#306586).
- commit ba3fdbf
* Wed Dec 14 2011 mmarek@suse.cz
- rpm/kernel-source.spec.in, rpm/mkspec: Fix tarball URL for -rcX and
  do not generate any URL for linux-next and vanilla snapshots.
- commit 1548daf
* Wed Dec 14 2011 mmarek@suse.cz
- rpm/kernel-source.spec.in, rpm/mkspec: Fix linux tarball URL
- commit 5453f99
* Tue Dec 13 2011 bpoirier@suse.de
- batman-adv: Only write requested number of byte to user buffer
  (bnc#736149 CVE-2011-4604).
- batman-adv: bat_socket_read missing checks (bnc#736149
  CVE-2011-4604).
- commit 94c2b73
* Tue Dec 13 2011 agraf@suse.de
- doc/config-options.changes: add CONFIG_DEBUG_STACKOVERFLOW change
- commit 42de6ff
* Tue Dec 13 2011 agraf@suse.de
- PPC: Update config files: disable CONFIG_DEBUG_STACKOVERFLOW
- commit 4d462dd
* Mon Dec 12 2011 aj@suse.de
- Silence missing defattr warning.
- commit e7e3743
* Mon Dec 12 2011 aj@suse.de
- Silence warning about dangling symlink and vdsos
- commit 701c5c7
* Mon Dec 12 2011 mmarek@suse.cz
- Revert "USB: fix ehci alignment error".
- kabi/severities: Check drivers/usb again
- commit 6f443ef
* Mon Dec 12 2011 trenn@suse.de
- x86, x2apic: Enable the bios request for x2apic optout.
- commit c1c0cfd
* Sat Dec 10 2011 jslaby@suse.cz
- Revert "Import 12.1 GA kabi files."
  This reverts commit b888bde97978ecb527b6ab1c68edf71b63039c2b.
  We don't need them in stable.
- commit d70fd6b
* Sat Dec 10 2011 jslaby@suse.cz
- Linux 3.1.5.
- Delete
  patches.fixes/drm-radeon-kms-fix-up-gpio-i2c-mask-bits-for-r4xx.patch.
- commit fe92352
* Sat Dec 10 2011 jslaby@suse.cz
- media/staging: fix allyesconfig build error.
- Refresh
  patches.drivers/0014-media-staging-as102-Enable-compilation.patch.
- commit 28aa839
* Fri Dec  9 2011 aj@suse.de
- No self-obsoletions.
- commit 1d2e747
* Fri Dec  9 2011 aj@suse.de
- Do not show rpmlint warnings.
- commit bb45b41
* Fri Dec  9 2011 aj@suse.de
- Use versioned provides/obsoletes.
- commit cf4f296
* Fri Dec  9 2011 aj@suse.de
- Adjust kernel-source.rpmlintrc for Linux 3.x
- commit bc1534e
* Thu Dec  8 2011 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Do not package the vmlinux image in the devel
  package.
- commit 02bb976
* Wed Dec  7 2011 aj@suse.de
- Use GPL-2.0 as license tag (from http://spdx.org/licenses/)
  Only have one licenses line per file, the rest was just duplicated.
- commit f7c443c
* Wed Dec  7 2011 aj@suse.de
- Fix typo: Base package should not conflict with itself but with main package.
- commit e961ef0
* Tue Dec  6 2011 jeffm@suse.com
- Update to 3.2-rc4.
  - Eliminated 1 patch.
- commit a7d546d
* Mon Dec  5 2011 agraf@suse.de
- ARM: Update config files: omap: enable power management
- commit b97f846
* Sat Dec  3 2011 mmarek@suse.cz
- kabi: fix jiffies_to_clock_t breakage.
- commit c361d8d
* Fri Dec  2 2011 mmarek@suse.cz
- kabi/severities: Ignore changes to usb, nfs and some drivers for now.
- commit c267225
* Fri Dec  2 2011 mmarek@suse.cz
- Import 12.1 GA kabi files.
- commit b888bde
* Thu Dec  1 2011 mhocko@suse.cz
- mm: Ensure that pfn_valid is called once per pageblock when
  reserving pageblocks (bnc#731261, bnc#730731).
- commit 2d4e916
* Tue Nov 29 2011 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Make the -base package conflict with the main
  one.
- commit 45ada0d
* Tue Nov 29 2011 jslaby@suse.cz
- Linux 3.1.4.
- commit f68e526
* Mon Nov 28 2011 jeffm@suse.com
- Fix kernel-source spec to give ownership of the /usr/src/linux link
  to kernel-devel. kernel-source depends on kernel-devel, so this is correct.
- commit 7160a9c
* Mon Nov 28 2011 jbeulich@novell.com
- Refresh patches.xen/xen-pcpu-hotplug.
- Refresh patches.xen/xen3-patch-3.2-rc3.
- commit 7956240
* Mon Nov 28 2011 jbeulich@novell.com
- Update Xen patches to 3,2-rc3 and c/s 1127.
- Update frontswap patches to v10.
- config.conf: Re-enable Xen.
- Update config files.
- commit b08ea4f
* Mon Nov 28 2011 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Ignore staging failures only in vanilla only
  branches.
- commit eeaaaf1
* Mon Nov 28 2011 mmarek@suse.cz
- Build the kotd against 12.1, not Factory.
- commit 2787ebe
* Mon Nov 28 2011 trenn@suse.de
- intel_idle: Fix kvm -cpu host Null pointer enter function issue
  (bnc#726296).
- commit 84d23cb
* Sun Nov 27 2011 jslaby@suse.cz
- Linux 3.1.3.
- commit e70a1d9
* Fri Nov 25 2011 agraf@suse.de
- ARM: config: omap: set omap_fb=y
- commit c1efd33
* Fri Nov 25 2011 agraf@suse.de
- ARM: config: omap: disable OMAP2 to fix reboots
- commit 2d07cf1
* Fri Nov 25 2011 agraf@suse.de
- ARM: config: omap: enable DVI
- commit 40ecc5c
* Fri Nov 25 2011 agraf@suse.de
- ARM: config: omap: enable ehci
- commit 96a74f9
* Fri Nov 25 2011 agraf@suse.de
- ARM: config: omap: enable pandaboard usb
- commit bab20e3
* Fri Nov 25 2011 agraf@suse.de
- ARM: config: omap: enable pandaboard LAN
- commit db7157b
* Fri Nov 25 2011 agraf@suse.de
- ARM: configs: Align with non-arm configs
- commit 9a9b9ee
* Fri Nov 25 2011 agraf@suse.de
- new script common_config.sh: find identical config options
- commit 1562f91
* Fri Nov 25 2011 agraf@suse.de
- ARM: configs: enable devtmpfs on all targets
- commit 5c31b37
* Fri Nov 25 2011 jeffm@suse.com
- Update config files for vanilla.
- commit 4c5b0b9
* Fri Nov 25 2011 jeffm@suse.com
- Update to 3.2-rc3.
  - stack unwind: cfi_ignore takes more arguments.
  - iio: Fix build error in industrialio-core.c.
- commit 48ef020
* Thu Nov 24 2011 ohering@suse.de
- ata_piix: ignore disks in a hyper-v guest.
- commit d0bebdb
* Thu Nov 24 2011 mmarek@suse.cz
- rpm/try-disable-staging-driver: Script to disable failing staging
  driver and restart make.
- commit 819d1fa
* Thu Nov 24 2011 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Do not have a separate make invocation for
  s390 and the rest.
- commit d72f6c1
* Thu Nov 24 2011 jdelvare@suse.de
- patches.fixes/drm-radeon-kms-fix-up-gpio-i2c-mask-bits-for-r4xx.patch: Add missing git-commit.
- commit 3556d24
* Thu Nov 24 2011 agraf@suse.de
- ARM: Update config file file i.MX51 (disable i.MX53)
- commit 6557e92
* Wed Nov 23 2011 agraf@suse.de
- ARM: Refresh patches.arch/arm-phys-offset.patch. (fix warnings)
- commit 519c94a
* Wed Nov 23 2011 agraf@suse.de
- ARM: create uImage, not zImage, so we can boot with u-boot
- commit 63a7b2c
* Wed Nov 23 2011 jdelvare@suse.de
- drm/radeon/kms: fix up gpio i2c mask bits for r4xx (bnc#691052).
- commit 6c3bb8d
* Wed Nov 23 2011 agraf@suse.de
- ARM: Fix compile breakage for generic kernel.
- commit 9d31b12
* Tue Nov 22 2011 agraf@suse.de
- ARM: Update config files: fix several issues in 3.2
- commit 3488f8d
* Tue Nov 22 2011 agraf@suse.de
- ARM: Update config files: disable broken eth driver
- commit 3729fdf
* Tue Nov 22 2011 jslaby@suse.cz
- Linux 3.1.2.
- commit 51ae099
* Tue Nov 22 2011 agraf@suse.de
- ARM: Update config files: run_oldconfig.sh
- commit ae90ef9
* Tue Nov 22 2011 agraf@suse.de
- ARM: fix run_oldconfig.sh
- commit 0362ed5
* Tue Nov 22 2011 agraf@suse.de
- ARM: Use zImage, not vmlinux
  On ARM we use the arch/arm/boot/zImage file similar to x86 to boot systems.
  Put that into the rpm as vmlinuz instead of the vmlinux ELF binary.
- commit 4c08eb0
* Tue Nov 22 2011 agraf@suse.de
- ARM: Dont generalize the target
  On ARM we can not build generic kernels that work through different generations,
  such as armv5 and armv7. So we better list them explicitly and not export an rpm
  that wouldn't even work on the respective architecture :).
- commit 854928d
* Thu Nov 17 2011 bpoirier@suse.de
- dm-raid45: split region hash and log, used by mirror and raid45.
- Update config files.
- commit a85f754
* Wed Nov 16 2011 jslaby@suse.cz
- add as102 dvb-t driver to staging
- staging: as102: Initial import from Abilis.
- staging: as102: Fix CodingStyle errors in file as102_drv.c.
- staging: as102: Fix CodingStyle errors in file as102_fw.c.
- staging: as102: Fix CodingStyle errors in file as10x_cmd.c.
- staging: as102: Fix CodingStyle errors in file
  as10x_cmd_stream.c.
- staging: as102: Fix CodingStyle errors in file as102_fe.c.
- staging: as102: Fix CodingStyle errors in file as102_usb_drv.c.
- staging: as102: Fix CodingStyle errors in file as10x_cmd_cfg.c.
- staging: as102: Add Elgato EyeTV DTT Deluxe.
- staging: as102: Properly handle multiple product names.
- staging: as102: Fix licensing oversight.
- staging: as102: Remove non-linux headers inclusion.
- staging: as102: Convert the comments to kernel-doc style.
- staging: as102: Enable compilation.
- staging: as102: Add nBox Tuner Dongle support.
- staging: as102: Unconditionally compile code dependent on
  DVB_CORE.
- staging: as102: Remove conditional compilation based on
  kernel version.
- Update config files.
- commit f08cab1
* Wed Nov 16 2011 jeffm@suse.com
- Update to 3.2-rc2.
  - Eliminated 1 patch.
- commit 85c9930
* Wed Nov 16 2011 jeffm@suse.com
- Update to 3.2-rc1.
  - Eliminate 212 patches.
- commit 6318d5b
* Tue Nov 15 2011 jeffm@suse.com
- Update Patch-mainline headers.
- commit e170ca1
* Mon Nov 14 2011 awafaa@opensuse.org
- Add package descriptions for ARM kernels
- Add ARM support for iMX51, OMAP2plus & Tegra SoC
- commit 51ebb2d
* Mon Nov 14 2011 jeffm@suse.com
- Updated incorrect Patch-mainline header.
- commit ef7dc61
* Sat Nov 12 2011 adrian@suse.de
- initial armv7l default kernel config, everything enable except the non compiling modules
- commit 7a5cd10
* Sat Nov 12 2011 gregkh@suse.de
- Linux 3.1.1.
- Update config files.
- Refresh patches.fixes/scsi-dh-queuedata-accessors.
- Refresh
  patches.suse/staging-hv-staging-next-20110829-0327-Staging-hv-storvsc-Add-the-contents-of-hyperv_sto.patch.
- Refresh patches.xen/xen-x86-no-lapic.
- Delete
  patches.drivers/alsa-hda-0002-Keep-EAPD-turned-on-for-old-Conexant-chips.
- Delete
  patches.drivers/alsa-hda-0003-Fix-ADC-input-amp-handling-for-Cx20549.
- Delete
  patches.drivers/alsa-hda-0004-Add-missing-static-ADC-tables-for-ALC269-qu.
- Delete
  patches.drivers/alsa-hda-0005-realtek-Skip-invalid-digital-out-pins.
- Delete patches.fixes/drm-radeon-kms-fix-i2c-masks.patch.
- Delete
  patches.suse/staging-hv-staging-next-20111001-0058-staging-hv-fix-a-kernel-warning-in-netvsc_linkstat.patch.
- Delete
  patches.suse/staging-hv-staging-next-20111001-0129-Staging-hv-Add-support-for-2-TB-LUN-in-storage-dr.patch.
- commit ce7f6bd
* Mon Nov  7 2011 neilb@suse.de
- sunrpc: wake up SOFTCONN tasks when a connection error happens
  (bnc#679059).
- commit f97b834
* Sat Nov  5 2011 trenn@suse.de
- X86: Solve Dell Latitudes do not reboot on x86_64 more
  generally.
- commit b3cc84a
* Thu Nov  3 2011 mszeredi@suse.cz
- patches.fixes/hfs-fix-hfs_find_init-sb-ext_tree-null-ptr-oops.patch:
  hfs: fix hfs_find_init() sb->ext_tree NULL ptr oops
  (CVE-2011-2203 bnc#699709).
- commit 7923119
* Thu Nov  3 2011 tiwai@suse.de
- ALSA: hda/realtek - Skip invalid digital out pins (bnc#727348).
- ALSA: hda - Add missing static ADC tables for ALC269 quirks.
- commit 102bac3
* Thu Nov  3 2011 jdelvare@suse.de
- patches.fixes/drm-radeon-kms-fix-i2c-masks.patch: Add git commit ID.
- commit ee8439f
* Thu Nov  3 2011 mhocko@suse.cz
- oom: thaw threads if oom killed thread is frozen before
  deferring (bnc#723999).
- commit 74af598
* Thu Nov  3 2011 jeffm@suse.com
- Re-disabled patches.xen/xencons-tty_mutex.patch
- commit 187dde0
* Thu Nov  3 2011 jeffm@suse.com
- Re-added patches accidentally dropped with commit 28551a0c.
- commit 3795fde
* Thu Nov  3 2011 jbeulich@novell.com
- Update Xen patches to 3.1-final and c/s 1123.
- commit 35973e8
* Wed Nov  2 2011 jeffm@suse.com
- Add Elantech touchpad v3/v4 support (bnc#716852):
  - Input: elantech - add v3 hardware support.
  - Input: elantech - add v4 hardware support.
  - Input: elantech - better support all those v2 variants.
  - Input: elantech - clean up elantech_init.
  - Input: elantech - correct x, y value range for v2 hardware.
  - Input: elantech - get rid of ETP_2FT_* in elantech.h.
  - Input: elantech - packet checking for v2 hardware.
  - Input: elantech - remove ETP_EDGE_FUZZ_V2.
  - Input: elantech - remove module parameter force_elantech.
  - Input: elantech - use firmware provided x, y ranges.
- commit 28551a0
* Sun Oct 30 2011 mmarek@suse.cz
- rpm/{arch-symbols,mkspec}: Add support for ARM
  The various ARM families need similar handling like i?86.
- commit 0c6be6b
* Thu Oct 27 2011 tiwai@suse.de
- ALSA: hda - Fix ADC input-amp handling for Cx20549 codec.
- ALSA: hda - Keep EAPD turned on for old Conexant chips.
- ALSA: hda/realtek - Fix missing volume controls with ALC260
  (bnc#726812).
- commit 08229b0
* Tue Oct 25 2011 ohering@suse.de
- tty deadlock in kernel-xen, xenconsole (bnc#726333).
- commit 68289aa
* Tue Oct 25 2011 eich@suse.de
-  patches.suse/SUSE-bootsplash: remove DEBUG macro which was
  left in the code by accident.
- commit a56ba15
* Mon Oct 24 2011 jeffm@suse.com
- Update to 3.1-final.
- commit ec0449c
* Mon Oct 24 2011 ohering@suse.de
- patches.suse/staging-hv-pata_piix-ignore-disks.patch:
  Update comments in code and reduce patch size
- commit 8913d07
* Thu Oct 20 2011 eich@suse.de
- bootsplash: fix logo location when a splash image with an off-center
  logo is rescaled (bnc #722471).
- commit f6d77d4
* Tue Oct 18 2011 jeffm@suse.com
- -Update to 3.1-rc10.
- commit 239957e
* Mon Oct 17 2011 jslaby@suse.cz
- Linux 3.0.7.
- commit b7d5dba
* Fri Oct 14 2011 trenn@suse.de
- x86: Fix reboot issue for Dell Optiplex 990.
- commit 00ea2b5
* Fri Oct 14 2011 mmarek@suse.cz
- rpm/*.spec.in, rpm/mkspec: Generate specfiles according to Factory
  requirements.
- commit aebe2d9
* Thu Oct 13 2011 ohering@suse.de
- series.conf: really apply all hv_mouse patches
- commit 11f65b5
* Wed Oct 12 2011 ohering@suse.de
- Various updates for hv drivers, which fix also the hv_mouse driver
- staging: hv: storvsc: ignore SET_WINDOWN scsi command
  (bnc#722646).
- staging/hv: advertise hv_storvsc instead of storvsc as sysfs
  driver name (bnc#716708).
- staging/hv: fill scsi/proc_name for the sake of mkinitrd
  (bnc#716708).
- Staging: hv: util: Invoke cn_netlink_send() in a work context.
- Refresh patches.suse/staging-hv-pata_piix-ignore-disks.patch.
- Refresh patches.xen/xen3-patch-2.6.32.
- Delete patches.suse/staging-hv-vmbus-modalias-show.patch.
- commit c836841
* Wed Oct 12 2011 eich@suse.de
- SUSE-bootsplash: Don't crash when splash is turned off.
  Fix crash when splash is off (ie. (struct fb_info *)->splash_data == NULL)
  but someone tries to manipulate the splash image thru the /proc interface.
  All other functions in render.c seem to be save - ie. upper level code
  already protects them from being called if the splash_data member is NULL
  (bnc #718666).
- commit 2fc2aaf
* Tue Oct 11 2011 jdelvare@suse.de
- drm/radeon/kms: Fix I2C mask definitions (bnc#712023).
- commit d4a7ce4
* Fri Oct  7 2011 jbeulich@novell.com
- Update Xen patches to 3.1-rc9 and c/s 1116.
- commit 8f986a2
* Thu Oct  6 2011 jdelvare@suse.de
- drm/radeon/kms: Fix I2C mask definitions (bnc#712023).
- commit f1106c1
* Wed Oct  5 2011 jbeulich@novell.com
- patches.suse/supported-flag: Also look for Module.supported in the
  source tree.
- Refresh patches.suse/supported-flag-enterprise.
- commit 9c8680a
* Wed Oct  5 2011 jeffm@suse.com
- Update to 3.1-rc9.
- commit a477439
* Tue Oct  4 2011 jslaby@suse.cz
- vmscan: clear ZONE_CONGESTED for zone with good watermark
  (MM fixes 3.0 to 3.1-rc4 not in -stable).
- mm: vmscan: drop nr_force_scan[] from get_scan_count (MM fixes
  3.0 to 3.1-rc4 not in -stable).
- mm: vmscan: fix force-scanning small targets without swap
  (MM fixes 3.0 to 3.1-rc4 not in -stable).
- mm/memory.c: remove ZAP_BLOCK_SIZE (MM fixes 3.0 to 3.1-rc4
  not in -stable).
- mm/huge_memory.c: minor lock simplification in __khugepaged_exit
  (MM fixes 3.0 to 3.1-rc4 not in -stable).
- mm: swap-token: makes global variables to function local
  (MM fixes 3.0 to 3.1-rc4 not in -stable).
- commit 34e40aa
* Tue Oct  4 2011 jslaby@suse.cz
- Linux 3.0.6.
- Refresh patches.fixes/bridge-module-get-put.patch.
- Delete patches.fixes/pty-fix-pty-counting.patch.
- Delete patches.fixes/tg3-Fix-io-failures-after-chip-reset.patch.
- commit 8eedfe8
* Mon Oct  3 2011 jeffm@suse.com
- Update to 3.1-rc8.
- commit 6c33ac4
* Wed Sep 28 2011 jbeulich@novell.com
- Update Xen config files.
- commit 50fb02f
* Tue Sep 27 2011 eich@suse.de
- Refresh patches.suse/SUSE-bootsplash.
  Fix crash when updating boxes: Don't reallocate
  picture.
- commit ba0cfdc
* Mon Sep 26 2011 mmarek@suse.cz
- rpm/host-memcpy-hack.h: Hack to use older version of the memcpy symbol
  in userspace programs, so that they keep working on older systems.
- rpm/kernel-binary.spec.in: Pass -include
  %%_sourcedir/host-memcpy-hack.h to the compiler when compiling
  userspace programs.
- commit e3c78cf
* Mon Sep 26 2011 jbeulich@novell.com
- Update Xen patches to 3.1-rc7 and c/s 1105.
- pass PCI segment information to Xen.
- ACPI: Implement overriding of arbitrary ACPI tables via initrd.
- x86: allow NVS can be accessed by driver.
- commit 7de39e8
* Mon Sep 26 2011 jeffm@suse.com
- Update to 3.1-rc7.
- commit ee8cc90
* Thu Sep 22 2011 mmarek@suse.cz
- rpm/split-modules: Print the full path for modules missing in supported.conf
- commit e55e4c6
* Thu Sep 22 2011 mmarek@suse.cz
- supported.conf: Fix stray line making net/atm/atm suddenly unsupported.
- commit 58dbd06
* Wed Sep 21 2011 mmarek@suse.cz
- Add support for wildcards in supported.conf
- rpm/kernel-binary.spec.in: Generate Module.supported with all
  lines from supported conf, unsupported modules are marked as "no"
- rpm/split-modules: Use the supported flag in modules, instead of
  parsing the Module.supported file and report modules that have no
  supported marking.
- rpm/check-supported-list: Delete, this is done by split-modules
  now.
- commit edfdc2a
* Wed Sep 21 2011 trenn@suse.de
- Refresh
  patches.arch/acpi_implement_overriding_of_arbitrary_acpi_tables_via_initrd.patch.
  - > Fix build on ia64, by moving asm/e820.h into ifdef config protected region.
- commit 0ac4276
* Wed Sep 21 2011 mhocko@suse.cz
- Provide memory controller swap extension.
  Keep the feature disabled by default. Use swapaccount=1 kernel
  boot parameter for enabling it.
- commit 000742c
* Wed Sep 21 2011 mhocko@suse.cz
- Update config files.
  Clean run_oldconfig.sh run to get configs into sync
- commit c985824
* Tue Sep 20 2011 trenn@suse.de
- ACPI: Implement overriding of arbitrary ACPI tables via initrd
  (none).
- ACPICA: Fix wrongly mapped acpi table header when overriding
  via initrd (none).
- ACPICA: Introduce acpi_os_phys_table_override function (none).
- x86: allow NVS can be accessed by driver (none).
- Update config files:
  CONFIG_ACPI_INITRD_TABLE_OVERRIDE=y
  on i386 and x86_64 flavors
- commit 34bb195
* Thu Sep 15 2011 jeffm@suse.de
- Update to 3.1-rc6.
- commit 8f0eaba
* Thu Sep 15 2011 jbeulich@novell.com
- patches.arch/x86_64-unwind-annotations: Fix unwinding through
  interrupt frames, requiring ...
- patches.suse/stack-unwind: ... support for DW_CFA_def_cfa_expression.
- commit 4d917a5
* Wed Sep 14 2011 agraf@suse.de
- KVM: PPC: Fix incorrect CBE KVM hooks.
  There is another issue with KVM_HV and CBE that I only saw building
  this tree, so the patch is on its way to the kvm tree now.
- KVM: PPC: Assemble book3s{,_hv}_rmhandlers.S separately
  When building KVM HV mode with plenty other options enabled, the build
  fails. That's fixed upstream, but 3.1-rc5 doesn't have the patch yet.
  So I pulled it in from the kvm tree.
- commit 2be41bd
* Mon Sep 12 2011 jbeulich@novell.com
- Re-enabled patches.arch/x86_64-unwind-annotations.
- commit bfd10a0
* Mon Sep 12 2011 jbeulich@novell.com
- Refresh patches.arch/x86_64-unwind-annotations.
- Refresh patches.suse/supported-flag.
- commit aa89174
* Mon Sep 12 2011 jbeulich@novell.com
- Update Xen patches to 3.1-rc5 and c/s 1104.
- mm: frontswap: config and doc files.
- mm: frontswap: core code.
- mm: frontswap: add swap hooks and extend try_to_unuse.
- mm: frontswap: swap data structure changes.
- In HVM guests do not take over the CDROM device (bnc#645893).
- x86: report ACPI-reserved state of PCI MMCONFIG region to
  hypervisor.
- config.conf: Re-enable Xen flavors.
- Update config files.
- commit 3692f47
* Sun Sep 11 2011 agraf@suse.de
- Update config files (disable EHCA on PPC - gcc bug)
- commit 03a0c8c
* Sun Sep 11 2011 agraf@suse.de
- Update config files (enable KVM on PPC64 for OBS)
- commit 00b922d
* Mon Sep  5 2011 mmarek@suse.cz
- Update to 3.1-rc5 from https://github.com/torvalds/linux.git.
- commit 8a211c9
* Fri Sep  2 2011 ohering@suse.de
- Staging: hv: vmbus: Show the modalias in /sys/bus/vmbus/devices/*/
  (fate#311487).
- commit 94054c9
* Thu Sep  1 2011 ohering@suse.de
- ata_piix: ignore disks in a hyper-v guest.
- Staging: hv: vmbus: Don't wait indefinitely for IRQ resouces.
- Staging: hv: tools: Fix a checkpatch warning in hv_kvp_daemon.c.
- Staging: hv: vmbus: Fix checkpatch warnings.
- Staging: hv: util: kvp: Fix the reported OSVersion string.
- Staging: hv: util: kvp: Cleanup kvp_get_domain_name().
- Staging: hv: Fix macros, tab errors and warning in
  drivers/staging/hv/hv_mouse.c.
- Staging: hv: vmbus: VMBUS is an ACPI enumerated device, get
  rid of the PCI signature.
- Staging: hv: Replace struct hv_guid with the uuid type already
  defined in Linux.
- Staging: hv: vmbus: Introduce vmbus ID space in struct
  hv_driver.
- Staging: hv: blkvsc: Use the newly introduced vmbus ID in the
  blockvsc driver.
- Staging: hv: storvsc: Use the newly introduced vmbus ID in
  storvsc driver.
- Staging: hv: netvsc: Use the newly introduced vmbus ID in
  netvsc driver.
- Staging: hv: mousevsc: Use the newly introduced vmbus ID in
  mouse driver.
- Staging: hv: util: Make hv_utils a vmbus device driver.
- Staging: hv: create VMBUS_DEVICE macro and use it.
- Staging: hv: vmbus: Cleanup vmbus_match().
- Staging: hv: vmbus: Cleanup vmbus_uevent() code.
- Staging: hv: vmbus: Support the notion of id tables in
  vmbus_match().
- Staging: hv: vmbus: Get rid of an unnecessary include line
  in vmbus_drv.c.
- Staging: hv: storvsc: Get rid of the DMI signature.
- Staging: hv: netvsc: Get rid of the PCI signature.
- Staging: hv: netvsc: Get rid of the DMI signature in
  netvsc_drv.c.
- Staging: hv: util: Get rid of the DMI signature in hv_util.c.
- Staging: hv: util: Get rid of the PCI signature in hv_util.c.
- Staging: hv: fix up driver registering mess.
- Staging: hv: vmbus: Get rid of some unnecessary comments.
- Staging: hv: vmbus: Cleanup unnecessary comments in hv.c.
- Staging: hv: vmbus: Cleanup error handling in hv_init().
- Staging: hv: vmbus: Get rid of unnecessay comments in
  connection.c.
- Staging: hv: vmbus: Get rid of the function dump_gpadl_body().
- Staging: hv: vmbus: Get rid of the function dump_gpadl_header().
- Staging: hv: vmbus: Rename openMsg to open_msg in channel.c.
- Staging: hv: vmbus: Get rid of unnecessary comments in
  channel.c.
- Staging: hv: vmbus: Change the variable name openInfo to
  open_info in channel.c.
- Staging: hv: vmbus: Cleanup error values in ringbuffer.c.
- Staging: hv: vmbus: Cleanup the error return value in
  vmbus_recvpacket_raw().
- Staging: hv: netvsc: Get rid of an unnecessary print statement
  in netvsc_probe().
- Staging: hv: vmbus: Retry vmbus_post_msg() before giving up.
- Staging: hv: storvsc: Cleanup error handling in
  storvsc_dev_add().
- Staging: hv: storvsc: Cleanup error handling in
  storvsc_channel_init().
- Staging: hv: storvsc: Cleanup error handling in
  storvsc_connect_to_vsp().
- Staging: hv: storvsc: Cleanup error handling in storvsc_do_io().
- Storage: hv: storvsc: Get rid of some unnecessary DPRINTs
  from storvsc.c.
- Staging: hv: storvsc: Fix/cleanup some dated comments in
  storvsc.c.
- Staging: hv: storvsc: Cleanup returned error code in
  storvsc_host_reset().
- Staging: hv: storvsc: Cleanup error code returned in
  storvsc_probe().
- Staging: hv: storvsc: Cleanup returned error code in
  storvsc_drv_init().
- Staging: hv: netvsc: Cleanup the returned error code in
  netvsc_probe().
- Staging: hv: netvsc: Cleanup error return codes in
  netvsc_destroy_recv_buf().
- Staging: hv: netvsc: Cleanup error return values in
  netvsc_init_recv_buf().
- Staging: hv: netvsc: Cleanup error returns in
  netvsc_connect_vsp().
- Staging: hv: netvsc: Cleanup error return values in
  netvsc_send().
- Staging: hv: netvsc: Cleanup error return codes in
  netvsc_device_add().
- Staging: hv: netvsc: Cleanup error codes in
  rndis_filter_receive().
- Staging: hv: netvsc: Cleanup error code in
  rndis_filter_query_device().
- Staging: hv: netvsc: Cleanup error return values in
  rndis_filter_set_packet_filter().
- Staging: hv: netvsc: Cleanup error returns in
  rndis_filter_init_device().
- Staging: hv: netvsc: Cleanup error code in
  rndis_filter_device_add().
- Staging: hv: mouse: Change the jump label Cleanup to cleanup.
- Staging: hv: netvsc: Change the jump label Cleanup to cleanup.
- Staging: hv: netvsc: Change the jump label Exit to exit.
- Staging: hv: mouse: Get rid of the unused PCI signature.
- Staging: hv: hv_mouse: remove deviceinfo_callback function.
- Staging: hv: hv_mouse: remove inputreport_callback function.
- Staging: hv: hv_mouse: remove a forward declaration.
- Staging: hv: hv_mouse: fix up remove() function.
- Staging: hv: Add struct hv_vmbus_device_id to mod_devicetable.h.
- Staging: hv: add driver_data to hv_vmbus_device_id.
- Staging: hv: Add code to parse struct hv_vmbus_device_id table.
- Staging: hv: file2alias: fix up alias creation logic for
  hv_vmbus_device_id.
- Staging: hv: storvsc: Inline free_stor_device().
- Staging: hv: storvsc: Do not aquire an unnecessary reference
  on stor_device.
- Staging: hv: storvsc: Rename must_get_stor_device().
- Staging: hv: storvsc: Rename get_stor_device().
- Staging: hv: storvsc: Cleanup alloc_stor_device().
- Staging: hv: storvsc: Introduce state to manage the lifecycle
  of stor device.
- Staging: hv: storvsc: Prevent outgoing traffic when stor dev
  is being destroyed.
- Staging: hv: storvsc: Get rid of release_stor_device() by
  inlining the code.
- Staging: hv: storvsc: Get rid of final_release_stor_device()
  by inlining code.
- Staging: hv: storvsc: Get rid of the reference counting in
  struct storvsc_device.
- Staging: hv: netvsc: Inline the code for free_net_device().
- Staging: hv: netvsc: Cleanup alloc_net_device().
- Staging: hv: netvsc: Introduce state to manage the lifecycle
  of net device.
- Staging: hv: netvsc: Prevent outgoing traffic when netvsc dev
  is destroyed.
- Staging: hv: netvsc: Get rid of release_outbound_net_device()
  by inlining the code.
- Staging: hv: netvsc: Get rid of release_inbound_net_device()
  by inlining the code.
- Staging: hv: netvsc: Get rid of the refcnt field in struct
  netvsc_device.
- Staging: hv: storvsc: Add code to handle IDE devices using
  the storvsc driver.
- Staging: hv: storvsc: Handle IDE devices using the storvsc
  driver.
- Staging: hv: blkvsc: Get rid of blkvsc_drv.c as this code is
  not used.
- Staging: hv: storvsc: Optimize bounce buffer handling for the
  "write" case.
- Staging: hv: storvsc: Optimize the bounce buffer handling in
  the "read" case.
- Staging: hv: storvsc: Include storvsc.c in storvsc_drv.c.
- Staging: hv: storvsc: Cleanup storvsc_drv.c after adding the
  contents of storvsc.c.
- Staging: hv: storvsc: Add the contents of hyperv_storage.h
  to storvsc_drv.c.
- Staging: hv: storvsc: Cleanup storvsc_drv.c after adding the
  contents of hyperv_storage.h.
- Staging: hv: storvsc: Fixup srb and scsi status for INQUIRY
  and MODE_SENSE.
- Staging: hv: storvsc: Fix a typo.
- Staging: hv: storvsc: In case of scsi errors offline the device.
- Staging: hv: storvsc: No need to copy from bounce buffer in
  case of a failure.
- Staging: hv: util: Forcefully shutdown when shutdown is
  requested.
- Staging: hv: util: Adjust guest time in a process context.
- Staging: hv: vmbus: Check before invoking the channel callback.
- Staging: hv: vmbus: Properly deal with de-registering channel
  callback.
- Staging: hv: Fix a bug in vmbus_match().
- Staging: hv: vmbus: Get rid of vmbus_on_isr() by inlining
  the code.
- Staging: hv: vmbus: Do not enable auto eoi.
- Staging: hv: vmbus: Fixup indentation in vmbus_acpi_add().
- Staging: hv: vmbus: Get rid of some dated/redundant comments.
- Staging: hv: vmbus: Get rid of an unnecessary check in
  vmbus_connect().
- Staging: hv: vmbus: Fix a checkpatch warning in ring_buffer.c.
- Staging: hv: vmbus: Fix checkpatch warnings in connection.c.
- Staging: hv: mousevsc: Fix checkpatch errors and warnings.
- Staging: hv: netvsc: return negative error codes.
- Delete patches.suse/staging-hv-vmbus-init-on-dmi-match.patch.
- commit d77df1b
* Wed Aug 31 2011 jslaby@suse.cz
- TTY: pty, fix pty counting (bnc#711203).
- commit a432f18
* Tue Aug 30 2011 jdelvare@suse.de
- Delete patches.fixes/net-tulip-debug-off-by-default.patch.
  Obsoleted by upstream commit 0b8f6273eb6fd0611849d6fb432151f04e042434.
- commit bd9ecd2
* Tue Aug 30 2011 jslaby@suse.cz
- Linux 3.0.4.
- Refresh patches.arch/reorganize_stop_cpus.patch.
- x86, mtrr: use stop_machine APIs for doing MTRR rendezvous
  (bnc#697859).
- Delete patches.arch/mtrr_stop_machine_quick_fix.patch.
- stop_machine: implement stop_machine_from_inactive_cpu().
- Delete
  patches.arch/implement_stop_machine_from_offline_cpu.patch.
- Delete patches.arch/kill-__stop_machine.patch.
- commit 1fb7ef5
* Tue Aug 30 2011 gregkh@suse.de
- supported.conf: xhci-hcd not xhci. Also move it to +base so you can boot
  off of USB3 devices.
- commit 66f95ad
* Tue Aug 30 2011 gregkh@suse.de
- supported.conf: xhci-hcd not xhci. Also move it to base so you can boot
  off of a USB3 device (bnc#712752)
- commit f6522ba
* Mon Aug 29 2011 jeffm@suse.com
- Re-Refresh patches.rpmify/pti-depends-on-x86-pci.
- commit 626749c
* Mon Aug 29 2011 jeffm@suse.com
- Refresh patches.rpmify/pti-depends-on-x86-pci.
- commit e82bcac
* Mon Aug 29 2011 jeffm@suse.com
- Disabled patches.rpmify/pti-depends-on-x86-pci
- commit 0baba30
* Mon Aug 29 2011 jeffm@suse.com
- Update to 3.1-rc4.
- commit 68e08b1
* Wed Aug 24 2011 jeffm@suse.com
- PTI: depends on X86 && PCI.
- commit e975e4b
* Wed Aug 24 2011 jeffm@suse.com
- scsi_dh_alua: always update TPGS status on activate.
- scsi_dh: Check for sdev state in store_dh_state() (bnc#616080).
- scsi_dh_alua: Evaluate TPGS setting from inquiry data.
- scsi_dh: Implement match callback function.
- Delete patches.fixes/scsi-dh-alua-retry-UA.
- Delete patches.fixes/scsi-dh-alua-send-stpg.
- commit 026eef6
* Wed Aug 24 2011 jeffm@suse.com
- Refresh and re-enable patches.arch/x86_64-hpet-64bit-timer.patch.
- commit bd2f299
* Wed Aug 24 2011 jeffm@suse.com
- Refreshed and re-enabled dm-path patches:
  - patches.suse/dm-mpath-accept-failed-paths.
  - patches.suse/dm-mpath-detach-existing-hardware-handler.
- commit d374e62
* Wed Aug 24 2011 jeffm@suse.com
- Update to 3.1-rc3.
  - Eliminated 8 patches.
  - Xen is disabled.
- commit eccefcc
* Thu Aug 18 2011 eich@suse.de
- * Refresh patches.suse/SUSE-bootsplash.
  * Fix bootsplash code for 15bpp framebuffers.
  These framebuffers are rare these days, the legendary and still
  popular server chipset Radeon ES1000 supports it, though.
- commit 637eb19
* Wed Aug 17 2011 jslaby@suse.cz
- Linux 3.0.3.
- commit e4182fa
* Tue Aug 16 2011 jslaby@suse.cz
- Linux 3.0.2.
- Revert "xen: allow enable use of VGA console on dom0".
- commit 9caf7b1
* Sun Aug 14 2011 trenn@suse.de
- Properly destroy pmsr devices:
  Refresh patches.xen/xen-x86-msr-on-pcpu.
- commit 934d81a
* Sat Aug 13 2011 gregkh@suse.de
- Update config files, enabling CONFIG_RT2800PCI as requested.
- commit b2f65f0
* Tue Aug  9 2011 trenn@suse.de
- Update config files:
  bnc#674988, change:
  - CONFIG_ACPI_CUSTOM_METHOD=m
  +# CONFIG_ACPI_CUSTOM_METHOD is not set
  for all flavors
- commit f1af972
* Fri Aug  5 2011 jslaby@suse.cz
- Linux 3.0.1.
- Refresh
  patches.suse/revert-x86-remove-warning-and-warning_symbol-from-struct-stacktrace_ops.
- Refresh patches.xen/kexec-move-segment-code-i386.patch.
- Refresh patches.xen/kexec-move-segment-code-x86_64.patch.
- Refresh patches.xen/xen3-patch-2.6.36.
- Delete patches.fixes/SCSI-fix-crash-in-scsi_dispatch_cmd.patch.
- commit 191d3db
* Mon Aug  1 2011 mmarek@suse.cz
- rpm/modversions: Support for new genksyms format with E# tags for enum
  constants.
- commit ee6da8c
* Fri Jul 29 2011 jslaby@suse.cz
- tg3: Fix io failures after chip reset (bnc#705962).
- commit c8d864c
* Mon Jul 25 2011 mmarek@suse.cz
- Fix format of patches to apply with series2git:
  patches.arch/s390-message-catalog.diff
  patches.drivers/input-Add-LED-support-to-Synaptics-device
  patches.fixes/kvm-macos.patch
  patches.fixes/mm-Fix-assertion-mapping-nrpages-0-in-end_writeback.patch
  patches.fixes/nfs-slot-table-alloc
  patches.fixes/oom-warning
  patches.fixes/scsi-dh-alua-send-stpg
  patches.suse/0001-vfs-Hooks-for-more-fine-grained-directory-permission.patch
  patches.suse/0002-vfs-Add-generic-IS_ACL-test-for-acl-support.patch
  patches.suse/0015-ext4-Use-IS_POSIXACL-to-check-for-POSIX-ACL-support.patch
  patches.suse/0016-ext4-Implement-richacl-support-in-ext4.patch
  patches.suse/dm-mpath-no-activate-for-offlined-paths
  patches.suse/dm-mpath-no-partitions-feature
  patches.suse/no-frame-pointer-select
  patches.suse/no-partition-scan
  patches.suse/revert-x86-remove-warning-and-warning_symbol-from-struct-stacktrace_ops
  patches.suse/setuid-dumpable-wrongdir
  patches.suse/stack-unwind
  patches.suse/supported-flag-enterprise
- commit b5f5212
* Mon Jul 25 2011 meissner@suse.de
- Powerpc config adjustments
  This makes CONFIG_POWER_SUPPLY=y like in the other architectures,
  it also disables the EHCA driver as gcc 4.6 currently fails to compile
  it correctly.
- commit aa27d23
* Sun Jul 24 2011 jslaby@suse.cz
- fix crash in scsi_dispatch_cmd() (bnc#707853).
- commit dfe0dcf
* Fri Jul 22 2011 mmarek@suse.cz
- Update to 3.0.
- commit 50c05d7
* Thu Jul 21 2011 jbeulich@novell.com
- Update Xen patches to 3.0-rc7 and c/s 1098.
- Update Xen config files.
- commit f4eb207
* Mon Jul 18 2011 jdelvare@suse.de
- tulip: Disable debugging messages by default
- commit 141a54f
* Fri Jul 15 2011 ohering@suse.de
- hv: only load the driver in a hyper-v guest (bnc#704957).
- commit f2f7449
* Thu Jul 14 2011 tiwai@suse.de
- Refresh patches.suse/SUSE-bootsplash.  Fix for nouveau.
- commit 27de298
* Thu Jul 14 2011 tiwai@suse.de
- ALSA: hda - Add Kconfig for the default buffer size
  (bnc#682725).
- Update config files.
- Delete, replaced with the new upstream patch
  patches.drivers/alsa-hda-0019-Increase-default-buffer-size.
- commit 40c7644
* Wed Jul 13 2011 jeffm@suse.com
- Update to 3.0-rc7.
- commit 0de37e1
* Sat Jul  9 2011 jslaby@suse.cz
- Delete patches.fixes/x86_mtrr_stop_machine_1_2.patch.
- Delete patches.fixes/x86_mtrr_use_stop_machine_2_2.patch.
  They were superseded by other patches in
  aa3d6e2b140aac24a432f830d30047b1842aed0b.
- commit 84b09a0
* Sat Jul  9 2011 jslaby@suse.cz
- Linux 2.6.39.3.
- Delete
  patches.fixes/bridge-provide-a-cow_metrics-method-for-fake_ops.patch.
- Delete
  patches.fixes/tty-ldisc-do-not-close-until-there-are-readers.patch.
- commit 8f499df
* Thu Jul  7 2011 jeffm@suse.com
- Update to 3.0-rc6.
  - Eliminated 1 patch.
- commit 56e99da
* Tue Jul  5 2011 jbeulich@novell.com
- Update Xen patches to 3.0-rc5 and c/s 1095.
- xen: prepare tmem shim to handle frontswap.
- support booting Xen from EFI (fate#311376, fate#311529,
  bnc#578927, bnc#628554).
- config.conf: Re-enabled Xen flavors.
- Update x86 config files.
- Delete patches.xen/xen-blkback-bimodal-suse.
- commit 4c2a76f
* Mon Jul  4 2011 tiwai@suse.de
- Fix invalid colormap override in SUSE-bootsplash patch (bnc#584493)
- commit b4495f4
* Wed Jun 29 2011 jeffm@suse.com
- Update to 3.0-rc5.
- commit 9eb1a0f
* Wed Jun 29 2011 jslaby@suse.cz
- TTY: ldisc, do not close until there are readers (bnc#698247
  bnc#693374).
- commit 0615f1a
* Sun Jun 26 2011 jslaby@suse.cz
- Update header: Revert "HID: magicmouse: ignore 'ivalid report id'
  while switching modes"
- commit aff1267
* Sun Jun 26 2011 jslaby@suse.cz
- bridge: provide a cow_metrics method for fake_ops.
- commit 5bff18d
* Fri Jun 24 2011 jeffm@suse.com
- Enable TOMOYO (FATE#310292, bnc#668381).
- commit 997e757
* Fri Jun 24 2011 jslaby@suse.cz
- Linux 2.6.39.2.
- Delete
  patches.fixes/asus-wmi-Remove-__init-from-asus_wmi_platform_init.patch.
- Delete
  patches.kernel.org/0001-Revert-x86-efi-Retain-boot-service-code-until-after-.patch.
- commit a1dc102
* Tue Jun 21 2011 mmarek@suse.cz
- Update vanilla configs.
- commit 1738011
* Tue Jun 21 2011 mmarek@suse.cz
- Update to 3.0-rc4
- commit 1b6bf5d
* Fri Jun 17 2011 mmarek@suse.cz
- rpm/post.sh: Touch /boot/do_purge_kernels on package install
  (fate#312018).
- rpm/postun.sh: Remove it again if it still exists on package
  uninstall.
- commit 82f4a5d
* Fri Jun 17 2011 trenn@suse.de
- stop_machine: implement stop_machine_from_offline_cpu()
  (bnc#697859).
- stop_machine: kill __stop_machine() (bnc#697859).
- x86, mtrr: lock stop machine during MTRR rendezvous sequence
  (bnc#697859).
- stop_machine: reorganize stop_cpus() implementation
  (bnc#697859).
- x86, mtrr: use __stop_machine() for doing MTRR rendezvous
  (bnc#697859).
- commit 303cc0e
* Thu Jun 16 2011 mmarek@suse.cz
- Remove the novfs patches, it should be packaged as a KMP, or
  ideally, reimplemented as a fuse filesystem (which is the reason why
  the current implementation it is never going to be accepted upstream).
- Delete patches.fixes/novfs-copy_user-fixes.diff.
- Delete patches.fixes/novfs-minsize-fixes.
- Delete patches.fixes/novfs-nwcapi.patch.
- Delete patches.suse/novfs-client-module.
- Delete patches.suse/novfs-remove-bkl.
- commit bc3a79d
* Thu Jun 16 2011 tiwai@suse.de
- ALSA: fix hda AZX_DCAPS_NO_TCSEL quirk check in driver_caps
  (bnc#700250,bnc#700251,bnc#700253).
- ALSA: hda - Reorganize controller quriks with bit flags
  (bnc#700250,bnc#700251,bnc#700253).
- ALSA: hda - Enable snoop bit for AMD controllers
  (bnc#700250,bnc#700251,bnc#700253).
- ALSA: hda - Enable sync_write workaround for AMD generically
  (bnc#700250,bnc#700251,bnc#700253).
- ALSA: hda - ALSA HD Audio patch for Intel Panther Point DeviceIDs
  (bnc#700250,bnc#700251,bnc#700253).
- commit e9fb121
* Thu Jun 16 2011 ohering@suse.de
- Update vanilla config files.
- commit a642909
* Thu Jun 16 2011 ohering@suse.de
- rpm/kernel-binary.spec.in:
  jobs is not defined for home: projects, use the new _smp_mflags to enable parallel build
- commit 1009eaf
* Thu Jun 16 2011 ohering@suse.de
- rpm/kernel-binary.spec.in:
  Update comment, get the number of cpus from /proc/stat
- commit b4cf18c
* Wed Jun 15 2011 jeffm@suse.com
- Update config files: Disable BRCMSMAC on ppc/ppc64.
- commit 20b3d8e
* Wed Jun 15 2011 jack@suse.cz
- "Unable to save Login Script" appears when trying to save a
  user login script (bnc#638985).
- commit fb87098
* Wed Jun 15 2011 jack@suse.cz
- fs: novfs: Limit check for datacopy between user and kernel space.
- commit 2985362
* Wed Jun 15 2011 jeffm@suse.com
- Update to 3.0-rc3.
  - Eliminated 2 patches.
- commit a1fe999
* Tue Jun 14 2011 mmarek@suse.cz
- scripts/config.sh: Remove MIRROR handling, _find_tarball() does it
  itself.
- commit 18ad47f
* Mon Jun 13 2011 jeffm@suse.com
- nouveau: Make vga_switcheroo code depend on VGA_SWITCHEROO.
- commit b3f32a6
* Mon Jun 13 2011 jeffm@suse.com
- apm: Honor CONFIG_APM_CPU_IDLE=n.
- commit 8ad9b51
* Mon Jun 13 2011 jeffm@suse.com
- Update config files.
- commit 2cd7359
* Mon Jun 13 2011 jeffm@suse.com
- Delete patches.rpmify/qla4xx-missing-readq-definition.
- commit b48337d
* Mon Jun 13 2011 mmarek@suse.cz
- Remove copypasted lines from vanilla configs.
- commit b395e52
* Mon Jun 13 2011 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Call gzip with -n.
- commit 9a65e48
* Mon Jun 13 2011 mmarek@suse.cz
- rpm/mkspec: Put the -rcX tag into the rpm version instead of the
  trailing zero. Rpm considers "rc" older than "0", so this will sort
  properly.
- commit 8d9b2b9
* Mon Jun 13 2011 mmarek@suse.cz
- x86, build: Do not set the root_dev field in bzImage.
- commit 15e4a82
* Mon Jun 13 2011 mmarek@suse.cz
- rpm/compute-PATCHVERSION.sh: Set default PATCHLEVEL and SUBLEVEL to 0.
  The package version will thus always match the Makefile version and
  the SRCVERSION variable will only be used to determine the tarball
  version.
- rpm/compute-PATCHVERSION.sh: Set default PATCHLEVEL and SUBLEVEL to 0.
  The package version will thus always match the Makefile version and
  the SRCVERSION variable will only be used to determine the tarball
  version.
- rpm/kernel-binary.spec.in: Revert the previous hack.
- commit 95c9977
* Sat Jun 11 2011 jeffm@suse.de
- kbuild: Fix KERNELVERSION for empty SUBLEVEL or PATCHLEVEL.
- kbuild: Fix <linux/version.h> for empty SUBLEVEL or PATCHLEVEL.
- Refresh patches.suse/supported-flag.
- rpm/kernel-binary.spec.in: Hack to work around v3.0 vs v3.0.0
- commit a95ebd8
* Fri Jun 10 2011 jeffm@suse.com
- Delete patches.suse/file-capabilities-disable-by-default.diff.
- commit 2694a88
* Fri Jun 10 2011 jeffm@suse.com
- x86: Remove warning and warning_symbol from struct
  stacktrace_ops.
- Delete
  patches.fixes/asus-wmi-Remove-__init-from-asus_wmi_platform_init.patch.
- commit 608ce9e
* Fri Jun 10 2011 trenn@suse.de
- Update Suresh's patchset to version 3:
- Refresh patches.fixes/x86_mtrr_stop_machine_1_2.patch.
- Refresh patches.fixes/x86_mtrr_use_stop_machine_2_2.patch.
- commit 9f2e923
* Wed Jun  8 2011 jeffm@suse.com
- Revert "Revert "- Updated to 3.0-rc1.""
  This reverts commit b2d9e72dc9cd8e62d49e0565babd76332f7c2114.
  Conflicts:
  rpm/config.sh
  series.conf
- commit 408e273
* Wed Jun  8 2011 jeffm@suse.com
- Update to 3.0-rc2.
- commit b97d26c
* Wed Jun  8 2011 trenn@suse.de
- Update Suresh's version 2 of the patchseries:
- Refresh patches.fixes/x86_mtrr_stop_machine_1_2.patch.
- Refresh patches.fixes/x86_mtrr_use_stop_machine_2_2.patch.
- commit 4ef8999
* Tue Jun  7 2011 mmarek@suse.cz
- rpm/compute-PATCHVERSION.sh: Fix for empty EXTRAVERSION
- commit a0a1386
* Tue Jun  7 2011 mmarek@suse.cz
- rpm/compute-PATCHVERSION.sh: Fix for 3.0
- commit dca1465
* Tue Jun  7 2011 mmarek@suse.cz
- rpm/mkspec: Fix perl warning
- commit 395d7d8
* Tue Jun  7 2011 trenn@suse.de
- x86, mtrr: use __stop_machine() for doing MTRR rendezvous
  (bnc#672008).
- stop_machine: enable __stop_machine() to be called from the
  cpu online path (bnc#672008).
- commit 684cd78
* Mon Jun  6 2011 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Loosen the mkinitrd requirement, this was
  only a workaround for a 11.3 update problem (cf bnc#615680).
- commit 05ade7d
* Sun Jun  5 2011 jslaby@suse.cz
- Revert "HID: magicmouse: ignore 'ivalid report id' while
  switching modes".
- Revert "x86, efi: Retain boot service code until after switching
  to virtual mode".
- commit 855dd58
* Sun Jun  5 2011 jslaby@suse.cz
- asus-wmi: Remove __init from asus_wmi_platform_init
  (bnc#696212).
- commit 2e6cc6b
* Fri Jun  3 2011 mmarek@suse.cz
- Temporarily set PPC_DISABLE_WERROR=y in power to fix build
- commit 5e9cb3b
* Fri Jun  3 2011 mmarek@suse.cz
- scripts/kmsg-doc: Do not require Switch.pm.
- commit 83a39c7
* Fri Jun  3 2011 mmarek@suse.cz
- rpm/macros.kernel-source: Add -b option to %%kernel_module_package
  to unconditionally call mkinitrd on kmp install (fate#309400).
- rpm/kernel-module-subpackage: Pass KMP_NEEDS_MKINITRD=1 to
  weak-modules2 if the -b option is used.
- commit 83331f5
* Fri Jun  3 2011 jslaby@suse.cz
- Linux 2.6.39.1.
- Refresh patches.suse/no-partition-scan.
- Refresh patches.xen/xen3-patch-2.6.27.
- Delete
  patches.fixes/block-add-proper-state-guards-to-__elv_next_request.patch.
- commit 577661d
* Thu Jun  2 2011 jslaby@suse.cz
- rpm/config.sh: allow building in IBS
- commit 607aaf6
* Wed Jun  1 2011 jbeulich@novell.com
- Delete patches.xen/sfc-* (as advised by Solarflare).
- commit a144c73
* Tue May 31 2011 jeffm@suse.com
- Revert "- Updated to 3.0-rc1."
  This reverts commit 5710413eb834b0f215f6f4249d6ff7c3f7673eb7.
  Should have been committed to the merge-v3.0 branch.
- commit b2d9e72
* Tue May 31 2011 jeffm@suse.com
- Updated to 3.0-rc1.
  - Eliminated 9 patches.
- commit 5710413
* Mon May 30 2011 jack@suse.cz
- mm: Fix assertion mapping->nrpages == 0 in end_writeback()
  (bnc#693013 bnc#666423).
- Refresh patches.xen/tmem.
- commit d3e465a
* Mon May 30 2011 jslaby@suse.cz
- Refresh
  patches.fixes/block-add-proper-state-guards-to-__elv_next_request.patch.
- aic94xx: world-writable sysfs update_bios file.
  Update upstream info.
- commit 8912816
* Mon May 30 2011 jack@suse.cz
- mm: Fix assertion mapping->nrpages == 0 in end_writeback()
  (bnc#693013 bnc#666423).
- Refresh patches.xen/tmem.
- commit 646bfb1
* Fri May 27 2011 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Set KBUILD_BUILD_{USER,HOST} to
  geeko@buildhost, obsoleting the patch to scripts/mkcompile_h.
- commit b4b7255
* Mon May 23 2011 jbeulich@novell.com
- Update Xen patches to 2.6.39 final and c/s 1085.
- xen/sfc_netfront: fix an unused variable error.
- commit 3b6edff
* Fri May 20 2011 jslaby@suse.cz
- PM: Print a warning if firmware is requested when tasks are
  frozen (bnc#695219).
- commit e78f4ce
* Fri May 20 2011 jslaby@suse.cz
- Refresh
  patches.fixes/block-add-proper-state-guards-to-__elv_next_request.patch.
  Bah, cherry-picked a wrong version. Fix it.
- commit f9674b8
* Fri May 20 2011 jslaby@suse.cz
- Delete patches.suse/slab-handle-memoryless-nodes-v2a.patch.
  It was part of removed SoN patches.
- commit 1d0599a
* Fri May 20 2011 jeffm@suse.com
- Updated to 2.6.39-final.
- commit 7c72384
* Thu May 19 2011 jbeulich@novell.com
- supported.conf: blktap2 modules are supported.
- commit fa60394
* Tue May 17 2011 jslaby@suse.cz
- Refresh
  patches.kernel.org/libata-fix-oops-when-lpm-is-used-with-pmp.patch.
  Note upstream commit SHA.
- commit 17fc03c
* Mon May 16 2011 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Add the commit hash to uname -v, cleanup.
- commit f3bdb4c
* Sun May 15 2011 jslaby@suse.cz
- eeepc-laptop: Use ACPI handle to identify rfkill port
  (bnc#595586).
- commit 3c190ca
* Fri May 13 2011 mhocko@suse.cz
- proc: fix oops on invalid /proc/<pid>/maps access (bnc#693382).
- commit 0422a7e
* Fri May 13 2011 jeffm@suse.com
- Update to 2.6.39-rc7.
  - Eliminated 5 patches.
- commit a8a170f
* Fri May 13 2011 mmarek@suse.cz
- Build the kotd against 11.4
- commit 2ad3395
* Fri May 13 2011 mhocko@suse.cz
- memcg: allocate memory cgroup structures in local nodes
  (bnc#692502, bnc#669889).
- mm: add alloc_pages_exact_nid() (bnc#692502, bnc#669889).
- commit fe168ad
* Thu May 12 2011 jslaby@suse.cz
- Refresh
  patches.kernel.org/libata-fix-oops-when-lpm-is-used-with-pmp.patch.
  Just change the patch-mainline field. It's not upstream yet.
- commit 485c6fe
* Thu May 12 2011 jslaby@suse.cz
- block: add proper state guards to __elv_next_request.
- commit bcb6433
* Thu May 12 2011 gregkh@suse.de
- libata: fix oops when LPM is used with PMP.
- commit 762704b
* Thu May 12 2011 jslaby@suse.cz
- Delete
  patches.fixes/iwlwifi-fix-tx-power-configuration-on-3945-and-4965-devices.
  It's fixed differently by commits 43f12d47f and f844a709a7 in .38.5.
- Delete
  patches.fixes/iwlwifi-fix-tx-power-configuration-on-3945-and-4965-devices.
  It's fixed differently by commits 43f12d47f and f844a709a7 in .39-rc1
- commit b64bc58
* Thu May 12 2011 jslaby@suse.cz
- Refresh
  patches.fixes/iwlwifi-fix-tx-power-configuration-on-3945-and-4965-devices.
  Note about submission.
- commit 9922e20
* Tue May 10 2011 mhocko@suse.cz
- Delete patches.suse/files-slab-rcu.patch.
- commit 6547edf
* Tue May 10 2011 mhocko@suse.cz
- patches.fixes/aggressive-zone-reclaim.patch: delete because
  the patch is very workload specific and can lead to unexpected
  reclaims in parallel node local workloads.
- commit 56cf10e
* Tue May 10 2011 mhocko@suse.cz
- Delete patches.suse/mm-devzero-optimisation.patch: we do not need
  it anymore as we have zero page back since 2.6.32
- commit 323a093
* Tue May 10 2011 mmarek@suse.cz
- Really delete patches.fixes/aggressive-zone-reclaim.patch.
- commit b21d4b6
* Tue May 10 2011 jslaby@suse.cz
- deal with races in /proc/*/{syscall,stack,personality}
  (bnc#674982 CVE-2011-1020).
- auxv: require the target to be tracable (or yourself)
  (bnc#674982 CVE-2011-1020).
- close race in /proc/*/environ (bnc#674982 CVE-2011-1020).
- report errors in /proc/*/*map* sanely (bnc#674982
  CVE-2011-1020).
- pagemap: close races with suid execve (bnc#674982
  CVE-2011-1020).
- commit 346cb46
* Tue May 10 2011 jslaby@suse.cz
- Linux 2.6.38.6.
- Refresh patches.fixes/scsi-dh-queuedata-accessors.
- commit 5e831f6
* Mon May  9 2011 jbeulich@novell.com
- Update Xen patches to 2.6.39-rc6.
- commit b976a7e
* Mon May  9 2011 jbeulich@novell.com
- patches.suse/kconfig-automate-kernel-desktop: Remove stray blank
  lines (for older versions of "patch" to grok).
- commit 4dfa74d
* Sat May  7 2011 jeffm@suse.com
- Removed network driver entropy patches. haveged is installed by default
  and should be enabled to generate entropy from non-predictable sources.
  - Delete patches.drivers/bnx2-entropy-source.patch.
  - Delete patches.drivers/e1000-entropy-source.patch.
  - Delete patches.drivers/e1000e-entropy-source.patch.
  - Delete patches.drivers/igb-entropy-source.patch.
  - Delete patches.drivers/ixgbe-entropy-source.patch.
  - Delete patches.drivers/tg3-entropy-source.patch.
- commit c88b893
* Fri May  6 2011 jeffm@suse.com
- Update
  patches.fixes/netfilter-implement-rfc-1123-for-ftp-conntrack
  (bnc#466279 bnc#681639).
- commit 72e779f
* Fri May  6 2011 jeffm@suse.com
- Disabled patches.drivers/libata-unlock-hpa-by-default; It may have
  been obsoleted by upstream commit d8d9129e.
- commit 1a21ab3
* Fri May  6 2011 jeffm@suse.com
- sysctl: Increase IPC defaults (bnc#146656)
  - Delete patches.suse/shmall-bigger.
- commit a70e34f
* Fri May  6 2011 jeffm@suse.com
- sysctl/i386/desktop, sysctl/x86_64/desktop: Add vm.dirty_ratio = 20
  for desktop flavors (bnc#552883)
  - Delete patches.suse/mm-tune-dirty-limits.patch.
- commit dbe73e2
* Fri May  6 2011 jeffm@suse.com
- sysctl/defaults: Added kernel.hung_task_timeout=0
  - Delete patches.suse/hung_task_timeout-configurable-default.
- commit 78f9eed
* Fri May  6 2011 mmarek@suse.cz
- rpm/kernel-{binary,source}.spec.in: Install per-kernel /boot/sysctl-*
  files (patch from Jeff Mahoney).
- commit 473f2d1
* Thu May  5 2011 jeffm@suse.com
- Update config files for -vanilla.
- commit 97ce5d8
* Thu May  5 2011 jeffm@suse.com
- Updated to 2.6.39-rc6.
  - 2 patches eliminated.
- commit 2643e59
* Tue May  3 2011 tonyj@suse.de
- Delete patches.fixes/oprofile_bios_ctr.patch.
- Delete patches.suse/kdump-dump_after_notifier.patch.
- commit 012455a
* Mon May  2 2011 gregkh@suse.de
- Update config files to handle .5 changes
- commit 0274ea5
* Mon May  2 2011 gregkh@suse.de
- Linux 2.6.38.5.
- Delete
  patches.fixes/flexcop-fix-registering-braindead-stupid-names.
- commit d41164a
* Fri Apr 29 2011 jeffm@suse.com
- rpm/compute-PATCHVERSION.sh: Replace ^+++ with ^\+\+\+ as an
    awk regex. It's technically invalid.
- commit 52dd0f0
* Fri Apr 29 2011 jslaby@suse.cz
- Refresh
  patches.fixes/iwlwifi-fix-tx-power-configuration-on-3945-and-4965-devices.
- commit c602ee1
* Fri Apr 29 2011 sjayaraman@suse.de
- Delete patches.suse/sched-revert-latency-defaults.
- commit 90be226
* Fri Apr 29 2011 tiwai@suse.de
- Delete patches.arch/ppc-ipic-suspend-without-83xx-fix.
- Delete patches.arch/x86-hpet-pre-read.
- commit 3489146
* Fri Apr 29 2011 gregkh@suse.de
- Delete patches.suse/linux-2.6.29-dont-wait-for-mouse.patch.
- Delete patches.suse/linux-2.6.29-even-faster-kms.patch.
- Delete
  patches.suse/linux-2.6.29-jbd-longer-commit-interval.patch.
- Delete patches.suse/linux-2.6.29-kms-after-sata.patch.
- Delete patches.suse/linux-2.6.29-touchkit.patch.
- commit c13427d
* Fri Apr 29 2011 jbenc@suse.cz
- Delete patches.suse/panic-on-io-nmi-SLE11-user-space-api.patch.
- commit df46fe0
* Thu Apr 28 2011 rjw@suse.de
- Delete patches.xen/xen3-x86-mcp51-no-dac.
  Also remove the series.conf entires for the x86-mcp-no-dac patches.
- commit 574577b
* Thu Apr 28 2011 rjw@suse.de
- Delete patches.arch/x86-mcp51-no-dac.  (This is a blacklist entry that
  has been rejected by the mainline, the problem reporter is gone and
  it's next to impossible to verify it now.)
- commit 195b113
* Thu Apr 28 2011 jslaby@suse.cz
- Refresh
  patches.fixes/iwlwifi-fix-tx-power-configuration-on-3945-and-4965-devices.
- commit a2662ae
* Thu Apr 28 2011 jslaby@suse.cz
- Delete patches.suse/wireless-no-aes-select.
  Optimized x86 AES implementations select CRYPTO_AES themselves. So we
  don't need the patch anymore -- AES is selected always.
- commit 88f80fa
* Thu Apr 28 2011 bphilips@suse.de
- Delete
  patches.drivers/tg3-5785-and-57780-asic-revs-not-working.patch.
- commit 9917206
* Thu Apr 28 2011 bphilips@suse.de
- Delete
  patches.suse/uvcvideo-ignore-hue-control-for-5986-0241.patch.
- commit 08374b3
* Thu Apr 28 2011 jeffm@suse.com
- Delete patches.suse/audit-export-logging.patch.
- commit de054eb
* Thu Apr 28 2011 jbeulich@novell.com
- Update i386 Xen config files.
- commit 7b776ee
* Thu Apr 28 2011 jack@suse.cz
- Fix checking of login id (bnc#626119).
- commit 0fd91a9
* Thu Apr 28 2011 jbeulich@novell.com
- Update Xen patches to 2.6.39-rc5.
- Delete patches.xen/xen3-seccomp-disable-tsc-option.
- Delete patches.xen/xen3-x86-mark_rodata_rw.patch.
- commit 81fdf67
* Thu Apr 28 2011 mfasheh@suse.com
- btrfs: return EXDEV when linking from different subvolumes
  (bnc#679545).
- commit f9ddc29
* Wed Apr 27 2011 jeffm@suse.com
- Delete
  patches.drivers/disable-catas_reset-by-default-to-avoid-problems-with-eeh.patch.
- commit 399a100
* Wed Apr 27 2011 jeffm@suse.com
- Delete patches.arch/x86_agpgart-g33-stoeln-fix-2.patch.
- commit e5c964a
* Wed Apr 27 2011 jeffm@suse.com
- Merged patches.fixes/fix-nf_conntrack_slp into patches.suse/netfilter-ip_conntrack_slp.patch.
- commit 213a0d5
* Wed Apr 27 2011 jeffm@suse.com
- Removed Swap-over-NFS patches.
- commit e061d16
* Wed Apr 27 2011 jeffm@suse.com
- Unified novfs patches into patches.suse/novfs-client-module.
- commit 3f8a199
* Wed Apr 27 2011 jeffm@suse.com
- Delete patches.fixes/reiserfs-remove-2-tb-file-size-limit.
- commit 2d63b14
* Wed Apr 27 2011 jeffm@suse.com
- Delete patches.suse/mm-increase-dirty-limits.patch: Replaced by patches.suse/mm-tune-dirty-limits.patch
- commit 4f8033f
* Wed Apr 27 2011 jeffm@suse.com
- series.conf: Removed commented out patches for cpuidle. The patches themselves are long gone.
- commit 93ce9f3
* Wed Apr 27 2011 jeffm@suse.com
- Delete patches.arch/acpi-export-hotplug_execute: ACPI_DOCK is now a boolean.
- commit f178332
* Wed Apr 27 2011 jeffm@suse.com
- Delete patches.suse/acpi-dsdt-initrd-v0.9a-2.6.25.patch.
- commit 5a2eae2
* Wed Apr 27 2011 jeffm@suse.com
- Delete patches.suse/acpi-don-t-preempt-until-the-system-is-up.
- Delete
  patches.suse/acpi-generic-initramfs-table-override-support.
- Delete patches.suse/add-initramfs-file_read_write.
- Delete
  patches.suse/init-move-populate_rootfs-back-to-start_kernel.
- commit d4910b3
* Wed Apr 27 2011 jeffm@suse.com
- Delete patches.fixes/nfs-acl-caching.diff.
- Delete patches.suse/nfsacl-client-cache-CHECK.diff.
- commit e1a5c5c
* Wed Apr 27 2011 jeffm@suse.com
- Delete patches.suse/osync-error. It was unused and the issue it fixed in
  kernels prior to 2.6.32 doesn't exist anymore.
- commit 52cc654
* Wed Apr 27 2011 jeffm@suse.com
- Delete patches.suse/s390-System.map.diff: Proper fix in binutils has
  long since been upstream.
- commit 2847a36
* Wed Apr 27 2011 jeffm@suse.com
- patches.suse/x86-mark_rodata_rw.patch: Removed as promised.
- commit f196f98
* Wed Apr 27 2011 jeffm@suse.com
- Delete patches.arch/ia64-page-migration.
- Delete patches.arch/ia64-page-migration.fix.
- Delete patches.arch/mm-avoid-bad-page-on-lru.
- commit e469a91
* Wed Apr 27 2011 jeffm@suse.com
- patches.suse/hung_task_timeout-configurable-default: Update patch-mainline.
- commit 4bcc987
* Wed Apr 27 2011 jeffm@suse.com
- Delete patches.fixes/seccomp-disable-tsc-option: Unused in all configs.
- commit 0833556
* Wed Apr 27 2011 jeffm@suse.com
- Delete patches.suse/unmap_vmas-lat: No bug report or signed-off-by.
  - Delete patches.arch/s390-add-FREE_PTE_NR.
- commit 2a392c2
* Wed Apr 27 2011 jeffm@suse.com
- Updated Patch-mainline for  patches.fixes/ia64-sparse-fixes.diff.
- commit d79b32f
* Wed Apr 27 2011 jeffm@suse.com
- Update to 2.6.39-rc5.
  - Eliminated 2 patches.
- commit 5288a05
* Wed Apr 27 2011 jeffm@suse.com
- Delete patches.suse/export-release_open_intent.
- Delete patches.suse/export-security_inode_permission.
- commit 5cd669f
* Wed Apr 27 2011 jeffm@suse.com
- Delete patches.trace/utrace-core.
- commit a9639aa
* Tue Apr 26 2011 jslaby@suse.cz
- NET: cdc-phonet, fix stop-queue handling (bnc#689583).
- commit 7b4abdd
* Tue Apr 26 2011 jkosina@suse.cz
- HID: add noget quirk barcode scanners from Symbol Technologies
  (bnc#689290).
- commit dcae8fa
* Fri Apr 22 2011 jslaby@suse.cz
- XEN: add fixup_4gb_segment ENDPROC.
- Refresh patches.xen/xen3-patch-2.6.19.
- Refresh patches.xen/xen3-patch-2.6.21.
- Refresh patches.xen/xen3-patch-2.6.33.
- Refresh patches.xen/xen3-patch-2.6.37.
  Now, with binutils 2.21.0 we see build errors like:
  arch/x86/kernel/entry_32-xen.S: Assembler messages:
  arch/x86/kernel/entry_32-xen.S:1734: Error: .size expression for spurious_interrupt_bug does not evaluate to a constant
  BS doesn't complain about this yet, only abuild.
- commit b5e9a32
* Fri Apr 22 2011 jslaby@suse.cz
- Update to 2.6.38.4:
  - obsoletes:
  - patches.arch/i386-unwind-annotations.
  - patches.drivers/alsa-hda-0018-Fix-pin-config-of-Gigabyte-mobo.
  - patches.fixes/cdc-phonet-handle-empty-phonet-header.patch.
  - patches.fixes/media-video-sn9c102-world-wirtable-sysfs-files.
  - patches.fixes/ubifs-restrict-world-writable-debugfs-files.
  - patches.rpmify/ia64-mca-fix-cast-from-integer-to-pointer-warning.
  - patches.rpmify/tioca-fix-assignment-from-incompatible-pointer-warnings.
- Refresh patches.xen/xen3-auto-common.diff.
- Refresh patches.xen/xen3-patch-2.6.27.
- Update config files.
- commit 4632d1a
* Fri Apr 22 2011 jeffm@suse.com
- Delete patches.suse/nameif-track-rename.patch: The same info is made available via udev.
- commit e74929e
* Tue Apr 19 2011 jack@suse.cz
- Revert changes to sparc configs to not make life harder for Jan Engelhardt
  maintaining sparc architecture.
- commit cdac873
* Tue Apr 19 2011 jack@suse.cz
- config.conf: Remove sparc as it is maintained separately by Jan Engelhardt
- commit 91307e3
* Tue Apr 19 2011 jack@suse.cz
- Update vanilla config files.
- commit 5e3c232
* Tue Apr 19 2011 jack@suse.cz
- ext4: fix ext4_da_block_invalidatepages() to handle page range
  properly (bnc#679898).
- commit 616d360
* Tue Apr 19 2011 jack@suse.cz
- ext4: mark multi-page IO complete on mapping failure
  (bnc#679898).
- commit c04b19f
* Tue Apr 19 2011 jeffm@suse.com
- Updated to 2.6.39-rc4.
  - Eliminated 1 patch.
- commit 3f654c8
* Tue Apr 19 2011 jeffm@suse.com
- libata: DVR-216D can't do SETXFER DVD-RW DVR-216D (bnc#679143).
- commit b09d00e
* Mon Apr 18 2011 eich@suse.de
- Combined and consolidated bootsplash patch (bnc#669777,
  bnc#570082, bnc#595657, bnc#594209, bnc#544645).
  - Delete patches.suse/Cleanup-and-make-boot-splash-work-with-KMS.patch.
  - Delete patches.suse/bootsplash.
  - Delete patches.suse/bootsplash-console-fix.
  - Delete patches.suse/bootsplash-keep-multiple-data.
  - Delete patches.suse/bootsplash-scaler.
  - Reformatted code, fixed some minor bugs that became obvious.
  - Fixed race that led to null pointer dereference in splash_read_proc():
    bnc#669777.
- commit 95844c5
* Sat Apr 16 2011 trenn@suse.de
- intel_idle: Add a boot param to keep flushing TLBs (bnc#675161).
- commit 02c0d8a
* Sat Apr 16 2011 trenn@suse.de
- intel_idle: Make lapic_timer_reliable_states a boot param
  (bnc#675161).
- commit 85b156b
* Sat Apr 16 2011 jack@suse.cz
- Disable ext2, use ext4 instead as a driver
- Update config files.
- commit 2601b15
* Fri Apr 15 2011 jeffm@suse.com
- Enabled CONFIG_GIGASET_CAPI (bnc#686008).
  - This results in automatically disabling CONFIG_GIGASET_I4L.
- commit 697e68b
* Fri Apr 15 2011 jack@suse.cz
- novfs: Set the sticky bit for the novfs mountpoint (bnc#686412).
- commit 860f111
* Fri Apr 15 2011 jbeulich@novell.com
- patches.arch/x86_64-unwind-annotations: Re-add.
- commit 728e154
* Fri Apr 15 2011 jbeulich@novell.com
- Update Xen patches to 2.6.39-rc3 and c/s 1079.
- blktap2: replace hard-coded limit of tap devices with
  configurable one.
- config.conf: Re-enable Xen configs.
- Update x86 config files.
- commit d3bfd6c
* Fri Apr 15 2011 bphilips@suse.de
- bonding: Incorrect TX queue offset (bnc#687116, CVE-2011-1581).
- commit 6d208f9
* Thu Apr 14 2011 gregkh@suse.de
- Linux 2.6.38.3.
  - lots of security updates and bugfixes
  - obsoletes:
  patches.drivers/alsa-hda-0017-Fix-SPDIF-out-regression-on-ALC889.
  patches.drivers/sound-oss-opl3-validate-voice-and-channel-indexes.
  patches.drivers/sound-oss-remove-offset-from-load_patch-callbacks.
  patches.fixes/drivers-leds-leds-lp5521-c-world-writable-sysfs-engine-files.
  patches.fixes/drivers-leds-leds-lp5523-c-world-writable-engine-sysfs-files.
  patches.fixes/drivers-misc-ep93xx_pwm-c-world-writable-sysfs-files.
  patches.fixes/drivers-rtc-rtc-ds1511-c-world-writable-sysfs-nvram-file.
  patches.fixes/irda-validate-peer-name-and-attribute-lengths.
  patches.fixes/mfd-ab3100-world-writable-debugfs-_priv-files.
  patches.fixes/mfd-ab3500-world-writable-debugfs-register-files.
  patches.fixes/mfd-ab8500-world-writable-debugfs-register-files.
  patches.fixes/prevent-rt_sigqueueinfo-from-spoofing-fix.patch.
  patches.fixes/scsi-scsi_transport_iscsi-make-priv_sess-file-writeable-only-by-root.
  patches.kernel.org/revert-x86-Cleanup-highmap-after-brk-is-concluded.patch.
- commit a6acdda
* Thu Apr 14 2011 jeffm@suse.com
- fs/partitions/efi.c: corrupted GUID partition tables can cause
  kernel oops (bnc#687113 CVE-2011-1577).
- commit cc60bed
* Thu Apr 14 2011 jeffm@suse.com
- fs/partitions/efi.c: corrupted GUID partition tables can cause
  kernel oops (bnc#687113 CVE-2011-1577).
- commit 385b393
* Thu Apr 14 2011 jeffm@suse.com
- scsi: aic94xx: world-writable sysfs update_bios file.
- drivers/leds/leds-lp5523.c: world-writable engine* sysfs files
  (bnc#673934).
- drivers/leds/leds-lp5521.c: world-writable sysfs engine* files
  (bnc#673934).
- mfd: ab8500: world-writable debugfs register-* files
  (bnc#673934).
- scsi_transport_iscsi: make priv_sess file writeable only by root
  (bnc#673934).
- mfd: ab3500: world-writable debugfs register-* files
  (bnc#673934).
- drivers/misc/ep93xx_pwm.c: world-writable sysfs files
  (bnc#673934).
- mfd: ab3100: world-writable debugfs *_priv files (bnc#673934).
- UBIFS: restrict world-writable debugfs files (bnc#673934).
- scsi: aic94xx: world-writable sysfs update_bios file.
- drivers/rtc/rtc-ds1511.c: world-writable sysfs nvram file
  (bnc#673934).
- video: sn9c102: world-wirtable sysfs files (bnc#673934).
- commit 7f827e6
* Wed Apr 13 2011 jeffm@suse.com
- irda: validate peer name and attribute lengths (bnc#681497
  CVE-2011-1180).
- commit 1d6013e
* Wed Apr 13 2011 jeffm@suse.com
- mpc5xxx_can: Fix typo causing build failure (of_dev -> ofdev).
- ft1000: Remove unnecessary EXPORT_SYMBOLs.
- commit 62653bb
* Wed Apr 13 2011 jeffm@suse.de
- fhandle: Add <linux/personality.h> for ia64.
- commit 83cec5a
* Wed Apr 13 2011 jeffm@suse.com
- kvm: Fix off by one in kvm_for_each_vcpu iteration.
- commit 4e5c2b7
* Wed Apr 13 2011 jeffm@suse.com
- rts_pstor: Add <linux/vmalloc.h>.
- rts_pstor: use #ifdef instead of #if.
- commit caa5347
* Tue Apr 12 2011 jeffm@suse.com
- gma500: Depend on X86.
- commit 3aa298c
* Tue Apr 12 2011 jeffm@suse.com
- Updated to 2.6.39-rc3.
  - Eliminated 2 patches.
- commit 200c913
* Tue Apr 12 2011 jeffm@suse.com
- patches.suse/s390-Kerntypes.diff: remove <linux/smp_lock.h>
- commit d7c79f2
* Tue Apr 12 2011 jeffm@suse.com
- olpc: Add <linux/delay.h>.
- commit 58ce0db
* Tue Apr 12 2011 jeffm@suse.com
- Update config files for -vanilla.
- commit 52fe306
* Tue Apr 12 2011 jeffm@suse.com
- Update to 2.6.39-rc2.
  - Eliminated 18 patches.
  - Added 3 patches.
  - hv_mouse: needs <linux/delay.h>.
  - dm-raid45: Remove blk_unplug calls.
  - novfs: 2.6.39 API update.
  - Xen, Swap-over-NFS, and certain SCSI multipath features are disabled.
  - patches.kernel.org is no longer used to contain upstream patches
    for -rc releases. Users planning on building their own kernel should
    have a copy of the tarball corresponding to the -rc releases.
- commit adf9d16
* Mon Apr 11 2011 neilb@suse.de
- Make selection of 'readdir-plus' adapt to usage patterns
  (bnc#678123).
- commit 78e8a63
* Wed Apr  6 2011 jslaby@suse.cz
- Revert "x86: Cleanup highmap after brk is concluded"
  (bnc#684248).
- Delete
  patches.arch/x86-save-cr4-to-mmu_cr4_features-at-boot.patch.
- commit 2d275f3
* Wed Apr  6 2011 jeffm@suse.de
- reiserfs: Force inode evictions before umount to avoid crash
  (bnc#610598 bnc#680073 bnc#684112).
- Delete patches.fixes/reiserfs-xattr-crash-fix.
- commit bf57d20
* Tue Apr  5 2011 jslaby@suse.cz
- remove obsolete comment from series.conf
- commit 4bad172
* Thu Mar 31 2011 jslaby@suse.cz
- x86: Save cr4 to mmu_cr4_features at boot time (bnc#684248).
- commit 98ac070
* Wed Mar 30 2011 jeffm@suse.com
- Delete patches.suse/twofish-2.6.
  - This was for 2.4 compatibility and has been moved to KMP purgatory.
- commit dcca506
* Wed Mar 30 2011 jslaby@suse.cz
- Relax si_code check in rt_sigqueueinfo and rt_tgsigqueueinfo
  (bnc#681826).
- commit 2e71042
* Mon Mar 28 2011 trenn@suse.de
- Update config files, remove CONFIG_X86_MCE_XEON75XX=m
  - >driver got reverted with previous commit
- Refresh patches.xen/xen3-auto-arch-x86.diff.
- commit b367e7b
* Mon Mar 28 2011 trenn@suse.de
- Remove xeon75xx driver, was intended as a SLE11 SP1 workaround
  to decode physical memory address on Boxboro-EX for MCEs.
  APEI implementation should take care of that in recent kernels.
- Delete patches.arch/x86_mce_intel_decode_physical_address.patch.
- Delete
  patches.arch/x86_mce_intel_decode_physical_address_compile_fix.patch.
- Delete
  patches.arch/x86_mce_intel_decode_physical_address_rename_fix.patch.
- Delete
  patches.arch/x86_mce_intel_decode_physical_fix_dynamic_debug.patch.
- commit 1fe7a22
* Mon Mar 28 2011 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Do not install unneeded packages in the
  build chroot.
- commit 7f4c49d
* Mon Mar 28 2011 tiwai@suse.de
- ALSA: hda - Increase the default buffer size (682725).
- ALSA: hda - Fix pin-config of Gigabyte mobo (bnc#677256).
- commit 8088cec
* Mon Mar 28 2011 jslaby@suse.cz
- Update to 2.6.38.2:
  - obsoletes:
  - patches.fixes/prevent-rt_sigqueueinfo-from-spoofing.patch.
- Refresh patches.xen/tmem.
- Refresh patches.xen/xen-dcdbas.
- commit 5b9dd3d
* Fri Mar 25 2011 mhocko@suse.cz
- page_cgroup: reduce allocation overhead for page_cgroup array
  for CONFIG_SPARSEMEM (bnc#669889).
- commit 6a934f2
* Fri Mar 25 2011 jslaby@suse.cz
- Update patches.kernel.org/patch-2.6.38.1 (bnc#558740).
  (Add a bug reference)
- commit 3285b9b
* Thu Mar 24 2011 tiwai@suse.de
- ALSA: hda - Fix SPDIF out regression on ALC889 (bnc#679588).
- commit f9b1d82
* Thu Mar 24 2011 jslaby@suse.cz
- Prevent rt_sigqueueinfo and rt_tgsigqueueinfo from spoofing
  the signal code (bnc#681826 CVE-2011-1020).
- commit 2e42fd4
* Thu Mar 24 2011 tiwai@suse.de
- sound/oss/opl3: validate voice and channel indexes (bnc#681999).
- sound/oss: remove offset from load_patch callbacks (bnc#681999).
- ALSA: sound/pci/asihpi: check adapter index in hpi_ioctl
  (bnc#680816).
- commit 09ff6e9
* Thu Mar 24 2011 jslaby@suse.cz
- Update to 2.6.38.1:
  - obsoletes:
  - patches.rpmify/winbond-needs-msleep.
- Refresh
  patches.fixes/hid-add-support-for-Skycable-0x3f07-wireless-present.patch.
- Update config files.
- commit 4836c9f
* Mon Mar 21 2011 jack@suse.cz
- Fix almost-infinite slab cache growing (bnc#554081).
- commit 44e668f
* Mon Mar 21 2011 jkosina@suse.cz
- HID: add support for Skycable 0x3f07 wireless presenter
  (bnc#681297).
- commit c88c4a7
* Mon Mar 21 2011 mmarek@suse.cz
- Delete config/i386/vmi, it was an artifact from SLE11-SP1 development.
- commit 9877488
* Fri Mar 18 2011 jslaby@suse.cz
- NET: cdc-phonet, handle empty phonet header (bnc#673992).
- commit da6e6d1
* Fri Mar 18 2011 jslaby@suse.cz
- SPI: dw_spi, fix PPC build.
- commit 80ca063
* Fri Mar 18 2011 jbeulich@novell.com
- Update Xen patches to 2.6.38 and c/s 1073.
- commit 89cb2b4
* Thu Mar 17 2011 sjayaraman@suse.de
- netvm: Do not mark requests for swapfile writes as dirty or
  kswapd fails to free the page (bnc#678472).
- nfs: Use page_file_offset during page writeback (bnc#677738).
- nfs: Convert nfs_mark_request_dirty() to use page_file_mapping()
  (bnc#677738).
- netvm: Remove duplicated initialization in net/ipv4/route.c
  (bnc#678970).
- collapse: mm: Report the low watermark correctly (bnc#678497).
- commit a798dd1
* Tue Mar 15 2011 jeffm@suse.com
- Update to 2.6.38.
- commit f2ec6ad
* Tue Mar 15 2011 jslaby@suse.cz
- Update to 2.6.37.4:
  - obsoletes:
  - patches.fixes/ath9k-Fix-ath9k-prevents-CPU-to-enter-C3-states.patch.
  - patches.fixes/media-DiB7000M-add-pid-filtering.patch.
- commit b3091d2
* Mon Mar 14 2011 tiwai@suse.de
- ALSA: HDA: Realtek ALC88x: Do not over-initialize speakers
  and hp that are primary outputs (bnc#679016).
- ALSA: HDA: Fixup unnecessary volume control index on Realtek
  ALC88x (bnc#679016).
- ALSA: HDA: Fix volume control naming for surround speakers on
  Realtek auto-parser (bnc#679016).
- ALSA: HDA: Enable surround and subwoofer on Lenovo Ideapad Y530
  (bnc#679016).
- ALSA: hda - Add support for multiple headphone/speaker controls
  for Realtek (bnc#679016).
- ALSA: hda - 4930g add internal lfe slider (bnc#679016).
- ALSA: hda - Fix unable to record issue on ASUS N82JV
  (bnc#679016).
- ALSA: hda - switch lfe with side in mixer for 4930g
  (bnc#679016).
- ALSA: HDA: Fix automute on Thinkpad L412/L512 (bnc#679016).
- ALSA: HDA: Add SKU ignore for another Thinkpad Edge 14
  (bnc#679016).
- ALSA: hda - Apply Sony VAIO hweq fixup only once (bnc#679016).
- ALSA: hda - Fix ALC275 enable hardware EQ for SONY VAIO
  (bnc#679016).
- ALSA: hda - Fix EAPD on Lenovo NB ALC269 to low (bnc#679016).
- commit b5b352b
* Mon Mar 14 2011 tiwai@suse.de
- ALSA: hda - Add a generic fixup callback for Realtek codecs
  (bnc#679016).
- ALSA: hda - Fix missing EAPD for Acer 4930G (bnc#679016).
- commit 35da099
* Mon Mar 14 2011 jeffm@suse.com
- Linux: 2.6.38-rc8.
  - Eliminated 1 patch.
- commit 7da557d
* Fri Mar 11 2011 jbeulich@novell.com
- Update Xen patches to 2.6.38-rc7 and c/s 1072
- pv-ops blktap2.
- adjust xen build after addition of pv-ops' blktap2.
- blktap: Fix reference to freed struct request.
- cleanup to blkback and blktap.
- apply xen specific patch to the Chelsio ethernet drivers.
- Update Xen config files.
- commit 289ecca
* Fri Mar 11 2011 jbeulich@novell.com
- fix i386 unwind annotations.
- commit 02bd501
* Fri Mar 11 2011 jslaby@suse.cz
- DiB7000M: add pid filtering (bnc#644807).
- commit ab6796e
* Fri Mar 11 2011 jbeulich@novell.com
- Update Xen patches to 2.6.37.3 and c/s 1072.
- apply xen specific patch to the Chelsio ethernet drivers.
- commit 7db4348
* Thu Mar 10 2011 jslaby@suse.cz
- Mantis, hopper: use MODULE_DEVICE_TABLE (bnc#607239).
- commit 33a71b9
* Tue Mar  8 2011 jslaby@suse.cz
- Update to 2.6.37.3:
  - obsoletes:
  - patches.drivers/alsa-usb-audio-fix-oops-due-to-cleanup-race-when-disconnect.
  - patches.drivers/e1000e-82579-PHY-incorrectly-identified-during-init.patch.
  - patches.arch/acpi-debugfs-fix-buffer-overflows-double-free.patch.
  - patches.fixes/loop-over-loop-hang-fix.patch.
- Refresh patches.xen/xen-x86-no-lapic.
- Refresh patches.xen/xen3-patch-2.6.19.
- commit dca38e6
* Tue Mar  8 2011 jeffm@suse.de
- Update to 2.6.38-rc7.
  - Refresh patches.xen/xen-x86-no-lapic.
  - Refresh patches.xen/xen3-patch-2.6.19.
- commit 7eb9d30
* Mon Mar  7 2011 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Do not abort build because of
  supported.conf inconsistency if %%supported_modules_check == 0.
- commit 88d5daa
* Fri Mar  4 2011 jack@suse.cz
- debugfs: Fix filesystem reference counting on debugfs_remove()
  failure (bnc#668101).
- commit 9166129
* Wed Mar  2 2011 jbeulich@novell.com
- patches.arch/x86_64-unwind-annotations: Fix a fatal oversight in
  yesterday's change.
- commit 098768b
* Wed Mar  2 2011 bphilips@suse.de
- e1000e: 82579 PHY incorrectly identified during init
  (bnc#668437).
- commit 8e49073
* Tue Mar  1 2011 knikanth@suse.de
- block: kill loop_mutex (bnc#669394).
- commit e8a3617
* Mon Feb 28 2011 jbeulich@novell.com
- patches.arch/x86_64-unwind-annotations: Add annotations to
  lib/rwsem_64.S.
- commit a1349cb
* Mon Feb 28 2011 jbeulich@novell.com
- patches.arch/x86_64-unwind-annotations: Add annotations to
  lib/rwsem_64.S.
- commit 87944ac
* Sun Feb 27 2011 jslaby@suse.cz
- iwlwifi: fix ack health for WiFi/BT combo devices (bnc#662733).
- iwlwifi: cleanup iwl_good_ack_health (bnc#662733).
- iwlwifi: fix ack health for WiFi/BT combo devices (bnc#662733).
- iwlwifi: cleanup iwl_good_ack_health (bnc#662733).
- commit 261a9d2
* Fri Feb 25 2011 jslaby@suse.cz
- Update to 2.6.37.2 (bnc#674245):
  - obsoletes:
  - patches.arch/perf_adjust_timechart_to_new_cpuidle_events.patch.
  - patches.drivers/alsa-01-caiaq-Fix-possible-string-buffer-overflow.
  - patches.fixes/revert-tpm_tis-Use-timeouts-returned-from-TPM.patch.
- commit d1287f4
* Thu Feb 24 2011 tiwai@suse.de
- ALSA: usb-audio: fix oops due to cleanup race when disconnecting
  (bnc#674735).
- commit 74b3781
* Thu Feb 24 2011 tiwai@suse.de
- ALSA: usb-audio: fix oops due to cleanup race when disconnecting
  (bnc#674735).
- commit ed81f8c
* Thu Feb 24 2011 jslaby@suse.cz
- ath9k: Fix ath9k prevents CPU to enter C3 states (bnc#667793).
- Refresh
  patches.fixes/revert-tpm_tis-Use-timeouts-returned-from-TPM.patch.
- Delete
  patches.fixes/0001-Revert-ath9k-use-per-device-struct-for-pm_qos_-opera.patch.
- Delete
  patches.fixes/0002-Revert-ath9k-Remove-pm_qos-request-after-hw-unregist.patch.
- Delete
  patches.fixes/0003-Revert-ath9k-Fix-a-DMA-latency-issue-for-Intel-Pinet.patch.
  These patches went upstream, update.
- commit be3e181
* Thu Feb 24 2011 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Remove unused code.
- commit dacbc44
* Tue Feb 22 2011 jeffm@suse.com
- Update to 2.6.38-rc6.
  - Eliminated 1 patch.
- commit 6cce7bb
* Tue Feb 22 2011 mszeredi@suse.cz
- xfs: prevent leaking uninitialized stack memory in FSGEOMETRY_V1
  (CVE-2011-0711 bnc#672524).
- commit 547a9f9
* Tue Feb 22 2011 mmarek@suse.cz
- rpm/mkspec: Do not create kernel-syms.spec on vanilla-only branches
- commit eb17bba
* Mon Feb 21 2011 tiwai@suse.de
- ALSA: caiaq - Fix possible string-buffer overflow (bnc#672499,
  CVE-2011-0712).
- commit f6a72cc
* Mon Feb 21 2011 tiwai@suse.de
- ALSA: caiaq - Fix possible string-buffer overflow (bnc#672499,
  CVE-2011-0712).
- commit 5ef002b
* Sun Feb 20 2011 jslaby@suse.cz
- Revert "tpm_tis: Use timeouts returned from TPM" (bnc#673619).
- commit d991856
* Sat Feb 19 2011 rjw@suse.de
- ACPI / debugfs: Fix buffer overflows, double free (bnc#666095).
- commit 41c6654
* Fri Feb 18 2011 rjw@suse.de
- ACPI / debugfs: Fix buffer overflows, double free (bnc#666095).
- commit da9d3a8
* Fri Feb 18 2011 jslaby@suse.cz
- Update to 2.6.37.1:
  - obsoletes:
  - patches.arch/x86-mtrr-avoid-MTRR-reprogramming-on-BP-during-boot-on.patch
  - patches.drivers/alsa-hda-0001-Fix-memory-leaks-in-conexant-jack-arrays
  - patches.drivers/alsa-hda-0002-Fix-missing-CA-initialization-for-HDMI-DP
  - patches.fixes/calibrate-jiffy-overflow
  - patches.fixes/fix-ata-panic-with-ata_id
  - patches.fixes/fix-prlimit64-for-suid-sgid-processes.patch
  - patches.fixes/input-introduce-notimeout-blacklist-for-Dell-Vostro-.patch
  - patches.fixes/sched-cgroup-use-exit-hook-to-avoid-use-after-free-crash
  - patches.fixes/staging-rt2860-Fix-incorrect-netif_stop_queue-usage.patch
- Refresh patches.suse/SoN-08-mm-page_alloc-emerg.patch.
- Refresh patches.suse/SoN-16-netvm-reserve-inet.patch.
- Refresh patches.suse/dm-mpath-accept-failed-paths.
- Refresh patches.suse/sched-automated-per-session-task-groups.
- Refresh patches.xen/xen3-auto-common.diff.
- Refresh patches.xen/xen3-fixup-common.
- Refresh patches.xen/xen3-patch-2.6.37.
- commit a638bb4
* Fri Feb 18 2011 sjayaraman@suse.de
- Refresh patches.suse/SoN-06-mm-kmem_estimate_pages.patch to accomodate
  an upstream change.
- commit a4e281e
* Thu Feb 17 2011 rjw@suse.de
- PNP / ACPI: Use DEVICE_ACPI_HANDLE() for device ACPI handle access (bnc#434742).
- commit a73834f
* Thu Feb 17 2011 jeffm@suse.de
- Update to 2.6.38-rc5.
- commit 8344657
* Thu Feb 17 2011 gregkh@suse.de
- Update config files.
  - disable CONFIG_DRM_VMWGFX (bnc#606458)
  - update sparc configs to at least be able to run "make oldconfig"
- commit da75bd9
* Thu Feb 17 2011 gregkh@suse.de
- Update config files.
  disable CONFIG_DRM_VMWGFX. (bnc#606458)
- commit 409d54e
* Wed Feb 16 2011 jbeulich@novell.com
- patches.arch/x86_64-unwind-annotations: Re-add change lost during
  initial 2.6.37 merge.
- commit 7a5313d
* Wed Feb 16 2011 jbeulich@novell.com
- patches.arch/x86_64-unwind-annotations: Re-add change lost during
  initial 2.6.37 merge.
- commit e493205
* Wed Feb 16 2011 tiwai@suse.de
- ALSA: HDA: Add Lenovo vendor quirk for Conexant 205xx
  (bnc#670946).
- commit b3bc287
* Tue Feb 15 2011 jeffm@suse.com
- tty: add 'active' sysfs attribute to tty0 and console device.
- commit 7ae6e9a
* Tue Feb 15 2011 jslaby@suse.cz
- Revert "ath9k: Fix a DMA latency issue for Intel Pinetrail
  platforms." (bnc#667793).
- Revert "ath9k: Remove pm_qos request after hw
  unregister." (bnc#667793).
- Revert "ath9k: use per-device struct for pm_qos_* operations"
  (bnc#667793).
- commit b2849f6
* Tue Feb 15 2011 jack@suse.cz
- bridge: Replace mp->mglist hlist with a bool (bnc#653547).
- bridge: Fix timer typo that may render snooping less effective
  (bnc#653547).
- bridge: Fix mglist corruption that leads to memory corruption
  (bnc#653547).
- commit a70e5ca
* Mon Feb 14 2011 mmarek@suse.cz
- Move spec file templates and helper scripts to a separate branch, to
  ease synchronizing these files among master, vanilla and linux-next.
- commit 411abb8
* Mon Feb 14 2011 mmarek@suse.cz
- Delete a couple of obsolete kabi and other scripts from misc/:
- Delete misc/checkmod.
- Delete misc/collect_ksyms.
- Delete misc/diff-the-xfs-cvs.
- Delete misc/ksyms.py.
- Delete misc/mangle-ifdef.py.
- Delete misc/obsolete-module-aliases.
- Delete misc/testmodule.
- commit 3dd255b
* Mon Feb 14 2011 mmarek@suse.cz
- rpm/kernel-source.spec.in: Delete misc/extract-modaliases, the code
  was merged into rpm's find-supplements script.
- Delete rpm/check-build.sh, not needed anymore.
- commit bd6fa48
* Thu Feb 10 2011 jeffm@suse.com
- flexcop: fix registering braindead stupid names (brc#575873
  bnc#661429).
- commit 72bd3d0
* Thu Feb 10 2011 jeffm@suse.com
- flexcop: fix registering braindead stupid names (brc#575873
  bnc#661429).
- commit 2e98bfc
* Wed Feb  9 2011 gregkh@suse.de
- Staging: samsung-laptop: add support for lots of laptops
  (bnc#661682).
- commit 1eb5eaa
* Wed Feb  9 2011 gregkh@suse.de
- Staging: samsung-laptop: add support for lots of laptops
  (bnc#661682).
- commit c6d0dc9
* Wed Feb  9 2011 mmarek@suse.cz
- rpm/kernel-source.spec.in: Set timestamp of sources to the commit
  timestamp, so that they are always older than generated files in
  /usr/src/linux-obj (bnc#669669).
- commit 31e675a
* Wed Feb  9 2011 tiwai@suse.de
- ALSA: hda - Fix missing CA initialization for HDMI/DP
  (bnc#670577).
- commit 474305e
* Wed Feb  9 2011 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Do not run fdupes in /usr/src/linux-obj, to
  keep timestamps intact.
- commit e211a69
* Wed Feb  9 2011 mmarek@suse.cz
- rpm/kernel-source.spec.in: Remove .gitignore files after applying patches
  (fix last change).
- commit d6a7494
* Tue Feb  8 2011 jeffm@suse.com
- Updated to 2.6.38-rc4.
  - Eliminated 1 patch.
- commit c327e0a
* Tue Feb  8 2011 jslaby@suse.cz
- orinoco: allow IW_AUTH_MFP to pass through (bnc#661624).
- commit 442a3d7
* Tue Feb  8 2011 jbeulich@novell.com
- Fix a few issues in patches.suse/stack-unwind (bnc#661409).
- commit f82619b
* Tue Feb  8 2011 jbeulich@novell.com
- Fix a few issues in patches.suse/stack-unwind (bnc#661409).
- commit 027481c
* Tue Feb  8 2011 jbeulich@novell.com
- Update Xen patches to 2.6.38-rc4 and c/s 1066.
- config.conf: Re-enable Xen.
- Update x86 config files.
- commit 72cea6e
* Tue Feb  8 2011 jbeulich@novell.com
- Update config files.
- Refresh and re-enable patches.arch/x86_64-unwind-annotations.
- Refresh and re-enable patches.suse/stack-unwind.
- commit 1fabeda
* Tue Feb  8 2011 sjayaraman@suse.de
- Refresh patches.suse/SoN-06-mm-kmem_estimate_pages.patch to accomodate an
  upstream change.
- commit ae5bb3f
* Mon Feb  7 2011 jslaby@suse.cz
- staging: rt2860: Fix incorrect netif_stop_queue usage warning
  (bnc#661657).
- commit 39b4c1e
* Mon Feb  7 2011 mmarek@suse.cz
- rpm/{kernel-source.spec.in,mkspec}: Sync with vanilla and linux-next
- commit fecf998
* Mon Feb  7 2011 mmarek@suse.cz
- rpm/kernel-source.spec.in: Remove dead code.
- commit b97b6f2
* Mon Feb  7 2011 mmarek@suse.cz
- rpm/kernel-binary.spec.in, rpm/kernel-spec-macros: Fix the definition
  of %%release_major and rename it to %%release_num to better describe
  what it does. Add some comments to explain how the versioning works.
- commit 3de2a1a
* Fri Feb  4 2011 mmarek@suse.cz
- rpm/compute-PATCHVERSION.sh: Fix sed regexp
- commit d889fe7
* Fri Feb  4 2011 jeffm@suse.com
- hfs: avoid crash in hfs_bnode_create (bnc#552250).
- commit d84296a
* Fri Feb  4 2011 jeffm@suse.com
- Updated to 2.6.38-rc3.
  - Eliminated 2 patches.
- commit b6b51ca
* Thu Feb  3 2011 rjw@suse.de
- x86, mtrr: avoid MTRR reprogramming on BP during boot on (bnc#623393).
- commit 0664ad4
* Thu Feb  3 2011 jbeulich@novell.com
- Update Xen patches to c/s 1066.
- cpuidle/x86/perf: fix power:cpu_idle double end events and
  throw cpu_idle events from the cpuidle layer (bnc#665153).
- perf: Clean up power events by introducing new, more generic
  ones (bnc#665153).
- commit e88242f
* Thu Feb  3 2011 jbeulich@novell.com
- Fix jiffy calculations in calibrate_delay_direct to handle
  overflow.
- commit 4a69163
* Wed Feb  2 2011 jeffm@suse.com
- patches.fixes/reiserfs-xattr-crash-fix: fix crash
  during failed mount (bnc#668878)
- commit de24d15
* Wed Feb  2 2011 tiwai@suse.de
- ALSA: hda - Fix memory leaks in conexant jack arrays
  (bnc#668929).
- commit 7dbcb59
* Tue Feb  1 2011 jslaby@suse.cz
- Refresh patches.rpmify/cloneconfig.diff.
  scripts/kconfig/conf accepts long parameters only for some time already
- commit 939410c
* Mon Jan 31 2011 jslaby@suse.cz
- block: loop queue_lock null pointer derefence in blk_throtl_exit
  v3 (bnc#666598).
- commit cd38efd
* Mon Jan 31 2011 jslaby@suse.cz
- Fix prlimit64 for suid/sgid processes (bnc#668262).
- commit dae8217
* Mon Jan 24 2011 jeffm@suse.com
- netfilter: Implement RFC 1123 for FTP conntrack (bnc#466279).
- commit 3e2a2b2
* Mon Jan 24 2011 jeffm@suse.com
- netfilter: Implement RFC 1123 for FTP conntrack (bnc#466279).
- commit 4bf0e68
* Sun Jan 23 2011 jeffm@suse.de
- winbond: needs <linux/delay.h> for msleep and friends.
- commit e394a2e
* Sun Jan 23 2011 jeffm@suse.de
- Refresh patches.arch/ia64-page-migration: Update for migrate_pages() API change.
- commit 40d2921
* Sun Jan 23 2011 jeffm@suse.de
- supported.conf: Added rc_core as a dependency.
- commit 8b2c1b9
* Sun Jan 23 2011 jeffm@suse.com
- Update config files.
  - CONFIG_EXPERT=n on all but ps3
  - Vanilla configs updated.
- commit b25e639
* Sun Jan 23 2011 jeffm@suse.com
- Revert "- Update config files: CONFIG_EXPERT=n except ps3"
  This reverts commit 3f2c93d6a0593b2cc0c40f5ffee426eef27cc400.
  This was a bad commit. I have no idea where all the changes came from.
- commit 459f3f1
* Sun Jan 23 2011 jeffm@suse.com
- Update config files: CONFIG_EXPERT=n except ps3
- commit 3f2c93d
* Sun Jan 23 2011 jeffm@suse.com
- Updated to 2.6.38-rc2.
  - Eliminated 1 patch.
- commit 90baa82
* Sat Jan 22 2011 jeffm@suse.com
- ata: Fix panics with ata_id (bnc#660464).
- commit fa7af15
* Sat Jan 22 2011 jeffm@suse.de
- Updated some Patch-mainline headers.
- commit 9122bf0
* Sat Jan 22 2011 jeffm@suse.de
- Update to 2.6.38-rc1.
  - Removed 12 patches.
  - Xen is disabled.
  - Quite a few patches need updating.
- commit 9163bb7
* Fri Jan 21 2011 trenn@suse.de
- perf: Do not export power_frequency, but power_start event
  (bnc#665153).
- cpuidle/x86/perf: fix power:cpu_idle double end events and
  throw cpu_idle events from the cpuidle layer (bnc#665153).
- perf: Clean up power events by introducing new, more generic
  ones (bnc#665153).
- cpuidle: Rename X86 specific idle poll state from C0 to POLL
  (bnc#665153).
- perf timechart: Adjust perf timechart to the new power events
  (bnc#665153).
- Fix display of idle boxes (none).
- Fix huge and wronge C-state drawings due to uninitialized
  start/end timestamps (none).
- Update config files.
- doc/config-options.changes:
  CONFIG_EVENT_POWER_TRACING_DEPRECATED=y
- commit b308eff
* Wed Jan 19 2011 jbohac@suse.cz
-    revert: ipv6: don't flush routes when setting loopback down.
- commit de347ac
* Tue Jan 18 2011 trenn@suse.de
- ACPI / ACPICA: Initialize the global lock spinlock as
  appropriate (bnc#637377).
- commit c4b8238
* Tue Jan 18 2011 trenn@suse.de
- ACPI / ACPICA: Fix global lock acquisition (bnc#637377).
- commit 15cd726
* Mon Jan 17 2011 jeffm@suse.com
- mISDN: Add support for group membership check (bnc#564423).
- commit 3f46938
* Fri Jan 14 2011 mmarek@suse.cz
- Revert %%kernelrelease changes originally made on the vanilla branch,
  they break on master and must be done differently.
- commit b610327
* Thu Jan 13 2011 jkosina@suse.cz
- Input: introduce 'notimeout' blacklist for Dell Vostro V13
  (bnc#641105).
- commit cb76856
* Wed Jan 12 2011 jeffm@suse.com
- In-kernel dependencies for reiser4
  - Delete patches.suse/reiser4-exports.
  - Delete patches.suse/reiser4-set_page_dirty_notag.
- commit 1b97130
* Tue Jan 11 2011 jbeulich@novell.com
- patches.xen/xen3-patch-2.6.29: Fix a regression.
- commit 6acb967
* Mon Jan 10 2011 jack@suse.cz
- novfs: NCP Fragments can be upto 64k in size (bnc#625965).
- commit afd7489
* Mon Jan 10 2011 jbeulich@novell.com
- Update Xen patches to 2.6.37-final and c/s 1062.
- commit ef70146
* Mon Jan 10 2011 jeffm@suse.com
- Enabled AGP modules as parts of the static kernel on i386 (bnc#609607)
- commit 9446eb0
* Sat Jan  8 2011 jengelh@medozas.de
- config: run oldconfig on sparc64/default
- commit aa3e940
* Sat Jan  8 2011 jengelh@medozas.de
- config: update sparc64/net and throw out unworthy options
- commit 1aca53d
* Sat Jan  8 2011 gregkh@suse.de
- Comment out broken rt2x00 driver patch, don't know how to fix it right
  now.
- commit 70ec9f3
* Sat Jan  8 2011 gregkh@suse.de
- updated to Linux 2.6.36.3.
  - security fixes
  - bug fixes
  - obsoleted:
  - patches.fixes/rt2x00-Fix-max-TX-power-settings.patch.
  - patches.fixes/tehuti-firmware-name.
- commit d4997c9
* Fri Jan  7 2011 mmarek@suse.cz
- Delete patches.suse/gfs2-ro-mounts-only.patch (obsolete and unused)
- commit 38ff246
* Fri Jan  7 2011 trenn@suse.de
- Some are mainline, some are/will be implemented differently:
- Delete patches.drivers/dynamic_debug_1.patch.
- Delete patches.drivers/dynamic_debug_2.patch.
- Delete patches.drivers/dynamic_debug_3.patch.
- Delete patches.drivers/dynamic_debug_4.patch.
- Delete patches.drivers/dynamic_debug_5.patch.
- Delete patches.drivers/dynamic_debug_6.patch.
- Delete patches.drivers/dynamic_debug_7.patch.
- commit 68dc5c8
* Fri Jan  7 2011 neilb@suse.de
- Remove old patch
- commit 7fc009b
* Thu Jan  6 2011 jeffm@suse.com
- reiserfs: Fix crash during umount (bnc#610598).
- commit 88f26ac
* Thu Jan  6 2011 mmarek@suse.cz
- rpm/kernel-source.spec.in: Move the source tree if %%kernelrelease is
  different from the tarball version.
- commit 6be9ffe
* Thu Jan  6 2011 mmarek@suse.cz
- Delete patches.suse/export-sync_page_range (unused).
- commit d19ee6d
* Thu Jan  6 2011 jeffm@suse.com
- Delete patches.suse/supported-flag-sysfs: Merged with patches.suse/supported-flag
- commit 0f2e67b
* Thu Jan  6 2011 jeffm@suse.com
- Removed unused kdb patches.
  - Delete patches.suse/kdb-build-fixes.
  - Delete patches.suse/kdb-common.
  - Delete
    patches.suse/kdb-fix-assignment-from-incompatible-pointer-warnings.
  - Delete
    patches.suse/kdb-fix-kdb_cmds-to-include-the-arch-common-macro.
  - Delete patches.suse/kdb-handle-nonexistance-keyboard-controller.
  - Delete patches.suse/kdb-ia64.
  - Delete patches.suse/kdb-usb-rework.
  - Delete patches.suse/kdb-vm-api-changes-for-2-6-34.
  - Delete patches.suse/kdb-x86.
  - Delete patches.suse/kdb-x86-build-fixes.
  - Delete patches.suse/kdb_dont_touch_i8042_early.patch.
  - Delete patches.suse/kdb_fix_ia64_build.patch.
  - Delete patches.xen/xen3-kdb-x86.
- commit c9e725d
* Thu Jan  6 2011 jeffm@suse.com
- rpm/kernel-source.spec.in: Remove the relocation of the source tree.
  It's expanded in-place.
- commit 8cde941
* Thu Jan  6 2011 jack@suse.cz
- Delete patches.suse/ext2-fsync-err as it is obsolete and unused.
- commit c8f4ebe
* Thu Jan  6 2011 mmarek@suse.cz
- Delete patches.fixes/kbuild-fix-generating-of-.symtypes-files.
  Fixed upstream in commit e26d6b8.
- commit 1b628e1
* Thu Jan  6 2011 mgalbraith@suse.de
- Replaced autogroup patch with what will appear in 2.6.38
- Replaced cgroup use after free fix wtih what will appear in 2.6.38
- Refresh
  patches.fixes/sched-cgroup-use-exit-hook-to-avoid-use-after-free-crash.
- Refresh patches.suse/sched-automated-per-session-task-groups.
- Delete patches.fixes/sched-fix-autogroup-proc-interface-race.
- commit 81f018b
* Thu Jan  6 2011 jeffm@suse.com
- Update to 2.6.37-final.
- commit f4cd126
* Thu Dec 30 2010 jeffm@suse.com
- taskstats: Use better ifdef for alignment (bko#24272).
- commit 2948ffa
* Wed Dec 29 2010 jeffm@suse.com
- Update to 2.6.37-rc8.
  - Eliminated 1 patch.
- commit 42518e6
* Tue Dec 28 2010 mgalbraith@suse.de
- sched: fix autogroup /proc interface race.
- commit fd7019c
* Tue Dec 28 2010 jeffm@suse.com
- scripts/wd-functions.sh: Re-added support for finding tarball in $MIRROR.
- commit c8014fb
* Tue Dec 28 2010 jeffm@suse.com
- sched, cgroup: Use exit hook to avoid use-after-free crash.
- commit 59c0581
* Tue Dec 28 2010 jeffm@suse.com
- Update to 2.6.37-rc7.
  - Eliminated 9 patches.
- commit d38591c
* Mon Dec 20 2010 jslaby@suse.cz
- Revert "x86: allocate space within a region top-down"
  (bnc#655048).
  Backport to XEN.
- commit 92c0965
* Mon Dec 20 2010 jslaby@suse.cz
- Revert "PCI: fix pci_bus_alloc_resource() hang, prefer positive
  decode" (bnc#655048).
- Revert "x86: allocate space within a region top-down"
  (bnc#655048).
- Revert "x86/PCI: allocate space from the end of a region,
  not the beginning" (bnc#655048).
- Revert "PCI: allocate bus resources from the top down"
  (bnc#655048).
- Revert "resources: support allocating space within a region
  from the top down" (bnc#655048).
- resources: add arch hook for preventing allocation in reserved
  areas (bnc#655048).
- x86: avoid low BIOS area when allocating address space
  (bnc#655048).
- x86: avoid E820 regions when allocating address space
  (bnc#655048).
- x86: avoid high BIOS area when allocating address space
  (bnc#655048).
- Refresh patches.xen/xen3-patch-2.6.34.
- commit 7bbbf27
* Mon Dec 20 2010 jslaby@suse.cz
- Revert "- resources: add arch hook for preventing allocation in reserved"
  This reverts commit 7e253537787f4fb057e12a166356169c5adb9665. It was unintended to be pushed as the patches are obsoleted.
- commit 6f3bdf8
* Mon Dec 20 2010 jslaby@suse.cz
- Delete
  patches.fixes/res-0010-PCI-fix-pci_bus_alloc_resource-hang-prefer-positive-.patch.
  It's unreferenced and wrong.
- commit 9e6fc50
* Fri Dec 17 2010 mmarek@suse.cz
- rpm/kernel-source.spec.in: Define %%kernelrelease
- commit 1d67b13
* Thu Dec 16 2010 jeffm@suse.com
- Linux: 2.6.37-rc6.
- Update config files.
- Refresh patches.suse/SoN-23-mm-swapfile.patch.
- Refresh patches.suse/SoN-26-nfs-swapper.patch.
- Refresh patches.xen/xen3-fixup-xen.
- Refresh patches.xen/xen3-patch-2.6.24.
- commit 5650f90
* Mon Dec 13 2010 jbeulich@novell.com
- Update Xen config files (XEN_NETDEV_LOOPBACK=n).
- supported.conf: Update.
- commit d385dff
* Mon Dec 13 2010 tiwai@suse.de
- Refresh patches.suse/bootsplash-scaler: Fix crash when bootsplash animation is used (bnc#646908)
- commit c5eced1
* Fri Dec 10 2010 jslaby@suse.cz
- Update to Linux 2.6.36.2
- Obsoletes:
  patches.drivers/alsa-hda-01-Fix-wrong-SPDIF-NID-assignment-for-CA0110
  patches.drivers/alsa-hda-02-Add-some-workarounds-for-Creative-IBG
  patches.drivers/alsa-hda-03-Add-workarounds-for-CT-IBG-controllers
  patches.fixes/hpet-unmap-unused-I-O-space.patch
  patches.fixes/net-Limit-socket-I-O-iovec-total-length.patch
  patches.fixes/tty-restore-tty_ldisc_wait_idle.patch
- Refresh patches.suse/SoN-22-netvm.patch
- commit 8c48718
* Fri Dec 10 2010 jslaby@suse.cz
- resources: add arch hook for preventing allocation in reserved
  areas (bnc#655048).
- x86: avoid BIOS area when allocating address space (bnc#655048).
- x86: avoid PNP resources when allocating address space
  (bnc#655048).
- Refresh patches.xen/xen3-patch-2.6.34.
- commit 7e25353
* Fri Dec 10 2010 jbeulich@novell.com
- Update Xen config files (CONFIG_XEN_COMPAT=0x040000).
- commit 5343e5f
* Fri Dec 10 2010 jbeulich@novell.com
- Update Xen patches to 2.6.37-rc5.
- commit bef1a0d
* Thu Dec  9 2010 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Fix timestamp of /usr/src/linux-obj/.../.config
- commit dbec62c
* Thu Dec  9 2010 mmarek@suse.cz
- rpm/config.sh: Build against openSUSE:Factory
- commit bf19860
* Wed Dec  8 2010 mmarek@suse.cz
- rpm/kernel-docs.spec.in: Allow to build against any version of
  kernel-source
- commit da8598f
* Tue Dec  7 2010 jbeulich@novell.com
- patches.arch/x86_64-unwind-annotations: Remove stringification
  (needed only with very old assemblers).
- commit 987c244
* Tue Dec  7 2010 jeffm@suse.com
- scripts/sequence-patch.sh: Added -vanilla suffix to the directory name when expanding vanilla tree.
- commit 77ad87b
* Tue Dec  7 2010 jeffm@suse.com
- Update vanilla config files.
- commit f55f81b
* Tue Dec  7 2010 jeffm@suse.com
- Update to 2.6.37-rc5.
- commit ca102d9
* Tue Dec  7 2010 jbeulich@novell.com
- patches.suse/novfs-fix-ioctl-usage: Fix compiler warnings.
- commit faf2142
* Mon Dec  6 2010 mgalbraith@suse.de
- Replace buggy per tty autogroup patch with final per session patch as
  integrated into tip.
- sched: Add 'autogroup' scheduling feature: automated per session task groups (bnc#657613).
- Delete patches.suse/sched-automated-per-tty-task-groups.
- commit 0db6b6b
* Mon Dec  6 2010 jbeulich@novell.com
- patches.rpmify/rpm-kernel-config, patches.rpmify/split-package,
  patches.suse/0004-richacl-In-memory-representation-and-helper-function.patch,
  patches.suse/SoN-15-netvm-reserve.patch,
  patches.suse/SoN-27-nfs-swap_ops.patch,
  patches.suse/kconfig-automate-kernel-desktop,
  patches.suse/mm-tune-dirty-limits.patch,
  patches.suse/supported-flag-enterprise: Clean up Kconfig portions.
- commit 713650c
* Mon Dec  6 2010 jeffm@suse.com
- Fixed corrupted -rc4 patch.
- commit 9802d4e
* Mon Dec  6 2010 jeffm@suse.de
- Update to 2.6.37-rc4.
- commit d102b44
* Wed Dec  1 2010 jslaby@suse.cz
- Update README.BRANCH
  To reflect what the stable branch really is.
- commit 59a125e
* Mon Nov 29 2010 jeffm@suse.com
- Merge 2.6.37-rc3-git6 with Xen.
- commit 7089cd5
* Mon Nov 29 2010 jeffm@suse.com
- Update to 2.6.37-rc3-git6.
- commit 1294ef9
* Mon Nov 29 2010 jslaby@suse.cz
- Update to Linux 2.6.36.1
- commit 11bcaf3
* Fri Nov 26 2010 jbeulich@novell.com
- Update Xen patches to 2.6.37-rc3-git1 and c/s 1055.
- xen/acpi: Add memory hotadd to pvops dom0 (bnc#651066).
- xen/acpi: Export host physical CPU information to dom0
  (bnc#651066).
- Xen: para-virtual watchdog driver.
- introduce {rd,wr}msr_safe_on_pcpu() and add/enable users.
- eliminate scalability issues from initrd handling.
- config.conf: Re-enable Xen.
- Update x86 config files.
- commit cf6d991
* Fri Nov 26 2010 trenn@suse.de
- PERF: Fix perf timechart C-state regression (none).
- commit ba2671d
* Wed Nov 24 2010 jeffm@suse.com
- Update to 2.6.37-rc3-git1.
- commit 4ad245f
* Mon Nov 22 2010 jeffm@suse.com
- Update to 2.6.37-rc3.
  - Eliminated 1 patch.
- commit 12ac0ac
* Mon Nov 22 2010 jslaby@suse.cz
- Delete patches.fixes/make-note_interrupt-fast.diff.
- Delete patches.fixes/twl6030-fix-note_interrupt-call.
  __do_IRQ from ia64 lapic code is no longer called, because they use
  genirqs properly. So these patches don't make sense anymore. If we
  need something to do, then it's adding action_ret == IRQ_NONE test
  into handle_percpu_irq before jumping into note_interrupt.
- commit facd623
* Sun Nov 21 2010 jslaby@suse.cz
- PCI: fix offset check for sysfs mmapped files (bnc#655157).
- commit 2938f56
* Wed Nov 17 2010 jeffm@suse.com
- sched: automated per tty task groups.
  - Enabled in -desktop flavors for better interactivity.
- commit 2d5d397
* Tue Nov 16 2010 jeffm@suse.de
- doc/config-options.changes: Updated changes for 2.6.37-rc1 and -rc2.
- commit 0aca8b8
* Tue Nov 16 2010 jeffm@suse.com
- Update to 2.6.37-rc2.
- commit 1453a04
* Tue Nov 16 2010 jslaby@suse.cz
- PCI: fix pci_bus_alloc_resource() hang, prefer positive decode
  (bnc#651256).
- commit b4888f0
* Mon Nov 15 2010 jeffm@suse.com
- Update vanilla config files.
- commit 60b4a47
* Mon Nov 15 2010 jeffm@suse.com
- Update to 2.6.37-rc1-git11.
  - Eliminated 2 patches.
- commit 5959a67
* Mon Nov 15 2010 jeffm@suse.com
- supported.conf: Added missing dependencies.
- commit 0537c35
* Sat Nov 13 2010 jslaby@suse.cz
- TTY: restore tty_ldisc_wait_idle (bnc#642043).
- commit 84d87bf
* Fri Nov 12 2010 jeffm@suse.de
- Update to 2.6.37-rc1.
  - Eliminated 26 patches.
  - Xen is disabled.
- commit b9044e3
* Thu Nov 11 2010 gregkh@suse.de
- Update config files. (bnc#652954) increase the number of possible and
  default uarts for users with multi-port serial cards for the i386 and
  x86-64 default configs.
- commit 85c87e3
* Thu Nov 11 2010 jslaby@suse.cz
- rt2x00: Fix max TX power settings (bnc#584028).
- rt2x00: Fix channel configuration for RF3052 (bnc#584028).
- commit 60c0452
* Thu Nov 11 2010 jslaby@suse.cz
- resources: add a default alignf to simplify find_resource()
  (bnc#651256).
- resources: factor out resource_clip() to simplify
  find_resource() (bnc#651256).
- resources: ensure callback doesn't allocate outside available
  space (bnc#651256).
- resources: handle overflow when aligning start of available area
  (bnc#651256).
- resources: support allocating space within a region from the
  top down (bnc#651256).
- PCI: allocate bus resources from the top down (bnc#651256).
- x86/PCI: allocate space from the end of a region, not the
  beginning (bnc#651256).
- x86: update iomem_resource end based on CPU physical address
  capabilities (bnc#651256).
- x86: allocate space within a region top-down (bnc#651256).
- Refresh patches.xen/xen3-patch-2.6.34.
- commit 8c68ad1
* Tue Nov  9 2010 jack@suse.cz
- novfs: Fix for the issue of kernel dumps core on restart
  (bnc#641811).
- commit 76ba833
* Fri Oct 29 2010 jslaby@suse.cz
- net: Limit socket I/O iovec total length to INT_MAX
  (bnc#650128).
- commit 2ba74bb
* Fri Oct 29 2010 trenn@suse.de
- Update config files.
  Forgot to enable ACPI_EC_DEBUGFS on i386/pae
- commit 66b605b
* Wed Oct 27 2010 jslaby@suse.cz
- aha152x: enable PCMCIA on 64bit (bnc#630652).
- Update config files.
- commit a91d17c
* Wed Oct 27 2010 jslaby@suse.cz
- hpet: unmap unused I/O space (bnc#629908 bnc#629901).
- commit dad22c3
* Tue Oct 26 2010 trenn@suse.de
- Update config files.
  Enable CONFIG_ACPI_EC_DEBUGFS=m on supported archs.
- commit 9035254
* Tue Oct 26 2010 jbeulich@novell.com
- Update Xen config files (restore options accidentally deleted
  by 1b1584fccbfdc42e6e8b35c3c207ca65feb0c7d5).
- commit f8e5000
* Mon Oct 25 2010 jbeulich@novell.com
- Update Xen patches to 2.6.36 and c/s 1043.
- xen: netback: take net_schedule_list_lock when removing entry
  from net_schedule_list.
- Update Xen config files.
- commit b772cd8
* Mon Oct 25 2010 tiwai@suse.de
- ALSA: hda - Add workarounds for CT-IBG controllers (bnc#564324).
- ALSA: hda - Add some workarounds for Creative IBG (bnc#564324).
- ALSA: hda - Fix wrong SPDIF NID assignment for CA0110
  (bnc#564324).
- commit 2256eda
* Fri Oct 22 2010 jeffm@suse.de
- Update to 2.6.36-final.
- commit 1b1584f
* Fri Oct 22 2010 jbeulich@novell.com
- patches.arch/i386-unwind-annotations,
  patches.arch/x86_64-unwind-annotations: Update Patch-mainline tags.
- commit 6ee5ccb
* Thu Oct 21 2010 sjayaraman@suse.de
- SoN: fix null pointer dereference in swap_entry_free.
- SoN: fix mess up on swap with multi files from same nfs server.
- Refresh patches.xen/tmem.
- commit d068f12
* Mon Oct 18 2010 trenn@suse.de
- ACPI: Make Embedded Controller command timeout delay
  configurable (bnc#639261).
- commit 9ea38cf
* Fri Oct 15 2010 jslaby@suse.cz
- Update to 2.6.36-rc8.
- commit 0c0e67c
* Fri Oct 15 2010 jslaby@suse.cz
- Refresh patches.suse/SoN-22-netvm.patch.
  Fix lock imbalance in net core (caused errors with bridges). (bnc#637235)
- commit f7ca98f
* Tue Oct 12 2010 jbeulich@novell.com
- Update Xen patches to 2.6.36-rc7 and c/s 1042.
- Update tmem interface to v1.
- commit 03c1043
* Mon Oct 11 2010 mmarek@suse.cz
- Generate per-symbol provides again (fate#305945).
  11.4 will do incremental downloads of repository metadata
  (fate#309561), so there should be no problem with the update
  repository anymore.
- commit 4258cf2
* Mon Oct 11 2010 jbeulich@novell.com
- patches.apparmor/apparmor-compatibility-patch-for-v5-network-control:
  Remove .rej file from this patch.
- commit 8828ce5
* Fri Oct  8 2010 jeffm@suse.de
- Update to 2.6.36-rc7.
- commit 82673e4
* Tue Oct  5 2010 jbeulich@novell.com
- patches.drivers/dynamic_debug_4.patch: Fix build issues with
  !DYNAMIC_DEBUG and build warning.
- commit b08d2aa
* Tue Oct  5 2010 jeffm@suse.de
- Enable SECURITY_APPARMOR_COMPAT_24
- commit f9b83fc
* Tue Oct  5 2010 jeffm@suse.de
- AppArmor: Allow dfa backward compatibility with broken
  userspace.
- AppArmor: compatibility patch for v5 interface.
- AppArmor: compatibility patch for v5 network control.
- commit cb27981
* Mon Oct  4 2010 jeffm@suse.de
- Update to 2.6.36-rc6.
  - Eliminated 2 patches.
- commit 57ae577
* Fri Sep 24 2010 jbeulich@novell.com
- Refresh patches.xen/xen3-patch-2.6.28 one more time.
- commit d527087
* Fri Sep 24 2010 trenn@suse.de
- acpi: ec_sys: access user space with get_user()/put_user()
  (none).
- commit d028761
* Fri Sep 24 2010 trenn@suse.de
- kernel/module.c: Fix compiler warnings if debug is compiled in
  (none).
- PNP: Use dev_dbg instead of dev_printk(KERN_DEBUG.. if
  DYNAMIC_DEBUG is compiled in (none).
- PNP: Compile all pnp built-in stuff in one module namespace
  (none).
- Dynamic Debug: Introduce global fake module param module.ddebug
  - V4 (none).
- Dynamic Debug: Initialize dynamic debug earlier via
  arch_initcall (none).
- Dynamic Debug: Introduce ddebug_query= boot parameter (none).
- Dynamic Debug: Split out query string parsing/setup from
  proc_write (none).
- commit dcd5c68
* Fri Sep 24 2010 jbeulich@novell.com
- Refresh patches.xen/xen3-patch-2.6.28 again.
- commit 2fbc89f
* Fri Sep 24 2010 jbeulich@novell.com
- Refresh patches.xen/xen3-patch-2.6.28.
- commit cba31c7
* Fri Sep 24 2010 jbeulich@novell.com
- Update Xen patches to 2.6.36-rc5 and c/s 1038.
- commit 7b86243
* Thu Sep 23 2010 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Fix for kernel release strings like
  2.6.36-rc5-73-g57aebd7-vanilla.
- rpm/kernel-spec-macros: Cleanup.
- commit 0926a18
* Thu Sep 23 2010 jeffm@suse.de
- rose: Fix signedness issues wrt. digi count (CVE-2010-3310
  bnc#640721).
- commit bcdc88b
* Tue Sep 21 2010 jeffm@suse.de
- qla4xxx: add workaround for missing readq/writeq.
- commit 643f9cf
* Tue Sep 21 2010 mmarek@suse.cz
- rpm/kernel-docs.spec.in: BuildRequire proper version of kernel-source
- commit beb33d1
* Tue Sep 21 2010 jeffm@suse.de
- Linux: 2.6.36-rc5.
  - Eliminated 6 patches (all security backports).
- commit d4603b4
* Mon Sep 20 2010 jeffm@suse.de
- Revert "- make SCSI and ATA drivers modules again. (bnc#564357)."
  This reverts commit 75e8e5eae2c1e8dd279370f2c7650835ee821deb.
  - make SCSI and ATA drivers modules again.
    (bnc#564357)
  This change only applies to enterprise releases and should have been
  reverted prior to the release of openSUSE 11.3.
- commit 7fc084f
* Mon Sep 20 2010 sjayaraman@suse.de
- Update patches.suse/SoN-05-reserve-slub.patch to accomodate an upstream
  change that uses kmem_cache flags instead of PageSlubDebug flag.
- commit 4ea582b
* Mon Sep 20 2010 jeffm@suse.de
- Set LSM_MMAP_MIN_ADDR=0 to allow tools like DOSemu to work properly. The
  default is still set to 64k.
- commit 0581892
* Sun Sep 19 2010 jeffm@suse.com
- Delete patches.suse/cgroup-disable-memory.patch: It is no longer needed. The performance hit that it caused has been eliminated.
- commit 1ec7da8
* Fri Sep 17 2010 jeffm@suse.de
- wext: fix potential private ioctl memory content leak
  (CVE-2010-2955 bnc#635413).
- commit 6df45c9
* Thu Sep 16 2010 jeffm@suse.de
- x86-64, compat: Test %%rax for the syscall number, not %%eax
  (CVE-2010-3301 bnc#639708).
- x86-64, compat: Retruncate rax after ia32 syscall entry tracing
  (CVE-2010-3301 bnc#639708).
- commit fb77404
* Thu Sep 16 2010 jeffm@suse.de
- compat: Make compat_alloc_user_space() incorporate the
  access_ok() (CVE-2010-3081 bnc#639709).
- commit 664a0ac
* Wed Sep 15 2010 jeffm@suse.com
- Remove reference to unused patch.
- commit a3abfe2
* Wed Sep 15 2010 jeffm@suse.de
- drivers/net/usb/hso.c: prevent reading uninitialized memory
  (CVE-2010-3298 bnc#639483).
- commit 35e70c8
* Wed Sep 15 2010 jeffm@suse.de
- drivers/net/cxgb3/cxgb3_main.c: prevent reading uninitialized
  stack memory (CVE-2010-3296 bnc#639481).
- commit a0634a9
* Wed Sep 15 2010 jeffm@suse.de
- drivers/net/eql.c: prevent reading uninitialized stack memory
  (CVE-2010-3297 bnc#639482).
- commit 2a7b160
* Wed Sep 15 2010 tiwai@suse.de
- Revert "patches.drivers/matador_reset_quirk.diff: Fix reset with Matador btusb devices bnc#626171"
  This reverts commit c6a176c1df9ab4c69dd54ff3076bc92806eac8fd.
  It should have been applied to SLE11-SP1 branch.
- commit 05f07f3
* Tue Sep 14 2010 jslaby@suse.cz
- Update to Linux 2.6.36-rc4.
  - Obsoletes:
  - patches.fixes/bonding-jiffies2.patch.
  - patches.fixes/irda-correctly-clean-up-self-ias_obj-on-irda_bind-failure.
  - patches.fixes/net-sched-fix-kernel-leak-in-act_police.
  - patches.rpmify/spectra-depends-on-moorestown.
- fix build on s390 as of 2.6.36-rc4.
- Refresh patches.suse/SoN-08-mm-page_alloc-emerg.patch.
- Refresh patches.suse/reiser4-set_page_dirty_notag.
- Refresh patches.xen/pci-guestdev.
- Update config files.
- commit 6915057
* Mon Sep 13 2010 oneukum@suse.de
- patches.drivers/matador_reset_quirk.diff: Fix reset with Matador btusb devices bnc#626171
- commit c6a176c
* Mon Sep 13 2010 jdelvare@suse.de
- patches.fixes/bonding-jiffies2.patch: Update patch-mainline.
- commit a1a8fdd
* Fri Sep  3 2010 jeffm@suse.de
- Always build in AGP on x86/x86_64 so KMS works on LiveCDs (bnc#609607).
- commit d9bfa1e
* Fri Sep  3 2010 jeffm@suse.com
- irda: Correctly clean up self->ias_obj on irda_bind() failure
  (CVE-2010-2954 bnc#636112).
- commit f04e61f
* Wed Sep  1 2010 jbeulich@novell.com
- Update Xen patches to 2.6.36-rc3 and c/s 1029.
- fix unwind annotations.
- config.conf: Re-enable Xen.
- Update x86 config files.
- commit 6836619
* Wed Sep  1 2010 jbeulich@novell.com
- fix unwind annotations.
- commit 5aa6daf
* Wed Sep  1 2010 jeffm@suse.com
- net sched: fix kernel leak in act_police (CVE-2010-2942
  bnc#632309).
- commit 66e1d72
* Tue Aug 31 2010 jdelvare@suse.de
- fix jiffies overflow problems in bonding (bnc#613273).
- commit 28bd2e8
* Mon Aug 30 2010 jeffm@suse.de
- Refresh vanilla configs.
- commit 26a681e
* Mon Aug 30 2010 jeffm@suse.de
- Update to Linux: 2.6.36-rc3.
  - Eliminated 7 patches.
- commit d298d2d
* Sat Aug 28 2010 jslaby@suse.cz
- Delete
  patches.suse/rlim-0020-core-optimize-setrlimit-for-current-task.patch.
- Delete
  patches.suse/rlim-0021-FS-proc-switch-limits-reading-to-fops.patch.
- Delete
  patches.suse/rlim-0022-FS-proc-make-limits-writable.patch.
  This was just a workaround crap. In 2.6.36 we have a nice syscall
  instead. Sorry for commiting this to the merge-36 branch first. I
  didn't notice it was already merged here.
- commit 5449fcb
* Fri Aug 27 2010 jeffm@suse.com
- Disabled ACPI table override patches again. fsnotify was introduced into
  the truncate path and causes crashes.
- commit e18fc2c
* Thu Aug 26 2010 jeffm@suse.de
- Refresh patches.suse/supported-flag-enterprise: Fixed recovery on load failure.
- commit 8a06643
* Thu Aug 26 2010 jeffm@suse.de
- Refresh patches.suse/stack-unwind: Fixed recovery on load failure.
- commit 7f15b29
* Tue Aug 24 2010 jeffm@suse.com
- patches.arch/s390-message-catalog.diff: dev_info -> _dev_info
- commit ba20988
* Tue Aug 24 2010 jeffm@suse.de
- patches.suse/stack-unwind: Fix build on !SMP
- commit abd5493
* Tue Aug 24 2010 jeffm@suse.de
- s390: Fix prototype for execve.
- commit b448268
* Tue Aug 24 2010 jeffm@suse.de
- spectra: depend on X86_MRST.
- commit 1e3fb89
* Tue Aug 24 2010 jeffm@suse.de
- Delete patches.arch/ppc-vmcoreinfo.diff.
- commit ea39e14
* Tue Aug 24 2010 jeffm@suse.de
- caif: Use asm/unaligned.h.
- commit 92c07c2
* Tue Aug 24 2010 jeffm@suse.de
- Refresh patches.suse/SoN-20-netvm-tcp-deadlock.patch: Added missing
  fixup for sk_rmem_schedule in caif.
- commit a9ff761
* Tue Aug 24 2010 mmarek@suse.cz
- makefile: not need to regenerate kernel.release file when
  make kernelrelease.
- commit 81237a8
* Tue Aug 24 2010 jeffm@suse.com
- rpm/kernel-source.spec.in, scripts/tar-up.sh: Renamed config-options.changes
  to config-options.changes.txt in the exported package to avoid triggering
  a build service rule error.
- commit ff4889e
* Tue Aug 24 2010 jeffm@suse.com
- Revert "- Renamed doc/config-options.changes to doc/config-options.changes.txt to"
  This reverts commit 124ac26de4839f8181a5badedb231eedf5770a3e.
- commit 2932c62
* Tue Aug 24 2010 jeffm@suse.com
- Renamed doc/config-options.changes to doc/config-options.changes.txt to
  avoid triggering a build service rule error.
- commit 124ac26
* Mon Aug 23 2010 jeffm@suse.de
- supported.conf: Add iscsi_boot_sysfs
- commit 80e2ea9
* Mon Aug 23 2010 jeffm@suse.de
- rpm/kernel-binary.spec.in: Fixed typo with last fix.
- commit 22210d9
* Mon Aug 23 2010 jeffm@suse.de
- rpm/kernel-binary.spec.in: Disable CONFIG_DEBUG_INFO. It's enabled
  dynamically in the spec file and now has follow-on options.
- commit d270759
* Mon Aug 23 2010 jeffm@suse.de
- patches.rpmify/spectra-drop-locked_ioctl-support: add <linux/smp_lock.h>
  to grab the BKL
- commit 1df02ec
* Mon Aug 23 2010 jeffm@suse.de
- Update config files: Disabled DEBUG_INFO_REDUCED.
- commit 393680a
* Mon Aug 23 2010 jeffm@suse.de
- Updated to 2.6.36-rc2.
  - Eliminated 2 patches.
- commit 52d47a0
* Wed Aug 18 2010 jeffm@suse.de
- Update to 2.6.36-rc1.
  - Eliminated 71 patches.
  - spectra: Drop ->locked_ioctl support.
  - spectra: Drop ->prepare_flush_fn support.
  - spectra: Remove duplicate GLOB_VERSION.
  - novfs: Fix ioctl usage.
  - novfs: use evict_inode.
  - Xen is disabled.
- commit 63642f6
* Mon Aug 16 2010 tiwai@suse.de
- ALSA: hda - Add quirk for Dell Vostro 1220 (bnc#631066).
- commit df12c34
* Fri Aug 13 2010 jeffm@suse.com
- README.BRANCH: Updated to reflect the permenent in-progress status.
- commit a2c882e
* Thu Aug 12 2010 gregkh@suse.de
- Update to 2.6.35.1
  - security fixes
  - bug fixes
  - obsoletes:
    patches.fixes/e1000e-don-t-inadvertently-re-set-INTX_DISABLE.patch.
- commit a009fb4
* Thu Aug 12 2010 gregkh@suse.de
- Delete patches.kernel.org/patch-2.6.35-rc1.
- Delete patches.kernel.org/patch-2.6.35-rc1-rc2.
- Delete patches.kernel.org/patch-2.6.35-rc2-rc3.
- Delete patches.kernel.org/patch-2.6.35-rc3-rc4.
- Delete patches.kernel.org/patch-2.6.35-rc4-rc5.
- Delete patches.kernel.org/patch-2.6.35-rc5-rc6.
- commit 2e67843
* Thu Aug 12 2010 gregkh@suse.de
- Refresh patches.fixes/novfs-lindent.
  Someone needs to remember to actually test out their patches before
  adding them to the repo...
- commit 6569c56
* Thu Aug 12 2010 jeffm@suse.com
- doc/README.SUSE: Updated to describe the process used to add custom patches
- commit e5f4670
* Thu Aug 12 2010 jslaby@suse.cz
- patches.fixes/vmscan-fix-stalls.patch: vmscan: raise the bar
  to PAGEOUT_IO_SYNC stalls (bnc#625339).
- commit 1efea94
* Wed Aug 11 2010 jack@suse.cz
- novfs: Lindent novfs sources.
- commit 361594a
* Wed Aug 11 2010 neilb@suse.de
- Refresh
  patches.fixes/nfsd-05-sunrpc-cache-allow-thread-to-block-while-waiting-for.patch.
- Refresh patches.fixes/sunrpc-monotonic-expiry.
- Delete patches.fixes/nfs-write.c-bug-removal.patch.
  Update some patches for 2.6.35
- commit 15d7a62
* Wed Aug 11 2010 neilb@suse.de
- NFS: allow close-to-open cache semantics to apply to root of
  NFS filesystem (bnc#584720).
- commit deea101
* Tue Aug 10 2010 tiwai@suse.de
- ALSA: hda - patch_nvhdmi.c: Add missing codec IDs, unify names
  (bnc#627212).
- ALSA: hda - Add pin-fix for HP dc5750 (bnc#624118).
- commit 4844a71
* Mon Aug  9 2010 jbeulich@novell.com
- Update Xen patches to 2.6.35 final and c/s 1025.
- create devices in /dev/xen when they are expected to be
  used there.
- xen/netback: Allow setting of large MTU before rings have
  connected.
- xen/netback: Always pull through PKT_PROT_LEN bytes into the
  linear part of an skb.
- pass trigger mode and polarity information to Xen for all
  interrupts.
- Update Xen config files.
- supported.conf: Add pci-iomul.ko.
- commit c642c1b
* Fri Aug  6 2010 jeffm@suse.de
- patches.xen/xen3-auto-xen-arch.diff: Update struct acpi_power_register
  usage from upstream commit 718be4aa.
- commit 4ce0b48
* Fri Aug  6 2010 jeffm@suse.de
- Update to 2.6.35-final and refresh patch set.
- commit a40327f
* Mon Aug  2 2010 mmarek@suse.cz
- rpm/kernel-source.spec.in: Package log.sh in the source rpm
- commit 53246ff
* Fri Jul 23 2010 jack@suse.cz
- novfs: Fix error codes for getxattr for novfs (bnc#529535).
- commit 06b3243
* Fri Jul 23 2010 jeffm@suse.de
- Update to 2.6.35-rc6.
- commit 643df99
* Fri Jul 23 2010 jack@suse.cz
- novfs: code cleanup for one case of novfs return value
  (bnc#624606).
- commit 4875860
* Wed Jul 21 2010 jack@suse.cz
- Fixed patch headers of patches.fixes/novfs-xattr-memleak
- commit 65ab01f
* Wed Jul 21 2010 jack@suse.cz
- novfs: Fix a memory leak that causes an OOM condition
  (bnc#610828).
- commit 519d8a0
* Tue Jul 20 2010 jack@suse.cz
- novfs: backing device info initialization (bnc#623472).
- commit b576dae
* Tue Jul 20 2010 mmarek@suse.cz
- scripts/tar-up.sh: Generate the rpm changelog using gitlog2changes.
- Move kernel-source.changes.old to rpm/ (not included in the pachage
  though).
- commit 8ed2389
* Tue Jul 20 2010 jblunck@suse.de
- rpm/package-descriptions: Change summary/description for trace flavor (bnc#488692).
- commit da8e17e
* Mon Jul 19 2010 mmarek@suse.cz
- Move rpm changelog to kernel-source.changes.old
- commit 93036bd
* Thu Jul 15 2010 bphilips@suse.de
- X86_MRST: Disable moorsetown since it deselects SERIO_I8042
  - See 0b28bac5aef7bd1ab213723df031e61db9ff151a, fixed in -tip but we
    still don't want X86_MRST
* Wed Jul 14 2010 trenn@suse.de
- patches.arch/acpi_fix_fadt_32_bit_zero_length.patch: Only use
  32 bit addresses if they have a valid length (bug#581644).
* Wed Jul 14 2010 bphilips@suse.de
- Update -desktop config files to enable CGROUPS for systemd
* Wed Jul 14 2010 jeffm@suse.de
- Update to 2.6.35-rc5.
  - Eliminated 5 patches.
* Tue Jul 13 2010 jack@suse.de
- patches.fixes/novfs-overflow-fixes: novfs: security: Add buffer
  overflow, integer wraparound fixes (bnc#594362).
* Wed Jul  7 2010 jbeulich@novell.com
- Update Xen patches to 2.6.35-rc4.
* Wed Jul  7 2010 jeffm@suse.de
- patches.suse/xfs-dmapi-2.6.35-api-changes: Updated for -debug flavor.
* Wed Jul  7 2010 jeffm@suse.de
- Update config files for vanilla.
* Wed Jul  7 2010 mmarek@suse.cz
- rpm/kernel-source.spec.in: Install config-option.changes
  This file documents the changes in the kernel configs.
* Wed Jul  7 2010 mmarek@suse.cz
- patches.rpmify/kbuild-setlocalversion-fix: kbuild: Fix path
  to scripts/setlocalversion.
* Wed Jul  7 2010 jeffm@suse.de
- Update to 2.6.35-rc4.
  - Eliminated 4 patches.
* Fri Jul  2 2010 jeffm@suse.de
- patches.fixes/iwlwifi-fix-tx-power-configuration-on-3945-and-4965-devices:
  iwlwifi: fix TX power configuration on 3945 and 4965 devices
  (bnc#619440 bnc#610421).
* Fri Jul  2 2010 jbeulich@novell.com
- patches.suse/stack-unwind: Fix after upstream commit
  9e565292270a2d55524be38835104c564ac8f795.
* Fri Jul  2 2010 trenn@suse.de
- patches.arch/x86_mce_intel_decode_physical_fix_dynamic_debug.patch:
  For some reason the macro used by dynamic debug breaks things
  (bnc#619416).
* Fri Jul  2 2010 trenn@suse.de
  Mainline goes another way (bug #476509).
  Also there is a problem with this patch, breaking dynamic debugging
  (bnc#619416) -> just remove it, there will show up something else
  mainline.
- patches.xen/xen3-auto-arch-x86.diff: Refresh.
- patches.arch/x86_mce_intel_decode_physical_address.patch:
  Delete.
- patches.arch/x86_mce_intel_decode_physical_address_compile_fix.patch:
  Delete.
- patches.arch/x86_mce_intel_decode_physical_address_rename_fix.patch:
  Delete.
* Thu Jul  1 2010 jeffm@suse.de
- patches.suse/dm-raid45-api-update-remove-dm_put-after-dm_table_get_md:
  dm-raid45: API update: Remove dm_put after dm_table_get_md
  (bnc#615656).
* Thu Jul  1 2010 jdelvare@suse.de
- patches.fixes/e1000e-don-t-inadvertently-re-set-INTX_DISABLE.patch:
  Update references (bnc#610362).
* Thu Jul  1 2010 bphilips@suse.de
- patches.drivers/ixgbe-disable-tx-engine-before-disabling-tx-laser.patch:
  ixgbe: disable tx engine before disabling tx laser.
- patches.drivers/ixgbe-fix-panic-when-shutting-down-system-with-WoL-e.patch:
  ixgbe: fix panic when shutting down system with WoL enabled.
- patches.drivers/ixgbe-skip-non-IPv4-packets-in-ATR-filter.patch:
  ixgbe: skip non IPv4 packets in ATR filter.
- patches.fixes/e1000e-don-t-inadvertently-re-set-INTX_DISABLE.patch:
  e1000e: don't inadvertently re-set INTX_DISABLE.
* Wed Jun 30 2010 bphilips@suse.de
- patches.drivers/e1000-enhance-frame-fragment-detection.patch:
  Delete.
- patches.drivers/e1000e-enhance-frame-fragment-detection.patch:
  Delete.
* Tue Jun 29 2010 nfbrown@suse.de
- patches.fixes/nfs_wb_page_deadlock.fix: NFS: Fix another
  nfs_wb_page() deadlock (bnc#612794).
* Mon Jun 28 2010 mmarek@suse.cz
- rpm/find-provides: Add base symsets to the main subpackage.
* Fri Jun 25 2010 jeffm@suse.de
- Update config files for sparc64/net to remove unnecessary options.
* Fri Jun 25 2010 jeffm@suse.de
- patches.suse/add-initramfs-file_read_write: Fixed typo.
* Fri Jun 25 2010 jbeulich@novell.com
- patches.arch/kvm-split-paravirt-ops-by-functionality: Adjust
  Kconfig style to match upstream.
- patches.fixes/seccomp-disable-tsc-option: Adjust Kconfig style
  to match upstream.
- patches.suse/SoN-11-mm-reserve.patch: Fix compiler warning.
* Fri Jun 25 2010 jbeulich@novell.com
- Update Xen patches to 2.6.35-rc3.
- config.conf: Re-enable Xen.
- Update x86 config files.
* Thu Jun 24 2010 agruen@suse.de
- Replace the nfs4acl patches by their successor patch queue,
  richacls (see http://www.suse.de/~agruen/richacl/).
- Update config files: CONFIG_EXT4_FS_RICHACL=y.
* Thu Jun 24 2010 jeffm@suse.de
- patches.fixes/ext4-make-sure-the-move_ext-ioctl-can-t-overwrite-append-only-files:
  ext4: Make sure the MOVE_EXT ioctl can't overwrite append-only
  files (bnc#612457 CVE-2010-2066).
* Thu Jun 24 2010 jeffm@suse.de
- patches.fixes/gfs2-fix-writing-to-non-page-aligned-gfs2_quota-structures:
  GFS2: Fix writing to non-page aligned gfs2_quota structures
  (bnc#599957 CVE-2010-1436).
* Thu Jun 24 2010 jeffm@suse.de
- patches.fixes/gfs2-fix-permissions-checking-for-setflags-ioctl:
  GFS2: Fix permissions checking for setflags ioctl() (bnc#608576
  CVE-2010-1641).
* Thu Jun 24 2010 jdelvare@suse.de
- patches.drivers/hwmon-it87-fix-in7-on-IT8720F.patch: hwmon:
  (it87) Fix in7 on IT8720F (bnc#612910).
* Thu Jun 24 2010 jdelvare@suse.de
- patches.drivers/hwmon-it87-fix-in7-on-IT8720F.patch: hwmon:
  (it87) Fix in7 on IT8720F (bnc#612910).
* Thu Jun 24 2010 jeffm@suse.de
- btrfs fix rollup from v2.6.35:
- patches.fixes/btrfs-handle-err_ptr-from-posix_acl_from_xattr:
  Btrfs: handle ERR_PTR from posix_acl_from_xattr().
- patches.fixes/btrfs-avoid-bug-when-dropping-root-and-reference-in-same-transaction:
  Btrfs: avoid BUG when dropping root and reference in same
  transaction.
- patches.fixes/btrfs-prohibit-a-operation-of-changing-acl-s-mask-when-noacl-mount-option-used:
  Btrfs: prohibit a operation of changing acl's mask when noacl
  mount option used.
- patches.fixes/btrfs-should-add-a-permission-check-for-setfacl:
  Btrfs: should add a permission check for setfacl.
- patches.fixes/btrfs-btrfs_lookup_dir_item-can-return-err_ptr:
  Btrfs: btrfs_lookup_dir_item() can return ERR_PTR.
- patches.fixes/btrfs-btrfs_read_fs_root_no_name-returns-err_ptrs:
  Btrfs: btrfs_read_fs_root_no_name() returns ERR_PTRs.
- patches.fixes/btrfs-unwind-after-btrfs_start_transaction-errors:
  Btrfs: unwind after btrfs_start_transaction() errors.
- patches.fixes/btrfs-btrfs_iget-returns-err_ptr: Btrfs:
  btrfs_iget() returns ERR_PTR.
- patches.fixes/btrfs-handle-kzalloc-failure-in-open_ctree:
  Btrfs: handle kzalloc() failure in open_ctree().
- patches.fixes/btrfs-handle-error-returns-from-btrfs_lookup_dir_item:
  Btrfs: handle error returns from btrfs_lookup_dir_item().
- patches.fixes/btrfs-fix-bug_on-for-fs-converted-from-extn:
  Btrfs: Fix BUG_ON for fs converted from extN.
- patches.fixes/btrfs-fix-null-dereference-in-relocation-c:
  Btrfs: Fix null dereference in relocation.c.
- patches.fixes/btrfs-fix-remap_file_pages-error: Btrfs: fix
  remap_file_pages error.
- patches.fixes/btrfs-uninitialized-data-is-check_path_shared:
  Btrfs: uninitialized data is check_path_shared().
- patches.fixes/btrfs-fix-fallocate-regression: Btrfs: fix
  fallocate regression.
- patches.fixes/btrfs-fix-loop-device-on-top-of-btrfs: Btrfs:
  fix loop device on top of btrfs.
- patches.fixes/btrfs-add-more-error-checking-to-btrfs_dirty_inode:
  Btrfs: add more error checking to btrfs_dirty_inode.
- patches.fixes/btrfs-allow-unaligned-dio: Btrfs: allow unaligned
  DIO.
- patches.fixes/btrfs-drop-verbose-enospc-printk: Btrfs: drop
  verbose enospc printk.
- patches.fixes/btrfs-fix-block-generation-verification-race:
  Btrfs: Fix block generation verification race.
- patches.fixes/btrfs-fix-preallocation-and-nodatacow-checks-in-o_direct:
  Btrfs: fix preallocation and nodatacow checks in O_DIRECT.
- patches.fixes/btrfs-avoid-enospc-errors-in-btrfs_dirty_inode:
  Btrfs: avoid ENOSPC errors in btrfs_dirty_inode.
- patches.fixes/btrfs-move-o_direct-space-reservation-to-btrfs_direct_io:
  Btrfs: move O_DIRECT space reservation to btrfs_direct_IO.
- patches.fixes/btrfs-rework-o_direct-enospc-handling: Btrfs:
  rework O_DIRECT enospc handling.
- patches.fixes/btrfs-use-async-helpers-for-dio-write-checksumming:
  Btrfs: use async helpers for DIO write checksumming.
- patches.fixes/btrfs-don-t-walk-around-with-task-state-task_running:
  Btrfs: don't walk around with task->state != TASK_RUNNING.
- patches.fixes/btrfs-do-aio_write-instead-of-write: Btrfs:
  do aio_write instead of write.
- patches.fixes/btrfs-add-basic-dio-read-write-support: Btrfs:
  add basic DIO read/write support.
- patches.fixes/direct-io-add-a-hook-for-the-fs-to-provide-its-own-submit_bio-function:
  direct-io: add a hook for the fs to provide its own submit_bio
  function.
- patches.fixes/btrfs-metadata-enospc-handling-for-balance:
  Btrfs: Metadata ENOSPC handling for balance.
- patches.fixes/btrfs-pre-allocate-space-for-data-relocation:
  Btrfs: Pre-allocate space for data relocation.
- patches.fixes/btrfs-metadata-enospc-handling-for-tree-log:
  Btrfs: Metadata ENOSPC handling for tree log.
- patches.fixes/btrfs-metadata-reservation-for-orphan-inodes:
  Btrfs: Metadata reservation for orphan inodes.
- patches.fixes/btrfs-introduce-global-metadata-reservation:
  Btrfs: Introduce global metadata reservation.
- patches.fixes/btrfs-update-metadata-reservation-for-delayed-allocation:
  Btrfs: Update metadata reservation for delayed allocation.
- patches.fixes/btrfs-integrate-metadata-reservation-with-start_transaction:
  Btrfs: Integrate metadata reservation with start_transaction.
- patches.fixes/btrfs-introduce-contexts-for-metadata-reservation:
  Btrfs: Introduce contexts for metadata reservation.
- patches.fixes/btrfs-kill-init_btrfs_i: Btrfs: Kill
  init_btrfs_i().
- patches.fixes/btrfs-shrink-delay-allocated-space-in-a-synchronized:
  Btrfs: Shrink delay allocated space in a synchronized.
- patches.fixes/btrfs-kill-allocate_wait-in-space_info: Btrfs:
  Kill allocate_wait in space_info.
- patches.fixes/btrfs-link-block-groups-of-different-raid-types:
  Btrfs: Link block groups of different raid types.
- patches.fixes/nilfs-fix-breakage-caused-by-barrier-flag-changes:
  nilfs: fix breakage caused by barrier flag changes.
- patches.fixes/blkdev-generalize-flags-for-blkdev_issue_fn-functions:
  blkdev: generalize flags for blkdev_issue_fn functions.
* Wed Jun 23 2010 jeffm@suse.de
- patches.suse/add-initramfs-file_read_write: Fixed typo.
* Tue Jun 22 2010 teheo@suse.de
- patches.drivers/libata-ata_generic-force_dma: ata_generic:
  implement ATA_GEN_* flags and force enable DMA on MBP 7,1
  (bko#15923).
* Tue Jun 22 2010 knikanth@suse.de
- patches.suse/dm-raid45-26-Nov-2009.patch: DMRAID45 module
  (bnc#615906, bnc#565962).
- patches.suse/dm-raid45_2.6.27_20081027.patch: Delete.
- Sync dm-raid45 to the later version.
* Tue Jun 22 2010 mmarek@suse.cz
- rpm/config.sh: Build against openSUSE:11.3.
* Tue Jun 22 2010 knikanth@suse.de
- patches.suse/dm-raid45-26-Nov-2009.patch: DMRAID45 module
  (bnc#615906, bnc#565962).
- patches.suse/dm-raid45_2.6.27_20081027.patch: Delete.
- Sync dm-raid45 to the later version.
* Mon Jun 21 2010 jeffm@suse.de
- Resync v2.6.35 with master.
* Mon Jun 21 2010 jeffm@suse.de
- patches.suse/acpi-generic-initramfs-table-override-support:
  Refresh.
- patches.suse/init-move-populate_rootfs-back-to-start_kernel:
  Refresh.
* Mon Jun 21 2010 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Require a mkinitrd that supports
  KMS (bnc#615680).
* Mon Jun 21 2010 jeffm@suse.de
- patches.suse/add-initramfs-file_read_write: Fix missing kmap calls
  while loading initramfs files.
* Mon Jun 21 2010 jeffm@suse.de
- patches.suse/add-initramfs-file_read_write: Fix missing kmap of
  pages for initramfs loading.
* Fri Jun 18 2010 jbeulich@novell.com
- patches.xen/xen3-driver-core-add-devname-module-aliases-to-allow-module-on-demand-auto-loading.patch:
  driver core: add devname module aliases to allow module
  on-demand auto-loading.
- Refresh other Xen patches.
- Update Xen config files.
* Thu Jun 17 2010 teheo@suse.de
- patches.drivers/libata-ata_generic-mcp89-mbp71:
  ahci,ata_generic: let ata_generic handle new MBP w/ MCP89
  (bko#15923).
* Wed Jun 16 2010 jeffm@suse.de
- Update to 2.6.35-rc3.
  - Eliminated 1 patch.
* Mon Jun 14 2010 jslaby@suse.de
- patches.fixes/pci-hotplug-cpqphp-fix-crash.patch: PCI:
  hotplug/cpqphp, fix NULL dereference (bnc#609338).
* Wed Jun  9 2010 jeffm@suse.de
- patches.rpmify/ceph-atomic_long-init-fix: ceph: fix atomic64_t
  initialization on ia64.
* Tue Jun  8 2010 jeffm@suse.de
- patches.trace/utrace-core: Workaround missing kref_set().
* Tue Jun  8 2010 jeffm@suse.de
- patches.arch/ppc64-xmon-dmesg-printing.patch: Refresh.
* Tue Jun  8 2010 jeffm@suse.de
- patches.rpmify/powerpc-kvm-build-failure-workaround: Refresh.
- patches.rpmify/wlags49-missing-strlen-include: wlags49_h2:
  build fix.
* Tue Jun  8 2010 jeffm@suse.de
- patches.arch/x86_mce_intel_decode_physical_address.patch:
  Refresh.
- patches.arch/x86_mce_intel_decode_physical_address_rename_fix.patch:
  Refresh.
* Tue Jun  8 2010 jeffm@suse.com
- supported.conf: Updated dependencies for 2.6.35
* Mon Jun  7 2010 jeffm@suse.com
- patches.kernel.org/revert-tty-fix-a-little-bug-in-scrup-vt-c:
  Revert "tty: fix a little bug in scrup, vt.c".
* Mon Jun  7 2010 jeffm@suse.com
- Update to 2.6.35-rc2.
* Thu Jun  3 2010 jeffm@suse.de
- Re-enable DSDT in initramfs code.
- patches.suse/acpi-don-t-preempt-until-the-system-is-up: acpi:
  don't preempt until the system is up.
* Wed Jun  2 2010 bphilips@suse.de
- patches.drivers/e1000e-entropy-source.patch: Reintroduce IRQF_SHARED
  to fix non-MSI case (bnc#610362).
* Wed Jun  2 2010 mmarek@suse.cz
- rpm/kernel-docs.spec.in: More -rt fixes.
* Tue Jun  1 2010 jeffm@suse.com
- Update to 2.6.35-rc1.
  - Eliminated 13 patches.
  - Xen is disabled.
* Tue Jun  1 2010 bphilips@suse.de
- patches.drivers/tg3-5785-and-57780-asic-revs-not-working.patch:
  tg3: 5785 and 57780 asic revs not working (bnc#580780).
* Tue Jun  1 2010 mmarek@suse.cz
- rpm/kernel-module-subpackage: Change the kmp versioning to prefix
  the kernel version with "k" to avoid false version downgrades
  (bnc#609483).
* Tue Jun  1 2010 mmarek@suse.cz
- rpm/kernel-source.spec.in: pcre-tools is not needed.
* Mon May 31 2010 mmarek@suse.cz
- rpm/kernel-docs.spec.in: Fix for -rt.
* Wed May 26 2010 gregkh@suse.de
- patches.drivers/driver-core-add-devname-module-aliases-to-allow-module-on-demand-auto-loading.patch:
  driver core: add devname module aliases to allow module
  on-demand auto-loading.
* Tue May 25 2010 jeffm@suse.de
- supported.conf: Added mperf, which powernow and acpi-cpufreq now
  depend on.
* Tue May 25 2010 jeffm@suse.com
- patches.arch/powernow-k8-add-core-performance-boost-support:
  powernow-k8: Add core performance boost support (bnc#602209).
- patches.arch/x86-cpu-add-amd-core-boosting-feature-flag-to-proc-cpuinfo:
  x86, cpu: Add AMD core boosting feature flag to /proc/cpuinfo.
- patches.arch/x86-cpufreq-add-aperf-mperf-support-for-amd-processors:
  x86, cpufreq: Add APERF/MPERF support for AMD processors
  (bnc#602209).
* Tue May 25 2010 jbeulich@novell.com
- Update Xen patches to 2.6.34 final.
- Update Xen config files.
- patches.xen/xen3-acpi_processor_check_maxcpus.patch: Do not
  try to set up acpi processor stuff on cores exceeding maxcpus=
  (bnc#601520).
* Mon May 24 2010 jbenc@suse.cz
- patches.suse/b43-missing-firmware-info.patch: b43: Change
  firmware missing message to refer to openSUSE script.
* Sun May 23 2010 teheo@suse.de
- patches.drivers/pci-disable-msi-on-K8M800: pci: disable MSI
  on VIA K8M800 (bnc#599508).
* Sat May 22 2010 trenn@suse.de
- patches.xen/xen3-auto-common.diff: Refresh.
* Sat May 22 2010 trenn@suse.de
- patches.fixes/acpi_processor_check_maxcpus.patch: Do not try
  to set up acpi processor stuff on cores exceeding maxcpus=
  (bnc#601520).
* Sat May 22 2010 trenn@suse.de
- patches.fixes/acpi_processor_check_maxcpus.patch: Do not try
  to set up acpi processor stuff on cores exceeding maxcpus=
  (bnc#601520).
- patches.fixes/acpi_wmi_debug.patch: X86 platform wmi: Introduce
  debug param to log all WMI events (bnc#598059).
- patches.fixes/hp_wmi_fix_acpi_version_integer_size.patch:
  x86 platform drivers: hp-wmi fix buffer size depending on ACPI
  version (bnc#598059).
- patches.fixes/wmi_debug_pass_guid: X86 platform wmi: Also log
  GUID string when an event happens and debug is set (bnc#598059).
- patches.fixes/wmi_dump_wdg_data.patch: X86 platfrom wmi: Add
  debug facility to dump WMI data in a readable way (bnc#598059).
* Thu May 20 2010 jeffm@suse.com
- Disabled CONFIG_RT2800PCI (bnc#606243)
  - These devices are handled by the rt2860 staging driver.
* Mon May 17 2010 jeffm@suse.com
- patches.fixes/kvm-ioapic.patch: Refresh.
* Mon May 17 2010 jeffm@suse.com
- Update to 2.6.34-final.
* Wed May 12 2010 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Fix preserving of old symsets.
* Wed May 12 2010 jbeulich@novell.com
- Update Xen patches to 2.6.34-rc7 and c/s 1017.
* Tue May 11 2010 jeffm@suse.com
- Update config files for vanilla.
* Tue May 11 2010 jeffm@suse.com
- Updated to 2.6.34-rc7.
  - Eliminated 3 patches.
* Sun May  2 2010 jeffm@suse.com
- Update to 2.6.34-rc6.
  - Eliminated 2 patches.
* Sun May  2 2010 sjayaraman@suse.de
- patches.fixes/cifs-fix-oops-due-to-null-nameidata: Allow null nd
  (as nfs server uses) on create (bnc#593940).
* Fri Apr 30 2010 trenn@suse.de
- patches.fixes/acpi_ensure_spec_correct_address_space_length.patch:
  ACPI/x86/PCI: compute Address Space length rather than using
  _LEN (bnc#598641).
* Thu Apr 29 2010 jbeulich@novell.com
- Update -ec2 config files (X86_MSR=m again).
* Thu Apr 29 2010 jbeulich@novell.com
- Update Xen patches to 2.6.34-rc5-git8 and c/s 1016.
- Update Xen config files.
- patches.xen/xen-kzalloc: use kzalloc() in favor of
  kmalloc()+memset().
- patches.xen/xen-fix_trace_power.patch: Rename to ...
- patches.xen/xen3-x86_cpufreq_make_trace_power_frequency_cpufreq_driver_independent.patch:
  ... this.
* Thu Apr 29 2010 knikanth@suse.de
- patches.fixes/dm-release-map_lock-before-set_disk_ro: Refresh.
  Fix patch to call dm_table_get directly instead of calling
  dm_get_table unnecesarily.
* Thu Apr 29 2010 jeffm@suse.com
- Update to 2.6.34-rc5-git8.
  - Eliminated 1 patch.
* Wed Apr 28 2010 trenn@suse.de
- patches.xen/xen-fix_trace_power.patch: x86 cpufreq: Make
  trace_power_frequency cpufreq driver independent (none).
* Wed Apr 28 2010 mmarek@suse.cz
- Disable CONFIG_FIRMWARE_IN_KERNEL in all configs, we start udev
  early enough in the initrd.
* Wed Apr 28 2010 trenn@suse.de
- patches.fixes/acpi-cpufreq_fix_cpu_any_notification.patch:
  acpi-cpufreq: Fix CPU_ANY CPUFREQ_{PRE,POST}CHANGE notification
  (none).
- patches.trace/x86_cpufreq_make_trace_power_frequency_cpufreq_driver_independent.patch:
  x86 cpufreq: Make trace_power_frequency cpufreq driver
  independent (none).
* Wed Apr 28 2010 trenn@suse.de
- Update config files.
  Unify X86_MSR and X86_CPUID configs:
  - CONFIG_X86_CPUID=m
  - CONFIG_X86_MSR=y
  for all i386 and x86_64 flavors.
* Mon Apr 26 2010 jeffm@suse.com
- Disabled CONFIG_TUNE_CELL on ppc64 (bnc#599045)
* Mon Apr 26 2010 jeffm@suse.com
- Enabled CONFIG_FIREWIRE (bnc#586172)
  - CONFIG_IEEE1394 is still enabled but deprecated.
* Fri Apr 23 2010 trenn@suse.de
- patches.fixes/hp_wmi_add_media_key.patch: x86 platform drivers:
  hp-wmi Add media key 0x20e8 (bnc#598059).
* Fri Apr 23 2010 trenn@suse.de
- patches.fixes/hp-wmi_detect_keys.patch: x86 platform drivers:
  hp-wmi Reorder event id processing (bnc#598059).
- patches.fixes/hp_wmi_catch_unkown_event_key_codes.patch: x86
  platform drivers: hp-wmi Catch and log unkown event and key
  codes correctly (bnc#598059).
- patches.fixes/hp_wmi_use_prefix_string.patch: x86 platform
  drivers: hp-wmi Use consistent prefix string for messages
  (bnc#598059).
* Thu Apr 22 2010 jeffm@suse.com
- patches.suse/s390-Kerntypes.diff: Fix slab.h vs slab_def.h
  include ordering in kerntypes.c
* Thu Apr 22 2010 mmarek@suse.cz
- rpm/kernel-*.spec.in: Provide %%name = %%version-%%source_rel in
  all spec files (bnc#598453).
* Thu Apr 22 2010 tiwai@suse.de
- Update config files: Fix remaining CONFIG_LEDS_CLASS=m
* Thu Apr 22 2010 tiwai@suse.de
- patches.drivers/input-Add-LED-support-to-Synaptics-device:
  Refresh.  Fix dependency with LED class.
- Update config files.
* Wed Apr 21 2010 tiwai@suse.de
- patches.drivers/input-Add-LED-support-to-Synaptics-device:
  input: Add LED support to Synaptics device
  (bnc#547370,bnc#582529,bnc#589014).
- patches.drivers/input-Add-support-of-Synaptics-Clickpad-device:
  input: Add support of Synaptics Clickpad device
  (bnc#547370,bnc#582529,bnc#589014).
- patches.drivers/synaptics-hp-clickpad: Delete.
* Wed Apr 21 2010 jeffm@suse.com
- Update to  2.6.34-rc5.
  - Eliminated 1 patch.
* Tue Apr 20 2010 jack@suse.de
- patches.fixes/novfs-LFS-initialization: fs: novfs: Initialize
  super-block with standard macros.
- patches.fixes/novfs-return-ENOTEMPTY-when-deleting-nonempty-dir:
  fs: novfs: Return ENOTEMPTY when tyring to delete a non-empty
  folder (bnc#583964).
* Mon Apr 19 2010 jeffm@suse.de
- patches.fixes/x86-apbt-conditionally-register-cpu-hp-notifier-for-apbt:
  x86/apbt: conditionally register cpu hp notifier for apbt
  (bko#15786).
* Fri Apr 16 2010 mmarek@suse.cz
- rpm/kernel-binary.spec.in, rpm/mkspec, rpm/old-packages.conf:
  Obsolete kernel-vmi-base by kernel-pae-base (bnc#594271).
- commit a48fbdf
* Fri Apr 16 2010 mmarek@suse.cz
- rpm/mkspec, rpm/old-packages.conf: Explicitly list ppc64 flavors that
  obsolete kernel-kdump.
- commit 0a4f75b
* Fri Apr 16 2010 mmarek@suse.cz
- rpm/old-packages.conf: s390(x) provides/obsoletes not needed anymore.
- commit 0e039b7
* Thu Apr 15 2010 jbeulich@novell.com
- Update Xen patches to 2.6.34-rc4 and c/s 1011.
- patches.xen/xen-netfront-ethtool: netfront: ethtool -i does
  not return info about xennet driver (bnc#591179).
- patches.xen/xen-no-reboot-vector: eliminate REBOOT_VECTOR.
- patches.xen/xen-x86_64-kern_addr_valid: x86-64:
  kern_addr_valid() must not walk page tables mapping hypervisor
  space (bnc#591371).
- Update Xen config files.
- supported.conf: drivers/xen/evtchn.ko is supported.
* Thu Apr 15 2010 teheo@suse.de
- patches.fixes/block-blk_abort_request-lock-fix: libata/SCSI:
  fix locking around blk_abort_request() (bnc#585927).
* Wed Apr 14 2010 jeffm@suse.de
- Update to 2.6.34-rc4.
  - Eliminated 3 patches.
* Tue Apr 13 2010 mmarek@suse.cz
- Update vanilla config files.
* Tue Apr 13 2010 tiwai@suse.de
- patches.suse/bootsplash-console-fix: Fix rendering on linux
  console with bootsplash (bnc#595657,bnc#594209).
* Tue Apr 13 2010 agraf@suse.de
- Update config files to disable KVM on PPC also for ppc/ppc64.
* Tue Apr 13 2010 teheo@suse.de
- Update config files to disable CONFIG_DEBUG_BLOCK_EXT_DEVT which was
  enabled by 5246824c to ease testing userland handling of ext devt.
* Mon Apr 12 2010 jslaby@suse.de
- patches.fixes/hibernation-fix-s2disk.patch: PM / Hibernate:
  user.c, fix SNAPSHOT_SET_SWAP_AREA handling (bko#15728).
* Mon Apr 12 2010 jack@suse.de
- patches.fixes/novfs-dentry-cache-limit.patch: novfs: Remove
  dcache count restricting code (bnc#576026).
* Mon Apr 12 2010 jbeulich@novell.com
- patches.arch/x86_64-unwind-annotations: Refresh (bnc#588458).
* Fri Apr  9 2010 jeffm@suse.de
- patches.fixes/reiserfs-remove-2-tb-file-size-limit: Fix issue on
  32-bit systems.
* Fri Apr  9 2010 knikanth@suse.de
- patches.fixes/loop-update-mtime.patch: loop: Update mtime when
  writing using aops (bnc#590738).
* Fri Apr  9 2010 jeffm@suse.de
- patches.fixes/reiserfs-fix-permissions-on-reiserfs_priv:
  reiserfs: Fix permissions on .reiserfs_priv (bnc#593906
  CVE-2010-1146).
* Thu Apr  8 2010 agraf@suse.de
- Update PPC config files to disable KVM on PPC. It's not ready yet.
  Please enable it again as soon as we hit 2.6.35.
* Wed Apr  7 2010 jengelh@medozas.de
- Add config/sparc64/net that is light on size. For netbooting,
  both the kernel and initrd must fit into 10MB.
* Wed Mar 31 2010 jeffm@suse.de
- Updated sparc64 config.
* Wed Mar 31 2010 jeffm@suse.de
- Update to 2.6.34-rc3.
* Wed Mar 31 2010 mmarek@suse.cz
- doc/README.SUSE: Update some obsolete information.
* Wed Mar 31 2010 mmarek@suse.cz
- rpm/kernel-docs.spec.in: Fix path to kernel source.
* Wed Mar 31 2010 mmarek@suse.cz
- rpm/configtool.pl, rpm/kernel-binary.spec.in,
  rpm/kernel-source.spec.in: Add support for custom config options
  in config.addon.tar.bz2. This tarball is expected to have the
  same layout as config.tar.bz2 and the config options listed there
  take precedence over config.tar.bz2.
* Wed Mar 31 2010 mmarek@suse.cz
- rpm/kernel-binary.spec.in, rpm/kernel-source.spec.in, rpm/mkspec:
  Generate the chmod +x line automatically.
* Wed Mar 31 2010 mmarek@suse.cz
- rpm/kernel-binary.spec.in, rpm/mkspec, scripts/tar-up.sh:
  Generate the Source: lines from kernel-source.spec.in.
* Tue Mar 30 2010 jeffm@suse.de
- patches.fixes/reiserfs-remove-2-tb-file-size-limit: reiserfs:
  Remove 2 TB file size limit (bnc#592100).
* Tue Mar 30 2010 mmarek@suse.cz
- rpm/kernel-binary.spec.in, rpm/kernel-source.spec.in, rpm/mkspec:
  Generated the NoSource and %%setup lines automatically from the
  preamble.
* Tue Mar 30 2010 mmarek@suse.cz
- rpm/kernel-source.spec.in: Provide $pkg = %%version-%%source_rel
  in kernel-devel and kernel-source-vanilla.
* Mon Mar 29 2010 jeffm@suse.de
- patches.fixes/reiserfs-fix-locking-BUG-during-mount-failure:
  reiserfs: Fix locking BUG during mount failure (bnc#591807).
* Mon Mar 29 2010 jeffm@suse.de
- Disabled MAX63XX_WATCHDOG on s390.
* Mon Mar 29 2010 jeffm@suse.de
- Update to 2.6.34-rc2-git3.
  - Eliminated 1 patch.
  - Fixed ps3 config.
* Mon Mar 29 2010 jbeulich@novell.com
- Update Xen patches to 2.6.34-rc2 and c/s 1007.
- Update config files.
- config.conf: Re-enable Xen configs.
- patches.xen/xen-floppy: Xen: improve floppy behavior
  (bnc#584216).
- patches.xen/xen-vscsi-module-alias: allow pv scsi hba driver
  to be loaded automatically.
- patches.xen/xen-vusb-module-alias: allow pv usb hcd driver to
  be loaded automatically (bnc#584213).
* Fri Mar 26 2010 jkosina@suse.cz
- patches.fixes/hid-fix-gyration-oops.patch: HID: fix oops in
  gyration_event() (bnc#589329).
* Fri Mar 26 2010 jack@suse.de
- patches.fixes/novfs-fix-oops-in-scope-finding: novfs: fix an
  oops in novfs scope-finding code (bnc#588579).
* Thu Mar 25 2010 jeffm@suse.de
- patches.fixes/powerpc-fix-handling-of-strnlen-with-zero-len:
  powerpc: fix handling of strnlen with zero len (bnc#582681).
* Tue Mar 23 2010 jeffm@suse.de
- patches.drivers/lpfc-add-raywire-id: Delete.
* Tue Mar 23 2010 jeffm@suse.de
- patches.suse/linux-2.6.29-kms-after-sata.patch: Refresh.
* Tue Mar 23 2010 jeffm@suse.de
- patches.fixes/do_anonymous_page-race: Delete.
* Tue Mar 23 2010 jeffm@suse.de
- patches.drivers/libata-prefer-over-ide: Delete.
- patches.drivers/libata-ahci-aspire-3810t-noncq: Delete.
- patches.drivers/libata-ata_piix-clear-spurious-IRQ: Delete.
- patches.suse/block-add-mangle-devt-switch: Delete.
* Tue Mar 23 2010 jeffm@suse.de
- patches.suse/apm_setup_UP.diff: Delete.
* Mon Mar 22 2010 jeffm@suse.de
- patches.arch/ppc-efika-bestcomm-ata-dma.patch: Delete.
- patches.arch/ppc-efika-mpc52xx-ac97.patch: Delete.
- patches.arch/ppc-efika-psc-console-autodetection.patch: Delete.
- patches.suse/suse-ppc32-mol-BIT: Delete.
- patches.suse/suse-ppc32-mol-get-property: Delete.
- patches.suse/suse-ppc32-mol-handle-mm-fault: Delete.
- patches.suse/suse-ppc32-mol-ioctl: Delete.
- patches.suse/suse-ppc32-mol-kbuild.patch: Delete.
- patches.suse/suse-ppc32-mol-semaphore: Delete.
- patches.suse/suse-ppc32-mol-sheep: Delete.
- patches.suse/suse-ppc32-mol.patch: Delete.
* Mon Mar 22 2010 jeffm@suse.de
- patches.fixes/dlm-enable-debug.patch: Delete.
* Mon Mar 22 2010 jeffm@suse.de
- patches.fixes/ds1682-build-fix: Delete.
* Mon Mar 22 2010 jeffm@suse.de
- patches.suse/kvm-as-kmp: Delete.
* Mon Mar 22 2010 jeffm@suse.de
- patches.suse/xfs-dmapi-fix-incompatible-pointer-type-warning:
  xfs/dmapi: fix incompatible pointer type warning.
* Mon Mar 22 2010 jeffm@suse.de
- Updated to 2.6.34-rc2.
  - Eliminated 4 patches.
* Fri Mar 19 2010 jbohac@suse.cz
- set CONFIG_IPV6=y for all flavours (bnc#561611)
* Thu Mar 18 2010 jeffm@suse.de
- Refreshed patch series.
* Wed Mar 17 2010 jeffm@suse.de
- Updated to 2.6.34-rc1-git6.
  - Eliminated 8 patches.
* Tue Mar 16 2010 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Remove Obsoletes: for 10.3 KMPs.
* Tue Mar 16 2010 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Move Obsoletes: msi-wmi-kmp to the
  sle11-ga group and make the comment more explanatory.
* Tue Mar 16 2010 trenn@suse.de
- rpm/kernel-binary.spec.in:
  bnc#587578
* Thu Mar 11 2010 jeffm@suse.de
- patches.rpmify/powerpc-mpc52xx-build-fix: powerpc: Build fix
  for mpc52xx.
* Thu Mar 11 2010 knikanth@suse.de
- patches.fixes/xfs-nonblocking-inode-locking-io-completion.patch:
  Fix unintialized variable. Refresh.
* Wed Mar 10 2010 jeffm@suse.de
- supported.conf: Added kernel/drivers/gpio/max730x, max7301 now
  depends on it.
* Wed Mar 10 2010 jeffm@suse.de
- Enabled CONFIG_DRM_RADEON_KMS; Matching KMS-enabled X.org has
  been committed to Factory.
* Wed Mar 10 2010 jeffm@suse.de
- patches.rpmify/powerpc-kvm-build-failure-workaround: powerpc:
  kvm build failure workaround.
* Wed Mar 10 2010 jeffm@suse.de
- patches.rpmify/powerpc-mpc52xx-build-fix: powerpc: Build fix
  for mpc52xx.
* Wed Mar 10 2010 jeffm@suse.de
- supported.conf: Added kernel/drivers/i2c/i2c-smbus, i2c-parport
  now depends on it.
* Wed Mar 10 2010 mmarek@suse.cz
- rpm/kernel-binary.spec.in: the dwarfextract package has been
  dropped from Factory.
* Wed Mar 10 2010 jeffm@suse.de
- Update config files for vanilla.
* Wed Mar 10 2010 jdelvare@suse.de
- supported.conf: Add hwmon/ams back.
* Wed Mar 10 2010 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Fix symsets for non-split kernels.
* Wed Mar 10 2010 mmarek@suse.cz
- rpm/kernel-source.spec.in: Add symsets.pl to the src.rpm.
* Wed Mar 10 2010 jeffm@suse.de
- Updated to 2.6.34-rc1.
  - Eliminated 36 patches.
  - Xen is disabled
  - Added new doc/config-options.changes to document configuration
    changes.
* Tue Mar  9 2010 mmarek@suse.cz
- rpm/old-packages.conf: Obsolete kernel-vmi by kernel-default.
- rpm/kernel-module-subpackage: Also obsolete vmi KMPs.
- commit bf55479
* Tue Mar  9 2010 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Package symsets in the -devel package.
* Tue Mar  9 2010 mmarek@suse.cz
- rpm/find-provides: Do not generate ksym(...) provides.
* Tue Mar  9 2010 mmarek@suse.cz
- rpm/find-provides, rpm/symsets.pl: Generate symsets again
  (bnc#582907).
* Fri Mar  5 2010 knikanth@suse.de
- patches.fixes/xfs-nonblocking-inode-locking-io-completion.patch:
  xfs: Non-blocking inode locking in IO completion (bnc#568319).
* Fri Mar  5 2010 jengelh@medozas.de
- rpm/kernel-source.spec.in: split devel files and full source
  into two rpms, of which only the former is really required for
  KMP building
* Fri Mar  5 2010 jengelh@medozas.de
- add configs/sparc64/default
* Wed Mar  3 2010 tonyj@suse.de
- patches.trace/powerpc-rename-irq-tracing: should have been deleted by
  previous commit
* Wed Mar  3 2010 tonyj@suse.de
- remove perfmon2 patches
* Wed Mar  3 2010 tonyj@suse.de
- Remove lttng-instrumentation patches, they have been removed from
  SLE11SP1
- patches.xen/tmem: Refresh.
- patches.xen/xen3-auto-common.diff: Refresh.
* Tue Mar  2 2010 jbeulich@novell.com
- Update Xen patches to 2.6.33 and c/s 1003.
- patches.xen/xen-clockevents: replace Xen's custom time handling
  with such using GENERIC_CLOCKEVENTS infrastructure.
- Update Xen config files.
* Tue Mar  2 2010 nfbrown@suse.de
- patches.fixes/sunrpc-monotonic-expiry: sunrpc: use monotonic
  time in expiry cache (bnc#578668).
* Thu Feb 25 2010 jeffm@suse.de
- patches.rpmify/ia64-sn-fix-percpu-warnings: Obsolete.
* Thu Feb 25 2010 mmarek@suse.cz
- Drop include of generated/autoconf.h in our patches, it's not
  needed since 2.6.15:
- patches.suse/novfs-client-module: Refresh.
- patches.suse/s390-Kerntypes.diff: Refresh.
- patches.suse/suse-ppc32-mol.patch: Refresh.
* Thu Feb 25 2010 teheo@suse.de
- scripts/run_oldconfig.sh doesn't update ppc/vanilla for some reason.
  Do it manually.
* Thu Feb 25 2010 teheo@suse.de
- ppc explicitly sets CONFIG_LEDS_TRIGGER_IDE_DISK.  Run
  scripts/run_oldconfig.sh to fix configs up.
* Thu Feb 25 2010 teheo@suse.de
- Drop CONFIG_IDE from all configs.
* Thu Feb 25 2010 jeffm@suse.com
- patches.xen/xen3-patch-2.6.33-rc8-final: Build fix for the
  2.6.33-final update.
* Wed Feb 24 2010 jeffm@suse.de
- Updated to 2.6.33-final.
  - Eliminated 4 patches.
* Wed Feb 24 2010 jeffm@suse.de
- patches.rpmify/ftrace-fix-ftrace_event_call-alignment-for-use-with-gcc-4-5:
  ftrace: fix ftrace_event_call alignment for use with gcc 4.5
  (bnc#582222).
* Wed Feb 24 2010 jbeulich@novell.com
- Update Xen patches to 2.6.33-rc8 and c/s 997.
- patches.xen/xen-x86-time-per-cpu: fold per-CPU accounting data
  into a structure.
- patches.xen/xen-x86-xtime-lock: reduce contention on xtime_lock
  (bnc#569014, bnc#571041, bnc#571769, bnc#572146).
* Wed Feb 24 2010 jengelh@medozas.de
- rpm/kernel-source.spec.in: use macros in a few more places
* Tue Feb 23 2010 jack@suse.de
- patches.fixes/novfs-fix-inode-uid: novfs: Get proper UID when
  looking up inode (bnc#486997).
- patches.fixes/novfs-incorrect-filesize-fix: novfs: novfs
  reports incorrect file size (bnc#426536).
- patches.fixes/novfs-truncate-fix: novfs: Fixes corruption of
  OO documents on NSS Volumes (bnc#508259).
* Sun Feb 21 2010 jengelh@medozas.de
- use standard short options in tar commands
* Wed Feb 17 2010 nfbrown@suse.de
- patches.fixes/nfs-find-crash: Fix potential oops when running
  find on an NFS mount. (bnc#573107).
* Tue Feb 16 2010 jeffm@suse.com
- Set CONFIG_LSM_MMAP_MIN_ADDR=4096 to allow qemu to emulate
  other architectures properly (bnc#574654).
* Tue Feb 16 2010 jeffm@suse.com
- Update to 2.6.33-rc8.
  - Eliminated 1 patch.
* Mon Feb 15 2010 rgoldwyn@suse.de
- patches.fixes/novfs-err_ptr-fix.diff: Oops in novfs:unlink_local
  (bnc#569071).
* Fri Feb 12 2010 trenn@suse.de
- Update config files.
  Enable p4_clockmod for i386 desktop
  While this is broken by design it allows to remove clocking
  limits from the vendor on e.g. eeepc 701
* Fri Feb 12 2010 jeffm@suse.com
- patches.fixes/taskstats-alignment: delayacct: align to 8 byte
  boundary on 64-bit systems (bnc#578065).
* Fri Feb 12 2010 trenn@suse.de
- patches.fixes/acpi_fix_no_critical_tp.patch: ACPI thermal:
  Don't invalidate thermal zone if critical trip point is bad
  (bnc#531547).
- patches.fixes/acpi_pci_hot_plug_sanity_checks.patch: ACPI:
  acpi_bus_{scan,bus,add}: return -ENODEV if no device was found
  (bnc#531547).
- patches.fixes/acpi_thermal_check_trip_points.patch: ACPI
  thermal: Check for thermal zone requirement (bnc#531547).
* Fri Feb 12 2010 jdelvare@suse.de
- supported.conf: saa7111 and saa7114 are gone.
* Wed Feb 10 2010 jeffm@suse.com
- patches.suse/kdb-fix-kdb_cmds-to-include-the-arch-common-macro:
  kdb: fix kdb_cmds to include the arch common macro (bnc#578421).
* Wed Feb 10 2010 jeffm@suse.com
- patches.suse/kdb-handle-nonexistance-keyboard-controller: kdb:
  handle nonexistance keyboard controller (bnc#578051).
* Wed Feb 10 2010 gregkh@suse.de
- patches.fixes/dvb-l64781.ko-broken-with-gcc-4.5.patch: dvb:
  l64781.ko broken with gcc 4.5.
* Tue Feb  9 2010 jeffm@suse.com
- patches.apparmor/apparmor-check-for-network-in-interrupt-and-work-around:
  apparmor: check for network in interrupt and work around
  (bnc#492961, bln#350789).
* Tue Feb  9 2010 jeffm@suse.com
- Update to 2.6.33-rc7.
  - Eliminated 1 patch.
* Tue Feb  9 2010 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-66-idt-hp-mute-led-fix-polarity:
  ALSA: hda - Fix default polarity of mute-LED GPIO on 92HD83x/88x
  codecs (bnc#578190).
* Mon Feb  8 2010 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-63-idt-hp-mute-led-detect:
  ALSA: hda - Detect HP mute-LED GPIO setup from GPIO counts
  (bnc#577927).
- patches.drivers/alsa-sp1-hda-64-idt-hp-mute-led-cleanup: ALSA:
  hda - Merge HP mute-LED status callback on both IDT 92HD7x
  and 8x codecs (bnc#577927).
- patches.drivers/alsa-sp1-hda-65-idt-hp-mute-led-cleanup2:
  ALSA: hda - Remove static gpio_led setup via model (bnc#577927).
* Fri Feb  5 2010 coly.li@suse.de
- patches.suse/64bytes_lvb_len.diff: Delete from repo and series.conf.
  Back to 32bytes lvb length for clvm (bnc#573460).
* Fri Feb  5 2010 duwe@suse.de
- Update config files: Compile IBM_BSR into kernel, not as module.
  (ppc only, bnc#572381)
* Fri Feb  5 2010 duwe@suse.de
- patches.arch/ppc-pseries-ncpus-1: powerpc: Add static fields
  to ibm,client-architecture call (bnc#570909).
- patches.arch/ppc-pseries-ncpus-2: powerpc/pseries: Pass more
  accurate number of supported cores to firmware (bnc#570909).
* Fri Feb  5 2010 coly.li@suse.de
- disable patches.suse/64bytes_lvb_len.diff in series.conf
* Thu Feb  4 2010 mmarek@suse.de
- rpm/find-provides, rpm/kernel-binary.spec.in: Remove the previous
  hack and set STRIP_KEEP_SYMTAB='*/vmlinux-*' instead to avoid
  stripping symbols from the ppc vmlinux image (bnc#572148).
* Thu Feb  4 2010 knikanth@suse.de
- patches.fixes/dm-stripe-zero-stripes: dm-stripe: return -EINVAL
  if stripe count is zero (bnc#576312).
* Thu Feb  4 2010 npiggin@suse.de
- Disable patches.suse/files-slab-rcu.patch.
* Thu Feb  4 2010 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Obsolete iwlagn-2-6-27-kmp
  (bnc#559533).
* Thu Feb  4 2010 tiwai@suse.de
- supported.conf: mark snd-wss-lib unsupported
* Thu Feb  4 2010 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-61-add-idt92hd88x-support2:
  ALSA: hda - Adding support for another IDT 92HD83XXX codec
  (bnc#569354).
* Wed Feb  3 2010 jbohac@suse.cz
- supported.conf: marked em_cmp supported (bnc#568130)
* Wed Feb  3 2010 mmarek@suse.cz
- rpm/kernel-binary.spec.in: automatically install a matching
  - devel package if kernel-source is installed.
* Wed Feb  3 2010 jbeulich@novell.com
- Update Xen patches to 2.6.33-rc6 and c/s 989.
- patches.xen/xen-netback-generalize: Netback: Generalize
  static/global variables into 'struct xen_netbk'.
- patches.xen/xen-netback-kernel-threads: Use Kernel thread to
  replace the tasklet.
- patches.xen/xen-netback-multiple-tasklets: Netback:
  Multiple tasklets support.
* Tue Feb  2 2010 jkosina@suse.cz
- patches.suse/suse-ppc64-branding: the message about crashed kernel
  doesn't make sense any more with CONFIG_CRASH_DUMP enabled by
  default (bnc#575884).
* Sat Jan 30 2010 jeffm@suse.com
- Update to 2.6.33-rc6.
  - Eliminated 12 patches.
* Sat Jan 30 2010 jeffm@suse.com
- patches.rpmify/hugetlbfs-fix-section-mismatches: Removed __init
  from hugetlb_sysfs_add_hstate instead of adding it elsewhere.
* Sat Jan 30 2010 jslaby@suse.de
- patches.suse/kdb-common: Fix hid crash (bnc#570591)
* Fri Jan 29 2010 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-60-add-idt92hd88x-support: ALSA:
  hda - Add support for IDT 92HD88 family codecs (bnc#569354).
* Fri Jan 29 2010 jkosina@suse.cz
- patches.fixes/pci-fix-nested-spinlock-hang-in-aer_inject.patch:
  Update patch-mainline tag.
* Fri Jan 29 2010 jbenc@suse.cz
- Update config files: fixed vanilla configs.
* Thu Jan 28 2010 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-59-idt92hd83xxx-hp-mute-led: ALSA:
  hda - Add mute LED check for HP laptops with IDT 92HD83xxx codec
  (bnc#569354).
* Thu Jan 28 2010 jbeulich@novell.com
- patches.suse/supported-flag: Fix -ec2 build.
- patches.suse/supported-flag-enterprise: Refresh.
- patches.xen/xen3-patch-2.6.33-rc3: Fix ia64 build.
* Thu Jan 28 2010 jbeulich@novell.com
- Update Xen patches to 2.6.33-rc5 and c/s 987.
- config.conf: Re-enable Xen.
- Update config files.
* Thu Jan 28 2010 jbenc@suse.cz
- Update config files: enabled CONFIG_CFG80211_WEXT to keep backward
  user space compatibility and enabled few wireless drivers.
* Thu Jan 28 2010 mmarek@suse.cz
- rpm/apply-patches: Add support for an additional series file in
  patches.addon/series, this will be applied after the main series.
* Thu Jan 28 2010 mmarek@suse.cz
- rpm/apply-patches: put the patch loops from kernel-binary.spec.in
  and kernel-source.spec.in to one place.
* Wed Jan 27 2010 jeffm@suse.de
- Deleted 28 unused patches.
* Wed Jan 27 2010 jeffm@suse.com
- Update config files.
* Wed Jan 27 2010 jkosina@suse.cz
- patches.fixes/pci-fix-nested-spinlock-hang-in-aer_inject.patch:
  pci: fix nested spinlock hang in aer_inject (bnc#573578).
* Wed Jan 27 2010 mmarek@suse.cz
- Update config files: disable generic_serial users.
- patches.drivers/reenable-generic_serial: Delete.
- rpm/generic_serial-blacklist: Delete (bnc#569676).
* Wed Jan 27 2010 jengelh@medozas.de
- remove patches.suse/netfilter-ipv4options [bnc#490142]
* Wed Jan 27 2010 jeffm@suse.com
- patches.suse/slab-handle-memoryless-nodes-v2a.patch: Refresh.
* Tue Jan 26 2010 knikanth@suse.de
- supported.conf: Fix misspelt dm-region-hash and mark it supported
  correctly (bnc#565962)
* Mon Jan 25 2010 gregkh@suse.de
- Update to 2.6.32.6
  - security fixes
  - bugfixes
  - obsoletes:
  - patches.drivers/8250_pnp-wacom-add
  - patches.drivers/staging-hv-fix-smp-problems-in-the-hyperv-core-code.patch
  - patches.kernel.org/scsi-enclosure-fix-oops-while-iterating-enclosure_status-array.patch
  - patches.kernel.org/x86-msr-cpuid-register-enough-minors-for-the-msr-and-cpuid-drivers.patch
* Mon Jan 25 2010 jeffm@suse.com
- supported.conf: Added sparse_keymap (eeepc_laptop depends on it)
* Mon Jan 25 2010 npiggin@suse.de
- patches.suse/slab-handle-memoryless-nodes-v2a.patch: slab -
  handle memoryless nodes V2a (bnc#436025, bnc#570492).
* Mon Jan 25 2010 jeffm@suse.com
- Updated to 2.6.33-rc5.
  - Eliminated 2 patches.
* Mon Jan 25 2010 trenn@suse.de
- Update config files.
- patches.arch/x86_mce_intel_decode_physical_address.patch: x86,
  mce: Xeon75xx specific interface to get corrected memory error
  information (bnc#573380, fate#307738).
- patches.arch/x86_mce_intel_decode_physical_address_compile_fix.patch:
  x86, mce: Xeon75xx specific interface to get corrected memory
  error information (bnc#573380, fate#307738).
- patches.arch/x86_mce_intel_decode_physical_address_rename_fix.patch:
  x86, mce: Rename cpu_specific_poll to mce_cpu_specific_poll
  (bnc#573380, fate#307738).
- patches.xen/xen3-auto-arch-x86.diff: Refresh.
* Mon Jan 25 2010 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-57-cx5051-toshiba-quirk:
  ALSA: hda - Add support for Toshiba Satellite M300
  (bnc#492233,bnc#565904).
- patches.drivers/alsa-sp1-hda-58-cx5051-lenovo-mute-fix: ALSA:
  hda - Change headphone pin control with master volume on cx5051
  (bnc#573050).
* Mon Jan 25 2010 trenn@suse.de
- patches.arch/x86_enable_tsc_sync_check_again.patch: x86:
  Reenable TSC sync check at boot, even with NONSTOP_TSC
  (bnc#573379).
* Mon Jan 25 2010 trenn@suse.de
- patches.arch/x86_node_hotplug_parse_srat_fix_2nd_ver.patch:
  x86: Set hotpluggable nodes in nodes_possible_map (bnc#567216).
- patches.arch/x86_node_hotplug_parse_srat_fix.patch: Delete.
* Mon Jan 25 2010 trenn@suse.de
- supported.conf:
  Add mce-inject and hwpoison-inject so that Intel can easier test
  this. As these are debug drivers, they might get reverted from
  support.conf again if kernel-extra package gets fixed for SLES,
  only seem to exist for SLED because "NCC is not yet working for SP1".
  (bnc#572552).
* Sat Jan 23 2010 bphilips@suse.de
- patches.drivers/tg3-updates-from-f4188d-to-ba5b0bf.patch: tg3:
  updates from f4188d to ba5b0bf (bnc#573237).
* Sat Jan 23 2010 rjw@suse.de
- patches.arch/x86-irq-check-move_in_progress-before-freeing-the-vector-mapping.patch:
  x86, irq: Check move_in_progress before freeing the vector
  mapping (bnc#558247).
* Sat Jan 23 2010 rjw@suse.de
- patches.arch/x86-apic-use-logical-flat-for-systems-with-8-or-fewer-logical-cpus.patch:
  x86, apic: use logical flat for systems with <= 8 logical cpus
  (bnc#567510).
- patches.arch/x86-revert-apic-Use-logical-flat-on-intel-with-8-or-fewer-logical-cpus.patch:
  x86: Revert "apic: Use logical flat on intel with <= 8 logical
  cpus" (bnc#567510).
* Sat Jan 23 2010 gregkh@suse.de
- Update to 2.6.32.5:
  - security fixes
  - bug fixes
  - obsoletes:
  - patches.drivers/alsa-sp1-hda-54-alc861-capture-fix
  - patches.fixes/hid-add-device-ids-for-new-model-of-apple-wireless-keyboard
  - patches.fixes/megaraid_sas-fix-permissions-on-poll_mode_io
  - patches.fixes/reiserfs-truncate-blocks-not-used-by-a-write.patch
* Fri Jan 22 2010 tonyj@suse.de
- Update config files: drop UTRACE from default s390 configs
  as per communication from Ihno.
* Fri Jan 22 2010 gregkh@suse.de
- patches.kernel.org/x86-msr-cpuid-register-enough-minors-for-the-msr-and-cpuid-drivers.patch:
  x86, msr/cpuid: Register enough minors for the MSR and CPUID
  drivers (bnc#572720).
* Fri Jan 22 2010 gregkh@suse.de
- patches.kernel.org/scsi-enclosure-fix-oops-while-iterating-enclosure_status-array.patch:
  SCSI: enclosure: fix oops while iterating enclosure_status array
  (bnc#572818).
- patches.fixes/enclosure-fix-oops-while-iterating-enclosure_status-array:
  Delete.
* Fri Jan 22 2010 duwe@suse.de
- Update config files.
- patches.arch/ppc-extended_h_cede-update-to-mainline: Incremental
  patch set to sync H_CEDE with actual mainline (bnc#550447,
  FATE#307059).
* Fri Jan 22 2010 trenn@suse.de
- Update config files.
  Add DMAR to -trace flavor -> get in sync with -default
* Fri Jan 22 2010 hare@suse.de
- patches.fixes/qla2xxx-restore-pci-state-after-eeh-recovery:
  Re-save PCI state after EEH recovery (bnc#570233).
* Fri Jan 22 2010 jjolly@suse.de
- patches.arch/s390-06-01-zfcp-introduce-bsg-timeout-callback.patch:
  zfcp: introduce BSG timeout callback (BNC#572659).
- patches.arch/s390-06-02-zfcp-set-hw-timeout-requested-by-bsg.patch:
  zfcp: set HW timeout requested by BSG request (BNC#572659).
* Fri Jan 22 2010 bphilips@suse.de
- patches.drivers/netxen-8f9b3f-to-c651a8.patch: netxen: 8f9b3f
  to c651a8 (bnc#572832).
* Fri Jan 22 2010 mfasheh@suse.com
- patches.suse/ocfs2-allocation-resrvations.patch: Refresh to
  newest version of patch.
* Thu Jan 21 2010 astarikovskiy@suse.de
- supported.conf: added power_meter driver (FATE #306959).
* Thu Jan 21 2010 tonyj@suse.de
- config.conf: add -trace flavor for s390* at Ihno's request
- Add more tracers to existing ppc64 trace config at IBM request
  Both related to FATE# 307051.
- patches.trace/ftrace-framepointer.diff: Delete.
* Thu Jan 21 2010 hare@suse.de
- patches.fixes/scsi-fc-class-allow-LLD-bsg-timeout:
  scsi_transport_fc: Allow LLD to reset FC BSG timeout
  (bnc#572658).
* Thu Jan 21 2010 jbeulich@novell.com
- patches.xen/xen-privcmd-mmap-batch-clear: privcmd: mmapbatch-v2
  fixes.
* Thu Jan 21 2010 hare@suse.de
- patches.drivers/lpfc-8.3.5-update: lpfc update to 8.3.5
  (bnc#572427).
- patches.drivers/lpfc-8.3.5.3-update: lpfc driver update to
  8.3.5.3 (bnc#572427).
* Thu Jan 21 2010 hare@suse.de
- patches.drivers/e1000-enhance-frame-fragment-detection.patch:
  Update headers for series2git.
- patches.drivers/e1000e-enhance-frame-fragment-detection.patch:
  Update headers for series2git.
* Wed Jan 20 2010 tiwai@suse.de
- patches.suse/bootsplash-scaler: Refresh. More updates and
  clean-up by Egbert (bnc#570082)
* Wed Jan 20 2010 jkosina@suse.cz
- patches.drivers/add-support-for-intel-cougar-point-chipset.patch:
  Intel Cougar Point PCH Support (FATE#308854 bnc#565845).
* Wed Jan 20 2010 jslaby@suse.de
- patches.drivers/bnx2x-backports-v2.6.32-to-af901ca.patch:
  Refresh.
  (change firmwares in makefile)
* Wed Jan 20 2010 jslaby@suse.de
- patches.suse/rlim-0006-PPC-use-helpers-for-rlimits.patch: Refresh.
- patches.suse/rlim-0007-S390-use-helpers-for-rlimits.patch: Refresh.
* Wed Jan 20 2010 jbeulich@novell.com
- Update Xen patches to 2.6.32.4 and c/s 984.
- Update Xen config files.
* Wed Jan 20 2010 bphilips@suse.de
- patches.drivers/bnx2i-backport-from-v2.6.32-to-45ca38e.patch:
  bnx2i: Backport from v2.6.32 to 45ca38e (bnc#564640).
- patches.drivers/bnx2x-backports-v2.6.32-to-af901ca.patch:
  bnx2x: backports v2.6.32 to af901ca (bnc#564638).
- patches.drivers/cnic-backport-from-v2.6.32-4e9c4f.patch: cnic:
  backport from v2.6.32-4e9c4f (bnc#564640).
* Wed Jan 20 2010 gregkh@suse.de
- Update config files.  2.6.32.4 changed one of them.
* Wed Jan 20 2010 tiwai@suse.de
- patches.suse/bootsplash-scaler: Refresh.  Fixed the text area
  calculation, and added the upscaling (bnc#570082).
* Tue Jan 19 2010 jeffm@suse.com
- Updated to 2.6.33-rc4-git7.
  - Eliminated 4 patches.
* Tue Jan 19 2010 gregkh@suse.de
- Patch refresh for fuzz due to upstream -stable additions.
* Tue Jan 19 2010 gregkh@suse.de
- Update to 2.6.32.4
  - security fixes
  - bug fixes
  - obsoletes:
  - patches.arch/module-handle-ppc64-relocating-kcrctabs-when-config_relocatable-y
  - patches.drivers/alsa-sp1-hda-53-alc861vd-capture-fix
  - patches.fixes/audit_untag_chunk.patch
  - patches.fixes/quota-fix-reserved-space-management-for-ordinary-fs.patch
  - patches.fixes/signal-fix-kernel-information-leak-with-print-fatal-signals-1
* Tue Jan 19 2010 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-55-alc259-hp-pin-fix: ALSA: hda -
  Fix parsing pin node 0x21 on ALC259 (bnc#571879).
- patches.drivers/alsa-sp1-hda-56-realtek-eapd-fix: ALSA: hda -
  Turn on EAPD only if available for Realtek codecs (bnc#571879).
* Tue Jan 19 2010 tiwai@suse.de
- patches.suse/bootsplash-scaler: Refresh.  Fix the hang-up with
  resolution changes (bnc#570082)
* Tue Jan 19 2010 jkosina@suse.cz
- supported.conf: added aesni-intel (bnc#566618 FATE#304209).
* Tue Jan 19 2010 jkosina@suse.cz
- Update config files: set CONFIG_CRYPTO_HMAC=y to avoid
  regression from SLE11 (bnc#571501).
* Tue Jan 19 2010 jack@suse.de
- patches.fixes/reiserfs-truncate-blocks-not-used-by-a-write.patch:
  reiserfs: truncate blocks not used by a write (bnc#483375).
* Mon Jan 18 2010 jeffm@suse.de
- patches.suse/smtnice-disable: Delete (obsolete).
* Mon Jan 18 2010 jeffm@suse.com
- Disabled custom ACPI table loading from initramfs again.
* Mon Jan 18 2010 jeffm@suse.com
- patches.fixes/nfsd-05-sunrpc-cache-allow-thread-to-block-while-waiting-for.patch:
  Refresh.
* Mon Jan 18 2010 trenn@suse.de
- patches.arch/x86_node_hotplug_parse_srat_fix.patch:
  x86/mm/srat_64.c: nodes_parsed should include all nodes detected
  by ACPI (bnc#567140).
* Mon Jan 18 2010 hare@suse.de
- patches.fixes/aic79xx-null-scb-in-nonpkt-busfree: aic79xx: check
  for non-NULL scb in ahd_handle_nonpkt_busfree (bnc#542568).
* Mon Jan 18 2010 nfbrown@suse.de
- patches.fixes/nfsd-05-sunrpc-cache-allow-thread-to-block-while-waiting-for.patch:
  Refresh to fix 60 second delay. (bnc#568271)
* Sat Jan 16 2010 tonyj@suse.de
- patches.fixes/audit_untag_chunk.patch: fix braindamage in
  audit_tree.c untag_chunk() (bnc#556282).
* Sat Jan 16 2010 rjw@suse.de
- patches.xen/xen-x86-rename-display_cacheinfo-to-cpu_detect_cache_sizes.patch:
  x86: Rename display_cacheinfo() to cpu_detect_cache_sizes().
* Fri Jan 15 2010 gregkh@suse.de
- Update config files.
- patches.drivers/vmw_pvscsi-scsi-driver-for-vmware-s-virtual-hba.patch:
  vmw_pvscsi: SCSI driver for VMware's virtual HBA.
* Fri Jan 15 2010 jeffm@suse.com
- patches.fixes/hid-add-device-ids-for-new-model-of-apple-wireless-keyboard:
  HID: add device IDs for new model of Apple Wireless Keyboard
  (bnc#568231).
* Fri Jan 15 2010 hare@suse.de
- patches.drivers/qla2xxx-8.03.01.01.11.1-k8-update: qla2xxx
  driver update to 8.03.01.01.11.1-k8 (bnc#560415).
- patches.drivers/qla2xxx-8.03.01.02.11.1-k8-update: qla2xxx
  driver update to 8.03.01.02.11.1-k8 (bnc#570233).
- patches.drivers/lpfc-add-raywire-id: Delete.
- patches.drivers/qla2xxx-8.03.01-k7-update: Delete.
* Fri Jan 15 2010 hare@suse.de
- patches.drivers/qla2xxx-8.03.01.01.11.1-k8-update: qla2xxx
  driver update to 8.03.01.01.11.1-k8 (bnc#560415).
- patches.drivers/qla2xxx-8.03.01.02.11.1-k8-update: qla2xxx
  driver update to 8.03.01.02.11.1-k8 (bnc#570233).
- patches.drivers/lpfc-add-raywire-id: Delete.
- patches.drivers/qla2xxx-8.03.01-k7-update: Delete.
* Fri Jan 15 2010 trenn@suse.de
- patches.suse/kdb_dont_touch_i8042_early.patch: Avoid early
  hang when i8042 controller is missing (bnc#528811).
* Fri Jan 15 2010 jeffm@suse.com
- patches.suse/reiser4-sync_inodes: Delete (obsolete).
* Fri Jan 15 2010 jeffm@suse.com
- patches.suse/reiser4-sync_inodes: Delete (obsolete).
* Fri Jan 15 2010 jeffm@suse.com
- patches.fixes/remount-no-shrink-dcache: Updated to 2.6.33.
* Fri Jan 15 2010 jeffm@suse.com
- patches.arch/s390-08-02-zfcp-gpn-align-fix.diff: Delete (obsolete).
* Fri Jan 15 2010 jeffm@suse.com
- patches.suse/smtnice-disable: Updated to 2.6.33.
* Fri Jan 15 2010 jeffm@suse.com
- patches.arch/s390-08-02-zfcp-gpn-align-fix.diff: Delete (obsolete).
* Fri Jan 15 2010 mfasheh@suse.com
- patches.fixes/Ocfs2-Let-ocfs2-support-fiemap-for-symlink-and-fast-.patch:
  Ocfs2: Let ocfs2 support fiemap for symlink and fast symlink..
- patches.fixes/Ocfs2-Should-ocfs2-support-fiemap-for-S_IFDIR-inode.patch:
  Ocfs2: Should ocfs2 support fiemap for S_IFDIR inode?.
- patches.fixes/ocfs-stop-using-do_sync_mapping_range.patch:
  ocfs: stop using do_sync_mapping_range.
- patches.fixes/ocfs2-Add-reflinked-file-s-inode-to-inode-hash-earil.patch:
  ocfs2: Add reflinked file's inode to inode hash eariler..
- patches.fixes/ocfs2-Find-proper-end-cpos-for-a-leaf-refcount-block.patch:
  ocfs2: Find proper end cpos for a leaf refcount block..
- patches.fixes/ocfs2-Set-i_nlink-properly-during-reflink.patch:
  ocfs2: Set i_nlink properly during reflink..
- patches.fixes/ocfs2-always-include-acl-support.patch: ocfs2:
  Always include ACL support.
- patches.fixes/ocfs2-cluster-Make-fence-method-configurable-v2.patch:
  ocfs2/cluster: Make fence method configurable - v2.
- patches.fixes/ocfs2-devel-remove-redundant-OCFS2_MOUNT_POSIX_ACL-c.patch:
  ocfs2-devel: remove redundant OCFS2_MOUNT_POSIX_ACL check
  in ocfs2_get_acl_nolock().
- patches.fixes/ocfs2-explicit-declare-uninitialized-var-in-user_clu.patch:
  ocfs2: explicit declare uninitialized var in
  user_cluster_connect().
- patches.fixes/ocfs2-make-acl-use-the-default.patch: ocfs2:
  Make acl use the default.
- patches.fixes/ocfs2-refcounttree.c-cleanup.patch: ocfs2:
  refcounttree.c cleanup..
- patches.fixes/ocfs2-replace-u8-by-__u8-in-ocfs2_fs.h.patch:
  ocfs2: replace u8 by __u8 in ocfs2_fs.h.
- patches.fixes/ocfs2-return-EAGAIN-instead-of-EAGAIN-in-dlm.patch:
  ocfs2: return -EAGAIN instead of EAGAIN in dlm.
- patches.fixes/ocfs2-set-MS_POSIXACL-on-remount.patch: ocfs2:
  Set MS_POSIXACL on remount.
- patches.fixes/ocfs2-trivial-Use-le16_to_cpu-for-a-disk-value-in-xa.patch:
  ocfs2/trivial: Use le16_to_cpu for a disk value in xattr.c.
- patches.fixes/ocfs2-trivial-Use-proper-mask-for-2-places-in-hearbe.patch:
  ocfs2/trivial: Use proper mask for 2 places in hearbeat.c.
- patches.suse/fiemap-Add-new-extent-flag-FIEMAP_EXTENT_SHARED.patch:
  fiemap: Add new extent flag FIEMAP_EXTENT_SHARED.
- patches.suse/ocfs2-Use-FIEMAP_EXTENT_SHARED.patch: ocfs2:
  Use FIEMAP_EXTENT_SHARED.
- patches.suse/ocfs2-allocation-resrvations.patch: Refresh.
* Thu Jan 14 2010 rjw@suse.de
- patches.arch/x86-Limit-number-of-per-cpu-TSC-sync-messages.patch:
  x86: Limit number of per cpu TSC sync messages (bnc#564618,
  FATE#306952).
- patches.arch/x86-Limit-the-number-of-processor-bootup-messages.patch:
  x86: Limit the number of processor bootup messages (bnc#564618,
  FATE#306952).
- patches.arch/x86-Remove-CPU-cache-size-output-for-non-Intel-too.patch:
  x86: Remove CPU cache size output for non-Intel too (bnc#564618,
  FATE#306952).
- patches.arch/x86-Remove-enabling-x2apic-message-for-every-CPU.patch:
  x86: Remove enabling x2apic message for every CPU (bnc#564618,
  FATE#306952).
- patches.arch/x86-Remove-the-CPU-cache-size-printks.patch: x86:
  Remove the CPU cache size printk's (bnc#564618, FATE#306952).
- patches.arch/x86-cpu-mv-display_cacheinfo-cpu_detect_cache_sizes.patch:
  x86, cpu: mv display_cacheinfo -> cpu_detect_cache_sizes
  (bnc#564618, FATE#306952).
- patches.arch/x86-ucode-amd-Load-ucode-patches-once-and-not-separately-of-each-CPU.patch:
  x86: ucode-amd: Load ucode-patches once and not separately of
  each CPU (bnc#564618, FATE#306952).
- patches.fixes/sched-Limit-the-number-of-scheduler-debug-messages.patch:
  sched: Limit the number of scheduler debug messages (bnc#564618,
  FATE#306952).
- patches.fixes/timers-init-Limit-the-number-of-per-cpu-calibration-bootup-messages.patch:
  timers, init: Limit the number of per cpu calibration bootup
  messages (bnc#564618, FATE#306952).
* Thu Jan 14 2010 jeffm@suse.com
- patches.suse/add-initramfs-file_read_write: Build fix.
* Thu Jan 14 2010 jeffm@suse.com
- patches.suse/supported-flag-enterprise: Refresh.
* Thu Jan 14 2010 jeffm@suse.com
- patches.suse/supported-flag-sysfs: Properly report proprietary modules
* Thu Jan 14 2010 jeffm@suse.de
- patches.suse/add-initramfs-file_read_write: initramfs: add
  initramfs_{read,write} (bnc#568120).
- Re-enabled custom ACPI table loading from initramfs.
* Thu Jan 14 2010 trenn@suse.de
- Update config files.
  Enable CONFIG_CPU_FREQ_DEBUG as requested by HP.
  This one adds conditional printks which can be enabled via:
  cpufreq.debug=7
* Thu Jan 14 2010 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-54-alc861-capture-fix: ALSA: hda -
  Fix missing capture mixer for ALC861/660 codecs (bnc#567340).
* Thu Jan 14 2010 mmarek@suse.de
- rpm/find-provides, rpm/kernel-binary.spec.in: really fix ppc
  symbol provides.
* Thu Jan 14 2010 rjw@suse.de
- patches.arch/UV-Expose-irq_desc-node-in-proc.patch: Expose the
  irq_desc node as /proc/irq/*/node. (bnc#566745, fate#306952).
* Thu Jan 14 2010 bphilips@suse.de
- patches.drivers/dmfe-tulip-Let-dmfe-handle-DM910x-except-for-SPARC-o.patch:
  dmfe/tulip: Let dmfe handle DM910x except for SPARC on-board
  chips (bnc#537016).
* Thu Jan 14 2010 jkosina@suse.cz
- patches.fixes/crypto-testmgr-fix-complain-about-lacking-test.patch:
  crypto: testmgr - Fix complain about lack test for internal
  used algorithm (bnc#568278 FATE#306883).
* Wed Jan 13 2010 jeffm@suse.com
- Update to 2.6.33-rc4.
  - Eliminated patches.fixes/megaraid_sas-fix-permissions-on-poll_mode_io
* Wed Jan 13 2010 mmarek@suse.cz
- patches.suse/bootsplash-keep-multiple-data: Keep multiple
  splash screens for KMS (bnc#570082).
- patches.suse/bootsplash-scaler: Add bootsplash image scaler
  (bnc#570082).
* Wed Jan 13 2010 mmarek@suse.de
- rpm/kernel-binary.spec.in, rpm/find-provides: extract exported
  symbols from /boot/vmlinux before the image is stripped (affects
  ppc).
* Wed Jan 13 2010 jeffm@suse.com
- patches.rpmify/twl6030-fix-note_interrupt-call: Rename to patches.fixes/twl6030-fix-note_interrupt-call
* Wed Jan 13 2010 bphilips@suse.de
- patches.drivers/e1000-enhance-frame-fragment-detection.patch:
  Avoid atomic op by introducing discarding flag instead
- patches.drivers/e1000e-enhance-frame-fragment-detection.patch:
  Avoid atomic op by introducing discarding flag instead
* Wed Jan 13 2010 jeffm@suse.com
- patches.rpmify/autoconf-h-fix-locations: autoconf.h: Fix
  locations.
* Wed Jan 13 2010 jeffm@suse.com
- patches.fixes/ppc-crashdump-typefix: Renamed to patches.rpmify/ppc-crashdump-typefix
* Wed Jan 13 2010 jeffm@suse.com
- patches.fixes/signal-fix-kernel-information-leak-with-print-fatal-signals-1:
  Delete.
* Tue Jan 12 2010 jeffm@suse.com
- Update config files.
* Tue Jan 12 2010 jeffm@suse.com
- patches.fixes/ppc-crashdump-typefix: rename to patches.rpmify/ppc-crashdump-typefix
* Tue Jan 12 2010 jeffm@suse.com
- patches.fixes/signal-fix-kernel-information-leak-with-print-fatal-signals-1:
  kernel/signal.c: fix kernel information leak with
  print-fatal-signals=1 (bnc#569902).
* Tue Jan 12 2010 jeffm@suse.com
- patches.fixes/signal-fix-kernel-information-leak-with-print-fatal-signals-1:
  kernel/signal.c: fix kernel information leak with
  print-fatal-signals=1 (bnc#569902).
* Tue Jan 12 2010 rjw@suse.de
- needs_update: Remove some patches that we've got through the
  upstream.
* Tue Jan 12 2010 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-53-alc861vd-capture-fix: ALSA:
  hda - Fix ALC861-VD capture source mixer (bnc#568305).
* Tue Jan 12 2010 jeffm@suse.com
- Update to 2.6.33-rc3-git5.
* Tue Jan 12 2010 trenn@suse.de
- patches.fixes/nohz_prevent_clocksource_wrapping_during_idle.patch:
  nohz: Prevent clocksource wrapping during idle (bnc#569238).
* Tue Jan 12 2010 jack@suse.de
- patches.suse/readahead-request-tunables.patch: Update readahead
  and max_sectors tunables (bnc#548529).
* Tue Jan 12 2010 jkosina@suse.cz
- patches.drivers/watchdog-iTCO_wdt-Add-support-for-Intel-Ibex-Peak.patch:
  iTCO_wdt: Add support for Intel Ibex Peak (bnc#557081
  FATE#308591).
* Tue Jan 12 2010 tonyj@suse.de
- needs_update: remove LTT/trace patches (assigned to jbl), all had
  already been taken care of by my fwd port to 2.6.32
* Tue Jan 12 2010 hare@suse.de
- patches.drivers/qla4xxx-5.01.00-k9-5.01.00.00.11.01-k10.patch:
  Fixup compilation error.
* Tue Jan 12 2010 rjw@suse.de
- patches.fixes/PCI-Always-set-prefetchable-base-limit-upper32-registers.patch:
  PCI: Always set prefetchable base/limit upper32 registers
  (bnc#569003).
* Mon Jan 11 2010 jeffm@suse.com
- Merged patches.rpmify/x86_64-ksyms-make-the-native_load_gs_index-export-depend-on-config_paravirt_cpu into
  patches.arch/kvm-split-paravirt-ops-by-functionality
* Mon Jan 11 2010 jeffm@suse.com
- Renamed patches.rpmify/kmsg-fix-parameter-limitations to
  patches.arch/kmsg-fix-parameter-limitations
* Mon Jan 11 2010 jeffm@suse.com
- patches.rpmify/x86_64-ksyms-make-the-native_load_gs_index-export-depend-on-config_paravirt_cpu:
  x86_64/ksyms: Make the native_load_gs_index export depend
  on CONFIG_PARAVIRT_CPU.
* Mon Jan 11 2010 jeffm@suse.com
- Renamed patches.rpmify/rt2870-fix-section-mismatches to
  patches.rpmify/rt2860-fix-section-mismatches
* Mon Jan 11 2010 jeffm@suse.de
- Updated to 2.6.33-rc3-git3.
  - Eliminated 392 patches.
  - Xen is disabled.
* Mon Jan 11 2010 hare@suse.de
- patches.drivers/qla4xxx-5.01.00-k9-5.01.00.00.11.01-k10.patch:
  Update qla4xxx driver for SLES11 SP1 (bnc#556572,FATE#307128).
* Mon Jan 11 2010 jblunck@suse.de
- needs_update: Removed some patches.
* Mon Jan 11 2010 hare@suse.de
- patches.drivers/bfa-2.1.2.1-update: Update bfa driver to
  version 2.1.2.1 (bnc#561881).
* Mon Jan 11 2010 hare@suse.de
- patches.fixes/fcoe-libfc-adds-enable-di: adds enable/disable
  for fcoe interface (bnc#562046).
- patches.fixes/fcoe-use-lld-s-wwpn-and-w: Use LLD's WWPN and
  WWNN for lport if LLD supports ndo_fcoe_get_wwn (bnc#562046).
- patches.fixes/libfc-reduce-hold-time-on: reduce hold time on
  SCSI host lock (bnc#562046).
- patches.fixes/libfc-remote-port-gets-st: remote port gets
  stuck in restart state without really restarting (bnc#562046).
* Mon Jan 11 2010 hare@suse.de
- patches.drivers/mpt2sas-03.100.03.00-update: LSI mptsas2 driver
  update to 03.100.03.00 (bnc#566013).
* Mon Jan 11 2010 jbeulich@novell.com
- patches.xen/xen-x86_64-nx-user-mappings: Delete (bnc#568741).
- patches.xen/xen3-rlim-0025-x86-add-ia32-compat-prlimit-syscalls.patch:
  Delete.
* Mon Jan 11 2010 hare@suse.de
- patches.fixes/qla4xxx-lun-reset-fix: Delete.
* Mon Jan 11 2010 hare@suse.de
- patches.fixes/scsi-dh-rdac-add-ibm-174x: scsi_dh_rdac: Add
  two new IBM devices (bnc# 556159).
* Sat Jan  9 2010 jslaby@suse.de
- patches.suse/perfmon2.patch: Refresh.
- patches.suse/rlim-0001-SECURITY-selinux-fix-update_rlimit_cpu-parameter.patch:
  Refresh.
- patches.suse/rlim-0002-resource-move-kernel-function-inside-__KERNEL__.patch:
  resource: move kernel function inside __KERNEL__ (FATE#305733).
- patches.suse/rlim-0003-resource-add-helpers-for-fetching-rlimits.patch:
  resource: add helpers for fetching rlimits (FATE#305733).
- patches.suse/rlim-0004-IA64-use-helpers-for-rlimits.patch:
  [IA64] use helpers for rlimits (FATE#305733).
- patches.suse/rlim-0005-core-posix-cpu-timers-cleanup-rlimits-usage.patch:
  core: posix-cpu-timers, cleanup rlimits usage (FATE#305733).
- patches.suse/rlim-0006-PPC-use-helpers-for-rlimits.patch: PPC:
  use helpers for rlimits (FATE#305733).
- patches.suse/rlim-0007-S390-use-helpers-for-rlimits.patch:
  S390: use helpers for rlimits (FATE#305733).
- patches.suse/rlim-0008-SPARC-use-helpers-for-rlimits.patch:
  SPARC: use helpers for rlimits (FATE#305733).
- patches.suse/rlim-0009-X86-use-helpers-for-rlimits.patch: X86:
  use helpers for rlimits (FATE#305733).
- patches.suse/rlim-0010-FS-use-helpers-for-rlimits.patch: FS:
  use helpers for rlimits (FATE#305733).
- patches.suse/rlim-0011-MM-use-helpers-for-rlimits.patch: MM:
  use helpers for rlimits (FATE#305733).
- patches.suse/rlim-0012-core-use-helpers-for-rlimits.patch:
  core: use helpers for rlimits (FATE#305733).
- patches.suse/rlim-0013-infiniband-use-helpers-for-rlimits.patch:
  infiniband: use helpers for rlimits (FATE#305733).
- patches.suse/rlim-0014-ipc-use-helpers-for-rlimits.patch: ipc:
  use helpers for rlimits (FATE#305733).
- patches.suse/rlim-0015-SECURITY-add-task_struct-to-setrlimit.patch:
  SECURITY: add task_struct to setrlimit (FATE#305733).
- patches.suse/rlim-0016-core-add-task_struct-to-update_rlimit_cpu.patch:
  core: add task_struct to update_rlimit_cpu (FATE#305733).
- patches.suse/rlim-0017-sys_setrlimit-make-sure-rlim_max-never-grows.patch:
  sys_setrlimit: make sure ->rlim_max never grows (FATE#305733).
- patches.suse/rlim-0018-core-split-sys_setrlimit.patch: core:
  split sys_setrlimit (FATE#305733).
- patches.suse/rlim-0019-core-allow-setrlimit-to-non-current-tasks.patch:
  core: allow setrlimit to non-current tasks (FATE#305733).
- patches.suse/rlim-0020-core-optimize-setrlimit-for-current-task.patch:
  core: optimize setrlimit for current task (FATE#305733).
- patches.suse/rlim-0021-FS-proc-switch-limits-reading-to-fops.patch:
  FS: proc, switch limits reading to fops (FATE#305733).
- patches.suse/rlim-0022-FS-proc-make-limits-writable.patch:
  FS: proc, make limits writable (FATE#305733).
- patches.suse/rlim-0023-core-do-security-check-under-task_lock.patch:
  core: do security check under task_lock (FATE#305733).
- patches.suse/rlim-0002-SECURITY-add-task_struct-to-setrlimit.patch:
  Delete.
- patches.suse/rlim-0003-core-add-task_struct-to-update_rlimit_cpu.patch:
  Delete.
- patches.suse/rlim-0004-sys_setrlimit-make-sure-rlim_max-never-grows.patch:
  Delete.
- patches.suse/rlim-0005-core-split-sys_setrlimit.patch: Delete.
- patches.suse/rlim-0006-core-allow-setrlimit-to-non-current-tasks.patch:
  Delete.
- patches.suse/rlim-0007-core-optimize-setrlimit-for-current-task.patch:
  Delete.
- patches.suse/rlim-0008-FS-proc-make-limits-writable.patch:
  Delete.
- patches.suse/rlim-0009-core-posix-cpu-timers-cleanup-rlimits-usage.patch:
  Delete.
- patches.suse/rlim-0010-core-do-security-check-under-task_lock.patch:
  Delete.
- patches.suse/rlim-0011-resource-add-helpers-for-fetching-rlimits.patch:
  Delete.
- patches.suse/rlim-0012-IA64-use-helpers-for-rlimits.patch:
  Delete.
- patches.suse/rlim-0013-PPC-use-helpers-for-rlimits.patch:
  Delete.
- patches.suse/rlim-0014-S390-use-helpers-for-rlimits.patch:
  Delete.
- patches.suse/rlim-0015-SPARC-use-helpers-for-rlimits.patch:
  Delete.
- patches.suse/rlim-0016-X86-use-helpers-for-rlimits.patch:
  Delete.
- patches.suse/rlim-0017-FS-use-helpers-for-rlimits.patch: Delete.
- patches.suse/rlim-0018-MM-use-helpers-for-rlimits.patch: Delete.
- patches.suse/rlim-0019-core-use-helpers-for-rlimits.patch:
  Delete.
- patches.suse/rlim-0020-misc-use-helpers-for-rlimits.patch:
  Delete.
- patches.suse/rlim-0021-core-rename-setrlimit-to-do_setrlimit.patch:
  Delete.
- patches.suse/rlim-0022-core-implement-getprlimit-and-setprlimit-syscalls.patch:
  Delete.
- patches.suse/rlim-0023-unistd-add-__NR_-get-set-prlimit-syscall-numbers.patch:
  Delete.
- patches.suse/rlim-0024-COMPAT-add-get-put_compat_rlimit.patch:
  Delete.
- patches.suse/rlim-0025-x86-add-ia32-compat-prlimit-syscalls.patch:
  Delete.
  Sync with upstream. Drop limits syscalls altogether.
* Sat Jan  9 2010 jkosina@suse.cz
- patches.apparmor/apparmor.diff: Delete, as it is unused after
  splitup into smaller patches.
* Fri Jan  8 2010 sjayaraman@suse.de
- patches.suse/SoN-23-mm-swapfile.patch: Fix up the enum declaration
  to avoid conflict due to a upstream change.
* Fri Jan  8 2010 jkosina@suse.cz
- patches.fixes/quota-fix-reserved-space-management-for-ordinary-fs.patch:
  quota: fix reserved space management for ordinary fs.
* Fri Jan  8 2010 gregkh@suse.de
- patches.drivers/staging-hv-fix-smp-problems-in-the-hyperv-core-code.patch:
  Staging: hv: fix smp problems in the hyperv core code.
* Fri Jan  8 2010 jeffm@suse.de
- Disable set,getprlimit compat syscalls on xen.
* Fri Jan  8 2010 jeffm@suse.de
- Disabled custom ACPI table loading from initramfs until
  the scheduling while atomic issues are worked out.
* Fri Jan  8 2010 jeffm@suse.de
- Disabled set,getprlimit syscalls until the syscall numbers
  have been officially reserved.
* Fri Jan  8 2010 jeffm@suse.com
- patches.arch/module-handle-ppc64-relocating-kcrctabs-when-config_relocatable-y:
  module: handle ppc64 relocating kcrctabs when
  CONFIG_RELOCATABLE=y (bnc#566243).
* Thu Jan  7 2010 jbeulich@novell.com
- Update Xen patches to 2.6.32.3 and c/s 974.
- Update EC2 config files.
- patches.xen/xen3-x86-Remove-local_irq_enable-local_irq_disable-in-fixup_irqs.patch:
  x86: Remove local_irq_enable()/local_irq_disable() in
  fixup_irqs() (bnc#558247).
- patches.xen/xen3-x86-Unify-fixup_irqs-for-32-bit-and-64-bit-kernels.patch:
  x86: Unify fixup_irqs() for 32-bit and 64-bit kernels
  (bnc#558247).
- patches.xen/xen3-x86-intr-remap-Avoid-irq_chip-mask-unmask-in-fixup_irqs-for-intr-remapping.patch:
  x86, intr-remap: Avoid irq_chip mask/unmask in fixup_irqs()
  for intr-remapping (bnc#558247).
- patches.xen/xen-fix-compilation-after-rename_generic_int.patch:
  Delete.
- patches.xen/xen-scsifront-block-timeout-update: Delete.
- patches.xen/xen3-x86-fix-nodac: Delete.
* Thu Jan  7 2010 bphilips@suse.de
- patches.drivers/e1000-enhance-frame-fragment-detection.patch:
  e1000: enhance frame fragment detection (bnc#567376,
  CVE-2009-4536).
- patches.drivers/e1000e-enhance-frame-fragment-detection.patch:
  e1000e: enhance frame fragment detection (bnc#567376,
  CVE-2009-4538).
* Thu Jan  7 2010 gregkh@suse.de
- Update to 2.6.32.3
  - security fixes
  - bugfixes
  - obsoletes:
  - patches.arch/s390-04-03-dasd-diag-ro.patch
  - patches.drivers/alsa-sp1-hda-50-alc88x-missing-capsrc_nids
  - patches.fixes/qla2xxx-dpc-thread-can-execute-before-scsi-host
  - patches.fixes/scsi-ipr-fix-eeh-recovery
* Wed Jan  6 2010 rjw@suse.de
- patches.arch/x86-Force-irq-complete-move-during-cpu-offline.patch:
  x86: Force irq complete move during cpu offline (bnc#558247).
- patches.arch/x86-Remove-local_irq_enable-local_irq_disable-in-fixup_irqs.patch:
  x86: Remove local_irq_enable()/local_irq_disable() in
  fixup_irqs() (bnc#558247).
- patches.arch/x86-Remove-move_cleanup_count-from-irq_cfg.patch:
  x86: Remove move_cleanup_count from irq_cfg (bnc#558247).
- patches.arch/x86-Remove-unnecessary-mdelay-from-cpu_disable_common.patch:
  x86: Remove unnecessary mdelay() from cpu_disable_common()   .
- patches.arch/x86-Unify-fixup_irqs-for-32-bit-and-64-bit-kernels.patch:
  x86: Unify fixup_irqs() for 32-bit and 64-bit kernels
  (bnc#558247).
- patches.arch/x86-Use-EOI-register-in-io-apic-on-intel-platforms.patch:
  x86: Use EOI register in io-apic on intel platforms
  (bnc#558247).
- patches.arch/x86-intr-remap-Avoid-irq_chip-mask-unmask-in-fixup_irqs-for-intr-remapping.patch:
  x86, intr-remap: Avoid irq_chip mask/unmask in fixup_irqs()
  for intr-remapping (bnc#558247).
- patches.arch/x86-io-apic-Move-the-effort-of-clearing-remoteIRR-explicitly-before-migrating-the-irq.patch:
  x86, io-apic: Move the effort of clearing remoteIRR explicitly
  before migrating the irq (bnc#558247).
- patches.arch/x86-ioapic-Document-another-case-when-level-irq-is-seen-as-an-edge.patch:
  x86, ioapic: Document another case when level irq is seen as
  an edge (bnc#558247).
- patches.arch/x86-ioapic-Fix-the-EOI-register-detection-mechanism.patch:
  x86, ioapic: Fix the EOI register detection mechanism
  (bnc#558247).
* Wed Jan  6 2010 trenn@suse.de
- patches.fixes/pci_aer_mce_inject_check_osc_for_aer.patch: PCI:
  AER: fix aer inject result in kernel oops (bnc#566619).
* Wed Jan  6 2010 trenn@suse.de
- patches.fixes/PCIe-AER-reject-aer-inject-if-hardware-mask-error-reporting.patch:
  PCIe AER: reject aer inject if hardware mask error reporting
  (bnc#566621).
* Wed Jan  6 2010 gregkh@suse.de
- patches.xen/xen3-patch-2.6.29: Refresh due to conflicts from i915
  changes.  Ick, the xen code sucks rocks, it shouldn't be touching
  stuff here at all.
* Wed Jan  6 2010 gregkh@suse.de
- patches.drivers/drm-i915-add-acpi-opregion-support-for-ironlake.patch:
  Refresh.
- patches.drivers/drm-i915-add-i915_lp_ring_sync-helper.patch:
  drm/i915: add i915_lp_ring_sync helper (bnc#568447).
- patches.drivers/drm-i915-fix-get_core_clock_speed-for-g33-class-desktop-chips.patch:
  drm/i915: fix get_core_clock_speed for G33 class desktop chips
  (bnc#568447).
- patches.drivers/drm-i915-fully-switch-off-overlay-when-not-in-use.patch:
  drm/i915: fully switch off overlay when not in use (bnc#568447).
- patches.drivers/drm-i915-implement-drmmode-overlay-support-v4.patch:
  drm/i915: implement drmmode overlay support v4 (bnc#568447).
- patches.drivers/drm-i915-implement-fastpath-for-overlay-flip-waiting.patch:
  drm/i915: implement fastpath for overlay flip waiting
  (bnc#568447).
* Wed Jan  6 2010 gregkh@suse.de
- patches.drivers/drm-i915-add-acpi-opregion-support-for-ironlake.patch:
  Refresh.
* Wed Jan  6 2010 gregkh@suse.de
- patches.drivers/drm-i915-add-acpi-opregion-support-for-ironlake.patch:
  drm/i915: Add ACPI OpRegion support for Ironlake (bnc#568436).
* Tue Jan  5 2010 tonyj@suse.de
- patches.fixes/oprofile_bios_ctr.patch: Update to newer version
* Wed Dec 30 2009 nfbrown@suse.de
- patches.fixes/nfs-fix-NFS4ERR_FILE_OPEN-handling:
  NFS4ERR_FILE_OPEN handling in Linux/NFS (bnc#526819).
* Mon Dec 28 2009 jeffm@suse.com
- patches.fixes/dmar-fix-oops-with-no-dmar-table: dmar: Fix oops
  with no DMAR table (bnc#548108).
* Sun Dec 27 2009 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-52-hdmi-sticky-stream-tag: ALSA:
  hda - HDMI sticky stream tag support (FATE#306783).
* Thu Dec 24 2009 rjw@suse.de
- patches.arch/xpc_first_contact_when_active.patch: X86: UV
  - xpc_make_first_contact hang due to not accepting ACTIVE
  state. (bnc#562288, fate#306952).
- patches.arch/xpc_fix_xpc_get_fifo_entry_uv.patch: x86: UV - XPC
  NULL deref when mesq becomes empty. (bnc#562288, fate#306952).
- patches.arch/xpc_introduce_xp_socket.patch: x86: UV - XPC
  needs to provide an abstraction for uv_gpa. (bnc#562288,
  fate #306952).
- patches.arch/xpc_pass_nasid_to_gru_create_message_queue.patch:
  UV - pass nasid instead of nid to gru_create_message_queue
  (bnc#562288, fate#306952).
- patches.arch/xpc_recv_msg_slots_wrap.patch: X86: UV - XPC
  receive message reuse triggers invalid BUG_ON(). (bnc#562288,
  fate#306952).
- patches.arch/xpc_uv_bios_changes.patch: x86: UV - Update XPC
  to handle updated BIOS interface. (bnc#562288, fate#306952).
* Wed Dec 23 2009 rjw@suse.de
- patches.arch/bug-561989_gru_rollup.patch: SGI GRU Updates
  (bnc#561989, fate#306952).
* Wed Dec 23 2009 jeffm@suse.com
- patches.fixes/ppc-crashdump-typefix: powerpc: use min_t in
  copy_oldmem_page.
* Wed Dec 23 2009 rjw@suse.de
- patches.arch/bug-561946_uv_irq_affinity.patch: x86: SGI UV: Fix
  irq affinity for hub based interrupts (bnc#561946, fate#306952).
- patches.arch/bug-561946_uv_move_ioapic.patch: x86, apic: Move
  SGI UV functionality out of generic IO-APIC code (bnc#561946,
  fate#306952).
- patches.arch/bug-561946_uv_use_rtc.patch: x86: UV RTC: Always
  enable RTC clocksource (bnc#561946, fate#306952).
* Wed Dec 23 2009 jeffm@suse.com
- patches.fixes/ia64-fix-sba-iommu-to-handle-allocation-failure-properly:
  fix SBA IOMMU to handle allocation failure properly
  (bnc#545367).
* Tue Dec 22 2009 jeffm@suse.com
- Enabled CONFIG_CRASH_DUMP on ppc/ppc64 (bnc#566243).
* Tue Dec 22 2009 jeffm@suse.com
- patches.fixes/scsi-ipr-fix-eeh-recovery: ipr: fix EEH recovery
  (bnc#566613).
* Sun Dec 20 2009 trenn@suse.de
- Update config files.
- patches.drivers/cpufreq_ondemand_limit_fix.patch: cpufreq:
  Fix ondemand to not request targets outside policy limits
  (fate#306746).
- patches.drivers/cpufreq_processor_clocking_control_pcc_driver.patch:
  x86,cpufreq: Processor Clocking Control (PCC) driver
  (fate#306746).
- supported.conf:
* Sun Dec 20 2009 rjw@suse.de
- patches.arch/bug-561939_uv_bios_call_hwperf_updated.patch:
  x86, uv: Add serial number parameter to uv_bios_get_sn_info()
  (bnc#561939, fate#306952).
- patches.arch/bug-561939_uv_bios_call_hwperf.patch: Delete.
* Sat Dec 19 2009 jeffm@suse.com
- patches.fixes/scsi_debug-scale-virtual_gb-with-sector_size-properly:
  scsi_debug: scale virtual_gb with sector_size properly
  (bnc#535939).
* Sat Dec 19 2009 gregkh@suse.de
- patches.xen/xen3-fixup-xen: Refresh.  Fix up build error from
  .32.2 import
* Sat Dec 19 2009 gregkh@suse.de
- Update to 2.6.32.2
  - lots of security fixes
  - loads of bugfixes
  - other goodness
  - obsoletes:
  - patches.arch/bug-561939_bau_data_config.patch
  - patches.arch/bug-564471_x86_Fix_duplicated_UV_BAU_interrupt_vector.patch
  - patches.arch/s390-04-01-clear-high-regs.patch
  - patches.arch/s390-kvm-prefix.patch
  - patches.arch/s390-kvm-psw.patch
  - patches.arch/x86-fix-nodac
  - patches.arch/x86_mce_nfs-mig2
  - patches.fixes/firewire-ohci-handle-receive-packets-with-a-data-length-of-zero
  - patches.fixes/uart-txen-race.patch
* Fri Dec 18 2009 jeffm@suse.com
- Update config files: CONFIG_STRICT_DEVMEM=n. It was enabled
  mistakenly in commit 3df90f9e and affects using tools like
  crash with a live system.
* Fri Dec 18 2009 gregkh@suse.de
- Update config files.
  CONFIG_CALGARY_IOMMU_ENABLED_BY_DEFAULT = n (bnc#565607)
* Fri Dec 18 2009 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-{24..51}-*: 2.6.33-rc1 backport
  fixes for HDMI and new Realtek codecs (FATE#306783)
- Refresh Patch-mainline tags in patches.drivers/alsa-*
* Fri Dec 18 2009 jjolly@suse.de
- patches.arch/s390-05-01-netiucv-tx-bytes.patch: netiucv:
  displayed TX bytes value much too high (BNC#565612).
- patches.arch/s390-05-02-cmm-suspend.patch: cmm: free pages on
  hibernate. (BNC#565612).
- patches.arch/s390-05-03-iucv-suspend.patch: iucv: add work_queue
  cleanup for suspend (BNC#565612).
- patches.arch/s390-05-04-zfcp-work-queue.patch: zfcp: Assign
  scheduled work to driver queue (BNC#565612).
- patches.arch/s390-05-05-zfcp-fail-commands.patch: zfcp: Don't
  fail SCSI commands when transitioning to blocked fc_rport
  (BNC#565612,LTC#58541).
- patches.arch/s390-05-06-zfcp-adisc.patch: zfcp: Improve ELS
  ADISC handling (BNC#565612).
- patches.arch/s390-05-07-zfcp-fsf-errors.patch: zfcp: Update
  FSF error reporting (BNC#565612).
- patches.arch/s390-05-08-zfcp-block.diff: zfcp: Block SCSI EH
  thread for rport state BLOCKED (BNC#565612).
- patches.arch/s390-05-09-ctcm-suspend-wait.diff: ctcm: suspend
  has to wait for outstanding I/O (BNC#565612).
- patches.arch/s390-05-10-rework-tso.diff: qeth: rework TSO
  functions (BNC#565612).
- patches.arch/s390-05-11-atomic-volatile.patch: kernel: improve
  code generated by atomic operations. (BNC#565612).
- patches.arch/s390-05-12-tape-remove-fn.patch: tape: incomplete
  device removal (BNC#565612).
- patches.arch/s390-05-13-qeth-blkt-defaults.patch: qeth:
  set default BLKT settings dependend on OSA hw level
  (BNC#565612,LTC#58654).
- patches.arch/s390-05-14-dasd-dasd-enable-prefix.patch: dasd:
  enable prefix independent of pav support (BNC#565612).
- patches.arch/s390-05-15-dasd-s390dbf-strings.patch: dasd:
  remove strings from s390dbf (BNC#565612).
- patches.arch/s390-05-16-dasd-wait-lcu-setup.patch: dasd:
  let device initialization wait for LCU setup (BNC#565612).
* Fri Dec 18 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Fix generating /boot/Kerntypes* for
  s390/vanilla.
* Fri Dec 18 2009 nfbrown@suse.de
- patches.fixes/md-start_ro-fix: md: fix small irregularity with
  start_ro module parameter (bnc#565219).
* Fri Dec 18 2009 rjw@suse.de
- patches.xen/xen-fix-compilation-after-rename_generic_int.patch:
  XEN: Fix compilation after renaming of generic_irqs.
* Fri Dec 18 2009 rjw@suse.de
- patches.arch/bug-561946_rename_generic_int.patch: x86: UV RTC:
  Rename generic_interrupt to x86_platform_ipi (bnc#561946,
  fate#306952).
* Fri Dec 18 2009 mmarek@suse.cz
- patches.suse/s390-Kerntypes.diff: S390: Generate Kerntypes file.
- rpm/kernel-binary.spec.in: install /boot/Kerntypes-$version.
* Thu Dec 17 2009 jeffm@suse.com
- patches.fixes/powerpc-fix-cpu-name-in-show-cpuinfo: powerpc:
  fix cpu name in show-cpuinfo (bnc#565267).
* Thu Dec 17 2009 hare@suse.de
- patches.fixes/fc-transport-remove-BUG_ON: scsi_transport_fc:
  remove invalid BUG_ON (bnc#564479).
- patches.fixes/lpfc-ia64-hang: lpfc: fix hang on SGI ia64
  platform (bnc#564479).
- patches.fixes/qla2xxx-dpc-thread-can-execute-before-scsi-host:
  qla2xxx: dpc thread can execute before scsi host has been added
  (bnc#564479).
- patches.suse/fc-transport-allow-dev_loss_tmo-disable: Remove
  capping from dev_loss_tmo (bnc#492469).
* Wed Dec 16 2009 gregkh@suse.de
- Update config files.
  - fix up CONFIG_IPV6 option that was built into the kernel
    incorrectly (bnc#564357)
* Wed Dec 16 2009 jeffm@suse.com
- patches.fixes/acpi-fix-build-when-config_acpi_custom_override_initramfs-is-not-defined:
  acpi: Fix build when CONFIG_ACPI_CUSTOM_OVERRIDE_INITRAMFS is
  not defined.
* Wed Dec 16 2009 jbeulich@novell.com
- Update Xen patches to c/s 960.
- Update Xen EC2 config files.
- patches.xen/xen3-bug-561933_uv_pat_is_gru_range.patch: x86:
  UV SGI: Don't track GRU space in PAT (bnc#561933, fate#306952).
- patches.xen/xen3-x86-mark_rodata_rw.patch: Add mark_rodata_rw()
  to un-protect read-only kernel code pages (bnc#439348).
* Wed Dec 16 2009 npiggin@suse.de
- needs_update:
- patches.fixes/aggressive-zone-reclaim.patch: be more aggressive
  with zone reclaims (bnc#476525).
* Wed Dec 16 2009 npiggin@suse.de
- needs_update:
- patches.suse/x86-mark_rodata_rw.patch: Refresh.
* Wed Dec 16 2009 npiggin@suse.de
- patches.suse/x86-mark_rodata_rw.patch: Add mark_rodata_rw()
  to un-protect read-only kernel code pages (bnc#439348).
* Tue Dec 15 2009 jeffm@suse.com
- patches.fixes/firewire-ohci-handle-receive-packets-with-a-data-length-of-zero:
  firewire: ohci: handle receive packets with a data length of
  zero (bnc#564712 CVE-2009-4138).
* Tue Dec 15 2009 mmarek@suse.cz
- rpm/config.sh: set OBS_PROJECT and IBS_PROJECT variables for
  osc_wrapper.
* Tue Dec 15 2009 knikanth@suse.de
- supported.conf: Mark dm-log-userspace as supported (fate#307380).
* Tue Dec 15 2009 sjayaraman@suse.de
- patches.fixes/sched-recalculate-tunables-on-hot-add-remove:
  Fix the build failure due to previous commit.
* Tue Dec 15 2009 sjayaraman@suse.de
- patches.fixes/sched-recalculate-tunables-on-hot-add-remove:
  sched: Fix missing sched tunable recalculation on cpu add/remove
  (bnc#560317).
- patches.fixes/sched-make-tunable-scaling-configurable: sched:
  Make tunable scaling style configurable (bnc#560317).
- patches.fixes/sched-sysctl-for-normalized-tunables:  sched:
  Update normalized values on user updates via proc (bnc#560317).
* Tue Dec 15 2009 gregkh@suse.de
- Update config files.
  - make SCSI and ATA drivers modules again.
    (bnc#564357)
* Tue Dec 15 2009 gregkh@suse.de
- Update config files.
  - fix up USB options that were built into the kernel incorrectly
    (bnc#564357)
* Mon Dec 14 2009 jjolly@suse.de
- patches.arch/s390-04-01-clear-high-regs.patch: kernel:
  clear high-order bits after switching to 64-bit mode
  (BNC#563999,LTC#58088).
- patches.arch/s390-04-02-zcrypt-hrtimer.patch: zcrypt: Do not
  simultaneously schedule hrtimer (BNC#563999,LTC#58222).
- patches.arch/s390-04-03-dasd-diag-ro.patch: dasd: support DIAG
  access for read-only devices (BNC#563999,LTC#57147).
- patches.arch/s390-04-04-mm-fault-fix.patch: kernel: performance
  counter fix and page fault optimization (BNC#563999).
- patches.arch/s390-04-05-sclp-dump-indicator.patch: kernel:
  fix dump indicator (BNC#563999).
- patches.arch/s390-04-06-dasd-move-diag-kmsg.patch: dasd:
  move diag kmsg to generic dasd kmsg (BNC#563999).
- patches.arch/s390-04-07-cio-fix-double-free.patch: cio: double
  free under memory pressure (BNC#563999).
- patches.arch/s390-04-08-cio-fix-dev-stall.patch: cio: device
  recovery stalls after multiple hardware events (BNC#563999).
- patches.arch/s390-04-09-cio-recover-hw-changes.patch: cio:
  device recovery fails after concurrent hardware changes
  (BNC#563999).
- patches.arch/s390-04-10-cio-fix-onoffline-failure.patch: cio:
  setting a device online or offline fails for unknown reasons
  (BNC#563999).
- patches.arch/s390-04-11-cio-error-reporting.patch: cio:
  incorrect device state after device recognition and recovery
  (BNC#563999).
- patches.arch/s390-04-12-cio-avoid-panic.patch: cio: kernel
  panic after unexpected interrupt (BNC#563999).
- patches.arch/s390-04-13-cio-internal-io.patch: cio:
  initialization of I/O devices fails (BNC#563999).
- patches.arch/s390-04-14-cio-allow-offline.patch: cio: not
  operational devices cannot be deactivated (BNC#563999).
- patches.arch/s390-04-15-cio-split-pgid.patch: cio: erratic
  DASD I/O behavior (BNC#563999).
- patches.arch/s390-04-16-cio-path-verification.patch: cio:
  DASD cannot be set online (BNC#563999).
- patches.arch/s390-04-17-cio-steal-lock.patch: cio: DASD steal
  lock task hangs (BNC#563999).
- patches.arch/s390-04-18-cio-fix-memleak-chk-dev.patch: cio:
  memory leaks when checking unusable devices (BNC#563999).
- patches.arch/s390-04-19-cio-fix-deact-dev-panic.patch: cio:
  deactivated devices can cause use after free panic (BNC#563999).
* Mon Dec 14 2009 rjw@suse.de
- patches.arch/bug-561933_uv_pat_is_gru_range.patch: x86: UV SGI:
  Don't track GRU space in PAT (bnc#561933, fate#306952).
- patches.arch/bug-561939_bau_data_config.patch: x86: SGI UV
  BAU initialization (bnc#561939, fate#306952).
- patches.arch/bug-561939_uv_bios_call_hwperf.patch: x86: UV
  hardware performance counter and topology access  (bnc#561939,
  fate#306952).
- patches.arch/bug-561939_uv_gpa_is_mmr_space.patch: x86: UV -
  Introduce uv_gpa_is_mmr. (bnc#561939, fate#306952).
- patches.arch/bug-561939_uv_gpa_to_soc_phys_ram.patch:
  x86: UV - Introduce a means to translate from gpa ->
  socket_paddr. (bnc#561939, fate#306952).
- patches.arch/bug-561939_uv_ipi_macro.patch: x86: UV: Introduce
  uv_hub_ipi_value (bnc#561939, fate#306952).
- patches.arch/bug-561939_uv_mmap_low.patch: x86: SGI UV: Map
  low MMR ranges (bnc#561939, fate#306952).
- patches.arch/bug-561939_uv_rtc_cleanup.patch: x86: UV RTC:
  Clean up error handling (bnc#561939, fate#306952).
- patches.arch/bug-561939_uv_rtc_fixes.patch: x86: UV RTC:
  Fix early expiry handling  (bnc#561939, fate#306952).
- patches.arch/bug-561939_uv_rtc_setup_evt.patch: x86: UV RTC:
  Add clocksource only boot option (bnc#561939, fate#306952).
- patches.arch/bug-564471_x86_Fix_duplicated_UV_BAU_interrupt_vector.patch:
  x86: Fix duplicated UV BAU interrupt vector (bnc#564471).
* Mon Dec 14 2009 gregkh@suse.de
- Refresh patches to be clean of fuzz
* Mon Dec 14 2009 gregkh@suse.de
- Update to 2.6.32.1
  - security fixes
  - bugfixes
  - obsoletes:
  - patches.fixes/ext4-fix-insufficient-checks-in-ext4_ioc_move_ext
  - patches.fixes/scsi-fix-bug-with-dma-maps-on-nested-scsi-objects
* Mon Dec 14 2009 jjolly@suse.de
- patches.drivers/dcb-data-center-bridging-ops-s: dcb: data
  center bridging ops should be r/o (BNC#562046).
- patches.drivers/drivers-net-request_irq-remove: drivers/net:
  request_irq - Remove unnecessary leading & from second arg
  (BNC#562046).
- patches.drivers/ethtool-add-direct-attach-supp: ethtool: Add
  Direct Attach support to connector port reporting (BNC#562046).
- patches.drivers/ixgbe-add-support-for-82599-al: ixgbe: Add
  support for 82599 alternative WWNN/WWPN prefix (BNC#562046).
- patches.drivers/ixgbe-add-support-for-82599-ba: ixgbe: add
  support for 82599 based Express Module X520-P2 (BNC#562046).
- patches.drivers/ixgbe-add-support-for-netdev_o: ixgbe: Add
  support for netdev_ops.ndo_fcoe_get_wwn to 82599 (BNC#562046).
- patches.drivers/ixgbe-change-default-ring-size: ixgbe: change
  default ring size (BNC#562046).
- patches.drivers/ixgbe-disable-flow-control-for: ixgbe: Disable
  Flow Control for certain devices (BNC#562046).
- patches.drivers/ixgbe-display-currently-attach: ixgbe: Display
  currently attached PHY through ethtool (BNC#562046).
- patches.drivers/ixgbe-fix-erroneous-display-of: ixgbe: Fix
  erroneous display of stats by ethtool -S (BNC#562046).
- patches.drivers/ixgbe-fix-kr-to-kx-fail-over-f: ixgbe: Fix KR
  to KX fail over for Mezzanine cards (BNC#562046).
- patches.drivers/ixgbe-fix-receive-address-regi: ixgbe:
  Fix Receive Address Register (RAR) cleaning and accounting
  (BNC#562046).
- patches.drivers/ixgbe-flush-the-lsc-mask-chang: ixgbe: Flush
  the LSC mask change to prevent repeated interrupts (BNC#562046).
- patches.drivers/ixgbe-handle-parameters-for-tx: ixgbe: handle
  parameters for tx and rx EITR, no div0 (BNC#562046).
- patches.drivers/ixgbe-links2-is-not-a-valid-re: ixgbe: LINKS2
  is not a valid register for 82598 (BNC#562046).
- patches.drivers/ixgbe-make-queue-pairs-on-sing: ixgbe: Make
  queue pairs on single MSI-X interrupts (BNC#562046).
- patches.drivers/ixgbe-modify-82599-hwrsc-stati: ixgbe: Modify
  82599 HWRSC statistics counters (BNC#562046).
- patches.drivers/ixgbe-only-set-clear-vfe-in-ix: ixgbe: Only
  set/clear VFE in ixgbe_set_rx_mode (BNC#562046).
- patches.drivers/ixgbe-performance-tweaks: ixgbe: performance
  tweaks (BNC#562046).
- patches.drivers/ixgbe-r_idx-not-used-in-ixgbe_: ixgbe: r_idx
  not used in ixgbe_msix_clean_rx() (BNC#562046).
- patches.drivers/ixgbe-select-fcoe-tx-queue-in-: ixgbe: select
  FCoE Tx queue in ndo_select_queue (BNC#562046).
- patches.drivers/ixgbe-use-eiam-to-automask-msi: ixgbe: use
  EIAM to automask MSI-X (BNC#562046).
- patches.drivers/ixgbe-use-known-user-priority-: ixgbe: use
  known user priority for FCoE when DCB is enabled (BNC#562046).
- patches.drivers/ixgbe-use-rx-buffer-length-fro: ixgbe: Use rx
  buffer length from rx ring for configuring rscctl (BNC#562046).
- patches.drivers/ixgbe-use-the-instance-of-net_: ixgbe: Use
  the instance of net_device_stats from net_device. (BNC#562046).
- patches.drivers/net-add-ndo_fcoe_get_wwn-to-ne: net: Add
  ndo_fcoe_get_wwn to net_device_ops (BNC#562046).
- patches.drivers/net-add-netdev_alloc_skb_ip_al: net: Add
  netdev_alloc_skb_ip_align() helper (BNC#562046).
- patches.drivers/net-use-netdev_alloc_skb_ip_al: net: Use
  netdev_alloc_skb_ip_align() (BNC#562046).
- patches.drivers/vlan-add-support-to-netdev_ops: vlan:
  Add support to netdev_ops.ndo_fcoe_get_wwn for VLAN device
  (BNC#562046).
- patches.fixes/fcoe-allow-scsi-fcp-to-be: fcoe: allow SCSI-FCP
  to be processed directly in softirq context (BNC#562046).
- patches.fixes/fcoe-libfc-add-get_lesb-t: fcoe, libfc: add
  get_lesb() to allow LLD to fill the link error status block
  (LESB) (BNC#562046).
- patches.fixes/libfc-add-fc-bb-5-lesb-co: libfc: add FC-BB-5
  LESB counters to fcoe_dev_stats (BNC#562046).
- patches.fixes/libfc-add-fcoe_fc_els_les: libfc: add
  fcoe_fc_els_lesb to fc_fcoe.h for FC-BB-5 LESB definitions
  (BNC#562046).
- patches.fixes/libfc-add-support-of-rece: libfc: add support
  of receiving ELS_RLS (BNC#562046).
- patches.fixes/libfc-add-target-reset-fl: libfc: Add target
  reset flag to FCP header file (BNC#562046).
- patches.fixes/libfc-fix-payload-size-pa: libfc: fix payload size
  passed to fc_frame_alloc() in fc_lport_els_request (BNC#562046).
- patches.fixes/libfcoe-add-checking-disa: libfcoe: add checking
  disable flag in FIP_FKA_ADV (BNC#562046).
- patches.fixes/libfcoe-add-tracking-fip-: libfcoe: add tracking
  FIP Missing Discovery Advertisement count (BNC#562046).
- patches.fixes/libfcoe-add-tracking-fip--0: libfcoe: add tracking
  FIP Virtual Link Failure count (BNC#562046).
* Mon Dec 14 2009 mmarek@suse.cz
- rpm/kabi.pl: Do not print harmless kabi changes by default.
* Mon Dec 14 2009 sjayaraman@suse.de
- patches.suse/sched-revert-latency-defaults: Revert sched
  latency defaults and turn FAIR_SLEEPERS off (bnc#557307).
* Mon Dec 14 2009 jkosina@suse.cz
- patches.fixes/uart-txen-race.patch: Serial: Do not read IIR in
  serial8250_start_tx when UART_BUG_TXEN (bnc#479304 bnc#509066).
* Mon Dec 14 2009 rjw@suse.de
- patches.fixes/bug-562290-Fix-isolcpus-boot-option.patch: sched:
  Fix isolcpus boot option (bnc#562290, fate#306952).
* Sat Dec 12 2009 mmarek@suse.cz
- patches.suse/supported-flag: Fix -Wmissing-prototypes warnings
  in modpost.c.
* Sat Dec 12 2009 mmarek@suse.cz
- patches.rpmify/modpost-segfault: modpost: fix segfault with
  short symbol names.
* Fri Dec 11 2009 jeffm@suse.com
- Moved kernel-docs into the git repo. It is now built automatically
  with the matching kernel sources.
* Fri Dec 11 2009 trenn@suse.de
- patches.suse/kdb_fix_ia64_build.patch: Fix ia64 - Export
  kdb_usb_kbds (none).
* Fri Dec 11 2009 trenn@suse.de
  Jeff updated kdb, try without this ugly workaround.
  If it still does not work, I have something better...
- patches.suse/kdb_x86_fix_hang.patch: Delete.
* Fri Dec 11 2009 hare@suse.de
  Cleanup patches for series2git:
- patches.suse/kdb-common: Refresh.
- patches.suse/kdump-dump_after_notifier.patch: Refresh.
* Fri Dec 11 2009 trenn@suse.de
  Updated MCE/MCA patches from Andi -> delete the old ones:
- patches.arch/x86_mce_hwpoison-action_result-valid-pfn.patch:
  HWPOISON: return ENXIO on invalid page number (fate#307738).
- patches.arch/x86_mce_hwpoison-is-free-page.patch: HWPOISON:
  detect free buddy pages explicitly (fate#307738).
- patches.arch/x86_mce_hwpoison-no-double-ref.patch: HWPOISON:
  avoid grabbing the page count multiple times during madvise
  injection (fate#307738).
- patches.arch/x86_mce_madvise-locking: HWPOISON: Use
  get_user_page_fast in hwpoison madvise (fate#307738).
- patches.arch/x86_mce_nfs-mig2: NFS: Fix nfs_migrate_page()
  (fate#307738).
- patches.arch/x86_mce_offline-inject: HWPOISON: Add a madvise()
  injector for soft page offlining (fate#307738).
- patches.arch/x86_mce_page-offline: HWPOISON: Add soft page
  offline support (fate#307738).
- patches.arch/x86_mce_ref-to-flags: HWPOISON: Turn ref argument
  into flags argument (fate#307738).
- patches.arch/x86_mce_shake-page: HWPOISON: Be more aggressive
  at freeing non LRU caches (fate#307738).
- patches.arch/x86_mce_undef-lru: HWPOISON: Undefine short-hand
  macros after use to avoid namespace conflict (fate#307738).
- patches.arch/x86_mce_lru_cleanup.patch: Delete.
- patches.arch/x86_mce_page_offlining.patch: Delete.
- patches.arch/x86_mce_page_offlining_test_ability.patch: Delete.
- patches.arch/x86_mce_test_page.patch: Delete.
* Fri Dec 11 2009 hare@suse.de
- needs_update: Merge or delete remaining patches.
- patches.fixes/scsi-dh-emc-mode-select-10-size: DM-MPIO fails
  to tresspass LUNs on CLARiiON arrays (bnc#484529).
- patches.fixes/scsi-dh-emc-rw-mismatch: Server crashes when
  path failures occur against EMC storage (bnc#474482).
- patches.fixes/scsi-dh-rdac-add-stk: STK arrays missing from
  rdac devicehandler (bnc#503855).
- patches.fixes/scsi-retry-alua-transition-in-progress: I/O
  errors for ALUA state transitions (bnc#491289).
- patches.suse/dm-mpath-no-activate-for-offlined-paths: DM-MPIO
  fails to tresspass LUNs on CLARiiON arrays (bnc#484529).
- patches.suse/dm-mpath-no-partitions-feature: Disable partitions
  scan for multipathed devices (bnc#402922,bnc#514767).
* Fri Dec 11 2009 tiwai@suse.de
- Update config files: set back to CONFIG_SOUND=m
* Fri Dec 11 2009 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-23-hp-mute-led-gpio-fixes:
  ALSA: hda - Fix LED GPIO setup for HP laptops with IDT codecs
  (bnc#547357,bnc#523487).
* Fri Dec 11 2009 jeffm@suse.de
- patches.suse/kdb-usb-rework: Fix ia64.
* Fri Dec 11 2009 jeffm@suse.com
- Update config files: Enable USB_SERIAL_DEBUG.
* Fri Dec 11 2009 jeffm@suse.com
- patches.suse/kdb-usb-rework: kdb: Cleanup KDB_USB.
* Fri Dec 11 2009 jeffm@suse.com
- Update config files.
  - Disabled USB_TEST and USB_LIBUSUAL.
* Thu Dec 10 2009 jeffm@suse.com
- Update config files. Re-enable missing options:
  - CONFIG_FRAMEBUFFER_CONSOLE_ROTATION=y
  - CONFIG_VIDEO_GO7007=m (and related options)
* Thu Dec 10 2009 bphilips@suse.de
- patches.drivers/netxen-0008-reset-sequence-changes.patch:
  Refresh to fix fuzz
* Thu Dec 10 2009 jeffm@suse.com
- Updated KDB to v4.4-2.6.32-3 and re-enabled USB keyboard support.
* Thu Dec 10 2009 mmarek@suse.de
- rpm/kernel-binary.spec.in: Fix vmlinux stripping on power
  (bnc#559547)
* Thu Dec 10 2009 bphilips@suse.de
- patches.drivers/netxen-0000-Use-the-instance-of-net_device_stats-from-net.patch:
  netxen: Use the instance of net_device_stats from
  net_device. (bnc#560003, fate#307134).
- patches.drivers/netxen-0001-remove-sub-64-bit-mem-accesses.patch:
  netxen: remove sub 64-bit mem accesses (bnc#560003,
  fate#307134).
- patches.drivers/netxen-0002-add-access-to-on-chip-memory-for-tools.patch:
  netxen: add access to on chip memory for tools (bnc#560003,
  fate#307134).
- patches.drivers/netxen-0003-annotate-register-windowing-code.patch:
  netxen: annotate register windowing code (bnc#560003,
  fate#307134).
- patches.drivers/netxen-0004-separate-register-and-memory-access-lock.patch:
  netxen: separate register and memory access lock (bnc#560003,
  fate#307134).
- patches.drivers/netxen-0005-add-sysfs-entries-for-diag-tools.patch:
  netxen: add sysfs entries for diag tools (bnc#560003,
  fate#307134).
- patches.drivers/netxen-0006-defines-for-next-revision.patch:
  netxen: defines for next revision (bnc#560003, fate#307134).
- patches.drivers/netxen-0007-128-memory-controller-support.patch:
  netxen: 128 memory controller support (bnc#560003, fate#307134).
- patches.drivers/netxen-0008-reset-sequence-changes.patch:
  netxen: reset sequence changes (bnc#560003, fate#307134).
- patches.drivers/netxen-0009-onchip-memory-access-change.patch:
  netxen: onchip memory access change (bnc#560003, fate#307134).
- patches.drivers/netxen-0010-fix-error-codes-in-for-tools-access.patch:
  netxen: fix error codes in for tools access (bnc#560003,
  fate#307134).
- patches.drivers/netxen-0011-sysfs-control-for-auto-firmware-recovery.patch:
  netxen: sysfs control for auto firmware recovery (bnc#560003,
  fate#307134).
- patches.drivers/netxen-0012-update-version-to-4.0.62.patch:
  netxen; update version to 4.0.62 (bnc#560003, fate#307134).
- patches.drivers/netxen-0013-fix-builds-for-SYSFS-n-or-MODULES-n.patch:
  netxen: fix builds for SYSFS=n or MODULES=n (bnc#560003,
  fate#307134).
- patches.drivers/netxen-0014-support-for-new-firmware-file-format.patch:
  netxen: support for new firmware file format (bnc#560003,
  fate#307134).
- patches.drivers/netxen-0015-refactor-indirect-register-access.patch:
  netxen: refactor indirect register access (bnc#560003,
  fate#307134).
- patches.drivers/netxen-0016-add-PCI-IDs-for-new-chip.patch:
  netxen: add PCI IDs for new chip (bnc#560003, fate#307134).
- patches.drivers/netxen-0017-update-module-info.patch: netxen:
  update module info (bnc#560003, fate#307134).
- patches.drivers/netxen-0018-module-firmware-hints.patch:
  netxen: module firmware hints (bnc#560003, fate#307134).
- patches.drivers/netxen-0019-update-version-to-4.0.65.patch:
  netxen: update version to 4.0.65 (bnc#560003, fate#307134).
- patches.drivers/netxen-0020-remove-PCI-IDs-of-CNA-device.patch:
  netxen: remove PCI IDs of CNA device (bnc#560003, fate#307134).
- patches.drivers/netxen-0021-fix-debug-tools-access-for-NX2031.patch:
  netxen : fix debug tools access for NX2031 (bnc#560003,
  fate#307134).
- patches.drivers/netxen-0022-fix-failure-cases-for-fw-hang-recovery.patch:
  netxen: fix failure cases for fw hang recovery (bnc#560003,
  fate#307134).
* Thu Dec 10 2009 bphilips@suse.de
- patches.drivers/qlge-0001-Use-the-instance-of-net_device_stats-from-net_.patch:
  qlge: Use the instance of net_device_stats from
  net_device. (bnc#560420, FATE#307130).
- patches.drivers/qlge-0002-Remove-explicit-setting-of-PCI-Dev-CTL-reg.patch:
  qlge: Remove explicit setting of PCI Dev CTL reg. (bnc#560420,
  FATE#307130).
- patches.drivers/qlge-0003-Set-PCIE-max-read-request-size.patch:
  qlge: Set PCIE max read request size. (bnc#560420, FATE#307130).
- patches.drivers/qlge-0004-Add-handler-for-DCBX-firmware-event.patch:
  qlge: Add handler for DCBX firmware event. (bnc#560420,
  FATE#307130).
- patches.drivers/qlge-0005-Store-firmware-revision-as-early-as-possible.patch:
  qlge: Store firmware revision as early as possible. (bnc#560420,
  FATE#307130).
- patches.drivers/qlge-0006-Remove-inline-math-for-small-rx-buf-mapping.patch:
  qlge: Remove inline math for small rx buf mapping. (bnc#560420,
  FATE#307130).
- patches.drivers/qlge-0007-Get-rid-of-firmware-handler-debug-code.patch:
  qlge: Get rid of firmware handler debug code. (bnc#560420,
  FATE#307130).
- patches.drivers/qlge-0008-Don-t-fail-open-when-port-is-not-initialized.patch:
  qlge: Don't fail open when port is not initialized. (bnc#560420,
  FATE#307130).
- patches.drivers/qlge-0009-Add-CBFC-pause-frame-counters-to-ethtool-stats.patch:
  qlge: Add CBFC pause frame counters to ethtool
  stats. (bnc#560420, FATE#307130).
- patches.drivers/qlge-0010-Size-RX-buffers-based-on-MTU.patch:
  qlge: Size RX buffers based on MTU. (bnc#560420, FATE#307130).
- patches.drivers/qlge-0011-Add-ethtool-get-set-pause-parameter.patch:
  qlge: Add ethtool get/set pause parameter. (bnc#560420,
  FATE#307130).
- patches.drivers/qlge-0012-Add-ethtool-blink-function.patch:
  qlge: Add ethtool blink function. (bnc#560420, FATE#307130).
- patches.drivers/qlge-0013-Add-ethtool-wake-on-LAN-function.patch:
  qlge: Add ethtool wake on LAN function. (bnc#560420,
  FATE#307130).
- patches.drivers/qlge-0014-Add-ethtool-register-dump-function.patch:
  qlge: Add ethtool register dump function. (bnc#560420,
  FATE#307130).
- patches.drivers/qlge-0015-Add-ethtool-self-test.patch: qlge:
  Add ethtool self-test. (bnc#560420, FATE#307130).
- patches.drivers/qlge-0016-Change-naming-on-vlan-API.patch:
  qlge: Change naming on vlan API. (bnc#560420, FATE#307130).
- patches.drivers/qlge-0017-Fix-indentations.patch: qlge: Fix
  indentations. (bnc#560420, FATE#307130).
- patches.drivers/qlge-0018-Add-firmware-driver-sub-command-support.patch:
  qlge: Add firmware/driver sub-command support. (bnc#560420,
  FATE#307130).
- patches.drivers/qlge-0019-Clean-up-netdev-stats-usage.patch:
  qlge: Clean up netdev->stats usage. (bnc#560420, FATE#307130).
- patches.drivers/qlge-0020-Do-not-change-frame-routing-during-suspend.patch:
  qlge: Do not change frame routing during suspend. (bnc#560420,
  FATE#307130).
- patches.drivers/qlge-0021-Add-asic-reset-to-open-call.patch:
  qlge: Add asic reset to open call. (bnc#560420, FATE#307130).
- patches.drivers/qlge-0022-Clean-up-module-parameter-name.patch:
  qlge: Clean up module parameter name. (bnc#560420, FATE#307130).
- patches.drivers/qlge-0023-Change-version-to-v1.00.00.23.00.00-01.patch:
  qlge: Change version to v1.00.00.23.00.00-01. (bnc#560420,
  FATE#307130).
- patches.drivers/qlge-0024-Bonding-fix-for-mode-6.patch: qlge:
  Bonding fix for mode 6. (bnc#560420, FATE#307130).
- patches.drivers/qlge-0025-Add-performance-change-for-non-split-headers.patch:
  qlge: Add performance change for non-split headers. (bnc#560420,
  FATE#307130).
- patches.drivers/qlge-0026-Add-firmware-core-dump.patch: qlge:
  Add firmware core dump. (bnc#560420, FATE#307130).
* Thu Dec 10 2009 hare@suse.de
- needs_update: Delete more merged fixes.
- patches.suse/dm-mpath-leastpending-path-update: Refresh.
* Thu Dec 10 2009 hare@suse.de
- needs_update: Delete merged driver fixes.
- patches.drivers/megaraid-mbox-fix-SG_IO: megaraid_mbox: Oops
  on SG_IO (bnc#475619).
* Thu Dec 10 2009 duwe@suse.de
- Disable PHYP_DUMP for all PPC flavours, per bnc#541302.
* Thu Dec 10 2009 jbenc@suse.cz
- patches.suse/novfs-fix-debug-message.patch: novfs: fix debug
  message.
* Thu Dec 10 2009 hare@suse.de
- patches.fixes/tehuti-firmware-name: Tehuti network driver
  references wrong firmware (bnc#562092).
* Wed Dec  9 2009 tonyj@suse.de
- patches.suse/audit-export-logging.patch: fix section mismatch due to
  previous checkin
* Wed Dec  9 2009 tonyj@suse.de
- patches.suse/audit-export-logging.patch: export audit logging
  symbols.
* Wed Dec  9 2009 jbohac@suse.cz
- Update config files: added CONFIG_IP_NF_MATCH_IPV4OPTIONS
  to ppc64/trace
* Wed Dec  9 2009 jeffm@suse.com
- patches.fixes/ext4-fix-insufficient-checks-in-ext4_ioc_move_ext:
  ext4: Fix insufficient checks in EXT4_IOC_MOVE_EXT (bnc#561018
  CVE-2009-4131).
* Wed Dec  9 2009 jbeulich@novell.com
- patches.xen/xen3-patch-2.6.32: Fix a potentially serious mis-merge
  in swiotlb code.
* Wed Dec  9 2009 jjolly@suse.de
- patches.fixes/nohz-delay-from-tip.diff: nohz: Introduce
  arch_needs_cpu.
- patches.fixes/reuse-ktime-from-tip.diff: nohz: Reuse ktime in
  sub-functions of tick_check_idle..
- series.conf: Moved s390 patchs to proper place
* Wed Dec  9 2009 npiggin@suse.de
- patches.fixes/ipc-ns-fix-memory-leak-idr.patch: ipc: ns fix
  memory leak (bnc#518767).
- patches.fixes/ipc-remove-unreachable-code-in-semc.patch:
  (bnc#518767).
- patches.fixes/ipc-semc-add-a-per-semaphore-pending-list.patch:
  (bnc#518767).
- patches.fixes/ipc-semc-optimize-if-semops-fail.patch:
  (bnc#518767).
- patches.fixes/ipc-semc-optimize-single-semop-operations.patch:
  (bnc#518767).
- patches.fixes/ipc-semc-optimize-single-sops-when-semval-is-zero.patch:
  (bnc#518767).
- patches.fixes/ipc-semc-sem-optimise-undo-list-search.patch:
  (bnc#518767).
- patches.fixes/ipc-semc-sem-preempt-improve.patch:  (bnc#518767).
- patches.fixes/ipc-semc-sem-use-list-operations.patch:
  (bnc#518767).
* Wed Dec  9 2009 bphilips@suse.de
- needs_update: patches moved upstream or obsoleted by upstream
* Tue Dec  8 2009 mmarek@suse.cz
- patches.suse/kbuild-generate-modules.builtin: Update to what will
  hopefully be in 2.6.33.
- patches.suse/kbuild-rebuild-fix-for-Makefile.modbuiltin: Delete.
* Tue Dec  8 2009 jbohac@suse.cz
- Update config files.
- patches.suse/netfilter-ipv4options: netfilter ipv4options
  match from patch-o-matic-ng (bnc#131728 - FATE#182).
* Tue Dec  8 2009 npiggin@suse.de
- needs_update:
- patches.suse/mm-devzero-optimisation.patch: mm: /dev/zero
  optimisation (bnc#430738).
* Tue Dec  8 2009 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-22-alc888-exclude-unusable-adcs:
  ALSA: hda - Exclude unusable ADCs for ALC88x (bnc#561235).
* Tue Dec  8 2009 mmarek@suse.cz
- patches.drivers/reenable-generic_serial: Revert "tty: Mark
  generic_serial users as BROKEN".
- Update config files: enable RIO and SX.
- rpm/generic_serial-blacklist: blacklist generic_serial users from
  automatic loading (bnc#551348).
* Tue Dec  8 2009 rgoldwyn@suse.de
- needs_update: patches merged upstream
- novfs patches to be handled by novfs team
* Tue Dec  8 2009 npiggin@suse.de
- needs_update:
- patches.suse/mm-vmalloc-fail-dump-stack.patch: mm: improve
  vmalloc reporting (bnc#511079).
* Tue Dec  8 2009 npiggin@suse.de
- needs_update: most of mine are merged. apparmor patch sent to Andreas.
* Tue Dec  8 2009 coly.li@suse.de
- patches.suse/64bytes_lvb_len.diff: use 64byte lvb len.(bnc#515645)
* Tue Dec  8 2009 agraf@suse.de
- patches.arch/s390-kvm-prefix.patch: KVM: s390: Fix prefix
  register checking in arch/s390/kvm/sigp.c (FATE#306513).
- patches.arch/s390-kvm-psw.patch: KVM: s390: Make psw available
  on all exits, not just a subset (FATE#306513).
* Mon Dec  7 2009 tiwai@suse.de
- patches.drivers/synaptics-hp-clickpad: Input: Add support of
  clickpad mode to synaptics mouse driver (bnc#547370).
* Mon Dec  7 2009 jbeulich@novell.com
- Update Xen patches to 2.6.32 final and c/s 958.
- patches.xen/xen-dcdbas: force proper address translation
  in DCDBAS.
- patches.xen&xen-vmalloc_32: guarantee 32-bit
  (bus-)addressability of vmalloc_32() output (bnc#548010,
  bnc#552492).
- patches.xen/xen-x86_64-nx-user-mappings: set NX bit in kernel
  version of top level user mode page table entries.
- patches.xen/xen3-rlim-0025-x86-add-ia32-compat-prlimit-syscalls.patch:
  x86: add ia32 compat prlimit syscalls (FATE#305733).
- patches.xen/xen3-x86-64-align-rodata-kernel-section-to-2mb-with-config_debug_rodata:
  x86-64: align RODATA kernel section to 2MB with
  CONFIG_DEBUG_RODATA (bnc#558249).
- patches.xen/xen3-x86-64-preserve-large-page-mapping-for-1st-2mb-kernel-txt-with-config_debug_rodata:
  x86-64: preserve large page mapping for 1st 2MB kernel txt
  with CONFIG_DEBUG_RODATA (bnc#558249).
- patches.xen/xen3-x86-fix-nodac: x86: fix iommu=nodac parameter
  handling (bnc#463829, bnc#482220).
- patches.xen/xen3-x86-mcp51-no-dac: x86: disallow DAC for MCP51
  PCI bridge (bnc#463829, bnc#482220).
- Update EC2 config files (disable CAN_DEV and UIO).
* Mon Dec  7 2009 jbeulich@novell.com
- patches.arch/x86-crypto-add-ghash-algorithm-test.patch,
  patches.fixes/cpufreq_ondemand_performance_optimise_default_settings.patch:
  Fix build warnings.
* Mon Dec  7 2009 hare@suse.de
- patches.drivers/lpfc-add-raywire-id: Add missing PCI-ID to lpfc.
* Sat Dec  5 2009 tonyj@suse.de
- config.conf: add trace flavor for ppc64 (fate# 307051)
- Update config files.
* Fri Dec  4 2009 jeffm@suse.com
- Split apparmor.diff out into separate patches to align more
  closely with the upstream AppArmor 2.4 repo.
- patches.apparmor/apparmor-fix-cap-audit_caching-preemption-disabling:
  AppArmor: Fix cap audit_caching preemption disabling.
- patches.apparmor/apparmor-fix-change_profile-failing-lpn401931:
  AppArmor: Fix change_profile failing lpn401931.
- patches.apparmor/apparmor-fix-change_profile-failure: AppArmor:
  Fix change_profile failure.
- patches.apparmor/apparmor-fix-determination-of-forced-audit-messages:
  AppArmor: Fix determination of forced AUDIT messages..
- patches.apparmor/apparmor-fix-failure-to-audit-change_hat-correctly:
  AppArmor: fix failure to audit change_hat correctly.
- patches.apparmor/apparmor-fix-file-auditing-when-quiet-is-used:
  AppArmor: Fix file auditing when quiet is used.
- patches.apparmor/apparmor-fix-leak-when-profile-transition-table-fails-unpack:
  AppArmor: Fix leak when profile transition table fails unpack.
- patches.apparmor/apparmor-fix-mediation-of-created-paths-that-look-like-deleted-paths:
  AppArmor: Fix mediation of created paths that look like
  "deleted" paths.
- patches.apparmor/apparmor-fix-oops-after-profile-removal:
  AppArmor: Fix oops after profile removal.
- patches.apparmor/apparmor-fix-oops-when-auditing-the-addition-of-profile-namespace:
  AppArmor: Fix oops when auditing the addition of profile
  namespace.
- patches.apparmor/apparmor-fix-oops-when-in-apparmor_bprm_set_creds:
  AppArmor: Fix Oops when in apparmor_bprm_set_creds.
- patches.apparmor/apparmor-fix-profile-namespace-removal:
  AppArmor: Fix profile namespace removal..
- patches.apparmor/apparmor-fix-refcounting-bug-causing-leak-of-creds-and-oops:
  AppArmor: Fix refcounting bug causing leak of creds and oops.
- patches.apparmor/apparmor-fully-close-race-condition-for-deleted-paths:
  AppArmor: Fully close race condition for deleted paths.
- patches.apparmor/apparmor-missing-unlock: AppArmor: Add missing
  unlock to next_profile.
- patches.apparmor/apparmor-policy-load-and-replacement-can-fail-to-alloc-mem:
  AppArmor: Policy load and replacement can fail to alloc mem.
- patches.apparmor/apparmor-fix-security_ops-task_setrlimit-api-use:
  AppArmor: Fix security_ops->task_setrlimit API use.
* Fri Dec  4 2009 gregkh@suse.de
- Update config files.
- patches.suse/revert-usb-remove-phidget-drivers-from-kernel-tree.patch:
  Revert "USB: remove phidget drivers from kernel tree.".
* Fri Dec  4 2009 jjolly@suse.de
- patches.arch/s390-message-catalog.diff: Updated patch
  (bnc#549193,FATE#306999,LTC#57210).
* Fri Dec  4 2009 mmarek@suse.cz
- supported.conf: Update wireless drivers.
* Fri Dec  4 2009 jjolly@suse.de
- patches.arch/s390-03-qeth-hs-traffic-analyzer.patch: qeth:
  HiperSockets Network Traffic Analyzer (bnc#560674).
* Fri Dec  4 2009 hare@suse.de
- patches.drivers/qla2xxx-8.03.01-k7-update: qla2xxx driver
  update to 8.03.01-k7 (bnc#560415).
* Fri Dec  4 2009 mmarek@suse.cz
- rpm/package-descriptions: Add description for kernel-vmi.
* Fri Dec  4 2009 trenn@suse.de
- patches.arch/x86_mce_lru_cleanup.patch: HWPOISON: Undefine lru
  define after table to avoid namespace conflict (fate#307738).
- patches.arch/x86_mce_page_offlining.patch: Add soft page
  offline support (fate#307738).
- patches.arch/x86_mce_page_offlining_test_ability.patch:
  HWPOISON: Add a madvise() injector for soft page offlining
  (fate#307738).
- patches.arch/x86_mce_test_page.patch: Expose Test pageflagA
  and set pageflagB primitive (fate#307738).
* Fri Dec  4 2009 mmarek@suse.cz
- Add the vmi flavor again.
* Fri Dec  4 2009 sjayaraman@suse.de
- patches.suse/SoN-18-netvm-skbuff-reserve.patch: add emergeny flag
  inside kmemcheck boundaries.
- patches.xen/xen3-auto-common.diff: Refresh.
* Fri Dec  4 2009 gregkh@suse.de
- Update config files.
  CONFIG_DRM_I915_KMS=y for x86-64 and i386 vanilla (bnc#560402)
* Fri Dec  4 2009 gregkh@suse.de
- Update config files.
  CONFIG_DRM_I915_KMS=y for x86-64 (bnc#560402)
* Fri Dec  4 2009 gregkh@suse.de
- Update config files.
  CONFIG_DRM_I915_KMS=y for i386 (bnc#560402)
* Thu Dec  3 2009 jeffm@suse.com
- patches.arch/ppc-spufs-07-Don-t-spu_acquire_saved-unnecessarily.patch:
  Delete. (bnc#560043)
* Thu Dec  3 2009 jeffm@suse.com
- Cleanup config files.
* Thu Dec  3 2009 bphilips@suse.de
- patches.drivers/tg3_libphy_workaround: Delete. We have all of the 57780
  phylib and tg3 changes due to 2.6.32 bump.
* Thu Dec  3 2009 duwe@suse.de
- back out cpuidle feature that is still unconsistent.
* Thu Dec  3 2009 mfasheh@suse.com
- patches.suse/ocfs2-allocation-resrvations.patch: Refresh.
* Thu Dec  3 2009 duwe@suse.de
- patches.suse/cpuidle-cleanup: Refresh.
  Fix the "fixed" feature patch set from IBM.
* Thu Dec  3 2009 mfasheh@suse.com
- Update config files.
- patches.suse/gfs2-ro-mounts-only.patch: gfs2: allow spectator
  mounts for migration to ocfs2 (FATE#307584).
* Thu Dec  3 2009 duwe@suse.de
- Update config files for 2.6.32 (again).
* Thu Dec  3 2009 duwe@suse.de
- Update config files for cpuidle.
* Thu Dec  3 2009 tiwai@suse.de
- patches.drivers/8250_pnp-wacom-add: serial/8250_pnp.c: add
  new Wacom devices (bnc#544763).
* Thu Dec  3 2009 duwe@suse.de
- patches.suse/cpuidle-cleanup: Refresh.
  one lonely hunk already seems to be in 2.6.32 final
* Thu Dec  3 2009 duwe@suse.de
- bnc#552860 / FATE#307104: kernel idle low power, take 2:
- patches.suse/cpuidle-cleanup: Refresh.
- patches.suse/cpuidle-cleanup-x86: Refresh.
- patches.suse/cpuidle-eliminate-ppcmdpowersave1: Refresh.
* Thu Dec  3 2009 jeffm@suse.com
- Updated to 2.6.32-final.
  - 2 patches eliminated.
* Thu Dec  3 2009 hare@suse.de
- Update config files: Enable Hibernation for zSeries.
* Thu Dec  3 2009 mmarek@suse.cz
- Update config files: Disable CONFIG_MFD_PCF50633, the chip is
  unlikely to be used on architectures we support.
* Thu Dec  3 2009 mmarek@suse.cz
- rpm/split-modules: Print which supported modules need unsupported
  modules.
* Thu Dec  3 2009 jdelvare@suse.de
- supported.conf: support lis3lv02d, hp_accel needs it.
* Thu Dec  3 2009 jdelvare@suse.de
- supported.conf: hp_accel is supported (FATE #306448).
* Thu Dec  3 2009 jdelvare@suse.de
- supported.conf: remove wm831x drivers, we no longer ship them.
* Thu Dec  3 2009 jdelvare@suse.de
- Update config files: disable all new hwmon drivers on ppc
  (default and vanilla) for consistency.
* Thu Dec  3 2009 mmarek@suse.cz
- supported.conf: Add wm831x, needed by drivers/input/misc/wm831x-on.
* Thu Dec  3 2009 mmarek@suse.cz
- supported.conf: Fix up after commit bfea0bd.
* Thu Dec  3 2009 jdelvare@suse.de
- Update config files: disable WM831x and WM8350 support entirely,
  as recommended by the drivers author. These devices are only
  found on embedded devices such as music players or mobile phones.
* Thu Dec  3 2009 hare@suse.de
- supported.conf: Mark pmcraid and igbvf as supported;
  OSD drivers as unsupported.
* Thu Dec  3 2009 jdelvare@suse.de
- Restore link from config/s390/vanilla to config/s390x/vanilla.
* Thu Dec  3 2009 jbeulich@novell.com
- supported.conf: Update Xen drivers.
* Thu Dec  3 2009 tonyj@suse.de
- needs_update: readd
  patches.suse/perfmon2-remove_get_base_syscall_attr.patch
  patches.suse/perfmon2-remove_syscalls.patch
* Thu Dec  3 2009 gregkh@suse.de
- rpm/post.sh:
- rpm/postun.sh: woh dluoc I tegrof ot esolc eht fi
* Thu Dec  3 2009 gregkh@suse.de
- rpm/post.sh:
- rpm/postun.sh: If this is a Moblin-based box, don't run yast-bootloader
* Thu Dec  3 2009 jdelvare@suse.de
- Update config files: stop shipping wm831x-hwmon, wm8350-hwmon,
  i2c-simtec and i2c-designware.
- supported.conf: remove i2c-simtec.
* Wed Dec  2 2009 jdelvare@suse.de
- supported.conf: Add all new hwmon and i2c/busses drivers. The
  former unsupported, the latter supported.
* Wed Dec  2 2009 jdelvare@suse.de
- Update config files: disable CONFIG_I2C_VOODOO3.
- supported.conf: drop i2c-voodoo3, superseded by tdfxfb.
* Wed Dec  2 2009 jdelvare@suse.de
- supported.conf: Drop hwmon and i2c/chips drivers which have been
  obsoleted.
* Wed Dec  2 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Obsolete perfmon-kmp.
* Wed Dec  2 2009 mmarek@suse.cz
- supported.conf: Add perfmon, hid and input modules.
* Wed Dec  2 2009 tiwai@suse.de
- Update config files: Fix vanilla configs
* Wed Dec  2 2009 tiwai@suse.de
- Update config files: disabled CONFIG_SND_SOC* in ppc configs.
* Wed Dec  2 2009 tiwai@suse.de
- Updated the sound section of supported.conf
* Wed Dec  2 2009 gregkh@suse.de
- Update config files. disable USB OTG drivers that should not
  have been enabled.
* Wed Dec  2 2009 gregkh@suse.de
- supported.conf: remove some usb drivers that were deleted or renamed.
* Wed Dec  2 2009 gregkh@suse.de
- supported.conf: update usb driver section
* Wed Dec  2 2009 mmarek@suse.cz
- rpm/check-supported-list: Skip modules in Documentation and
  drivers/staging.
* Wed Dec  2 2009 jbenc@suse.cz
- patches.fixes/mac80211-fix-remote-DoS.patch: mac80211: fix
  remote DoS (bnc#558267).
* Tue Dec  1 2009 tiwai@suse.de
- Forward-port 11.2 patches:
  patches.drivers/alsa-sp1-hda-18-msi-wind-u115-fix: ALSA: hda -
    Add a position_fix quirk for MSI Wind U115.
  patches.drivers/alsa-sp1-hda-19-cx5047-test-mode-fix: ALSA:
    hda - Fix Cxt5047 test mode (bnc#559062).
  patches.drivers/alsa-sp1-hda-20-fsc-amilo-pi1505-fix: ALSA:
    hda - Add a pin-fix for FSC Amilo Pi1505 (bnc#557403).
  patches.drivers/alsa-sp1-hda-21-hp-dv3-position-fix-quirk:
    ALSA: hda - Add position_fix quirk for HP dv3 (bnc#555935).
* Tue Dec  1 2009 jeffm@suse.com
- patches.fixes/megaraid_sas-fix-permissions-on-poll_mode_io:
  megaraid_sas: Fix permissions on poll_mode_io (bnc#557180
  CVE-2009-3939).
* Tue Dec  1 2009 jeffm@suse.com
- patches.arch/x86-64-add-comment-for-rodata-large-page-retainment:
  x86-64: add comment for RODATA large page retainment
  (bnc#558249).
- patches.arch/x86-64-align-rodata-kernel-section-to-2mb-with-config_debug_rodata:
  x86-64: align RODATA kernel section to 2MB with
  CONFIG_DEBUG_RODATA (bnc#558249).
- patches.arch/x86-64-preserve-large-page-mapping-for-1st-2mb-kernel-txt-with-config_debug_rodata:
  x86-64: preserve large page mapping for 1st 2MB kernel txt
  with CONFIG_DEBUG_RODATA (bnc#558249).
* Mon Nov 30 2009 teheo@suse.de
- needs_update: drop libata patches which are already included in
  2.6.31 vanilla.
* Mon Nov 30 2009 teheo@suse.de
- needs_update: drop patches which are already included in 2.6.31
  vanilla.
* Mon Nov 30 2009 teheo@suse.de
  Forward port two x86 patches from SLE11.
- needs_update:
- patches.arch/x86-fix-nodac: x86: fix iommu=nodac parameter
  handling (bnc#463829).
- patches.arch/x86-mcp51-no-dac: x86: disallow DAC for MCP51
  PCI bridge (bnc#463829).
* Mon Nov 30 2009 agraf@suse.de
- Update config files: Enable KSM (FATE#306513)
* Sat Nov 28 2009 gregkh@suse.de
- needs_update: acpi dock patch was hmacht's, not mine
* Sat Nov 28 2009 gregkh@suse.de
- needs_update: sysfs debugging crash patch is now upstream
* Sat Nov 28 2009 gregkh@suse.de
- needs_update: jeffm merged novfs patches into the main novfs patch.
* Sat Nov 28 2009 gregkh@suse.de
- needs_update: qualcomm modem driver is upstream
* Sat Nov 28 2009 gregkh@suse.de
- needs_update: squashfs is now upstream
* Sat Nov 28 2009 gregkh@suse.de
- needs_update: via driver bugfixes never went upstream, and people
  are complaining about them, so they were dropped.
* Sat Nov 28 2009 gregkh@suse.de
- needs_update: remove staging driver entries, they are all upstream.
* Sat Nov 28 2009 gregkh@suse.de
- needs_update: remove hv driver entries, those are upstream now.
* Sat Nov 28 2009 gregkh@suse.de
- needs_update: remove xen patches with my name on it.  Just because
  I refreshed the patch, doesn't mean I own it or even like the
  thing :)
* Sat Nov 28 2009 sjayaraman@suse.de
- patches.suse/SoN-11-mm-reserve.patch: Fix build errors in -trace
  and ppc64 flavors.
* Fri Nov 27 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Abort if supported modules depend on
  unsupported ones.
* Fri Nov 27 2009 mmarek@suse.cz
- supported.conf: mark cnic as supported (needed by bnx2i).
* Fri Nov 27 2009 jbenc@suse.cz
- patches.suse/panic-on-io-nmi-SLE11-user-space-api.patch: API
  fix: X86: sysctl to allow panic on IOCK NMI error (bnc#427979).
- patches.suse/kdb-common: Refresh.
- patches.suse/kdump-dump_after_notifier.patch: Refresh.
* Fri Nov 27 2009 jbohac@suse.cz
- patches.fixes/cpufreq_ondemand_performance_optimise_default_settings.patch:
  CPUFREQ: ondemand: Limit default sampling rate to 300ms
  max. (bnc#464461).
* Fri Nov 27 2009 trenn@suse.de
- needs_update:
  One I still have to send upstream, but it's nicer error output
  only, SP1 is fine in respect to removing all these, thanks.
* Fri Nov 27 2009 hare@suse.de
- Update config files: Compile in efivars module for
  x86_64 (FATE#306931).
* Fri Nov 27 2009 sjayaraman@suse.de
- needs_update:	sjayaraman's patches are either upstream already or
  rebased to SP1.
* Fri Nov 27 2009 sjayaraman@suse.de
- Update config files: NFS_SWAP=y.
* Fri Nov 27 2009 sjayaraman@suse.de
- patches.trace/lttng-instrumentation-swap.patch: Refresh and fix
  a build failure with fuzz factor 0.
* Fri Nov 27 2009 sjayaraman@suse.de
- Rebase Swap-over-NFS(SoN) patches:
- patches.xen/tmem: Refresh to accomodate changes due to SoN patches.
- patches.xen/xen3-auto-common.diff: Refresh to accomodate changes
  due to SoN patches.
* Fri Nov 27 2009 knikanth@suse.de
- needs_update: Verify knikanth's patches in SLE11 but not in SP1
- patches.fixes/dm-release-map_lock-before-set_disk_ro: Release
  md->map_lock before set_disk_ro  (bnc#556899 bnc#479784).
* Fri Nov 27 2009 nfbrown@suse.de
- Restore following patches from SLES11 that are still needed for
  SLES11-SP1
- patches.fixes/nfsd-05-sunrpc-cache-allow-thread-to-block-while-waiting-for.patch:
  sunrpc/cache: allow thread to block while waiting for cache
  update. (bnc#498708).
- patches.fixes/nfsd-06-sunrpc-cache-retry-cache-lookups-that-return-ETIMEDO.patch:
  sunrpc/cache: retry cache lookups that return -ETIMEDOUT
  (bnc#498708).
- patches.fixes/nfsd-07-nfsd-idmap-drop-special-request-deferal-in-favour-of.patch:
  nfsd/idmap: drop special request deferal in favour of improved
  default. (bnc#498708).
- patches.fixes/nfsd-09-fix-kabi: Fix kabi breakage in previous
  nfsd patch series (bnc#498708).
* Thu Nov 26 2009 coly.li@suse.de
- needs_update: remove patches item of coly.li, lmb and mfasheh.
- patches.fixes/dlm-enable-debug.patch: update the patch from SLES11
  to SLES11 SP1 tree.
* Thu Nov 26 2009 jslaby@suse.cz
- patches.fixes/make-note_interrupt-fast.diff: Fix performance
  regression on large IA64 systems (bnc #469589).
* Thu Nov 26 2009 mmarek@suse.cz
- rpm/old-packages.conf: obsolete kernel-kdump on ppc.
- config.conf: delete kdump configs.
- config/ppc/kdump: Delete.
- config/ppc64/kdump: Delete.
* Thu Nov 26 2009 duwe@suse.de
- patches.arch/ppc-extended_h_cede-Export_memory_sysdev_class:
  Refresh. Fix "typo", memory_sysdev_class should be exported
  only to GPL'ed modules.
* Thu Nov 26 2009 hare@suse.de
  Fixup patches for series2git:
- patches.xen/tmem: Refresh.
- patches.xen/xen3-auto-common.diff: Refresh.
* Thu Nov 26 2009 duwe@suse.de
- config.conf: disable build of ppc kdump flavours
  (FATE#304346)
* Thu Nov 26 2009 tiwai@suse.de
- patches.drivers/libata-missing-_SDD-is-not-an-error:
  libata-acpi: missing _SDD is not an error (bnc#551942).
* Thu Nov 26 2009 jbenc@suse.cz
- patches.fixes/mac80211-fix-spurious-delba-handling.patch:
  mac80211: fix spurious delBA handling (bnc#558267,
  CVE-2009-4026, CVE-2009-4027).
* Thu Nov 26 2009 tiwai@suse.de
- patches.drivers/sky2-add-register-definitions: sky2: add
  register definitions for new chips (bnc#544760).
- patches.drivers/sky2-88E8059-support: sky2: 88E8059 support
  (bnc#544760).
- patches.drivers/sky2-optima-tcp-offload-fix: net: Fix Yukon-2
  Optima TCP offload setup (bnc#544760).
- patches.drivers/sky2-optima-fix-pci-cfg: net: Add missing
  TST_CFG_WRITE bits around sky2_pci_write (bnc#544760).
* Thu Nov 26 2009 nfbrown@suse.de
- Update config files.
  disable CONFIG_MULTICOE_RAID456 as it is not yet stable.
  Enable CONFIG_ASYNC_TX_DMA for FATE#306368
* Thu Nov 26 2009 gregkh@suse.de
- clean up patch fuzz
* Thu Nov 26 2009 gregkh@suse.de
- patches.drivers/via-unichrome-drm-bugfixes.patch: Delete.
  it never went upstream, so we should drop it as well.
* Thu Nov 26 2009 tonyj@suse.de
- patches.trace/lttng-*: update for 2.6.32
- patches.trace/lttng-instrumentation-timer.patch: Delete.
- patches.xen/tmem: Refresh.
- patches.xen/xen3-auto-common.diff: Refresh.
* Thu Nov 26 2009 tonyj@suse.de
- patches.fixes/oprofile_bios_ctr.patch: detect oprofile counters
  reserved by bios (FATE#307426).
* Wed Nov 25 2009 jeffm@suse.com
- patches.fixes/netfilter-remove-pointless-config_nf_ct_acct-warning:
  netfilter: Remove pointless CONFIG_NF_CT_ACCT warning
  (bnc#552033 (and others)).
* Tue Nov 24 2009 hare@suse.de
- Update config files.
- patches.drivers/mpt-fusion-4.22.00.00-update: Update MPT Fusion
  driver to 4.22.00.00-suse (bnc#556587).
- patches.drivers/mpt-fusion-4.16.00.00-update: Delete.
* Tue Nov 24 2009 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-17-fix-mute-LED-sync-idt92h383xxx:
  ALSA: hda - Fix mute-LED sync on HP laptops with IDT92HD83xxx
  codecs (bnc#547357).
* Tue Nov 24 2009 duwe@suse.de
- patches.arch/ppc-extended_h_cede-*: Increase power savings
  by allowing the core to sleep.
  (FATE##307059, bnc#550447)
* Tue Nov 24 2009 sjayaraman@suse.de
- patches.suse/kconfig-automate-kernel-desktop: automate a few config
  options for kernel-desktop (FATE#305694).
* Tue Nov 24 2009 agraf@suse.de
- patches.arch/kvm-only-export-selected-pv-ops-feature-structs:
  Update references (bnc#556135, FATE#306453).
- patches.arch/kvm-replace-kvm-io-delay-pv-ops-with-linux-magic:
  Update references (bnc#556135, FATE#306453).
- patches.arch/kvm-split-paravirt-ops-by-functionality: Update
  references (bnc#556135, FATE#306453).
- patches.arch/kvm-split-the-KVM-pv-ops-support-by-feature:
  Update references (bnc#556135, FATE#306453).
* Mon Nov 23 2009 jeffm@suse.com
- Enabled:
  patches.fixes/enclosure-fix-oops-while-iterating-enclosure_status-array
* Mon Nov 23 2009 jkosina@suse.de
- patches.arch/x86-crypto-add-ghash-algorithm-test.patch: crypto:
  Add ghash algorithm test before provide to users (FATE#306883,
  bnc#554578).
* Mon Nov 23 2009 jkosina@suse.de
- patches.arch/x86-crypto-pclmulqdq-accelerated-implementation.patch:
  incorporate "ghash - put proper .data section in place" fix
* Mon Nov 23 2009 sjayaraman@suse.de
- Update config files.
  - Add new options KERNEL_DESKTOP and DEFAULT_VM_DIRTY_RATIO.
  - Enable KERNEL_DESKTOP for only desktop flavor.
* Mon Nov 23 2009 sjayaraman@suse.de
- patches.suse/mm-tune-dirty-limits.patch: mm: Make default
  VM dirty ratio configurable to suit different workloads
  (bnc#552883).
* Fri Nov 20 2009 mmarek@suse.cz
- rpm/kernel-syms.spec.in, rpm/mkspec: build kernel-syms only for
  supported architectures.
* Fri Nov 20 2009 jeffm@suse.com
- Enabled B43_PHY_LP=y for PHY support on certain b43 chips.
* Fri Nov 20 2009 mmarek@suse.cz
- patches.suse/export-sync_page_range: Revert "vfs: Remove
  generic_osync_inode() and sync_page_range{_nolock}()"
  (bnc#557231).
* Fri Nov 20 2009 jbeulich@novell.com
- patches.suse/init-move-populate_rootfs-back-to-start_kernel:
  Fix a bad-pointer warning.
* Fri Nov 20 2009 agruen@suse.de
- rpm/macros.kernel-source: Add kernel_module_package_moddir()
  macro for cross-distro compatibility (FATE 305225).
* Fri Nov 20 2009 jslaby@suse.cz
- patches.suse/rlim-0001-SECURITY-selinux-fix-update_rlimit_cpu-parameter.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0002-SECURITY-add-task_struct-to-setrlimit.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0003-core-add-task_struct-to-update_rlimit_cpu.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0004-sys_setrlimit-make-sure-rlim_max-never-grows.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0005-core-split-sys_setrlimit.patch: Update
  references (FATE#305733).
- patches.suse/rlim-0006-core-allow-setrlimit-to-non-current-tasks.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0007-core-optimize-setrlimit-for-current-task.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0008-FS-proc-make-limits-writable.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0009-core-posix-cpu-timers-cleanup-rlimits-usage.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0010-core-do-security-check-under-task_lock.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0011-resource-add-helpers-for-fetching-rlimits.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0012-IA64-use-helpers-for-rlimits.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0013-PPC-use-helpers-for-rlimits.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0014-S390-use-helpers-for-rlimits.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0015-SPARC-use-helpers-for-rlimits.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0016-X86-use-helpers-for-rlimits.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0017-FS-use-helpers-for-rlimits.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0018-MM-use-helpers-for-rlimits.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0019-core-use-helpers-for-rlimits.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0020-misc-use-helpers-for-rlimits.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0021-core-rename-setrlimit-to-do_setrlimit.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0022-core-implement-getprlimit-and-setprlimit-syscalls.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0023-unistd-add-__NR_-get-set-prlimit-syscall-numbers.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0024-COMPAT-add-get-put_compat_rlimit.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0025-x86-add-ia32-compat-prlimit-syscalls.patch:
  Update references (FATE#305733).
* Fri Nov 20 2009 jslaby@suse.cz
- Add writable resource limits support
- patches.suse/perfmon2.patch: Refresh.
- patches.suse/rlim-0001-SECURITY-selinux-fix-update_rlimit_cpu-parameter.patch:
  SECURITY: selinux, fix update_rlimit_cpu parameter.
- patches.suse/rlim-0002-SECURITY-add-task_struct-to-setrlimit.patch:
  SECURITY: add task_struct to setrlimit.
- patches.suse/rlim-0003-core-add-task_struct-to-update_rlimit_cpu.patch:
  core: add task_struct to update_rlimit_cpu.
- patches.suse/rlim-0004-sys_setrlimit-make-sure-rlim_max-never-grows.patch:
  sys_setrlimit: make sure ->rlim_max never grows.
- patches.suse/rlim-0005-core-split-sys_setrlimit.patch: core:
  split sys_setrlimit.
- patches.suse/rlim-0006-core-allow-setrlimit-to-non-current-tasks.patch:
  core: allow setrlimit to non-current tasks.
- patches.suse/rlim-0007-core-optimize-setrlimit-for-current-task.patch:
  core: optimize setrlimit for current task.
- patches.suse/rlim-0008-FS-proc-make-limits-writable.patch:
  FS: proc, make limits writable.
- patches.suse/rlim-0009-core-posix-cpu-timers-cleanup-rlimits-usage.patch:
  core: posix-cpu-timers, cleanup rlimits usage.
- patches.suse/rlim-0010-core-do-security-check-under-task_lock.patch:
  core: do security check under task_lock.
- patches.suse/rlim-0011-resource-add-helpers-for-fetching-rlimits.patch:
  resource: add helpers for fetching rlimits.
- patches.suse/rlim-0012-IA64-use-helpers-for-rlimits.patch:
  IA64: use helpers for rlimits.
- patches.suse/rlim-0013-PPC-use-helpers-for-rlimits.patch: PPC:
  use helpers for rlimits.
- patches.suse/rlim-0014-S390-use-helpers-for-rlimits.patch:
  S390: use helpers for rlimits.
- patches.suse/rlim-0015-SPARC-use-helpers-for-rlimits.patch:
  SPARC: use helpers for rlimits.
- patches.suse/rlim-0016-X86-use-helpers-for-rlimits.patch: X86:
  use helpers for rlimits.
- patches.suse/rlim-0017-FS-use-helpers-for-rlimits.patch: FS:
  use helpers for rlimits.
- patches.suse/rlim-0018-MM-use-helpers-for-rlimits.patch: MM:
  use helpers for rlimits.
- patches.suse/rlim-0019-core-use-helpers-for-rlimits.patch:
  core: use helpers for rlimits.
- patches.suse/rlim-0020-misc-use-helpers-for-rlimits.patch:
  misc: use helpers for rlimits.
- patches.suse/rlim-0021-core-rename-setrlimit-to-do_setrlimit.patch:
  core: rename setrlimit to do_setrlimit.
- patches.suse/rlim-0022-core-implement-getprlimit-and-setprlimit-syscalls.patch:
  core: implement getprlimit and setprlimit syscalls.
- patches.suse/rlim-0023-unistd-add-__NR_-get-set-prlimit-syscall-numbers.patch:
  unistd: add __NR_[get|set]prlimit syscall numbers.
- patches.suse/rlim-0024-COMPAT-add-get-put_compat_rlimit.patch:
  COMPAT: add get/put_compat_rlimit.
- patches.suse/rlim-0025-x86-add-ia32-compat-prlimit-syscalls.patch:
  x86: add ia32 compat prlimit syscalls.
* Fri Nov 20 2009 bphilips@suse.de
- patches.drivers/phy-broadcom-bug-fixes-for-sp1.patch:
  phy/broadcom: bug fixes for SP1 (FATE#307117, bnc#556234).
- patches.drivers/tg3-update-version-to-3.104.patch: tg3: Update
  version to 3.104 (bnc#556234, FATE#307117).
* Fri Nov 20 2009 bphilips@suse.de
- patches.drivers/phy-broadcom-bug-fixes-for-sp1.patch:
  phy/broadcom: bug fixes for SP1 (FATE#307117, bnc#556234).
- patches.drivers/tg3-update-version-to-3.104.patch: tg3: Update
  version to 3.104 (bnc#556234, FATE#307117).
* Fri Nov 20 2009 hare@suse.de
- patches.drivers/megaraid-04.12-update: megaraid: Update
  megaraid_sas to version 04.12 (FATE#307125).
* Fri Nov 20 2009 bphilips@suse.de
- patches.drivers/bnx2-entropy-source.patch: bnx2: entropy source
  (FATE#307517).
- patches.drivers/e1000-entropy-source.patch: Enable e1000 as
  entropy source (disabled by default) (FATE#307517).
- patches.drivers/e1000e-entropy-source.patch: Enable e1000e as
  entropy source (disabled by default) (FATE#307517).
- patches.drivers/igb-entropy-source.patch: Enable igb as entropy
  source (disabled by default) (FATE#307517).
- patches.drivers/ixgbe-entropy-source.patch: Enable ixgbe as
  entropy source (disabled by default) (FATE#307517).
- patches.drivers/tg3-entropy-source.patch: tg3: entropy source
  (FATE#307517).
* Fri Nov 20 2009 hare@suse.de
- patches.fixes/scsi-fix-bug-with-dma-maps-on-nested-scsi-objects:
  scsi_lib_dma: fix bug with dma maps on nested scsi objects
  (bnc#556595).
- patches.fixes/scsi-introduce-helper-function-for-blocking-eh:
  scsi_transport_fc: Introduce helper function for blocking
  scsi_eh (bnc#556595).
- patches.fixes/scsi-skip-nonscsi-device-for-dma: Delete.
* Fri Nov 20 2009 hare@suse.de
  Whitespace cleanup for series2git:
- patches.arch/s390-message-catalog.diff: Refresh.
- patches.drivers/aacraid-24701-update: Refresh.
- patches.suse/crasher-26.diff: Refresh.
- patches.suse/kdb-common: Refresh.
- patches.suse/kdb-ia64: Refresh.
- patches.suse/kdb-x86: Refresh.
- patches.suse/ocfs2-allocation-resrvations.patch: Refresh.
- patches.suse/perfmon2.patch: Refresh.
- patches.suse/perfmon2_ioctl.patch: Refresh.
- patches.suse/stack-unwind: Refresh.
* Fri Nov 20 2009 bphilips@suse.de
- patches.drivers/igb-add-support-for-82576NS-SerDes-adapter.patch:
  igb: add support for 82576NS SerDes adapter (FATE#306856).
* Fri Nov 20 2009 jbeulich@novell.com
- patches.suse/dm-mpath-evaluate-request-result-and-sense:
  Fix for !CONFIG_SCSI (in -ec2).
* Fri Nov 20 2009 mfasheh@suse.com
- patches.suse/ocfs2-allocation-resrvations.patch: ocfs2:
  allocation reservations (bnc#501563 FATE#307247).
* Fri Nov 20 2009 jjolly@suse.de
- patches.suse/perfmon2.patch: Refresh.
- patches.arch/x86-self-ptrace.patch: Delete. (bnc#554585,LTC#57794)
- patches.suse/self-ptrace.patch: Delete. (bnc#554585,LTC#57794)
* Fri Nov 20 2009 jeffm@suse.com
- Update to 2.6.32-rc8.
  - Eliminated 1 patch.
* Fri Nov 20 2009 jeffm@suse.de
- patches.fixes/enclosure-fix-oops-while-iterating-enclosure_status-array:
  enclosure: fix oops while iterating enclosure_status array
  (bnc#540997).
* Thu Nov 19 2009 tonyj@suse.de
- Update config files.
- patches.suse/perfmon2.patch: perfmon2 (FATE#303968).
- patches.suse/perfmon2_ioctl.patch: switch to ioctl interface
  for perfmon2.
- patches.suse/perfmon2_noutrace.patch: remove UTRACE code
  from perfmon2.
- patches.xen/xen3-patch-2.6.28: Refresh.
* Thu Nov 19 2009 jjolly@suse.de
- Update config files.
- patches.arch/s390-message-catalog.diff: Kernel message
  catalog. (bnc#549193,LTC#57210,FATE#306999).
- rpm/kernel-binary.spec.in:
* Thu Nov 19 2009 jbohac@suse.cz
- patches.suse/add-queue_depth-ramp-up-code.patch: add queue_depth
  ramp up code (fate#306857, fate#306859, bnc#551175).
- patches.suse/fcoe-add-a-separate-scsi-transport-template-for-npiv-vports.patch:
  fcoe: add a separate scsi transport template for NPIV vports
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/fcoe-add-check-to-fail-gracefully-in-bonding-mode.patch:
  fcoe: add check to fail gracefully in bonding mode (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/fcoe-call-ndo_fcoe_enable-disable-to-turn-fcoe-feature-on-off-in-lld.patch:
  fcoe: Call ndo_fcoe_enable/disable to turn FCoE feature on/off
  in LLD (fate#306857, fate#306859, bnc#551175).
- patches.suse/fcoe-fix-checking-san-mac-address.patch: fcoe: Fix
  checking san mac address (fate#306857, fate#306859, bnc#551175).
- patches.suse/fcoe-fix-getting-san-mac-for-vlan-interface.patch:
  fcoe: Fix getting san mac for VLAN interface (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/fcoe-fix-setting-lport-s-wwnn-wwpn-to-use-san-mac-address.patch:
  fcoe: Fix setting lport's WWNN/WWPN to use san mac address
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/fcoe-fix-using-vlan-id-in-creating-lport-s-wwwn-wwpn.patch:
  fcoe: Fix using VLAN ID in creating lport's WWWN/WWPN
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/fcoe-formatting-cleanups-and-commenting.patch:
  fcoe: Formatting cleanups and commenting (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/fcoe-increase-fcoe_max_lun-to-0xffff-65535.patch:
  fcoe: Increase FCOE_MAX_LUN to 0xFFFF (65535) (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/fcoe-initialize-return-value-in-fcoe_destroy.patch:
  fcoe: initialize return value in fcoe_destroy (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/fcoe-libfc-fix-an-libfc-issue-with-queue-ramp-down-in-libfc.patch:
  fcoe, libfc: fix an libfc issue with queue ramp down in libfc
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/fcoe-libfc-use-single-frame-allocation-api.patch:
  fcoe, libfc: use single frame allocation API (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/fcoe-npiv-vport-create-destroy.patch: fcoe: NPIV
  vport create/destroy (fate#306857, fate#306859, bnc#551175).
- patches.suse/fcoe-remove-extra-function-decalrations.patch:
  fcoe: remove extra function decalrations (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/fcoe-remove-redundant-checking-of-netdev-netdev_ops.patch:
  fcoe: remove redundant checking of netdev->netdev_ops
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/fcoe-use-netif_f_fcoe_mtu-flag-to-set-up-max-frame-size-lport-mfs.patch:
  fcoe: Use NETIF_F_FCOE_MTU flag to set up max frame size
  (lport->mfs) (fate#306857, fate#306859, bnc#551175).
- patches.suse/fcoe-vport-symbolic-name-support.patch: fcoe: vport
  symbolic name support (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-add-host-number-to-lport-link-up-down-messages.patch:
  libfc: add host number to lport link up/down
  messages. (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-add-libfc-fc_libfc-ch-for-libfc-internal-routines.patch:
  libfc: Add libfc/fc_libfc.[ch] for libfc internal routines
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-add-queue_depth-ramp-up.patch: libfc:
  add queue_depth ramp up (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-add-routine-to-copy-data-from-a-buffer-to-a-sg-list.patch:
  libfc: Add routine to copy data from a buffer to a SG list
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-add-set_fid-function-to-libfc-template.patch:
  libfc: add set_fid function to libfc template (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/libfc-add-some-generic-npiv-support-routines-to-libfc.patch:
  libfc: add some generic NPIV support routines to libfc
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-adds-can_queue-ramp-up.patch: libfc: adds
  can_queue ramp up (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-adds-missing-exch-release-for-accepted-rrq.patch:
  libfc: adds missing exch release for accepted RRQ (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/libfc-changes-to-libfc_host_alloc-to-consolidate-initialization-with-allocation.patch:
  libfc: changes to libfc_host_alloc to consolidate initialization
  with allocation (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-combine-name-server-registration-request-functions.patch:
  libfc: combine name server registration request functions
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-combine-name-server-registration-response-handlers.patch:
  libfc: combine name server registration response handlers
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-convert-to-scsi_track_queue_full.patch:
  libfc: convert to scsi_track_queue_full (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/libfc-do-not-use-did_no_connect-for-pkt-alloc-failures.patch:
  libfc: do not use DID_NO_CONNECT for pkt alloc
  failures. (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-don-t-warn_on-in-lport_timeout-for-reset-state.patch:
  libfc: don't WARN_ON in lport_timeout for RESET state
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-export-fc-headers.patch: libfc: Export FC
  headers (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-fcoe-add-fc-passthrough-support.patch: libfc,
  fcoe: Add FC passthrough support (fate#306857, fate#306859,
  bnc#551175).
- patches.suse/libfc-fcoe-don-t-export_symbols-unnecessarily.patch:
  libfc, fcoe: Don't EXPORT_SYMBOLS unnecessarily (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/libfc-fcoe-fixes-for-highmem-skb-linearize-panics.patch:
  libfc, fcoe: fixes for highmem skb linearize panics
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-fcoe-increase-els-and-ct-timeouts.patch:
  libfc fcoe: increase ELS and CT timeouts (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/libfc-fix-an-issue-of-pending-exch-es-after-i-f-destroyed-or-rmmod-fcoe.patch:
  libfc: fix an issue of pending exch/es after i/f destroyed or
  rmmod fcoe (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-fix-ddp-in-fc_fcp-for-0-xid.patch: libfc: fix
  ddp in fc_fcp for 0 xid (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-fix-fc_els_resp_type-to-correct-display-of-ct-responses.patch:
  libfc: fix fc_els_resp_type to correct display of CT responses
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-fix-frags-in-frame-exceeding-skb_max_frags-in-fc_fcp_send_data.patch:
  libfc: Fix frags in frame exceeding SKB_MAX_FRAGS in
  fc_fcp_send_data (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-fix-free-of-fc_rport_priv-with-timer-pending.patch:
  libfc: fix free of fc_rport_priv with timer pending
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-fix-memory-corruption-caused-by-double-frees-and-bad-error-handling.patch:
  libfc: fix memory corruption caused by double frees and bad
  error handling (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-fix-rnn_id-smashing-skb-payload.patch: libfc:
  fix RNN_ID smashing skb payload (fate#306857, fate#306859,
  bnc#551175).
- patches.suse/libfc-fix-symbolic-name-registrations-smashing-skb-data.patch:
  libfc: fix symbolic name registrations smashing skb data
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-fix-typo-in-retry-check-on-received-prli.patch:
  libfc: fix typo in retry check on received PRLI (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/libfc-fix-wrong-scsi-return-status-under-fc_data_undrun.patch:
  libfc: Fix wrong scsi return status under FC_DATA_UNDRUN
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-formatting-cleanups-across-libfc.patch:
  libfc: Formatting cleanups across libfc (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/libfc-libfcoe-fdisc-els-for-npiv.patch: libfc,
  libfcoe: FDISC ELS for NPIV (fate#306857, fate#306859,
  bnc#551175).
- patches.suse/libfc-lport-fix-minor-documentation-errors.patch:
  libfc: lport: fix minor documentation errors (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/libfc-move-libfc_init-and-libfc_exit-to-fc_libfc-c.patch:
  libfc: Move libfc_init and libfc_exit to fc_libfc.c
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-move-non-common-routines-and-prototypes-out-of-libfc-h.patch:
  libfc: Move non-common routines and prototypes out of libfc.h
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-reduce-can_queue-for-all-fcp-frame-allocation-failures.patch:
  libfc: reduce can_queue for all FCP frame allocation failures
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-register-fc4-features-with-the-fc-switch.patch:
  libfc: register FC4 features with the FC switch (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/libfc-register-symbolic-node-name-rsnn_nn.patch:
  libfc: Register Symbolic Node Name (RSNN_NN) (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/libfc-register-symbolic-port-name-rspn_id.patch:
  libfc: Register Symbolic Port Name (RSPN_ID) (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/libfc-remove-fc_fcp_complete.patch: libfc: Remove
  fc_fcp_complete (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-remove-unused-fc_lport-pointer-from-fc_fcp_pkt_abort.patch:
  libfc: Remove unused fc_lport pointer from fc_fcp_pkt_abort
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-removes-initializing-fc_cpu_order-and-fc_cpu_mask-per-lport.patch:
  libfc: removes initializing fc_cpu_order and fc_cpu_mask per
  lport (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-removes-unused-disc_work-and-ex_list.patch:
  libfc: removes unused disc_work and ex_list (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/libfc-rnn_id-may-be-required-before-rsnn_nn-with-some-switches.patch:
  libfc: RNN_ID may be required before RSNN_NN with some switches
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-rpn_id-is-obsolete-and-unnecessary.patch:
  libfc: RPN_ID is obsolete and unnecessary (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/libfc-vport-link-handling-and-fc_vport-state-managment.patch:
  libfc: vport link handling and fc_vport state managment
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfcoe-allow-fip-to-be-disabled-by-the-driver.patch:
  libfcoe: Allow FIP to be disabled by the driver (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/libfcoe-do-not-pad-fip-keep-alive-to-full-frame-size.patch:
  libfcoe: Do not pad FIP keep-alive to full frame size
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfcoe-don-t-send-els-in-fip-mode-if-no-fcf-selected.patch:
  libfcoe: don't send ELS in FIP mode if no FCF selected
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfcoe-fcoe-libfcoe-npiv-support.patch:
  libfcoe, fcoe: libfcoe NPIV support (fate#306857, fate#306859,
  bnc#551175).
- patches.suse/libfcoe-fcoe-simplify-receive-flogi-response.patch:
  libfcoe: fcoe: simplify receive FLOGI response (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/libfcoe-fip-allow-fip-receive-to-be-called-from-irq.patch:
  libfcoe: fip: allow FIP receive to be called from
  IRQ. (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfcoe-fip-should-report-link-to-libfc-whether-selected-or-not.patch:
  libfcoe: FIP should report link to libfc whether selected or
  not (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfcoe-fip-use-scsi-host-number-to-identify-debug-messages.patch:
  libfcoe: fip: use SCSI host number to identify debug
  messages. (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfcoe-formatting-and-comment-cleanups.patch:
  libfcoe: formatting and comment cleanups (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/modify-change_queue_depth-to-take-in-reason-why-it-is-being-called.patch:
  modify change_queue_depth to take in reason why it is being
  called (fate#306857, fate#306859, bnc#551175).
- patches.suse/scsi-error-have-scsi-ml-call-change_queue_depth-to-handle-queue_full.patch:
  scsi error: have scsi-ml call change_queue_depth to handle
  QUEUE_FULL (fate#306857, fate#306859, bnc#551175).
* Thu Nov 19 2009 hare@suse.de
- patches.suse/dm-mpath-accept-failed-paths: Fixup patch to apply.
* Thu Nov 19 2009 hare@suse.de
  Port patches from SLES11:
- patches.fixes/scsi-dh-queuedata-accessors: Kernel bug triggered
  in multipath (bnc#486001).
- patches.suse/dm-mpath-accept-failed-paths: Refresh.
- patches.suse/dm-mpath-detach-existing-hardware-handler:
  multipath: detach existing hardware handler if none was
  specified.
- patches.suse/dm-mpath-requeue-for-stopped-queue: Delete.
* Thu Nov 19 2009 hare@suse.de
- patches.suse/dm-mpath-evaluate-request-result-and-sense:
  multipath: Evaluate request result and sense code
  (FATE#303695,bnc#433920,bnc#442001).
* Thu Nov 19 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Kill support for kernel-$flavor
  symbols, we need a unified kernel-source for all flavors.
* Thu Nov 19 2009 hare@suse.de
- patches.fixes/bnx2i-use-common-iscsi-suspend-queue: bnx2i:
  use common iscsi suspend queue (FATE#307215).
- patches.fixes/iscsi-class-modify-handling-of-replacement-time:
  iscsi class: modify handling of replacement timeout
  (FATE#307215).
- patches.fixes/iser-set-tgt-and-lu-reset-timeout: iser: set
  tgt and lu reset timeout (FATE#307215).
- patches.fixes/libiscsi-add-warm-target-reset-tmf-support:
  libiscsi: add warm target reset tmf support (FATE#307215).
- patches.fixes/libiscsi-check-tmf-state-before-sending-pdu:
  libiscsi: Check TMF state before sending PDU (FATE#307215).
- patches.fixes/libiscsi-fix-login-text-checks-in-pdu-inject:
  libiscsi: fix login/text checks in pdu injection code
  (FATE#307215).
- patches.fixes/scsi-add-scsi-target-reset-support-to-ioctl:
  add scsi target reset support to scsi ioctl.
- patches.fixes/scsi-devinfo-update-hitachi-entries: scsi_devinfo:
  update Hitachi entries (v2).
- patches.fixes/scsi-fc-class-failfast-bsg-requests: [SCSI]
  fc class: fail fast bsg requests.
- patches.drivers/cxgb3i: Delete.
- patches.drivers/cxgb3i-fixed-offload-array-size: Delete.
- patches.fixes/disable-lro-per-default: Delete.
* Thu Nov 19 2009 hare@suse.de
- patches.fixes/scsi_dh-always-attach-sysfs: scsi_dh: create
  sysfs file, dh_state for all SCSI disk devices.
- patches.fixes/scsi_dh-change-activate-interface: scsi_dh: Change
  the scsidh_activate interface to be asynchronous (bnc#556144).
- patches.fixes/scsi_dh-make-alua-handler-asynchronous: scsi_dh:
  Make alua hardware handler's activate() async (bnc#556144).
- patches.fixes/scsi_dh-make-hp_sw-handler-asynchronous: scsi_dh:
  Make hp hardware handler's activate() async (bnc#556144).
- patches.fixes/scsi_dh-make-rdac-handler-asynchronous: scsi_dh:
  Make rdac hardware handler's activate() async (bnc#556144).
* Thu Nov 19 2009 hare@suse.de
- patches.drivers/qla4xxx-5.01.00-k8_sles11-03-update: Delete.
- patches.drivers/qla4xxx-sles11-update: Delete.
* Thu Nov 19 2009 hare@suse.de
- Update config files.
- patches.drivers/hpsa: hpsa: New driver SCSI driver for HP
  Smart Array (FATE#307153,bnc#555855).
- supported.conf: Mark hpsa as supported.
* Thu Nov 19 2009 jjolly@suse.de
- patches.arch/s390-01-qeth-isolation.patch: qeth: Exploit QDIO
  Data Connection Isolation (bnc#555199,LTC#57826,FATE#307015).
- patches.arch/s390-02-01-cex3-init-msg.patch:
  zcrypt: initialize ap_messages for cex3 exploitation
  (bnc#555200,LTC#57825,FATE#307112).
- patches.arch/s390-02-02-cex3-special-command.patch:
  zcrypt: special command support for cex3 exploitation
  (bnc#555200,LTC#57825,FATE#307112).
- patches.arch/s390-02-03-cex3-device.patch: zcrypt: add support
  for cex3 device types (bnc#555200,LTC#57825,FATE#307112).
- patches.arch/s390-02-04-cex3-use-def.patch: zcrypt: use
  definitions for cex3 (bnc#555200,LTC#57825,FATE#307112).
- patches.arch/s390-02-05-zcrypt-speed-cex2c.patch:
  zcrypt: adjust speed rating between cex2 and pcixcc
  (bnc#555200,LTC#57825,FATE#307112).
- patches.arch/s390-02-06-zcrypt-speed-cex3.patch:
  zcrypt: adjust speed rating of cex3 adapters
  (bnc#555200,LTC#57825,FATE#307112).
- patches.arch/s390-sles11sp1-01-qeth-isolation.patch: Delete.
* Thu Nov 19 2009 jjolly@suse.de
- patches.arch/s390-sles11sp1-01-qeth-isolation.patch:
  qeth: Exploit QDIO Data Connection Isolation
  (bnc#555199,LTC#57826,FATE#307015).
* Wed Nov 18 2009 jeffm@suse.com
- scripts/sequence-patch.sh: Add automatic generation of supported
  modules list.
* Wed Nov 18 2009 jeffm@suse.com
- Update config files: Enable CONFIG_ACPI_CUSTOM_OVERRIDE_INITRAMFS
* Wed Nov 18 2009 jeffm@suse.com
- patches.suse/acpi-generic-initramfs-table-override-support:
  ACPI: generic initramfs table override support (bnc#533555).
- patches.suse/init-move-populate_rootfs-back-to-start_kernel:
  init: move populate_rootfs back to start_kernel (bnc#533555).
* Wed Nov 18 2009 jkosina@suse.de
- patches.arch/x86-crypto-pclmulqdq-accelerated-implementation.patch:
  incorporate "crypto: ghash-intel - Hard-code pshufb" fix
* Wed Nov 18 2009 jeffm@suse.com
- patches.suse/hung_task_timeout-configurable-default:
  hung_task_timeout: configurable default (bnc#552820).
  - Default to runtime-disabled on all flavors except debug.
* Wed Nov 18 2009 agraf@suse.de
- patches.fixes/kvm-ioapic.patch: Ignore apic polarity
  (bnc#556564).
- patches.fixes/kvm-macos.patch: Implement some missing intercepts
  so osx doesn't blow up (bnc#556564).
* Wed Nov 18 2009 hare@suse.de
- supported.conf: mark missing 10Gb drivers as supported
  (bnc#555793)
* Wed Nov 18 2009 hare@suse.de
- patches.drivers/aacraid-24701-update: Problems with aacraid
  (bnc#524242,FATE#307437).
* Wed Nov 18 2009 hare@suse.de
  Cleanup patches for series2git:
- patches.apparmor/apparmor.diff: Refresh.
- patches.suse/Cleanup-and-make-boot-splash-work-with-KMS.patch:
  Refresh.
- patches.suse/bootsplash: Refresh.
- patches.suse/nfs4acl-ext3.diff: Refresh.
- patches.suse/silent-stack-overflow-2.patch: Refresh.
- patches.suse/suse-ppc32-mol.patch: Refresh.
- patches.suse/xfs-dmapi-src: Refresh.
* Wed Nov 18 2009 agraf@suse.de
- Update config files to enable pv-ops for KVM clock. (bnc#556135)
* Wed Nov 18 2009 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-01-select-ibexpeak-handler: ALSA:
  hda - select IbexPeak handler for Calpella (FATE#306783).
- patches.drivers/alsa-sp1-hda-02-vectorize-get_empty_pcm_device:
  ALSA: hda - vectorize get_empty_pcm_device() (FATE#306783).
- patches.drivers/alsa-sp1-hda-03-allow-up-to-4-HDMI: ALSA:
  hda - allow up to 4 HDMI devices (FATE#306783).
- patches.drivers/alsa-sp1-hda-04-convert-intelhdmi-global-references:
  ALSA: hda - convert intelhdmi global references to local
  parameters (FATE#306783).
- patches.drivers/alsa-sp1-hda-05-remove-intelhdmi-dependency-on-multiout:
  ALSA: hda - remove intelhdmi dependency on multiout
  (FATE#306783).
- patches.drivers/alsa-sp1-hda-06-use-pcm-prepare-callbacks-for-intelhdmi:
  ALSA: hda - use pcm prepare/cleanup callbacks for intelhdmi
  (FATE#306783).
- patches.drivers/alsa-sp1-hda-07-reorder-intelhemi-prepare-callbacks:
  ALSA: hda - reorder intelhdmi prepare/cleanup callbacks
  (FATE#306783).
- patches.drivers/alsa-sp1-hda-08-vectorize-intelhdmi: ALSA:
  hda - vectorize intelhdmi (FATE#306783).
- patches.drivers/alsa-sp1-hda-09-get-intelhtemi-max-channels:
  ALSA: hda - get intelhdmi max channels from widget caps
  (FATE#306783).
- patches.drivers/alsa-sp1-hda-10-auto-parse-intelhdmi-cvt-pin:
  ALSA: hda - auto parse intelhdmi cvt/pin configurations
  (FATE#306783).
- patches.drivers/alsa-sp1-hda-11-remove-static-intelhdmi-config:
  ALSA: hda - remove static intelhdmi configurations
  (FATE#306783).
- patches.drivers/alsa-sp1-hda-12-reset-pins-idt-codec-free:
  ALSA: hda - Reset pins of IDT/STAC codecs at free (bnc#544779).
- patches.drivers/alsa-sp1-hda-13-add-reboot-notifier: ALSA:
  hda - Add reboot notifier to each codec (bnc#544779).
- patches.drivers/alsa-sp1-hda-14-add-missing-export: ALSA: hda -
  Add missing export for snd_hda_bus_reboot_notify (bnc#544779).
- patches.drivers/alsa-sp1-hda-15-fix-build-warning: ALSA: hda -
  Add a proper ifdef to a debug code (FATE#306783).
- patches.drivers/alsa-sp1-hda-16-stac-dual-headphones-fix:
  ALSA: hda - Fix detection of dual headphones (bnc#556532).
* Wed Nov 18 2009 jkosina@suse.de
- patches.arch/x86-crypto-pclmulqdq-accelerated-implementation.patch:
  crypto: ghash - Add PCLMULQDQ accelerated implementation
  (FATE#306883, bnc#554578).
- Update config files: set CRYPTO_GHASH_CLMUL_NI_INTEL=m
- patches.xen/xen3-patch-2.6.28: Refresh to apply cleanly
* Wed Nov 18 2009 agraf@suse.de
- patches.arch/kvm-only-export-selected-pv-ops-feature-structs:
  Only export selected pv-ops feature structs (bnc#556135).
- patches.arch/kvm-replace-kvm-io-delay-pv-ops-with-linux-magic:
  Replace kvm io delay pv-ops with linux magic (bnc#556135).
- patches.arch/kvm-split-paravirt-ops-by-functionality: Split
  paravirt ops by functionality (bnc#556135).
- patches.arch/kvm-split-the-KVM-pv-ops-support-by-feature:
  Split the KVM pv-ops support by feature (bnc#556135).
- patches.xen/xen3-patch-2.6.23: Refresh.
- patches.xen/xen3-patch-2.6.31: Refresh.
* Wed Nov 18 2009 teheo@suse.de
- patches.suse/kbuild-icecream-workaround: Delete.
* Wed Nov 18 2009 trenn@suse.de
- Update config files.
  Also enable CONFIG_DMAR (fate#306796) for vanilla flavors
* Wed Nov 18 2009 trenn@suse.de
- Update config files.
  Do the same for i386
* Wed Nov 18 2009 trenn@suse.de
- Update config files.
  Enabling CONFIG_DMAR (fate#306796), introduces these changes:
    +CONFIG_HAVE_INTEL_TXT=y
  - # CONFIG_DMAR is not set
    +CONFIG_DMAR=y
    +# CONFIG_DMAR_DEFAULT_ON is not set
    +CONFIG_DMAR_FLOPPY_WA=y
    +# CONFIG_INTEL_TXT is not set
  Done for x86_64 for now only.
* Tue Nov 17 2009 jkosina@suse.de
- patches.fixes/hid-fixup-ncr-quirk.patch: HID: fixup quirk for
  NCR devices (bnc#548807).
* Fri Nov 13 2009 mmarek@suse.cz
- rpm/*.spec.in, rpm/kernel-module-subpackage: add
  Provides: multiversion(kernel) to binary kernel packages,
  kernel-source, kernel-syms and all KMPs so that zypp can be
  configured to keep multiple versions of these packages
  (fate#305311).
* Fri Nov 13 2009 npiggin@suse.de
- Disable LGUEST on x86 32. It doesn't build properly without PARAVIRT.
* Wed Nov 11 2009 jack@suse.cz
- patches.fixes/zisofs-large-pagesize-read.patch: zisofs:
  Implement reading of compressed files when PAGE_CACHE_SIZE >
  compress block size (bnc#540349).
* Wed Nov 11 2009 npiggin@suse.de
- Update config files.
* Wed Nov 11 2009 npiggin@suse.de
- Disable PARAVIRT_GUEST on x86 32 and 64.
* Tue Nov 10 2009 teheo@suse.de
- patches.drivers/libata-ahci-aspire-3810t-noncq: ahci: disable
  NCQ on Aspire 3810t (bnc#522790).
* Tue Nov 10 2009 npiggin@suse.de
- Update config files.
* Tue Nov 10 2009 npiggin@suse.de
- Update config files. Disable CONFIG_CC_STACKPROTECTOR on all
  x86 kernels except debug. Overhead is prohibitive.
* Mon Nov  9 2009 npiggin@suse.de
- patches.suse/files-slab-rcu.patch: SLAB_DESTROY_BY_RCU for
  file slab.
* Mon Nov  9 2009 npiggin@suse.de
- Update config files. Vanilla doesn't have unwinder, trace selects
  options which select frame pointers.
* Mon Nov  9 2009 npiggin@suse.de
- Disable FRAME_POINTER on i386 and x86-64, all kernels. Unwind info
  should provide all this functionality.
* Mon Nov  9 2009 nfbrown@suse.de
- patches.fixes/nfs-honour-server-preferred-io-size: NFS: Honour
  server-preferred io sizes (bnc#550648).
* Mon Nov  9 2009 nfbrown@suse.de
- patches.fixes/nfs-slot-table-alloc: Don't fail allocations
  for the slot table when mounting an NFS filesystem (bnc#519820).
* Fri Nov  6 2009 trenn@suse.de
- patches.arch/x86_amd_fix_erratum_63.patch: x86/amd-iommu:
  Workaround for erratum 63 (bnc#548274).
* Fri Nov  6 2009 jeffm@suse.de
- Disabled PARAVIRT_GUEST on ia64/trace and ia64/vanilla.
* Fri Nov  6 2009 trenn@suse.de
- patches.suse/kdb_x86_fix_hang.patch: X86 KDB: Reduce timeout
  for blinking LEDs (bnc#528811).
* Fri Nov  6 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: fix last change.
* Fri Nov  6 2009 jbeulich@novell.com
- Update Xen patches to 2.6.32-rc6 and c/s 941.
- Update Xen config files.
- supported.conf: Add domctl.
* Fri Nov  6 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: add the /lib/modules/.../{source,devel}
  symlinks to the -devel package (bnc#548728).
* Fri Nov  6 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: obsolete kvm-kmp.
* Thu Nov  5 2009 jeffm@suse.com
- Update to 2.6.32-rc6.
  - 2 patches eliminated
  - NR_CPUS=4096 on ia64/vanilla again
* Thu Nov  5 2009 jeffm@suse.com
- Performance: Disabled CONFIG_PARAVIRT on all flavors.
* Thu Nov  5 2009 mmarek@suse.cz
- Delete unused 2.6.31.y patches.
* Thu Nov  5 2009 mmarek@suse.cz
- supported.conf: add libfcoe and fix typo.
* Thu Nov  5 2009 mmarek@suse.cz
- supported.conf: update so that supported modules don't require
  unsupported ones by adding following modules: async_pq
  async_raid6_recov ath blkback_pagemap crypto_hash drm_kms_helper
  fddi fscache lib80211 libfcoe libipw libiscsi_tcp llc md_mod mdio
  mfd_core nf_defrag_ipv4 p8022 psnap raid6_pq tr ttm ucb1400_core
  v4l2_compat_ioctl32.
* Thu Nov  5 2009 mmarek@suse.cz
- config.conf: remove kernel-ps3-devel (does not exist) and
  kernel-debug-devel (not needed most of the time) from
  kernel-syms.
* Thu Nov  5 2009 hare@suse.de
- Update config files: Set CONFIG_HZ to 100 for zSeries
  (bnc#552564).
* Thu Nov  5 2009 hare@suse.de
- Update config files: Increase MAX_RAW_DEVS to 4096 on
  zSeries (bnc#552565).
* Thu Nov  5 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: delete stray text.
* Tue Nov  3 2009 mmarek@suse.cz
- config.conf: remove the ec2 flavor from kernel-syms, most KMPs
  don't make any sense on ec2
  (http://lists.opensuse.org/opensuse-kernel/2009-11/msg00001.html).
* Mon Nov  2 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: obsolete also brocade-bfa-kmp.
* Mon Nov  2 2009 mmarek@suse.cz
- rpm/kernel-source.spec.in: add split-modules to the src.rpm.
* Mon Nov  2 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: obsolete enic-kmp and fnic-kmp.
* Mon Nov  2 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: obsolete kmps by their full name, not
  just the foo-kmp virtual dependency (bnc#472410).
* Thu Oct 29 2009 tonyj@suse.de
- Update ppc/ps3 config for CONFIG_UTRACE
* Thu Oct 29 2009 tonyj@suse.de
- patches.trace/utrace-core: Update for SP1 (FATE# 304321)
* Wed Oct 28 2009 nfbrown@suse.de
- patches.fixes/nfsd-acl.patch: nfsd: Fix sort_pacl in
  fs/nfsd/nf4acl.c to actually sort groups (bnc#549748).
* Wed Oct 28 2009 jdelvare@suse.de
- Update config files:
  CONFIG_NTFS_FS=n
  We handle NTFS through FUSE these days.
* Tue Oct 27 2009 jbohac@suse.cz
- Update config files:
  CONFIG_NETLABEL=y
  CONFIG_SECURITY_NETWORK_XFRM=y
  (fate#307284)
* Tue Oct 27 2009 jkosina@suse.de
- patches.fixes/sched-move-rq_weight-data-array-out-of-percpu:
  fix compilation failure for configs with CONFIG_SMP=n and
  CONFIG_FAR_GROUP_SCHED=y
* Tue Oct 27 2009 jbeulich@novell.com
- Update config files (MINIX_FS=m globally, NTFS_FS off for -ec2).
- supported.conf: Add fs/minix.
* Tue Oct 27 2009 jkosina@suse.de
- patches.fixes/percpu-allow-pcpu_alloc-to-be-called-with-IRQs-off:
  percpu: allow pcpu_alloc() to be called with IRQs off
  (bnc#548119).
- patches.fixes/sched-move-rq_weight-data-array-out-of-percpu:
  Update to newer version which is going to be merged upstream.
* Fri Oct 23 2009 jeffm@suse.com
- Update to 2.6.32-rc5-git3.
* Fri Oct 23 2009 mmarek@suse.cz
- Update config files: set NR_CPUS back to 2048 for ia64/vanilla
  until there is a fix in mainline.
* Fri Oct 23 2009 mmarek@suse.cz
- patches.fixes/sched-move-rq_weight-data-array-out-of-percpu:
  fix for !CONFIG_SMP.
* Fri Oct 23 2009 mmarek@suse.cz
- patches.suse/Cleanup-and-make-boot-splash-work-with-KMS.patch:
  Cleanup and make boot splash work with KMS (bnc#544645).
* Thu Oct 22 2009 jeffm@suse.com
- Re-enabled NR_CPUS=4096 on ia64.
- patches.fixes/sched-move-rq_weight-data-array-out-of-percpu:
  sched: move rq_weight data array out of .percpu (bnc#548119).
* Tue Oct 20 2009 jbeulich@novell.com
- Update x86-64 Xen config file (NR_CPUS=512).
- Refresh a few Xen patches.
- rpm/kernel-binary.spec.in: Handle -ec2 flavor.
- rpm/package-descriptions: Describe -ec2 flavor.
- rpm/post.sh: Handle -ec2 flavor.
* Tue Oct 20 2009 jbeulich@novell.com
- patches.fixes/use-totalram_pages: Delete.
* Tue Oct 20 2009 jbeulich@novell.com
- config.conf: Add -ec2 configs (fate#305273)
- Add ec2 config files.
- patches.xen/xen-unpriv-build: No need to build certain bits
  when building non-privileged kernel.
- supported.conf: Add fs/nls/nls_base.
* Mon Oct 19 2009 jeffm@suse.com
- Temporarily reduce NR_CPUS to 2048 on ia64 to avoid build
  failures (bnc#548119)
* Mon Oct 19 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: [s390x] ignore errors from
  dwarfextract for now.
* Fri Oct 16 2009 jeffm@suse.com
- Update config files.
* Fri Oct 16 2009 jeffm@suse.com
- Update to 2.6.32-rc5.
* Fri Oct 16 2009 mmarek@suse.de
- patches.rpmify/ia64-sn-fix-percpu-warnings: ia64/sn: fix
  percpu warnings.
* Fri Oct 16 2009 mmarek@suse.de
- Update config files: disable MTD_GPIO_ADDR, VME_CA91CX42 and
  VME_TSI148 on ia64 to fix build.
* Fri Oct 16 2009 jbeulich@novell.com
- patches.xen/xen3-patch-2.6.32-rc4: Fix AGP for PowerPC.
* Fri Oct 16 2009 jbeulich@novell.com
- Update Xen patches to 2.6.32-rc4 and c/s 938.
- config.conf: Re-enable Xen.
- Update x86 config files.
* Tue Oct 13 2009 jeffm@suse.com
- patches.rpmify/staging-missing-sched.h: Added missing sites.
* Mon Oct 12 2009 jeffm@suse.com
- patches.rpmify/staging-missing-sched.h: staging: Complete
  sched.h removal from interrupt.h.
* Mon Oct 12 2009 jeffm@suse.de
- patches.apparmor/ptrace_may_access-fix: apparmor:
  ptrace_may_access -> ptrace_access_check.
* Mon Oct 12 2009 jeffm@suse.de
- Update config files.
* Mon Oct 12 2009 jeffm@suse.de
- Updated to 2.6.32-rc4.
  - Eliminated 4 patches.
  - Refreshed context.
* Mon Oct 12 2009 jeffm@suse.de
- patches.apparmor/apparmor.diff: Refresh and enable.
* Fri Oct  9 2009 jeffm@suse.de
- Cleanup unused patches:
  - patches.fixes/iwl3945-fix-rfkill.patch: Delete.
  - patches.fixes/iwlagn-fix-rfkill.patch: Delete.
  - patches.suse/kdb-serial-8250: Delete.
  - patches.suse/kdb-sysctl-context: Delete.
* Fri Oct  9 2009 jeffm@suse.de
- patches.fixes/scsi-add-tgps-setting: Refresh and re-enable.
* Fri Oct  9 2009 jeffm@suse.de
- patches.arch/x86_64-hpet-64bit-timer.patch: Refresh and re-enable.
* Fri Oct  9 2009 jeffm@suse.de
- patches.suse/kbuild-icecream-workaround: Refresh and re-enable.
* Fri Oct  9 2009 jeffm@suse.de
- patches.rpmify/spin_is_contended-fix: Delete.
* Fri Oct  9 2009 jeffm@suse.de
- patches.arch/mm-avoid-bad-page-on-lru: Refresh and re-enable.
* Fri Oct  9 2009 jeffm@suse.de
- Update vanilla config files.
* Fri Oct  9 2009 jeffm@suse.de
- Update to 2.6.32-rc3.
* Fri Oct  9 2009 jeffm@suse.de
- patches.rpmify/tsi148-dependency: vme/tsi148: Depend on VIRT_TO_BUS
* Thu Oct  8 2009 jeffm@suse.de
- patches.suse/kdb-x86-build-fixes: kdb: Use $srctree not $TOPDIR
  in Makefile.
* Thu Oct  8 2009 jeffm@suse.de
- patches.rpmify/winbond-prepare_multicast: winbond: implement
  prepare_multicast and fix API usage.
- patches.rpmify/winbond_beacon_timers: winbond: use
  bss_conf->beacon_int instead of conf->beacon_int.
- patches.rpmify/winbond-build-fixes: Delete.
* Thu Oct  8 2009 jeffm@suse.de
- patches.rpmify/rtl8192e-build-fixes: rtl8192e: Add #include
  <linux/vmalloc.h>.
* Thu Oct  8 2009 jeffm@suse.de
- patches.suse/kdb-build-fixes: kdb: Build fixes.
* Thu Oct  8 2009 jeffm@suse.de
- patches.rpmify/iio-s390-build-fix: iio: Don't build on s390.
* Thu Oct  8 2009 jeffm@suse.de
- patches.rpmify/winbond-build-fixes: winbond: API fix.
* Thu Oct  8 2009 jeffm@suse.de
- Update vanilla config files.
* Thu Oct  8 2009 jeffm@suse.de
- Update config files.
* Thu Oct  8 2009 jeffm@suse.de
- Updated to 2.6.32-rc1 (AKA 2.6.32-rc2).
  - Eliminated 28 patches.
  - 14 patches need further review.
  - Xen and AppArmor are currently disabled.
  - USB support in KDB is disabled.
* Thu Oct  8 2009 gregkh@suse.de
- patches.kernel.org/patch-2.6.31.2-3: Linux 2.6.31.3.
  - major tty bugfix
* Wed Oct  7 2009 tiwai@suse.de
- patches.drivers/alsa-hda-alc268-automic-fix: ALSA: hda -
  Fix yet another auto-mic bug in ALC268 (bnc#544899).
* Wed Oct  7 2009 knikanth@suse.de
- patches.suse/block-seperate-rw-inflight-stats: Fix the regression,
  "iostat reports wrong service time and utilization", introduced
  by this patch  (bnc#544926).
* Tue Oct  6 2009 gregkh@suse.de
- patches.suse/x86-mark_rodata_rw.patch: Delete.
- patches.xen/xen3-x86-mark_rodata_rw.patch: Delete.
  - both of these were not being used anyway.
* Tue Oct  6 2009 jbeulich@novell.com
- Update Xen patches to 2.6.31.2.
* Tue Oct  6 2009 tiwai@suse.de
- patches.drivers/alsa-hda-alc660vd-asus-a7k-fix: ALSA: hda -
  Add a workaround for ASUS A7K (bnc#494309).
* Mon Oct  5 2009 gregkh@suse.de
- refresh patch fuzz due to 2.6.31.2 import.
* Mon Oct  5 2009 gregkh@suse.de
- Update to Linux 2.6.31.2:
  - bugfixes, lots of them.
  - security fixes
* Mon Oct  5 2009 tiwai@suse.de
- patches.drivers/alsa-hda-alc861-toshiba-fix: ALSA: hda -
  Fix invalid initializations for ALC861 auto mode (bnc#544161).
* Fri Oct  2 2009 gregkh@suse.de
- Update config files.
- patches.drivers/add-via-chrome9-drm-support.patch: Delete.
  The code never got upstream and looks incorrect.
* Fri Oct  2 2009 tiwai@suse.de
- patches.drivers/alsa-ctxfi-04-fix-surround-side-mute: ALSA:
  ctxfi: Swapped SURROUND-SIDE mute.
- patches.drivers/alsa-hda-2.6.32-rc1-toshiba-fix: ALSA: hda -
  Added quirk to enable sound on Toshiba NB200.
- patches.drivers/alsa-hda-2.6.32-rc2: ALSA: backport 2.6.32-rc2
  fixes for HD-audio.
* Thu Oct  1 2009 jbeulich@novell.com
- Update Xen patches to 2.6.31.1 and c/s 934.
* Thu Oct  1 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: obsolete quickcam-kmp (bnc#543361).
* Wed Sep 30 2009 gregkh@suse.de
- Update to 2.6.31.1
  - lots of bugfixes
  - security fixes
* Wed Sep 30 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: obsolete the sle11 ocfs2-kmp.
* Tue Sep 29 2009 trenn@suse.de
- Disabled patches.suse/acpi-dsdt-initrd-v0.9a-2.6.25.patch
  with +trenn (bnc#542767)
* Wed Sep 23 2009 teheo@suse.de
- Update config files.  Build pci-stub driver into the kernel so that
  built in pci drivers can be blocked from attaching to devices.
* Tue Sep 22 2009 mmarek@suse.cz
- rpm/kernel-module-subpackage: when building against Linus'
  kernels (2.6.x), append a .0 to the kernel version embedded in
  the KMP version, to ensure that such KMP is older than a KMP
  built against a subsequent stable kernel (2.6.x.y, y > 0).
* Mon Sep 21 2009 jeffm@suse.de
- Update config files.
* Mon Sep 21 2009 jeffm@suse.de
- patches.suse/acpi-dsdt-initrd-v0.9a-2.6.25.patch: Ported to
  2.6.31 (bnc#533555).
* Sat Sep 19 2009 mmarek@suse.cz
- rpm/postun.sh: do not remove the bootloader entry if the kernel
  version didn't change (bnc#533766).
* Sat Sep 19 2009 mmarek@suse.cz
- rpm/postun.sh: remove dead code.
* Fri Sep 18 2009 jeffm@suse.de
- patches.fixes/reiserfs-replay-honor-ro: reiserfs: Properly
  honor read-only devices (bnc#441062).
* Thu Sep 17 2009 jeffm@suse.de
- patches.arch/acpi_srat-pxm-rev-ia64.patch: Use SRAT table rev
  to use 8bit or 16/32bit PXM fields (ia64) (bnc#503038).
- patches.arch/acpi_srat-pxm-rev-store.patch: Store SRAT table
  revision (bnc#503038).
- patches.arch/acpi_srat-pxm-rev-x86-64.patch: Use SRAT table
  rev to use 8bit or 32bit PXM fields (x86-64) (bnc#503038).
* Thu Sep 17 2009 tiwai@suse.de
- patches.drivers/alsa-hda-2.6.32-rc1: ALSA HD-audio backport
  from 2.6.32-rc1.
* Wed Sep 16 2009 jbeulich@novell.com
- Update Xen patches to 2.6.31 final.
* Tue Sep 15 2009 teheo@suse.de
  Backport attach inhibition for builtin pci drivers from 2.6.32-rc.
- patches.drivers/pci-separate-out-pci_add_dynid: pci: separate
  out pci_add_dynid().
- patches.drivers/pci_stub-add-ids-parameter: pci-stub: add
  pci_stub.ids parameter.
* Tue Sep 15 2009 teheo@suse.de
  Backport patches from 2.6.32-rc to ease ossp testing.
- Update config files - SOUND_OSS_CORE_PRECLAIM is set to N.
- patches.drivers/implement-register_chrdev: chrdev: implement
  __register_chrdev().
- patches.drivers/sound-make-oss-device-number-claiming-optional:
  sound: make OSS device number claiming optional and schedule
  its removal.
- patches.drivers/sound-request-char-major-aliases-for-oss-devices:
  sound: request char-major-* module aliases for missing OSS
  devices.
* Mon Sep 14 2009 sdietrich@suse.de
- patches.suse/novfs-client-module: Update header todo list with
  locking nits (semaphore used as mutex / completion)
* Mon Sep 14 2009 jeffm@suse.com
- Revert back to CONFIG_M586TSC from CONFIG_M686 for default flavor
  (bnc#538849)
* Fri Sep 11 2009 jbeulich@novell.com
- patches.suse/crasher-26.diff: Add capability to also trigger a
  kernel warning.
* Fri Sep 11 2009 knikanth@suse.de
- patches.suse/block-seperate-rw-inflight-stats: Seperate read
  and write statistics of in_flight requests (fate#306525).
* Thu Sep 10 2009 gregkh@suse.de
- patch fuzz removal now that 2.6.31 is the base.
* Thu Sep 10 2009 gregkh@suse.de
- Update config files.
    CONFIG_MOUSE_PS2_ELANTECH=y
    CONFIG_MOUSE_PS2_TOUCHKIT=y
    (bnc#525607)
* Thu Sep 10 2009 tiwai@suse.de
- patches.drivers/alsa-hda-2.6.32-pre: Refresh: fix misc realtek
  issues, add another Nvidia HDMI device id
* Thu Sep 10 2009 jeffm@suse.de
- Updated to 2.6.31-final.
* Tue Sep  8 2009 gregkh@suse.de
- refresh patches for fuzz due to upstream changes
* Tue Sep  8 2009 gregkh@suse.de
- Update to 2.6.31-rc9
  - obsoletes:
  - patches.drivers/alsa-hda-fix-01-add-missing-mux-for-vt1708
  - patches.drivers/alsa-hda-fix-02-mbp31-hp-fix
* Tue Sep  8 2009 knikanth@suse.de
- patches.fixes/scsi_dh-Provide-set_params-interface-in-emc-device-handler.patch:
  scsi_dh: Provide set_params interface in emc device handler
  (bnc#521607).
- patches.fixes/scsi_dh-Use-scsi_dh_set_params-in-multipath.patch:
  scsi_dh: Use scsi_dh_set_params() in multipath. (bnc#521607).
- patches.fixes/scsi_dh-add-the-interface-scsi_dh_set_params.patch:
  scsi_dh: add the interface scsi_dh_set_params() (bnc#521607).
* Mon Sep  7 2009 mmarek@suse.cz
- rpm/kernel-source.spec.in: delete obsolete macro.
* Mon Sep  7 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: require minimum versions of
  module-init-tools and perl-Bootloader, the %%post script is no
  longer compatible with ancient versions.
* Mon Sep  7 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: obsolete %%name-base <= 2.6.31, the
  previous <= 2.6.30-1 didn't catch some cases obviously
  (bnc#533766).
* Fri Sep  4 2009 jeffm@suse.de
- Enabled CONFIG_SCSI_DEBUG=m (bnc#535923).
* Fri Sep  4 2009 mmarek@suse.cz
- kabi/severities, rpm/kabi.pl, rpm/kernel-binary.spec.in,
- rpm/kernel-source.spec.in: Use a simple script to check kabi by
  comparing Module.symvers files (similar to the old SLES9 one).
- rpm/built-in-where: Delete.
- rpm/symsets.pl: Delete.
- kabi/commonsyms: Delete.
- kabi/usedsyms: Delete.
* Fri Sep  4 2009 mmarek@suse.cz
- patches.suse/kbuild-rebuild-fix-for-Makefile.modbuiltin:
  kbuild: rebuild fix for Makefile.modbuiltin.
* Thu Sep  3 2009 gregkh@suse.de
- patches.drivers/usb-storage-increase-the-bcd-range-in-sony-s-bad-device-table.patch:
  Delete, it was wrong.
* Wed Sep  2 2009 jbeulich@novell.com
- Update Xen config files.
* Wed Sep  2 2009 jbeulich@novell.com
- Update Xen patches to 2.6.31-rc8 and c/s 931.
- patches.fixes/use-totalram_pages: use totalram_pages in favor
  of num_physpages for sizing boot time allocations (bnc#509753).
- patches.xen/xen-x86-per-cpu-vcpu-info: x86: use per-cpu storage
  for shared vcpu_info structure.
* Wed Sep  2 2009 tiwai@suse.de
- patches.drivers/alsa-hda-2.6.32-pre: Refresh; merged fixes for
  IDT92HD73* codecs
* Tue Sep  1 2009 jeffm@suse.com
- patches.apparmor/apparmor.diff: Update to latest git.
* Tue Sep  1 2009 jeffm@suse.com
- patches.arch/add_support_for_hpet_msi_intr_remap.patch:
  intr-remap: generic support for remapping HPET MSIs
  (bnc#532758).
- patches.arch/add_x86_support_for_hpet_msi_intr_remap.patch:
  x86: arch specific support for remapping HPET MSIs (bnc#532758).
* Tue Sep  1 2009 mmarek@suse.cz
- rpm/package-descriptions: fix description of the x86_64
  kernel-desktop package (bnc#535457).
* Mon Aug 31 2009 jeffm@suse.com
- Update to 2.6.31-rc8.
  - Eliminated 1 patch.
* Mon Aug 31 2009 tiwai@suse.de
- patches.drivers/alsa-hda-fix-01-add-missing-mux-for-vt1708:
  ALSA: hda - Add missing mux check for VT1708 (bnc#534904).
- patches.drivers/alsa-hda-fix-02-mbp31-hp-fix: ALSA: hda -
  Fix MacBookPro 3,1/4,1 quirk with ALC889A.
- patches.drivers/alsa-hda-2.6.32-pre: Refresh.
* Wed Aug 26 2009 tiwai@suse.de
- patches.drivers/alsa-hda-[0-9]*: Delete, fold into a single patch
  patches.drivers/alsa-hda-2.6.32-pre
* Tue Aug 25 2009 gregkh@suse.de
- Update config files.
- patches.drivers/samsung-backlight-driver.patch: Delete.
* Tue Aug 25 2009 jbeulich@novell.com
- scripts/run_oldconfig.sh: Consistently use $prefix.
* Mon Aug 24 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: obsolete %%name-base <= 2.6.30-1
  (bnc#530752).
* Mon Aug 24 2009 jeffm@suse.com
- Update to 2.6.31-rc7.
  - Eliminated 3 patches.
* Mon Aug 24 2009 jeffm@suse.com
- Update config files: Enable CONFIG_PROC_EVENTS.
* Fri Aug 21 2009 mmarek@suse.cz
- rpm/post.sh: Do not call /sbin/module_upgrade, the rename
  happened before SLES10.
* Fri Aug 21 2009 mmarek@suse.cz
- rpm/module-renames: Delete, we don't need to care about modules
  renamed before SLES10. Also, current mkinitrd gets the list of
  storage drivers based on pci ids.
* Fri Aug 21 2009 mmarek@suse.cz
- rpm/post.sh, rpm/postun.sh: drop support for SLE10, the package
  can't be installed on SLE10 as is, so why not make it more
  adventurous.
* Fri Aug 21 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: remove product(openSUSE) supplements
  from the -extra subpackage which doesn't exist on openSUSE
  anymore.
* Thu Aug 20 2009 tiwai@suse.de
- patches.drivers/alsa-hda-fix-0*: Backport from 2.6.31-rc fixes
  (to be merged)
- patches.drivers/alsa-hda-32-Reword-auto-probe-messages: Refresh.
- patches.drivers/alsa-hda-33-IDT-codec-updates: Refresh.
* Thu Aug 20 2009 jbeulich@novell.com
- Update config files (modularize crypto again).
- supported.conf: Add resulting modules as supported.
* Wed Aug 19 2009 jbeulich@novell.com
- Update Xen patches to 2.6.31-rc6 and c/s 928.
* Wed Aug 19 2009 tiwai@suse.de
- patches.drivers/alsa-hda-48-alc268-oops-fix: ALSA: hda -
  Fix invalid capture mixers with some ALC268 models.
* Tue Aug 18 2009 gregkh@suse.de
- patches.drivers/usb-storage-increase-the-bcd-range-in-sony-s-bad-device-table.patch:
  USB: storage: increase the bcd range in Sony's bad device
  table. (bnc#466554).
* Mon Aug 17 2009 gregkh@suse.de
- patches.drivers/samsung-backlight-driver.patch: Change the range from
  0-255 to 0-7 to make it easier for HAL to handle the device without a
  need for custom scripts.
* Mon Aug 17 2009 jeffm@suse.com
- Updated to 2.6.31-rc6.
* Mon Aug 17 2009 gregkh@suse.de
- patches.drivers/samsung-backlight-driver.patch: added N120 support
  and some other devices that were integrated into the driver from
  upstream.
* Sun Aug 16 2009 coly.li@suse.de
- supported.conf:
  set kernel/fs/dlm/dlm as unsupported, since fs/dlm is provided
  separately in the ocfs2 KMP package
* Sat Aug 15 2009 tiwai@suse.de
- patches.drivers/alsa-hda-47-idt92hd8x-fix: ALSA: hda - Fix /
  clean up IDT92HD83xxx codec parser (bnc#531533).
* Sat Aug 15 2009 gregkh@suse.de
- Update config files.
- patches.drivers/samsung-backlight-driver.patch: Samsung
  backlight driver (bnc#527533, bnc#531297).
* Fri Aug 14 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: add some hints how to set the %%jobs
  macro (bnc#530535).
* Fri Aug 14 2009 mmarek@suse.cz
- rpm/modversions: for overriden functions, keep the keyword in
  - -pack.
* Thu Aug 13 2009 jeffm@suse.com
- Updated to 2.6.31-rc5-git9.
  - Eliminated 7 patches.
* Thu Aug 13 2009 tiwai@suse.de
- patches.drivers/alsa-hda-42-hp-more-quirk: ALSA: hda - Add
  quirks for some HP laptops (bnc#527284).
- patches.drivers/alsa-hda-4[35]-*: Improve Realtek codec mic
  support
- patches.drivers/alsa-hda-46-stac-lo-detect-fix: ALSA: hda -
  Enable line-out detection only with speakers (bnc#520975).
* Wed Aug 12 2009 mmarek@suse.cz
- rpm/split-modules, rpm/kernel-binary.spec.in: add the base files
  also to the main package. That way, kernel-$flavor-base is not
  needed in normal setups (fate#307154).
* Wed Aug 12 2009 mmarek@suse.cz
- rpm/find-provides: no rpm provides for drivers/staging. It's
  higly unlikely that any KMP would require them and they just
  take up space in the rpm metadata.
* Tue Aug 11 2009 tiwai@suse.de
- patches.drivers/alsa-hda-41-msi-white-list: ALSA: hda - Add
  a white-list for MSI option (bnc#529971).
* Tue Aug 11 2009 tiwai@suse.de
- patches.drivers/alsa-hda-39-dont-override-ADC-definitions:
  ALSA: hda - Don't override ADC definitions for ALC codecs
  (bnc#529467).
- patches.drivers/alsa-hda-40-auto-mic-support-for-realtek:
  ALSA: hda - Add auto-mic support for Realtek codecs.
* Tue Aug 11 2009 mmarek@suse.cz
- rpm/kernel-source.spec.in: do not rename kernel-source.rpmlintrc
  for the -rt variant.
* Mon Aug 10 2009 mmarek@suse.cz
- patches.rpmify/staging-rtl8192su-fix-build-error.patch: move to
  patches.rpmify to fix vanilla ppc builds.
* Mon Aug 10 2009 tiwai@suse.de
- patches.drivers/alsa-hda-38-fix-ALC269-vmaster: ALSA: hda -
  Add missing vmaster initialization for ALC269 (bnc#527361).
* Mon Aug 10 2009 tiwai@suse.de
- patches.drivers/alsa-hda-33-IDT-codec-updates: Refresh.
* Fri Aug  7 2009 jeffm@suse.com
- patches.fixes/recordmcount-fixup: recordmcount: Fixup wrong
  update_funcs() call.
* Fri Aug  7 2009 tiwai@suse.de
- patches.drivers/alsa-soc-fsl-build-fixes: ASoC: Add missing
  DRV_NAME definitions for fsl/* drivers (to fix PPC builds)
* Fri Aug  7 2009 tiwai@suse.de
- patches.arch/wmi-Fix-kernel-panic-when-stack-protection-enabled:
  wmi: Fix kernel panic when stack protection
  enabled. (bnc#529177).
- supported.conf: Update HD-audio modules
* Fri Aug  7 2009 mmarek@suse.cz
- make config/s390/vanilla a symlink again.
* Fri Aug  7 2009 mmarek@suse.de
- rpm/kernel-binary.spec.in: do not manually extract vmlinux
  debuginfo on ppc(64), rpm does it itself.
* Thu Aug  6 2009 jeffm@suse.de
- rpm/kernel-binary.spec.in,
  rpm/kernel-source.spec.in: Added kernel-spec-macros to Sources.
* Thu Aug  6 2009 jeffm@suse.de
- patches.suse/linux-2.6.29-even-faster-kms.patch: Disabled. It
  doesn't wake up the display on certain hardware.
* Wed Aug  5 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: do not split the -extra subpackage on
  openSUSE (bnc#528097).
* Wed Aug  5 2009 jeffm@suse.de
- Updated to 2.6.31-rc5-git3.
  - Eliminated 4 patches.
* Wed Aug  5 2009 gregkh@suse.de
- kernel-source.changes: remove old (pre 2008) messages, and move 2008
  to kernel-source.changes.old.  No need to spam email addresses that
  are no longer with the company for failed kernel builds.
* Wed Aug  5 2009 gregkh@suse.de
- patches.drivers/staging-rtl8192su-fix-build-error.patch:
  Staging: rtl8192su: fix build error.
* Wed Aug  5 2009 jeffm@suse.de
- patches.suse/supported-flag-enterprise: Make the supported
  flag configurable at build time (bnc#528097).
* Wed Aug  5 2009 gregkh@suse.de
- Update config files.
  disable CONFIG_DRM_RADEON_KMS as per bnc#527910 for vanilla builds
* Tue Aug  4 2009 gregkh@suse.de
- Update config files.
  disable CONFIG_DRM_RADEON_KMS as per bnc#527910
* Tue Aug  4 2009 jeffm@suse.de
- patches.rpmify/ttm-pgprot-fixes: ttm: Use pgprot_val for
  comparing pgprot_t.
* Tue Aug  4 2009 tiwai@suse.de
- patches.drivers/alsa-hda-3[0-8]*: ALSA HD-audio updates
- Update config files: enable CONFIG_SND_HDA_CIRRUS=y
* Mon Aug  3 2009 jeffm@suse.de
- Update config files: CONFIG_FRAME_WARN=2048 on all arches, fixes
  ppc build failures.
* Mon Aug  3 2009 jeffm@suse.de
- patches.xen/xen3-patch-2.6.31-rc4-rc5: Fixup pgtable port
* Mon Aug  3 2009 jeffm@suse.de
- Updated to 2.6.31-rc5.
  - Eliminated 11 patches.
* Mon Aug  3 2009 coly.li@suse.de
- Update config files to enable CONFIG_DLM_DEBUG.
* Fri Jul 31 2009 jbeulich@novell.com
- Update Xen patches to 2.6.31-rc4 and c/s 916.
- patches.xen/xen3-driver-core-misc-add-nodename-support-for-misc-devices.patch:
  Delete.
- patches.xen/xen3-panic-on-io-nmi.diff: Delete.
- config.conf: Re-enable Xen.
- Update config files.
* Wed Jul 29 2009 tiwai@suse.de
- Update config files: revert to CONFIG_SND=m and enabled again
  CONFIG_SND_DEBUG=y
* Tue Jul 28 2009 mmarek@suse.cz
- Update config files: disable CONFIG_PRISM2_USB on ia64 and ppc.
* Tue Jul 28 2009 mmarek@suse.cz
- Update config files: disable CONFIG_FB_UDL on ia64.
* Tue Jul 28 2009 jbeulich@novell.com
- config.conf: Remove duplicate i386/desktop entry.
* Tue Jul 28 2009 tiwai@suse.de
- patches.drivers/alsa-hda-29-Add-quirk-for-Dell-Studio-1555:
  ALSA: hda - Add quirk for Dell Studio 1555 (bnc#525244).
* Mon Jul 27 2009 tiwai@suse.de
- patches.drivers/alsa-pcm-*: ALSA PCM fixes
- Fix/enhancement patches backported from ALSA tree
  * patches.drivers/alsa-core-Add-new-TLV-types-for-dBwith-min-max:
    ALSA: Add new TLV types for dBwith min/max (for usb).
  * patches.drivers/alsa-ctxfi-*: SB X-Fi support (FATE#306935).
  * patches.drivers/alsa-hda-*: More HD-audio fixes
  * patches.drivers/alsa-ice-*: ICE17xx fixes
  * patches.drivers/alsa-midi-*: MIDI fixes
  * patches.drivers/alsa-usb-*: USB-audio/MIDI fixes
- Remove obsoleted patches: patches.drivers/alsa-ad1984a-hp-quirks,
  patches.drivers/alsa-ca0106-capture-bufsize-fix,
  patches.drivers/alsa-ctxfi
- Update config files.
* Mon Jul 27 2009 mmarek@suse.cz
- rpm/kernel-source.spec.in, scripts/tar-up.sh: really drop
  config-subst from the package.
* Mon Jul 27 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: manually create a -devel-debuginfo
  subpackage with vmlinux.debug to fix build with new rpm. This
  works for ix86 and x86_64, other archs might need further fixes.
* Mon Jul 27 2009 jeffm@suse.de
- patches.rpmify/rtl8192su-build-fix: more ia64 fixes
* Mon Jul 27 2009 jeffm@suse.de
- patches.rpmify/rtl8192su-build-fix: rtl8192su: compile fixes.
* Mon Jul 27 2009 jeffm@suse.de
- patches.rpmify/rtl8192su-build-fix: rtl8192su: compile fixes.
* Sun Jul 26 2009 jeffm@suse.de
- config.conf: Re-enabled trace flavor.
* Fri Jul 24 2009 jeffm@suse.de
- Update config files: Disabled optimize for size on i386 and x86_64
  across all flavors.
* Fri Jul 24 2009 jeffm@suse.de
- Update to 2.6.31-rc4.
* Thu Jul 23 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: cleanup %%cpu_arch_flavor definition,
  make %%symbols a variable and only use it for selecting patches.
  Also drop the RT symbol as there are not rt patches currently.
* Thu Jul 23 2009 mmarek@suse.cz
- Change the s390(x) config layout so that each arch has its own
  subdirectory, as it is done for other archs. s390/vanilla is a
  symlink to s390x/vanilla.
* Thu Jul 23 2009 mmarek@suse.cz
- rpm/kernel-*.spec.in, rpm/kernel-spec-macros: move some common
  macros to kernel-spec-macros.
* Wed Jul 22 2009 tiwai@suse.de
- patches.drivers/alsa-ca0106-capture-bufsize-fix: ALSA: ca0106 -
  Fix the max capture buffer size (bnc#521890).
* Wed Jul 22 2009 tiwai@suse.de
- patches.drivers/alsa-ctxfi: Add SoundBlaster X-Fi support
  (FATE#306935).
- Update config files.
* Wed Jul 22 2009 trenn@suse.de
  These are mainline:
- patches.drivers/cpufreq_add_cpu_number_paramater_1.patch:
  Delete.
- patches.drivers/cpufreq_add_idle_microaccounting_6.patch:
  Delete.
- patches.drivers/cpufreq_change_load_calculation_2.patch: Delete.
- patches.drivers/cpufreq_changes_to_get_cpu_idle_us_5.patch:
  Delete.
- patches.drivers/cpufreq_get_cpu_idle_time_changes_3.patch:
  Delete.
- patches.drivers/cpufreq_parameterize_down_differential_4.patch:
  Delete.
* Wed Jul 22 2009 trenn@suse.de
  These are mainline:
- patches.arch/acpi_video_thinkpad_exclude_IGD_devices.patch:
  Delete.
- patches.arch/thinkpad_fingers_off_backlight_igd.patch: Delete.
* Tue Jul 21 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: remove double-slash from include2/asm
  symlink.
* Tue Jul 21 2009 mmarek@suse.cz
- config.conf, rpm/mkspec: exclude trace, kdump and ia64/debug from
  the kernel-syms package. These flavor are often excluded in KMPs,
  so excluding them from kernel-syms reduces useless build
  dependencies. KMPs can buildrequire kernel-$flavor-devel
  explicitely if desired.
* Tue Jul 21 2009 mmarek@suse.cz
  Delete obsolete apparmor patches.
- patches.apparmor/add-path_permission.diff: Delete.
- patches.apparmor/add-security_path_permission: Delete.
- patches.apparmor/apparmor-2.6.25.diff: Delete.
- patches.apparmor/apparmor-audit.diff: Delete.
- patches.apparmor/apparmor-intree.diff: Delete.
- patches.apparmor/apparmor-lsm.diff: Delete.
- patches.apparmor/apparmor-main.diff: Delete.
- patches.apparmor/apparmor-misc.diff: Delete.
- patches.apparmor/apparmor-module_interface.diff: Delete.
- patches.apparmor/apparmor-network.diff: Delete.
- patches.apparmor/apparmor-path_permission: Delete.
- patches.apparmor/apparmor-ptrace-2.6.27.diff: Delete.
- patches.apparmor/apparmor-rlimits.diff: Delete.
- patches.apparmor/d_namespace_path.diff: Delete.
- patches.apparmor/d_namespace_path_oops_fix.diff: Delete.
- patches.apparmor/do_path_lookup-nameidata.diff: Delete.
- patches.apparmor/export-security_inode_permission-for-aufs:
  Delete.
- patches.apparmor/file-handle-ops.diff: Delete.
- patches.apparmor/fix-complain.diff: Delete.
- patches.apparmor/fix-vfs_rmdir.diff: Delete.
- patches.apparmor/fork-tracking.diff: Delete.
- patches.apparmor/fsetattr-reintro-ATTR_FILE.diff: Delete.
- patches.apparmor/fsetattr-restore-ia_file.diff: Delete.
- patches.apparmor/fsetattr.diff: Delete.
- patches.apparmor/remove_suid.diff: Delete.
- patches.apparmor/security-create.diff: Delete.
- patches.apparmor/security-getxattr.diff: Delete.
- patches.apparmor/security-link.diff: Delete.
- patches.apparmor/security-listxattr.diff: Delete.
- patches.apparmor/security-mkdir.diff: Delete.
- patches.apparmor/security-mknod.diff: Delete.
- patches.apparmor/security-readlink.diff: Delete.
- patches.apparmor/security-removexattr.diff: Delete.
- patches.apparmor/security-rename.diff: Delete.
- patches.apparmor/security-rmdir.diff: Delete.
- patches.apparmor/security-setattr.diff: Delete.
- patches.apparmor/security-setxattr.diff: Delete.
- patches.apparmor/security-symlink.diff: Delete.
- patches.apparmor/security-unlink.diff: Delete.
- patches.apparmor/security-xattr-file.diff: Delete.
- patches.apparmor/sysctl-pathname.diff: Delete.
- patches.apparmor/unambiguous-__d_path.diff: Delete.
- patches.apparmor/vfs-getxattr.diff: Delete.
- patches.apparmor/vfs-link.diff: Delete.
- patches.apparmor/vfs-listxattr.diff: Delete.
- patches.apparmor/vfs-mkdir.diff: Delete.
- patches.apparmor/vfs-mknod.diff: Delete.
- patches.apparmor/vfs-notify_change.diff: Delete.
- patches.apparmor/vfs-removexattr.diff: Delete.
- patches.apparmor/vfs-rename.diff: Delete.
- patches.apparmor/vfs-rmdir.diff: Delete.
- patches.apparmor/vfs-setxattr.diff: Delete.
- patches.apparmor/vfs-symlink.diff: Delete.
- patches.apparmor/vfs-unlink.diff: Delete.
* Tue Jul 21 2009 npiggin@suse.de
- Update config files for bnc#522686 -- set
  CONFIG_SECURITY_DEFAULT_MMAP_MIN_ADDR=65536.
* Mon Jul 20 2009 jeffm@suse.de
- Update config files: Disabled optimize for size on all flavors
  (FATE#305694)
* Mon Jul 20 2009 jeffm@suse.de
- Update config files.
* Mon Jul 20 2009 jeffm@suse.com
- Update to 2.6.30.2
  - lots of security and bug fixes
  - Obsoleted patches.fixes/firmware-memmap-64bit.diff
* Mon Jul 20 2009 mmarek@suse.cz
- rpm/split-modules: set LC_COLLATE=C
* Sat Jul 18 2009 jeffm@suse.de
- rpm/package-descriptions: Added desktop description.
* Sat Jul 18 2009 jeffm@suse.de
- rpm/package-descriptions: Added desktop description.
* Sat Jul 18 2009 jeffm@suse.de
- Add -desktop flavors for i386 and x86_64
  - Disabled group scheduler and groups
  - Disabled optimize for size
  - Enabled full preemption
  - Set HZ=1000
* Sat Jul 18 2009 jeffm@suse.de
- Add -desktop flavors for i386 and x86_64 (FATE#305694)
  - Disabled group scheduler and groups
  - Disabled optimize for size
  - Enabled full preemption
  - Set HZ=1000
* Fri Jul 17 2009 jeffm@suse.de
- patches.apparmor/apparmor.diff: ia64 build fix
* Fri Jul 17 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: simplify the add_dirs_to_filelist
  function and make it less chatty in build logs.
* Fri Jul 17 2009 jeffm@suse.com
- patches.apparmor/apparmor.diff: ia64 build fix
* Fri Jul 17 2009 jeffm@suse.com
- patches.apparmor/security-default-lsm: security: Define default
  LSM (bnc#442668).
* Thu Jul 16 2009 jeffm@suse.de
- patches.apparmor/apparmor.diff: AppArmor.
* Thu Jul 16 2009 jeffm@suse.de
- patches.apparmor/apparmor.diff: AppArmor.
* Thu Jul 16 2009 jeffm@suse.de
- patches.rpmify/sgi-hotplug-fixup: hotplug: fix sgi-hotplug
  attribute handling.
* Thu Jul 16 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: drop the config-subst script, use
  scripts/config instead.
* Thu Jul 16 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: fix debugsource generation.
* Thu Jul 16 2009 mmarek@suse.cz
- rpm/split-modules: fix last change.
* Wed Jul 15 2009 mmarek@suse.cz
- rpm/split-modules: fix for module names with underscores or
  dashes.
* Wed Jul 15 2009 jeffm@suse.de
- Update to 2.6.31-rc3.
  - Eliminated 2 patches.
* Wed Jul 15 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: annotate in which products the
  obsoleted kmps were last used, remove "ralink-rt2860-kmp" which
  I couldn't find anywhere.
* Wed Jul 15 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: obsolete btusb-kmp (bnc#514375).
* Tue Jul 14 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in, rpm/split-modules: move generating of
  the base / main / unsupported module lists to a separate script.
  Avoids 6k modinfo calls and fixes module dependencies
  (bnc#512179).
* Mon Jul 13 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: fix include2/asm symlink (bnc#509680).
* Mon Jul 13 2009 mmarek@suse.cz
- rpm/modversions: fix overriding of function symbols.
* Mon Jul 13 2009 mmarek@suse.cz
- rpm/modversions: fix overriding of unknown symbols.
* Tue Jul  7 2009 jkosina@suse.de
- patches.suse/e1000e_allow_bad_checksum: Delete.
- patches.suse/e1000e_call_dump_eeprom: Delete.
- patches.suse/e1000e_use_set_memory_ro-rw_to_protect_flash_memory:
  Delete.
  Delete the leftover debugging patches for e1000e EEPROM corruption
  that are not needed anymore.
* Tue Jul  7 2009 aj@suse.de
- README.BRANCH: Update, kotd will become 11.2 eventually.
* Mon Jul  6 2009 jeffm@suse.com
- Update to 2.6.31-rc2.
* Fri Jul  3 2009 jeffm@suse.com
- Update to 2.6.31-rc1-git10.
  - Eliminated 28 patches.
  - Xen is disabled.
* Fri Jul  3 2009 mmarek@suse.cz
- patches.suse/kbuild-generate-modules.builtin: kbuild: generate
  modules.builtin.
- rpm/kernel-binary.spec.in: package modules.builtin for use by
  modprobe / mkinitrd.
* Fri Jul  3 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in, rpm/kernel-source.spec.in: simplify
  the patch applying loops to reduce noise in build logs.
* Tue Jun 30 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: chmod +x find-provides
* Tue Jun 30 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: do not "annotate" the packaged
  Modules.symvers
- patches.suse/modpost-filter-out-built-in-depends: Delete.
* Tue Jun 30 2009 jbeulich@novell.com
- patches.arch/ia64-page-migration: Fix compiler warning.
* Mon Jun 29 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: move /boot/symvers* files back to
  - base, these are needed during KMP installation.
* Mon Jun 29 2009 mmarek@suse.cz
- patches.fixes/kbuild-fix-generating-of-.symtypes-files: kbuild:
  fix generating of *.symtypes files.
- patches.suse/genksyms-add-override-flag.diff: Refresh.
- rpm/kernel-binary.spec.in: create the *.symref files in the build
  directory
* Fri Jun 26 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: add Provides: kernel-{base,extra} to
  the subpackages (bnc#516827).
* Wed Jun 24 2009 gregkh@suse.de
- Update config files.
  revert the ACPI and thermal config changes:
    config/i386/pae and config/x86-64/default:
  CONFIG_ACPI_AC=m
  CONFIG_ACPI_BATTERY=m
  CONFIG_ACPI_BUTTON=m
  CONFIG_ACPI_VIDEO=m
  CONFIG_ACPI_FAN=m
  CONFIG_ACPI_PROCESSOR=m
  CONFIG_ACPI_THERMAL=m
  CONFIG_ACPI_CONTAINER=m
  CONFIG_X86_ACPI_CPUFREQ=m
  CONFIG_THERMAL=m
* Wed Jun 24 2009 gregkh@suse.de
- patches.suse/ec_merge_irq_and_poll_modes.patch: Delete.
- patches.suse/linux-2.6.29-retry-root-mount.patch: Delete.
* Wed Jun 24 2009 jbeulich@novell.com
- Update Xen patches to 2.6.30 and c/s 908.
- Update Xen config files.
- patches.xen/tmem: Transcendent memory ("tmem") for Linux.
* Tue Jun 23 2009 gregkh@suse.de
- Update config files.
  config/i386/pae and config/x86-64/default:
  CONFIG_ACPI_AC=y
  CONFIG_ACPI_BATTERY=y
  CONFIG_ACPI_BUTTON=y
  CONFIG_ACPI_VIDEO=y
  CONFIG_ACPI_FAN=y
  CONFIG_ACPI_PROCESSOR=y
  CONFIG_ACPI_THERMAL=y
  CONFIG_ACPI_CONTAINER=y
  CONFIG_X86_ACPI_CPUFREQ=y
  CONFIG_THERMAL=y
* Tue Jun 23 2009 gregkh@suse.de
- Update config files.
  config/i386/pae and config/x86-64/default:
  CONFIG_SND_TIMER=y
  CONFIG_SND_PCM=y
  CONFIG_SND_SEQUENCER=y
  CONFIG_SND_MIXER_OSS=y
  CONFIG_SND_PCM_OSS=y
* Tue Jun 23 2009 gregkh@suse.de
- Update config files.
  fix up config mistake in x86-64/default made in last commit.
* Tue Jun 23 2009 gregkh@suse.de
- Update config files.
  config/i386/pae and config/x86-64/default:
  CONFIG_VIDEO_OUTPUT_CONTROL=y
  CONFIG_SOUND=y
  CONFIG_SND=y
* Tue Jun 23 2009 gregkh@suse.de
- Update config files.
  config/i386/pae and config/x86-64/default:
  CONFIG_I2C=y
  CONFIG_HWMON=y
* Sat Jun 20 2009 gregkh@suse.de
- Update config files.
  config/i386/pae and config/x86-64/default:
  CONFIG_IPV6=y
* Sat Jun 20 2009 gregkh@suse.de
- Update config files.
  config/i386/pae and config/x86-64/default:
  CONFIG_HID=y
  CONFIG_USB_STORAGE=y
* Sat Jun 20 2009 gregkh@suse.de
- Update config files.
  config/i386/pae and config/x86-64/default:
  CONFIG_ATA_PIIX=Y
* Sat Jun 20 2009 gregkh@suse.de
- Update config files.
  config/i386/pae and config/x86-64/default:
  CONFIG_USB_EHCI_HCD=Y
  CONFIG_USB_OHCI_HCD=Y
  CONFIG_USB_UHCI_HCD=Y
* Sat Jun 20 2009 gregkh@suse.de
- Update config files.
  config/i386/pae and config/x86-64/default:
  CONFIG_CFG80211=Y
  CONFIG_LIB80211=Y
  CONFIG_MAC80211=Y
  CONFIG_ATH5K=Y
* Sat Jun 20 2009 gregkh@suse.de
- Update config files.
  config/i386/pae and config/x86-64/default:
  CONFIG_X86_MSR=Y
  CONFIG_X86_CPUID=Y
* Fri Jun 19 2009 gregkh@suse.de
- comment out broken acpi patch for the moment.
* Fri Jun 19 2009 gregkh@suse.de
- move the "preload" branch into master to get 2.6.30 working
  for Moblin.
- Update config files.
- patches.drivers/alsa-ad1984a-hp-quirks: ALSA: update HP
  quirks for Zenith & co (bnc#472789, bnc#479617, bnc#502425,
  bnc#503101).
- patches.suse/driver-core-add-nodename-callbacks.patch: Driver
  Core: add nodename callbacks.
- patches.suse/driver-core-aoe-add-nodename-for-aoe-devices.patch:
  Driver Core: aoe: add nodename for aoe devices.
- patches.suse/driver-core-block-add-nodename-support-for-block-drivers.patch:
  Driver Core: block: add nodename support for block drivers..
- patches.suse/driver-core-bsg-add-nodename-for-bsg-driver.patch:
  Driver Core: bsg: add nodename for bsg driver.
- patches.suse/driver-core-devtmpfs-driver-core-maintained-dev-tmpfs.patch:
  Driver Core: devtmpfs - kernel-maintained tmpfs-based /dev.
- patches.suse/driver-core-drm-add-nodename-for-drm-devices.patch:
  Driver Core: drm: add nodename for drm devices.
- patches.suse/driver-core-dvb-add-nodename-for-dvb-drivers.patch:
  Driver Core: dvb: add nodename for dvb drivers.
- patches.suse/driver-core-input-add-nodename-for-input-drivers.patch:
  Driver Core: input: add nodename for input drivers.
- patches.suse/driver-core-misc-add-nodename-support-for-misc-devices.patch:
  Driver Core: misc: add nodename support for misc devices..
- patches.suse/driver-core-raw-add-nodename-for-raw-devices.patch:
  Driver Core: raw: add nodename for raw devices.
- patches.suse/driver-core-sound-add-nodename-for-sound-drivers.patch:
  Driver Core: sound: add nodename for sound drivers.
- patches.suse/driver-core-usb-add-nodename-support-for-usb-drivers.patch:
  Driver Core: usb: add nodename support for usb drivers..
- patches.suse/driver-core-x86-add-nodename-for-cpuid-and-msr-drivers.patch:
  Driver Core: x86: add nodename for cpuid and msr drivers..
- patches.suse/ec_merge_irq_and_poll_modes.patch: ACPI: EC:
  Merge IRQ and POLL modes.
- patches.suse/linux-2.6.29-dont-wait-for-mouse.patch: fastboot:
  remove "wait for all devices before mounting root" delay.
- patches.suse/linux-2.6.29-enable-async-by-default.patch:
  enable async_enabled by default.
- patches.suse/linux-2.6.29-even-faster-kms.patch: speed up kms
  even more.
- patches.suse/linux-2.6.29-jbd-longer-commit-interval.patch:
  jbd: longer commit interval.
- patches.suse/linux-2.6.29-kms-after-sata.patch: make kms happen
  after sata.
- patches.suse/linux-2.6.29-retry-root-mount.patch: fastboot:
  retry mounting the root fs if we can't find init.
- patches.suse/linux-2.6.29-silence-acer-message.patch: Silence
  acer wmi driver on non-acer machines.
- patches.suse/linux-2.6.29-touchkit.patch: some new touch screen
  device ids
  .
- patches.suse/uvcvideo-ignore-hue-control-for-5986-0241.patch:
  uvcvideo: ignore hue control for 5986:0241 (bnc#499152).
- patches.suse/devtmpfs.patch: Delete.
* Fri Jun 12 2009 greg@suse.de
- scripts/sequence-patch.sh: fix bug in ketchup usage
* Wed Jun 10 2009 jeffm@suse.com
- Update to 2.6.30-final.
* Wed Jun 10 2009 jbeulich@novell.com
- Update Xen patches to 2.6.30-rc8 and c/s 898.
- Update Xen config files.
- patches.xen/pci-reserve: linux/pci: reserve io/memory space
  for bridge.
- patches.xen/xen-x86-exports: Delete.
* Tue Jun  9 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in, rpm/kernel-source.spec.in,
  rpm/kernel-syms.spec.in, rpm/mkspec: update copyright header and
  change indentation to what autobuild enforces on checkin. No
  functional change.
* Tue Jun  9 2009 jbeulich@novell.com
- patches.suse/stack-unwind-add-declaration.patch: Fold into ...
- patches.suse/stack-unwind: ... this one.
* Tue Jun  9 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: move /boot/vmlinux-*.gz to -devel
  again.
- rpm/find-provides: don't generate the ksym() provides ourself,
  let rpm do it. Add a workaround for vmlinux-*.gz in -devel.
* Mon Jun  8 2009 jeffm@suse.com
- patches.suse/reiser4-set_page_dirty_notag: mm: Add
  set_page_dirty_notag() helper for reiser4.
* Fri Jun  5 2009 mmarek@suse.cz
- rpm/kernel-module-subpackage: add Enhances: kernel-$flavor to
  kmps (bnc#502092).
* Thu Jun  4 2009 jeffm@suse.de
- Update to 2.6.30-rc8.
* Thu Jun  4 2009 sdietrich@suse.de
- supported.conf: remove duplicate kernel/drivers/md/dm-log
* Thu Jun  4 2009 teheo@suse.de
  Conver ide major allocation.
- patches.suse/block-add-mangle-devt-switch: block: add
  genhd.mangle_devt parameter (fate#305584).
* Mon Jun  1 2009 jeffm@suse.de
- Update to 2.6.30-rc7-git4.
* Fri May 29 2009 teheo@suse.de
  Rename mangle_minor to mangle_devt and also cover sd major allocation.
- patches.suse/block-add-mangle-devt-switch: block: add
  genhd.mangle_devt parameter (fate#305584).
* Fri May 29 2009 teheo@suse.de
- Update config files to enable DEBUG_BLOCK_EXT_DEVT on all configs
  except for vanilla and ppc/ps3.
- patches.suse/block-add-mangle-devt-switch: block: add
  genhd.mangle_minor parameter (fate#305584).
* Thu May 28 2009 jdelvare@suse.de
- patches.fixes/scsi-scan-blist-update: Add BLIST_REPORTLUN2 to
  EMC SYMMETRIX (bnc#185164, bnc#191648, bnc#505578).
* Wed May 27 2009 jeffm@suse.com
- Update to 2.6.30-rc7-git2.
* Wed May 27 2009 gregkh@suse.de
- patches.drivers/ath1e-add-new-device-id-for-asus-hardware.patch:
  ath1e: add new device id for asus hardware.
* Tue May 26 2009 mmarek@suse.cz
- rpm/mkspec: when using a custom release number, create a
  get_release_number.sh script for autobuild.
* Tue May 26 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: workaround for bnc#507084: strip
  binaries in /usr/src/linux-obj/*/*/scripts.
* Tue May 26 2009 jdelvare@suse.de
- patches.drivers/r8169-allow-true-forced-mode-setting.patch:
  r8169: allow true forced mode setting (bnc#467518).
* Mon May 25 2009 mmarek@suse.cz
- switch i386 flavors back to -default (non-pae) and -pae for
  milestone2
* Sun May 24 2009 mmarek@suse.cz
- rpm/find-provides: fix for kernel-kdump.
* Sat May 23 2009 mmarek@suse.cz
- rpm/find-provides, rpm/kernel-binary.spec.in, rpm/symsets.pl:
  workaround to fix provides of built-in symbols: move vmlinux*.gz
  back to -base and extract the provides from it.
* Fri May 22 2009 teheo@suse.de
- patches.arch/i586-unwind-quick-fix: i586-relocs: ignore NONE
  relocation.
* Fri May 22 2009 mmarek@suse.cz
- rpm/compute-PATCHVERSION.sh, rpm/mkspec, scripts/tar-up.sh: avoid
  unpacking the patches tarballs in compute-PATCHVERSION.sh.
* Fri May 22 2009 mmarek@suse.cz
- rpm/mkspec: add --release option to set a custom release string.
- scripts/tar-up.sh: revive -rs option.
* Wed May 20 2009 mmarek@suse.cz
- patches.arch/acpi_thermal_passive_blacklist.patch,
  patches.suse/devtmpfs.patch: fix patches to apply with git-apply.
* Tue May 19 2009 sdietrich@suse.de
- patches.suse/stack-unwind-add-declaration.patch: Fix compile
  error when CONFIG_STACK_UNWIND is not set.
* Tue May 19 2009 jblunck@suse.de
- patches.rpmify/arm-arch_include_asm-fix.diff: ARM: move
  mach-types.h to arch/include/asm.
* Tue May 19 2009 jeffm@suse.com
- Set CONFIG_FRAMEBUFFER_CONSOLE=y
* Tue May 19 2009 jeffm@suse.com
- Restored CONFIG_BOOTSPLASH=y and CONFIG_FB_VESA=y on
  x86/x86_64 (bnc#504608)
* Tue May 19 2009 jbeulich@novell.com
- patches.xen/sfc-endianness: fix building with gcc 4.4.
* Tue May 19 2009 jbeulich@novell.com
- Update Xen patches to 2.6.30/rc6-git3 and c/s 873.
* Mon May 18 2009 jeffm@suse.com
- Updated to 2.6.30-rc6-git3.
  - Eliminated 4 patches.
* Fri May 15 2009 jeffm@suse.de
- doc/README.SUSE: Updated to reflect building in an external
  directory so as not to contaminate /usr/src/linux
* Thu May 14 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: fix path in
  /usr/src/linux-obj/.../Makefile.
* Thu May 14 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: provide kernel-$flavor-devel =
  %%version-%%source_rel in the -devel packages (bnc#503280).
* Wed May 13 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: also fix kernel-$flavor-devel requires
  (bnc#503280).
* Wed May 13 2009 mmarek@suse.cz
- rpm/mkspec: fix kernel-syms requires (bnc#503280).
* Mon May 11 2009 jeffm@suse.com
- patches.fixes/dup2-retval-fix: dup2: Fix return value with
  oldfd == newfd and invalid fd (bnc#498042).
* Mon May 11 2009 jeffm@suse.com
- patches.fixes/reiserfs-xattr-fixup: reiserfs: clean up ifdefs.
- patches.fixes/reiserfs-xattr-root-fixup: reiserfs: deal with
  NULL xattr root w/ xattrs disabled.
- patches.fixes/reiserfs-xattrs-disabled-perms: reiserfs: fixup
  perms when xattrs are disabled.
- patches.fixes/reiserfs-expose-privroot: reiserfs: allow exposing
  privroot w/ xattrs enabled.
* Mon May 11 2009 jeffm@suse.de
- Updated to 2.6.30-rc5-git1.
  - Eliminated 4 patches.
* Wed May  6 2009 gregkh@suse.de
- Update config files. update vanilla configs so that the build works.
* Wed May  6 2009 gregkh@suse.de
- Update config files.
- patches.suse/devtmpfs.patch: driver-core: devtmpfs - driver-core
  maintained /dev tmpfs.
* Tue May  5 2009 jeffm@suse.com
- Update config files.
* Tue May  5 2009 jeffm@suse.com
- Update to 2.6.30-rc4-git1.
- patches.rpmify/fix-unexpected-non-allocable-warnings-with-suse-gcc:
  kbuild, modpost: fix "unexpected non-allocatable" warning with
  SUSE gcc.
* Tue May  5 2009 jbeulich@novell.com
- patches.fixes/iwl3945-build: iwl3945: fix ia64/ppc build.
* Tue May  5 2009 jbeulich@novell.com
- patches.xen/xen3-patch-2.6.30-rc4: Fix ia64 build.
* Tue May  5 2009 jbeulich@novell.com
- patches.suse/stack-unwind: Also initialize PT_GS() on 32-bit.
- patches.arch/x86_64-unwind-annotations: Refresh.
* Tue May  5 2009 jbeulich@novell.com
- Update Xen patches to 2.6.29-rc4 and c/s 867.
- Update i386 and x86_64 config files.
- config.conf: Re-enable Xen.
* Tue May  5 2009 teheo@suse.de
- patches.suse/kbuild-icecream-workaround: kbuild: add workaround
  for icecream bug (bnc#495786).
* Fri May  1 2009 jeffm@suse.com
- patches.fixes/reiserfs-xattr-locking: reiserfs: Expand i_mutex
  to enclose lookup_one_len.
* Fri May  1 2009 jeffm@suse.com
- Update to 2.6.30-rc4.
  - Eliminated 2 patches.
* Fri May  1 2009 jeffm@suse.com
- patches.drivers/libata-prefer-over-ide: libata: prefer libata
  drivers over ide ones (bnc#433105).
- patches.fixes/reiserfs-xattr-locking: reiserfs: Expand i_mutex
  to enclose lookup_one_len.
- patches.kernel.org/patch-2.6.30-rc3-rc4:
- patches.suse/no-frame-pointer-select: Fix stack unwinder Kconfig
  (bnc#402518).
- patches.arch/s390-08-05-af_iucv-msgpeek-fix.patch: Delete.
- patches.fixes/fix-periodic-mode-programming-on-amd81xx: Delete.
* Thu Apr 30 2009 mmarek@suse.cz
- scripts/submit-to-bs: tentative script to submit a new kernel to
  openSUSE:Factory
* Tue Apr 28 2009 npiggin@suse.de
- patches.apparmor/unambiguous-__d_path.diff: Put a reminder in here
  to fix the lock order problem when the patch is updated to HEAD.
* Mon Apr 27 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in, rpm/kernel-source.spec.in,
  rpm/kernel-syms.spec.in, rpm/mkspec: Fix prepending EXTRAVERSION,
  rename the variable back to @RELEASE_PREFIX@.
* Mon Apr 27 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in, rpm/kernel-source.spec.in,
  rpm/kernel-syms.spec.in, rpm/mkspec: prepend the EXTRAVERSION to
  the rpm release string (note that this won't have any effect in
  the openSUSE:* projects).
* Fri Apr 24 2009 gregkh@suse.de
- Update config files.
  - build rtc_cmos driver into the kernel for i386 and x86-64 default
    kernels.  This should automatically take care of the rtc/system time
    syncing so we don't need to do it in a boot script and should speed
    up booting time a lot.
* Fri Apr 24 2009 gregkh@suse.de
- Update config files. change CONFIG_ATA=y and CONFIG_SATA_AHCI=y
* Fri Apr 24 2009 gregkh@suse.de
- Update config files. change to CONFIG_EXT2_FS=y and CONFIG_EXT3_FS=y
* Fri Apr 24 2009 gregkh@suse.de
- Update config files. change to CONFIG_SCSI=y and CONFIG_BLK_DEV_SD=y
* Fri Apr 24 2009 gregkh@suse.de
- Update config files. change to use CONFIG_USB=y
* Thu Apr 23 2009 jeffm@suse.de
- Added legacy config.
* Thu Apr 23 2009 jeffm@suse.de
- Temporarily disabled patches.suse/acpi-dsdt-initrd-v0.9a-2.6.25.patch
* Thu Apr 23 2009 jeffm@suse.de
- Moved i386 kernel-default to kernel-legacy.
- Moved i386 kernel-pae config to kernel-default.
- Disabled CONFIG_ISA in i386 kernel-default to improve boot speed.
* Thu Apr 23 2009 jeffm@suse.de
- Update to 2.6.30-rc3.
* Thu Apr 23 2009 jeffm@suse.de
- patches.fixes/fix-periodic-mode-programming-on-amd81xx: x86:
  hpet: fix periodic mode programming on AMD 81xx.
- patches.fixes/hpet-boot-fix: Delete.
* Mon Apr 20 2009 jeffm@suse.de
- patches.fixes/hpet-boot-fix: hpet: fix "IO-APIC + timer doesn't work!"
* Mon Apr 20 2009 jeffm@suse.de
- Update to 2.6.30-rc2-git6.
* Wed Apr 15 2009 jeffm@suse.de
- Update to 2.6.30-rc2.
  - trace and xen flavors disabled.
  - CONFIG_OTUS disabled on ppc.
  - request-based multipath could use some testing.
  - Eliminated 96 patches.
* Fri Apr 10 2009 jeffm@suse.de
- rpm/devel-post.sh, rpm/kernel-binary.spec.in: Created i586 symlink
  for i386.
* Fri Apr 10 2009 jeffm@suse.de
- rpm/kernel-binary.spec.in: Added /usr/src/linux-obj to -devel
* Fri Apr 10 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Use xargs -r to fix case when no
  modules are supported.
* Fri Apr 10 2009 jeffm@suse.com
- Moved linux-obj symlink handling to kernel-$flavor-devel.
* Fri Apr 10 2009 mmarek@suse.cz
- rpm/package-descriptions: Add comment.
* Fri Apr 10 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in, rpm/kernel-source.spec.in,
  rpm/kernel-syms.spec.in, scripts/tar-up.sh: Rename the timestamp
  file to source-timestamp instead, so that autobuild does not add
  the timestamp verbatim.
* Thu Apr  9 2009 jbeulich@novell.com
- Update Xen patches to 2.6.29 final and c/s 854.
- patches.xen/sfc-external-sram: enable access to Falcon's
  external SRAM (bnc#489105).
- patches.xen/sfc-sync-headers: sync Solarflare accelerator
  headers (bnc#489105).
- Update Xen config files.
* Wed Apr  8 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in, rpm/kernel-source.spec.in,
  rpm/kernel-syms.spec.in: Fix last change: do not add the
  timestamp if it is already added verbatim (by prepare_spec during
  checkin)
* Tue Apr  7 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in, rpm/kernel-source.spec.in,
  rpm/kernel-syms.spec.in: Add source timestamp to package
  descriptions.
* Tue Apr  7 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in, rpm/kernel-source.spec.in,
  rpm/kernel-syms.spec.in, rpm/mkspec: add descriptions to
  generated spec files.
- rpm/package-descriptions: descriptions of binary packages.
* Mon Apr  6 2009 jeffm@suse.com
- Enabled STAGING on !x86 and disabled COMEDI.
* Mon Apr  6 2009 jeffm@suse.com
- patches.rpmify/split-package: Enable
* Mon Apr  6 2009 jeffm@suse.com
- Update config files: Fixed i386-vanilla.
* Mon Apr  6 2009 jeffm@suse.com
- patches.fixes/xfs-export-debug: xfs: export assertion handler.
* Mon Apr  6 2009 jeffm@suse.com
- Switch from SPARSEMEM to DISCONTIGMEM on i386.
* Sun Apr  5 2009 jeffm@suse.com
- scripts/tar-up_and_run_mbuild.sh: Added pae to the important
  specfiles list.
* Fri Apr  3 2009 jeffm@suse.com
- Update config files: Fix missing ia64-debug.
* Fri Apr  3 2009 jeffm@suse.com
- patches.xen/sfc-resource-driver: Fix uninitialized var warning.
* Fri Apr  3 2009 jeffm@suse.com
- Drop NR_CPUS back to 128 on i386.
* Fri Apr  3 2009 jeffm@suse.com
- rpm/kernel-binary.spec.in: Added CONFIG_SPLIT_PACKAGE.
* Fri Apr  3 2009 jeffm@suse.de
- Update config files: Enabled STAGING drivers on -vanilla.
* Fri Apr  3 2009 jblunck@suse.de
- patches.rpmify/rpm-kernel-config: Rediff.
* Fri Apr  3 2009 mmarek@suse.cz
- rpm/kernel-source.spec.in: chmod +x mkspec arch-symbols
  compute-PATCHVERSION.sh
* Fri Apr  3 2009 jeffm@suse.com
- Update config files: Enabled STAGING drivers.
* Fri Apr  3 2009 jeffm@suse.com
- Sync up kernel configs for x86/x86_64 flavors.
* Fri Apr  3 2009 mmarek@suse.cz
- rpm/kernel-source.spec.in, rpm/mkspec: do not package the binary
  spec files anymore.
* Thu Apr  2 2009 mmarek@suse.cz
- rpm/modversions: keep the override keyword in --pack.
* Thu Apr  2 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in, rpm/mkspec, scripts/tar-up.sh: remove
  @TOLERATE_UNKNOWN_NEW_CONFIG_OPTIONS@ expansion, check for a file
  named TOLERATE-UNKNOWN-NEW-CONFIG-OPTIONS in sourcedir instead.
* Thu Apr  2 2009 mmarek@suse.cz
- rpm/kernel-syms.spec.in: set LC_ALL=C in rpm -q call
* Thu Apr  2 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: add @FLAVOR@ again to avoid %%%%(...)
  expansion
* Thu Apr  2 2009 mmarek@suse.cz
- rpm/mkspec: new script to generate spec files from *.spec.in
  templates
- rpm/compute-PATCHVERSION.sh, rpm/kernel-binary.spec.in,
  rpm/kernel-source.spec.in, rpm/kernel-syms.spec.in: add to the
  source rpm
- scripts/tar-up.sh: just tar up patches directories and call
  mkspec
* Tue Mar 31 2009 mmarek@suse.cz
- rpm/kernel-dummy.spec.in: Delete.
* Tue Mar 31 2009 jeffm@suse.de
- doc/README.KSYMS: Add to repo.
* Tue Mar 31 2009 mmarek@suse.cz
- config.conf, rpm/old-packages.conf, scripts/arch-symbols,
  scripts/run_oldconfig.sh, scripts/tar-up.sh: drop the arch
  symbols completely, only map the various ix86 archs to i386.
* Tue Mar 31 2009 mmarek@suse.cz
- doc/README.SUSE: allow_unsupported_modules needs to be set before
  installing the kernel (bnc#484664).
* Tue Mar 31 2009 jeffm@suse.de
- Add %%changelog to spec files
* Tue Mar 31 2009 jeffm@suse.de
- rpm/kernel-binary.spec.in: Clean up %%build_$flavor macros
* Tue Mar 31 2009 jeffm@suse.de
- rpm/kernel-source.spec.in: Create kernel-source-vanilla
* Tue Mar 31 2009 jeffm@suse.de
- rpm/kernel-syms.spec.in, scripts/tar-up.sh: Depend on kernel-$flavor-devel
* Tue Mar 31 2009 jeffm@suse.de
- rpm/kernel-binary.spec.in, rpm/kernel-source.spec.in,
  rpm/kernel-syms.spec.in: Create a %%using_buildservice macro
* Tue Mar 31 2009 jeffm@suse.de
- rpm/kernel-binary.spec.in, rpm/kernel-source.spec.in,
  scripts/sequence-patch.sh, scripts/tar-up.sh:
  kernel-{binary,source}: Remove arch guards
* Tue Mar 31 2009 jeffm@suse.de
- doc/README.SUSE, rpm/kernel-binary.spec.in, rpm/kernel-source.spec.in,
  scripts/tar-up.sh: Move development files from kernel-source to
  kernel-$flavor-devel
* Tue Mar 31 2009 jeffm@suse.de
- rpm/kernel-binary.spec.in: Remove $CONFIG_MODULES
* Tue Mar 31 2009 jeffm@suse.de
- rpm/kernel-binary.spec.in: Remove duplicate CONFIG_DEBUG_INFO=y
* Tue Mar 31 2009 jeffm@suse.de
- rpm/kernel-binary.spec.in: Use macros for cpu_arch
* Tue Mar 31 2009 jeffm@suse.de
- rpm/kernel-binary.spec.in, rpm/kernel-source.spec.in:
  kernel-{source,binary}: Use path-related rpm macros
* Tue Mar 31 2009 jeffm@suse.de
- rpm/kernel-binary.spec.in,  rpm/kernel-source.spec.in:
  Use a %%kernelrelease macro.
* Tue Mar 31 2009 jeffm@suse.de
- rpm/kernel-source.spec.in, rpm/source-post.sh, scripts/tar-up.sh:
  Use %%variant instead of $variant
* Tue Mar 31 2009 jeffm@suse.de
- kernel-source: Kill old obsoletes
* Tue Mar 31 2009 jeffm@suse.de
- rpm/kernel-binary.spec.in, rpm/kernel-source.spec.in,
  rpm/kernel-syms.spec.in, scripts/tar-up.sh:
  Use %%var instead of @VAR@ except where necessary
* Tue Mar 31 2009 jeffm@suse.de
- kernel-syms: Sort by flavor, not architecture
* Tue Mar 31 2009 jeffm@suse.de
- kernel-syms: Stop the architecture %%else madness
* Tue Mar 31 2009 jeffm@suse.de
- kernel-binary: Stop the architecture %%else madness
* Mon Mar 30 2009 jeffm@suse.de
- Removed -RT guards and a dead patch.
* Mon Mar 30 2009 jeffm@suse.de
- patches.fixes/reiserfs-prealloc-fix: Delete.
* Mon Mar 30 2009 jeffm@suse.de
- patches.suse/reiserfs-inode-init: Delete.
* Thu Mar 26 2009 mmarek@suse.cz
- rpm/config.sh: introduce rpm/config.sh, defining SRCVERSION and
  VARIANT variables.
* Tue Mar 24 2009 jeffm@suse.de
- Update to 2.6.29-final.
  - Eliminated 4 patches.
* Fri Mar 20 2009 jbeulich@novell.com
- Update Xen config files.
- Update Xen patches to 2.6.29-rc8 and c/s 821.
* Wed Mar 18 2009 mmarek@suse.cz
- rpm/kernel-*.spec.in, scripts/tar-up.sh: don't add "<RELEASE>"
  to the release, breaks plain rpmbuild.
* Tue Mar 17 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: don't generate symsets
- rpm/kernel-syms.spec.in: don't package symsets
- rpm/find-provides: disable symset provides
- rpm/macros.kernel-source: don't check for /boot/symsets*
  (fate#305945)
* Tue Mar 17 2009 knikanth@suse.de
- patches.fixes/loop-barriers: Delete.
- patches.fixes/loop-barriers2: Delete.
  Remove non-mainline patches to loop driver making it honour
  O_SYNC, sync requests and barriers. (bnc#485089), (bnc#471249)
* Mon Mar 16 2009 bphilips@suse.de
- README: add rough guide to updating KABI
* Sat Mar 14 2009 jeffm@suse.com
- Update to 2.6.29-rc8.
* Thu Mar 12 2009 jbeulich@novell.com
- patches.fixes/fix-nf_conntrack_slp,
  patches.suse/perfmon2-remove_get_base_syscall_attr.patch,
  patches.suse/perfmon2.patch,
  patches.suse/silent-stack-overflow-2.patch: fix build warnings.
* Thu Mar 12 2009 jbeulich@novell.com
- Update Xen patches addressing several issues in initial commit
- Update Xen config files (re-enable oprofile, disable novfs).
- patches.xen/xen3-x86_64-unwind-annotations: fix unwind annotations
  in entry_64-xen.S.
* Thu Mar 12 2009 jbeulich@novell.com
- patches.arch/x86_64-unwind-annotations: fix unwind annotations in
  entry_64.S.
* Thu Mar 12 2009 rgoldwyn@suse.de
- patches.suse/novfs-creds-change-2.6.29: Changing credential
  according to new task_struct.
* Wed Mar 11 2009 jblunck@suse.de
- rpm/kernel-binary.spec.in: Use split_packages only if supported.conf
  is not empty.
* Mon Mar  9 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: renamed modprobe config to
  /etc/modprobe.d/50-module-renames.conf (required by new
  module-init-tools).
* Mon Mar  9 2009 jbeulich@novell.com
- patches.xen/xen3-patch-2.6.29-rc4: fix ia64 build.
* Mon Mar  9 2009 jbeulich@novell.com
- Update Xen config files (get tracing options back in sync with
  default).
* Fri Mar  6 2009 jeffm@suse.de
- Update config files: Enable CONFIG_FRAME_POINTER on Xen.
* Fri Mar  6 2009 jeffm@suse.de
- config.conf: Enabled Xen for building.
* Fri Mar  6 2009 jbeulich@novell.com
- Update Xen patches to 2.6.29-rc7.
* Fri Mar  6 2009 jbenc@suse.cz
- Update config files: enabled wireless debugging in -debug flavors.
* Fri Mar  6 2009 mmarek@suse.cz
- rpm/get_release_number.sh.in, rpm/kernel-binary.spec.in,
  rpm/kernel-source.spec.in, rpm/kernel-syms.spec.in,
  scripts/tar-up.sh, doc/README.SUSE: finally drop kernel-dummy
- rpm/prepare-build.sh: Delete.
* Wed Mar  4 2009 jeffm@suse.com
- Update to 2.6.29-rc7.
  - Eliminated 1 patch.
* Wed Mar  4 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: workaround a bash bug (bnc#481817)
  in kernel-vanilla.spec.
* Wed Mar  4 2009 jeffm@suse.com
- patches.suse/export-security_inode_permission: Export
  security_inode_permission for aufs.
* Thu Feb 26 2009 jeffm@suse.com
- scripts/tar-up.sh: Add -u to update existing spec files.
* Thu Feb 26 2009 sven@suse.de
- rpm/kernel-binary.spec.in: Fix sub-package install-time conflict.
* Wed Feb 25 2009 mmarek@suse.cz
- scripts/tar-up.sh: create tarballs that don't change
  unnecessarily: set owner/group to nobody/nobody, mtime to time of
  the latest commit and sort the input files.
* Wed Feb 25 2009 jeffm@suse.com
- Update to 2.6.29-rc6-git1.
* Sat Feb 21 2009 mmarek@suse.cz
- rpm/kernel-syms.spec.in: also check if the package versions match
  (bnc#478462)
* Fri Feb 20 2009 jbeulich@novell.com
- patches.suse/stack-unwind: fix 32-bit arch_unwind_init_running().
* Fri Feb 20 2009 jbeulich@novell.com
- patches.suse/stack-unwind: fix patch fuzz.
* Fri Feb 20 2009 jbeulich@novell.com
- misc/xen-port-patches.py: Adjust fro new x86 header placement.
- patches.arch/x86_64-unwind-annotations: fix unwind annotations
  (bnc#472783).
- patches.suse/stack-unwind: Properlz hook up unwinder again.
* Fri Feb 20 2009 jeffm@suse.de
- patches.suse/kdb-common: Build fix with -I directive.
* Fri Feb 20 2009 jeffm@suse.de
- Update config files.
* Fri Feb 20 2009 jeffm@suse.de
- Update to 2.6.29-rc5-git3.
  - Eliminated 1 patch.
* Thu Feb 19 2009 mmarek@suse.cz
- rpm/symsets.pl: allow passing only Module.symvers and no modules
* Wed Feb 18 2009 olh@suse.de
- disable ppc601 support, disable unused framebuffer drivers
* Wed Feb 18 2009 olh@suse.de
- disable kdump on ppc32
* Mon Feb 16 2009 jeffm@suse.com
- Update config files.
* Sat Feb 14 2009 jeffm@suse.de
- Update to 2.6.29-rc5.
* Fri Feb 13 2009 jeffm@suse.de
- Update to 2.6.29-rc4-git7.
  - Eliminated 2 patches.
* Mon Feb  9 2009 jeffm@suse.de
- patches.rpmify/spin_is_contended-fix: spin_is_contended
  Kconfig fixes.
* Mon Feb  9 2009 jeffm@suse.de
- Updated to 2.6.29-rc4.
  - Eliminated 3 patches.
* Fri Feb  6 2009 jeffm@suse.com
- patches.fixes/fix-warning-while-mapping-0-1MB-range-with-dev-mem:
  x86, pat: fix warn_on_once() while mapping 0-1MB range.
* Fri Feb  6 2009 mmarek@suse.cz
- rpm/kernel-module-subpackage, rpm/post.sh, rpm/postun.sh: fix
  last change: don't pass -e to weak-modules2.
* Fri Feb  6 2009 mmarek@suse.cz
- rpm/kernel-module-subpackage, rpm/post.sh, rpm/postun.sh: pass
  down shell options like -x to weak-modules2 to make debugging
  with rpm -ivv easier.
* Tue Feb  3 2009 jeffm@suse.de
- patches.fixes/fix-nf_conntrack_slp: make nf_conntrack_slp
  actually work (bnc#470963).
* Tue Feb  3 2009 mmarek@suse.cz
- scripts/tar-up.sh: fix branch name in KOTD packages.
* Tue Feb  3 2009 olh@suse.de
- config.conf: readde -debug flavor for ppc64
* Tue Feb  3 2009 olh@suse.de
- patches.fixes/scsi-ibmvfc_prli_initiator_fix.patch:
  Better handle other FC initiators (bnc#471217 - LTC51238)
* Tue Feb  3 2009 mmarek@suse.cz
- scripts/wd-functions.sh: display master as "master", not "HEAD"
  or "".
* Mon Feb  2 2009 jeffm@suse.de
- patches.fixes/ath9k-fix-led_device_naming.diff: ath9k: fix
  led naming.
- patches.fixes/b43legacy-fix-led_device_naming.diff: b43legacy:
  fix led naming.
- patches.fixes/iwlwifi-fix-iwl-3945_led_device_naming.diff:
  iwlwifi: another led naming fix.
- patches.fixes/iwlwifi-fix-iwl-led_device_naming.diff: iwlwifi:
  fix led naming   .
- patches.fixes/rt2x00-fix-led_device_naming.diff: rt2x00:
  fix led naming.
* Mon Feb  2 2009 jeffm@suse.de
- Updated to 2.6.29-rc3-git3.
  - Eliminated 6 patches.
* Mon Feb  2 2009 jeffm@suse.de
- Updated to 2.6.29-rc3.
  - AppArmor is disabled.
  - Xen is disabled.
  - Eliminated 745 patches.
* Mon Feb  2 2009 jeffm@suse.de
- Enabled patches.suse/reiserfs_warning-reentrant
* Mon Feb  2 2009 rw@suse.de
- patches.fixes/xpc-pass-physical,
  patches.kabi/xpc-pass-physical:
  kABI: restore upstream patch, add ABI cover-up. (bnc#458811)
* Mon Feb  2 2009 olh@suse.de
- patches.fixes/serial-jsm-enable_ms.patch:
  Add enable_ms to jsm driver (bnc#471224 - LTC51066)
* Mon Feb  2 2009 olh@suse.de
- patches.arch/ppc-optimize-sync.patch:
  Optimise smp_{r,w}mb and mutex (bnc#471222 - LTC51356)
* Sat Jan 31 2009 gregkh@suse.de
- refresh patches for fuzz due to 2.6.27.14-rc1 import.
* Sat Jan 31 2009 gregkh@suse.de
- patches.kabi/abi-fix-add-epoll_devs-back-to-struct-user_struct.patch:
  ABI fix: add epoll_devs back to struct user_struct.
* Sat Jan 31 2009 gregkh@suse.de
- Update to 2.6.27.14-rc1
  - lots of security fixes
  - lots of bugfixes
  - obsoletes:
  - patches.drivers/alsa-virtuoso-no-eeprom-overwrite
  - patches.drivers/pata_via.c-support-vx855-and-future-chips-whose-ide-controller-use-0x0571.patch
  - patches.fixes/SUNRPC-Fix-autobind-on-cloned-rpc-clients.patch
  - patches.fixes/sysfs-fix-problems-with-binary-files.patch
  - patches.fixes/xpc-fix-NULL-deref
  - patches.fixes/xpc-write-barrier
* Fri Jan 30 2009 olh@suse.de
- patches.arch/ppc-pseries-migration_hang_fix.patch:
  Fix partition migration hang under load (bnc#470563 - LTC51153)
* Fri Jan 30 2009 olh@suse.de
- disable CONFIG_DEBUG_STACKOVERFLOW and CONFIG_DEBUG_STACK_USAGE
  on ppc/ppc64
* Fri Jan 30 2009 teheo@suse.de
- patches.drivers/libata-fix-EH-device-failure-handling: libata:
  fix EH device failure handling (bnc#470845).
* Thu Jan 29 2009 jjolly@suse.de
- patches.arch/s390-08-08-add_qdio_utilization.patch: zfcp:
  queue_full is lacking the entry for qdio utilization
  (bnc#466462).
* Thu Jan 29 2009 gregkh@suse.de
- add ability to debug kernel using USB debug connector.
- Update config files.
- patches.suse/usb-move-ehci-reg-def.patch: usb: move ehci
  reg def.
- patches.suse/x86-usb-debug-port-early-console-v4.patch: x86:
  usb debug port early console, v4.
* Thu Jan 29 2009 mmarek@suse.cz
- patches.kabi/abi-fix-add-s_syncing-back-to-struct-super_block.patch
  patches.kabi/abi-fix-add-wb_sync_hold-enum-writeback_sync_modes.patch
  patches.kabi/export-iwl_rx_allocate
  patches.kabi/sched-kabi-compat-hack.patch: Introduce
  patches.kabi/ for patches that only work around kabi issues and
  can be safely dropped at the next SP.
* Wed Jan 28 2009 agruen@suse.de
- patches.xen/xen-x86-mark_rodata_rw.patch: Add missing pageattr.c
  changes to pageattr-xen.c (bnc#439348).
* Wed Jan 28 2009 agruen@suse.de
- patches.suse/x86-mark_rodata_rw.patch: Add mark_rodata_rw()
  to un-protect read-only kernel code pages (bnc#439348).
- patches.xen/xen-x86-mark_rodata_rw.patch: xen specific part
  (bnc#439348).
* Wed Jan 28 2009 mmarek@suse.cz
- config/s390/s390: the -man package still fails for s390, disable
  it
* Wed Jan 28 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: fix build of the -man subpackage on
  31bit s390
* Wed Jan 28 2009 mmarek@suse.cz
- fix kernel-default.ppc64 reference symsets
* Wed Jan 28 2009 jslaby@suse.cz
- patches.arch/x86_sgi_cpus4096-05-update-send_IPI_mask.patch:
  x86 cpumask: Updates to support NR_CPUS=4096 (bnc#425240
  FATE304266).
  [cpu_mask_to_apicid bigsmp fix]
* Wed Jan 28 2009 olh@suse.de
- patches.fixes/scsi-ibmvscsi-module_alias.patch:
  map scsi proc_name to module name (bnc#459933 - LTC50724)
* Wed Jan 28 2009 jeffm@suse.de
- Update config files: Disable ftrace in -debug on ppc64
* Wed Jan 28 2009 jeffm@suse.de
- config.conf: Added -debug flavor for ppc64.
* Tue Jan 27 2009 bwalle@suse.de
- patches.drivers/libfc-set-the-release-function.diff:
  Whitespace change.
* Tue Jan 27 2009 hare@suse.de
- patches.drivers/libfc-fix-read-IO-data-integrity: libfc:
  IO data integrity issue when a IO data frame lost (bnc#469536).
* Tue Jan 27 2009 jbeulich@novell.com
- re-enable patches.xen/xen3-e1000e_Export_set_memory_ro-rw.
* Tue Jan 27 2009 olh@suse.de
- update patches.arch/ppc-memoryless-nodes.patch:
  include prototype for PFN_UP() (bnc#462546 - LTC50009)
* Mon Jan 26 2009 kkeil@suse.de
- patches.suse/e1000e_Export_set_memory_ro-rw: Export
  set_memory_ro() and set_memory_rw() calls.
  readded to avoid kabi change
* Mon Jan 26 2009 jeffm@suse.de
- config.conf: Added kernel-vmi to i386.
* Mon Jan 26 2009 olh@suse.de
- update patches.arch/ppc-memoryless-nodes.patch:
  use PFN_UP() for end_pfn (bnc#462546 - LTC50009)
* Mon Jan 26 2009 mmarek@suse.cz
- kabi: import FCoE changes
* Mon Jan 26 2009 hare@suse.de
- patches.suse/dm-mpath-requeue-for-stopped-queue: disable
  wrong debug message again.
* Mon Jan 26 2009 rw@suse.de
- patches.fixes/taskstats-alignment:
  IA64: fill 'struct taskstats' on stack and 'memcpy' result to skb.
  (bnc#448410)
* Mon Jan 26 2009 olh@suse.de
- update patches.arch/ppc-memoryless-nodes.patch:
  fix calculation of reserve_size (bnc#462546 - LTC50009)
* Mon Jan 26 2009 kkeil@suse.de
- patches.fixes/disable-lro-per-default: Disable LRO per default
  in igb and ixgbe. (bnc#467519)
* Mon Jan 26 2009 jbeulich@novell.com
- Just comment out patches.xen/xen3-e1000e_* (to address build error)
  until disposition of their originals is known.
* Mon Jan 26 2009 kkeil@suse.de
- patches.fixes/sctp_do_not_use_stale_copy_of_sk: Do not use
  stale copy of sk. (bnc#440104)
* Mon Jan 26 2009 jblunck@suse.de
  Renamed some patches so they get included in vanilla builds.
- patches.rpmify/firmware-path: Renamed.
- patches.rpmify/no-include-asm: Renamed.
- patches.suse/md-raid-metadata-PAGE_SIZE.patch: Renamed.
* Mon Jan 26 2009 olh@suse.de
- patches.suse/led_classdev.sysfs-name.patch: use correct name
  for /sys/devices/virtual/leds/ entries (bnc#468350)
* Mon Jan 26 2009 kkeil@suse.de
- patches.suse/e1000e_Export_set_memory_ro-rw: Delete.
- patches.suse/e1000e_allow_bad_checksum: Delete.
- patches.suse/e1000e_call_dump_eeprom: Delete.
- patches.suse/e1000e_ioremap_sanity_check: Delete.
- patches.suse/e1000e_use_set_memory_ro-rw_to_protect_flash_memory:
  Delete.
  Remove not mainline e1000e patches which were added to help with
  the e1000e NVM corruption - root issue is fixed
* Mon Jan 26 2009 kkeil@suse.de
- patches.drivers/tg3_libphy_workaround: tg3 libphy workaround.
  (bnc#468725)
* Mon Jan 26 2009 hare@suse.de
- supported.conf: Correct spelling for dm-least-pending
  path checker.
* Mon Jan 26 2009 hare@suse.de
- patches.suse/dm-mpath-check-info-before-access: Kernel Oops
  during path failover (bnc#458393).
* Sun Jan 25 2009 gregkh@suse.de
- refresh patch fuzz now that 2.6.27.13 is in tree
* Sun Jan 25 2009 gregkh@suse.de
- Update to final version of 2.6.27.13
* Sun Jan 25 2009 gregkh@suse.de
- dynamic debugging fixes backported from upstream:
- patches.drivers/driver-core-add-newlines-to-debugging-enabled-disabled-messages.patch:
  driver core: add newlines to debugging enabled/disabled
  messages.
- patches.drivers/driver-core-fix-dynamic_debug-cmd-line-parameter.patch:
  Driver core: fix 'dynamic_debug' cmd line parameter.
- patches.drivers/driver-core-fix-using-ret-variable-in-unregister_dynamic_debug_module.patch:
  driver core: fix using 'ret' variable in
  unregister_dynamic_debug_module.
* Sat Jan 24 2009 jbohac@suse.cz
- patches.arch/x86_64-hpet-64bit-timer.patch:
  (fix return of an unitialized value (bnc#469017)
* Sat Jan 24 2009 mmarek@suse.cz
- update kabi files: ignore changes in struct pcie_link_state as
  it is an internal structure only.
* Sat Jan 24 2009 mmarek@suse.cz
- patches.suse/genksyms-add-override-flag.diff: genksyms: add
  - -override flag.
- rpm/kernel-binary.spec.in: set KBUILD_OVERRIDE=1
* Sat Jan 24 2009 ghaskins@suse.de
- patches.fixes/sched-kabi-compat-hack.patch: sched: leave
  RT_GROUP_SCHED structure components intact to preserve kABI.
  broke kabi with fix for 456542
* Sat Jan 24 2009 trenn@suse.de
- patches.fixes/cpufreq_export_latency.patch: CPUFREQ: Introduce
  /sys/devices/system/cpu/cpu*/cpufreq/cpuinfo_transition_latency
  (bnc#464461).
- patches.fixes/cpufreq_ondemand_adjust_sampling_rate_limit.patch:
  CPUFREQ: ondemand/conservative: sanitize sampling_rate
  restrictions (bnc#464461).
- patches.fixes/cpufreq_ondemand_performance_optimise_default_settings.patch:
  CPUFREQ: ondemand: Limit default sampling rate to 300ms
  max. (bnc#464461).
- patches.fixes/x86_cpufreq_powernow-k8_acpi_latency_values.patch:
  X86 powernow-k8 cpufreq: Get transition latency from acpi _PSS
  object (bnc#464461).
* Fri Jan 23 2009 jeffm@suse.de
- patches.fixes/xfs-dmapi-fixes: xfs/dmapi: fix crash on mount
  (bnc#458027).
* Fri Jan 23 2009 ghaskins@suse.de
- Update config files: Disable RT_GROUP_SCHED (bnc#456542).
  The RT_GROUP_SCHED feature is experimental and clearly broken, so
  lets turn it off for now.
* Fri Jan 23 2009 jeffm@suse.de
- patches.fixes/hpilo-open-close-fix: hpilo open/close fix
  (bnc#466517).
* Fri Jan 23 2009 hare@suse.de
- patches.suse/dm-mpath-requeue-for-stopped-queue: Handle I/O
  on stopped queues correctly (bnc#458393).
* Fri Jan 23 2009 jbenc@suse.cz
- patches.suse/mnt-want-write-speedup.patch,
  patches.suse/mnt_clone_write.patch: modified not to break kABI,
  enabled (bnc#436953).
* Fri Jan 23 2009 jbenc@suse.cz
- patches.fixes/iwlagn-fix-rfkill.patch: iwlagn: fix hw-rfkill
  while the interface is down (bnc#446158).
* Fri Jan 23 2009 mmarek@suse.cz
- kabi/severities: temporarily enable changes in FcOE modules.
* Fri Jan 23 2009 hare@suse.de
- patches.arch/s390-08-06-personality.patch: kernel: setting 32
  bit personality doesn't work (bnc#466462).
- patches.arch/s390-08-07-compat_wrappers.patch: kernel:
  Add missing wrapper functions for 31 bit compat
  syscalls. (bnc#466462,LTC#51229).
- patches.fixes/block-leave-the-request-timeout-timer-running:
  Delete obsolete patch.
* Fri Jan 23 2009 bwalle@suse.de
- patches.drivers/fcoe-change-fcoe_sw-sg_tablesi.diff: change
  fcoe_sw sg_tablesize to SG_ALL (bnc #459142).
- patches.drivers/fcoe-check-return-for-fc_set_m.diff: check
  return for fc_set_mfs (bnc #459142).
- patches.drivers/fcoe-fix-frame-length-validati.diff: fix frame
  length validation in the early receive path (bnc #459142).
- patches.drivers/fcoe-fix-incorrect-use-of-struct-module.diff:
  fcoe: fix incorrect use of struct module (bnc #468051).
- patches.drivers/fcoe-improved-load-balancing-i.diff: improved
  load balancing in rx path (bnc #459142).
- patches.drivers/fcoe-logoff-of-the-fabric-when.diff: Logoff
  of the fabric when destroying interface (bnc #459142).
- patches.drivers/fcoe-remove-warn_on-in-fc_set.diff: remove
  WARN_ON in fc_set_mfs (bnc #459142).
- patches.drivers/fcoe-user_mfs-is-never-used.diff: user_mfs is
  never used (bnc #459142).
- patches.drivers/libfc-add-fc_disc-c-locking-co.diff: Add
  fc_disc.c locking comment block (bnc #459142).
- patches.drivers/libfc-ensure-correct-device_pu.diff: libfc:
  Ensure correct device_put/get usage (round 2).
- patches.drivers/libfc-fix-rport-recursive-lock.diff: libfc:
  Fix rport recursive lock on rport mutex (bnc #459142).
- patches.drivers/libfc-handle-rrq-exch-timeout.diff: libfc:
  handle RRQ exch timeout (bnc #465596).
- patches.drivers/libfc-improve-fc_lport-c-locki.diff: Improve
  fc_lport.c locking comment block (bnc #459142).
- patches.drivers/libfc-improve-fc_rport-c-locki.diff: Improve
  fc_rport.c locking comment block (459142).
- patches.drivers/libfc-make-fc_disc-inline-with.diff: make
  fc_disc inline with the fc_lport structure (bnc #459142).
- patches.drivers/libfc-make-rscn-parsing-more-r.diff: make RSCN
  parsing more robust (bnc #459142).
- patches.drivers/libfc-make-sure-we-access-the.diff: make sure
  we access the CRC safely (bnc #459142).
- patches.drivers/libfc-pass-lport-in-exch_mgr_r.diff: libfc:
  Pass lport in exch_mgr_reset (bnc #465596).
- patches.drivers/libfc-remove-debug-print-state.diff: libfc:
  Remove debug print statement, too verbose (bnc #459142).
- patches.drivers/libfc-set-the-release-function.diff: Set
  the release function for the rport's kobject (round 2)
  (bnc #459142).
- patches.drivers/libfc-updated-comment-for-orde.diff: updated
  comment for order of em and ex locks (bnc #459142).
- patches.drivers/libfc-updated-libfc-fcoe-modul.diff: updated
  libfc fcoe module ver to 1.0.6 (bnc #459142).
- patches.drivers/libfc-use-an-operations-struct.diff: use an
  operations structure for rport callbacks (bnc #459142).
- patches.drivers/libfc-when-rport-goes-away-re.diff: libfc:
  when rport goes away (re-plogi), clean up exchanges to/from
  rport (bnc #465596).
- patches.drivers/libfc_locking.diff: libfc, fcoe: fixed locking
  issues with lport->lp_mutex around lport->link_status (bnc
  [#468053]).
- patches.drivers/libfc_rport.diff: libfc: rport retry on LS_RJT
  from certain ELS (bnc #468054).
* Fri Jan 23 2009 hare@suse.de
- patches.fixes/qla2xxx-check-fc-rport-validity:
  qla2xxx: added check for fcport is valid in
  qla2x00_terminate_rport_io(). (bnc#467624).
* Fri Jan 23 2009 tiwai@suse.de
- patches.drivers/alsa-hda-gateway-t1616-quirk: ALSA: hda -
  Add quirk for Gateway T1616 laptop (bnc#467597).
- patches.drivers/alsa-hda-hp-dv4-quirk: ALSA: hda - Add model
  entry for HP dv4.
- patches.drivers/alsa-hda-intel-d945-ref-quirk: ALSA: hda -
  Add model=ref for Intel board with STAC9221 (bnc#406529).
* Fri Jan 23 2009 hare@suse.de
- patches.fixes/blk-leave-sync-timer-running: block: Rediff
- patches.fixes/block-use-round_jiffies_up: Block: use
  round_jiffies_up() (bnc#464155).
- Add missing patches to series.conf:
  patches.fixes/round-jiffies-up
  patches.fixes/block-use-round_jiffies_up
  patches.fixes/block-fix-blk_start_queueing
  patches.fixes/suppress-buffer-IO-errors
  patches.fixes/block-optimizations-in-blk_rq_timed_out_timer
  patches.fixes/block-add-comment-in-blk_rq_timed_out
* Fri Jan 23 2009 olh@suse.de
- update patches.fixes/scsi-ibmvscsi-vio_leak.patch:
  handle also drivers/scsi/ibmvscsi/ibmvfc.c
* Fri Jan 23 2009 sjayaraman@suse.de
- patches.fixes/cifs-fix-oops-on-ipv6-mount: cifs: make sure we
  allocate enough storage for socket address (467691).
* Fri Jan 23 2009 gregkh@suse.de
- patches.kernel.org/abi-fix-add-wb_sync_hold-enum-writeback_sync_modes.patch:
  ABI fix: add WB_SYNC_HOLD enum writeback_sync_modes.
* Fri Jan 23 2009 gregkh@suse.de
- patches.kernel.org/abi-fix-add-s_syncing-back-to-struct-super_block.patch:
  ABI fix: add s_syncing back to struct super_block.
* Fri Jan 23 2009 gregkh@suse.de
- update to 2.6.27.13-rc1:
  - security updates
  - lots of bugfixes
  - obsoletes:
  - patches.arch/ppc-fix_hugepage_check.patch
  - patches.drivers/alsa-hda-ad1986a-laptop-eapd-model-back
  - patches.drivers/alsa-hda-samsung-q45-quirk
  - patches.fixes/security-introduce-missing-kfree.patch
  - patches.fixes/xpc-fix-heartbeat
- Update config files.
* Fri Jan 23 2009 kkeil@suse.de
- patches.drivers/e1000-fix-shared-emc.patch: e1000: fix bug
  with shared interrupt during reset (bnc#396687)
* Thu Jan 22 2009 tonyj@suse.de
- patches.fixes/revert-bgcolor-line-feed-93f78da4.patch: Revert
  "vt: fix background color on line feed" (bnc#418613).
* Thu Jan 22 2009 jbenc@suse.cz
- patches.fixes/iwlwifi-fix-rs_get_rate-oops.patch: iwlwifi:
  fix rs_get_rate WARN_ON() (bnc#456002).
- Reordered wireless patches to group together patches touching the same
  driver.
* Thu Jan 22 2009 bphilips@suse.de
- patches.drivers/disable-catas_reset-by-default-to-avoid-problems-with-eeh.patch:
  disable catas_reset by default to avoid problems with EEH
  (bnc#456389).
* Thu Jan 22 2009 rw@suse.de
- patches.fixes/xpc-pass-physical:
  fixed kABI breakage. (bnc#458811)
* Thu Jan 22 2009 bwalle@suse.de
- scripts/tar-up_and_run_mbuild.sh: s390 (the 31 bit variant) is
  not an important spec file.
* Thu Jan 22 2009 jbenc@suse.cz
- patches.fixes/mac80211-add-direct-probe.patch: fixed kABI
  breakage, reenabled.
* Thu Jan 22 2009 mmarek@suse.cz
- rpm/modversions: eat the "override" keyword before parsing the
  symbol definition.
* Thu Jan 22 2009 olh@suse.de
- patches.fixes/scsi-ibmvscsi-vio_leak.patch:
  Correct VIO bus/device CMO accounting problems (bnc#468304 - LTC51205)
* Thu Jan 22 2009 olh@suse.de
- patches.suse/of_platform_driver.module-owner.patch:
  add missing module symlink to /sys/bus/*/driver/*
  in struct of_platform_driver.
* Thu Jan 22 2009 kkeil@suse.de
- patches.drivers/ixgbe_DCB_compile_err.patch: DCB compile
  error fix - new version from Intel  (bnc#465923)
* Thu Jan 22 2009 jbohac@suse.cz
- patches.arch/x86_64-hpet-64bit-timer.patch: allow 64-bit mode
  for HPET Timer0 (bnc#456700).
  (fix compilation on i386 and add hpet64 to kernel-parameters.txt)
* Thu Jan 22 2009 jbohac@suse.cz
- patches.arch/x86_64-hpet-64bit-timer.patch: allow 64-bit mode
  for HPET Timer0 (bnc#456700).
* Thu Jan 22 2009 rw@suse.de
- patches.fixes/xpc-pass-physical:
  sgi-xpc: need to pass the physical address, not virtual. (bnc#458811)
- patches.fixes/xpc-fix-heartbeat:
  sgi-xpc: eliminate false detection of no heartbeat. (bnc#464545)
* Thu Jan 22 2009 jkosina@suse.de
- patches.fixes/input-add-nomux-dell-vostro-1510.patch: Input:
  add Dell Vostro 1510 to nomux list (bnc#404881).
* Thu Jan 22 2009 jblunck@suse.de
- scripts/compute-PATCHVERSION.sh: Fix SRCVERSION parsing (bnc#465113).
* Thu Jan 22 2009 tiwai@suse.de
- patches.drivers/alsa-hda-add-volume-offset: ALSA: hda - Add
  extra volume offset to standard volume amp macros (bnc#466428).
- patches.drivers/alsa-hda-stac-reduce-volume-scale: ALSA: hda -
  Halve too large volume scales for STAC/IDT codecs (bnc#466428).
* Thu Jan 22 2009 hare@suse.de
- patches.drivers/lpfc-8.2.8.12-update: Update lpfc from 8.2.8.11
  to 8.2.8.12 (bnc#467713).
* Thu Jan 22 2009 jeffm@suse.de
- patches.fixes/reiserfs-debug-1036: fix missing jl arg
* Wed Jan 21 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: delete duplicate error message in the
  kabi checks
* Wed Jan 21 2009 jeffm@suse.de
- patches.fixes/remove_kernel_physical_mapping_init_from_init:
  move kernel_physical_mapping_init to __meminit (bnc#467474).
* Wed Jan 21 2009 jbenc@suse.cz
- patches.fixes/mac80211-add-direct-probe.patch: disabled, as it changes
  kABI.
* Wed Jan 21 2009 gregkh@suse.de
- patches.fixes/security-introduce-missing-kfree.patch: security:
  introduce missing kfree (bnc#467322).
- patches.fixes/sysfs-fix-problems-with-binary-files.patch:
  sysfs: fix problems with binary files.
* Wed Jan 21 2009 rw@suse.de
- patches.arch/ia64-page-migration.fix:
  fix deadlock caused by cpe_migrate.ko and mark it supported.
  (bnc#464676)
* Wed Jan 21 2009 jeffm@suse.de
- patches.fixes/sn-irq-affinity: sn2: preserve irq affinity set
  in PROM (bnc#457679).
* Wed Jan 21 2009 jeffm@suse.de
- patches.fixes/uv_zalias_support: uv: Support for non-nasid 0
  systems (bnc#458869).
* Wed Jan 21 2009 jeffm@suse.de
- patches.fixes/xpc-fix-NULL-deref: sgi-xpc: Remove NULL pointer
  dereference. (bnc#466563).
- patches.fixes/xpc-write-barrier: sgi-xpc: ensure flags are
  updated before bte_copy (bnc#466563).
* Wed Jan 21 2009 jbenc@suse.cz
- patches.fixes/ipw2200-workaround-firmware-restarts-when-scanning.patch:
  ipw2200: fix scanning while associated (bnc#459067).
* Wed Jan 21 2009 jbenc@suse.cz
- patches.fixes/iwl3945-fix-rfkill.patch: iwl3945: report
  killswitch changes even if the interface is down (bnc#446013).
* Wed Jan 21 2009 jbenc@suse.cz
- patches.fixes/mac80211-add-direct-probe.patch: mac80211:
  add direct probe before association (bnc#461889).
* Wed Jan 21 2009 hare@suse.de
- patches.drivers/mptsas-discover-all-devices: mptsas driver
  fails to discover devices (bnc#459932).
* Wed Jan 21 2009 jbeulich@novell.com
- Update Xen patches to 2.6.27.12.
- patches.xen/764-netback-foreign-pages.patch: netback: handle
  non-netback foreign pages.
- patches.xen/769-evtchn-CPU-offline.patch: evtchn: Fix CPU offlining
  to switch all affected ports belonging to a particular /dev/evcthn
  user.
- patches.xen/gso-size-check.patch: gso: Ensure that the packet
  is long enough.
- patches.xen/xen-S3-MSI: fix Dom0 resume from S3 when MSI is
  in use (bnc#435596).
- patches.xen/xen3-e1000e_ioremap_sanity_check: ioremap sanity
  check to catch mapping requests exceeding the BAR sizes
  (bnc#425480).
- patches.xen/xen3-x86-fix-kmap-contig.patch: x86: contiguous
  kmap fix (bnc#449812).
* Wed Jan 21 2009 olh@suse.de
- update patches.suse/radeon-monitor-jsxx-quirk.patch:
  implement correct model matching
* Wed Jan 21 2009 olh@suse.de
- update patches.suse/dm-mpath-tracking-nr-bytes:
  lpp_end_io gets nr_bytes as third arg
* Wed Jan 21 2009 olh@suse.de
- update patches.suse/radeon-monitor-jsxx-quirk.patch:
  match all JSxx/QSxx models based on the first 4 chars in 'model'
* Wed Jan 21 2009 olh@suse.de
- update patches.arch/ppc-axon-missing-msi-workaround-5.diff:
  Fix MSI after kexec (bnc#467633)
* Tue Jan 20 2009 gregkh@suse.de
- clean up patch fuzz after 2.6.27.12 inclusion.
* Tue Jan 20 2009 gregkh@suse.de
- Update to the real 2.6.27.12
* Tue Jan 20 2009 jeffm@suse.de
- patches.suse/reiserfs_warning-reentrant: reiserfs: eliminate
  reiserfs_warning from uniqueness functions; Fixes deadlock.
* Tue Jan 20 2009 olh@suse.de
- patches.drivers/cxgb3-ser.patch:
  reset the adapter on fatal error (bnc#466062 - LTC51042)
* Tue Jan 20 2009 jjolly@suse.de
- patches.arch/s390-08-03-iucv-cpu-hotremove.diff: iucv: failing
  cpu hot remove for inactive iucv (bnc#466462,LTC#51104).
- patches.arch/s390-08-04-compat-sigaltstack.diff:
  kernel: 31 bit compat sigaltstack syscall fails with
  - EFAULT. (bnc#466462,LTC#50888).
- patches.arch/s390-08-05-af_iucv-msgpeek-fix.patch:
  af_iucv: System hang if recvmsg() is used with MSG_PEEK
  (bnc#466462,LTC#51136).
* Tue Jan 20 2009 hare@suse.de
- patches.suse/dm-mpath-accept-failed-paths: Only accept
  non-existing paths when adding failed paths (bnc#467579)
* Tue Jan 20 2009 mmarek@suse.cz
- rpm/kernel-source.spec.in: set CONFIG_DEBUG_INFO=y in the
  packaged .configs if builfing debug packages (bnc#460887)
* Mon Jan 19 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: set %%tolerate_kabi_changes to 6
* Mon Jan 19 2009 mmarek@suse.cz
- patches.suse/export-iwl_rx_allocate: reintroduce
  EXPORT_SYMBOL(iwl_rx_allocate).
* Mon Jan 19 2009 mmarek@suse.cz
- import SLE11 RC2 reference kabi
* Mon Jan 19 2009 hare@suse.de
- patches.drivers/mpt-return-all-sense-data: MPT Fusion doesn't
  return all sense data (bnc#466179).
* Sat Jan 17 2009 gregkh@suse.de
- Update to 2.6.27.12-rc2
* Fri Jan 16 2009 od@suse.de
- patches.arch/x86-call-boot-IRQ-quirks-at-end-of-device-init-and-during-resume.patch:
  call boot IRQ quirks at end of device init and during resume.
- patches.arch/x86-disable-AMD-ATI-boot-interrupt-generation.patch:
  update to upstream variant of this patch:
  - integrate an older quirk to make IO-APIC mode work on AMD
    8131 rev. A0 and B0
  - fix boot IRQ disabling logic for AMD 813x
  - remove unneeded code for AMD SB700S
* Fri Jan 16 2009 jbeulich@novell.com
- patches.arch/x86-fix-kmap-contig.patch: x86: contiguous kmap
  fix (bnc#449812).
* Fri Jan 16 2009 olh@suse.de
- enable mptsas in kdump kernel to allow crashdump on QS2x blades
* Fri Jan 16 2009 tiwai@suse.de
  Fix STAC925x patch again
- patches.drivers/alsa-hda-stac925x-init-fix: ALSA: hda - Fix
  (yet more) STAC925x issues (bnc#460478).
* Fri Jan 16 2009 jjolly@suse.de
- patches.arch/s390-08-01-cio-fix-mp-mode.diff: cio: fix
  subchannel multipath mode setup (bnc#466462,LTC#51047).
- patches.arch/s390-08-02-zfcp-gpn-align-fix.diff: zfcp: fix
  memory alignment for GPN_FT requests. (bnc#466462).
* Fri Jan 16 2009 gregkh@suse.de
- Update config files for vanilla kernel versions due to new config
  option added in 2.6.27.12-rc1.
* Fri Jan 16 2009 gregkh@suse.de
- Update to 2.6.27.12-rc1:
  - security fixes
  - fixes CVE-2009-0029
  - bug fixes all over the place.
  - obsoletes the following patches:
  - patches.arch/ppc-cmm_no_kdump.patch
  - patches.drivers/alsa-caiaq-midi-oops-fix
  - patches.drivers/alsa-hda-hp-6730b-quirk
  - patches.drivers/ibmvfc-host_init_delay.patch
  - patches.drivers/ibmvfc-improve_sync_events.patch
  - patches.fixes/PCI-Suspend-and-resume-PCI-Express-ports-with-interrupts-disabled.patch
  - patches.fixes/PCI-handle-PCI-state-saving-with-interrupts-disabled.patch
  - patches.fixes/fs-symlink-write_begin-allocation-context-fix.patch
  - patches.fixes/mm-lockless-pagecache-barrier.patch
  - patches.fixes/pci-rework-suspend-of-devices-with-no-drivers.patch
  - patches.fixes/uv-remove-erroneous-BAU-init
- Update config files.
* Thu Jan 15 2009 tiwai@suse.de
- patches.drivers/alsa-virtuoso-no-eeprom-overwrite: sound:
  virtuoso: do not overwrite EEPROM on Xonar D2/D2X (bnc#462365).
* Thu Jan 15 2009 bwalle@suse.de
- patches.suse/s390-System.map.diff:
  Strip L2^B symbols (bnc #456682).
* Thu Jan 15 2009 tiwai@suse.de
- patches.drivers/alsa-hda-gateway-fix: ALSA: patch_sigmatel:
  Add missing Gateway entries and autodetection (bnc#460478).
- patches.drivers/alsa-hda-gateway-fix2: ALSA: hda - More fixes
  on Gateway entries (bnc#460478).
- patches.drivers/alsa-hda-hp-dv5-mic-fix: ALSA: hda - Fix HP
  dv5 mic input (bnc#462913).
- patches.drivers/alsa-hda-hp-dv5-quirk: ALSA: hda - Add quirk
  for another HP dv5 (bnc#462913).
- patches.drivers/alsa-hda-idt92hd83-fix-typo: ALSA: hda -
  Fix a typo.
- patches.drivers/alsa-hda-samsung-q45-quirk: ALSA: hda - Add
  automatic model setting for Samsung Q45.
- patches.drivers/alsa-hda-seek-for-codec-id: ALSA: hda - Add
  a new function to seek for a codec ID (bnc#460478).
- patches.drivers/alsa-hda-sigmatel-no-hp-reset: ALSA: hda -
  Don't reset HP pinctl in patch_sigmatel.c (bnc#460478).
- patches.drivers/alsa-hda-stac925x-init-fix: ALSA: hda - Fix
  missing initialization of NID 0x0e for STAC925x (bnc#460478).
* Thu Jan 15 2009 olh@suse.de
- patches.arch/ppc-fix_hugepage_check.patch:
  is_hugepage_only_range() must account for both 4kB and 64kB
  slices (bnc#466229 - LTC51063)
* Thu Jan 15 2009 jeffm@suse.de
- Update config files: Disabled PARAVIRT on vanilla and LGUEST.
* Thu Jan 15 2009 jeffm@suse.de
- Enabled patches.suse/unlock_page-speedup.patch
* Wed Jan 14 2009 rjw@suse.de
- patches.fixes/PCI-PM-Split-PCI-Express-port-suspend-resume.patch:
  PCI PM: Split PCI Express port suspend-resume (bnc#455926).
- patches.fixes/PCI-Suspend-and-resume-PCI-Express-ports-with-interrupts-disabled.patch:
  PCI: Suspend and resume PCI Express ports with interrupts
  disabled (bnc#455926).
- patches.fixes/PCI-handle-PCI-state-saving-with-interrupts-disabled.patch:
  PCI: handle PCI state saving with interrupts disabled
  (bnc#455926).
- patches.fixes/pci-rework-suspend-of-devices-with-no-drivers.patch:
  PCI: Rework default handling of suspend and resume (bnc#455926).
* Wed Jan 14 2009 jeffm@suse.de
- Update config files: Disable PARAVIRT.
* Wed Jan 14 2009 gregkh@suse.de
- refresh patches for fuzz due to update to 2.6.27.11
* Wed Jan 14 2009 gregkh@suse.de
- Update to final version of 2.6.27.11
* Wed Jan 14 2009 kkeil@suse.de
- patches.drivers/ixgbe-dcb-setstate.patch: Bugfix for ixgbe
  and kernel DCB netlink code. (bnc#458194)
- patches.drivers/ixgbe_DCB_compile_err.patch: DCB compile
  error fix. (bnc#465923)
- Update config files.
* Wed Jan 14 2009 trenn@suse.de
- patches.fixes/acpi_irq_quirk_pci_irq_derive.patch: Delete.
  It came out that this is an already fixed BIOS bug. The quirk
  is not needed anymore.
* Wed Jan 14 2009 trenn@suse.de
- patches.fixes/acpi_fix_double_slash_root_prefix_handling.patch:
  In AcpiNsGetInternalNameLength, skip the redundant backslash
  of RootPrefix (http://bugzilla.kernel.org/show_bug.cgi?id=11541
  http://www.acpica.org/bugzilla/show_bug.cgi?id=739).
- patches.fixes/acpi_video_always_update_sys.patch: video: always
  update the brightness when poking "brightness" (bnc#450149).
- patches.fixes/acpi_video_handle_reversed_brightness_info.patch:
  ACPI: video: Fix reversed brightness behavior on ThinkPad SL
  series (bnc#450149).
* Wed Jan 14 2009 olh@suse.de
- patches.fixes/sched-fix-__load_balance_iterator-for-cfs-with-on.patch:
  fix __load_balance_iterator() for cfs with only one task
  (bnc#457594 - LTC50544)
* Wed Jan 14 2009 olh@suse.de
- patches.fixes/xfs-redirty-ENOSPC.patch: Re-dirty pages on
  ENOSPC when converting delayed allocations (bnc#433112 - LTC48749)
* Wed Jan 14 2009 npiggin@suse.de
- Added guarded patches:
- patches.suse/mnt-want-write-speedup.patch: fs: mnt_want_write
  speedup (bnc#436953).
- patches.suse/mnt_clone_write.patch: fs: introduce
  mnt_clone_write (bnc#436953).
- patches.suse/unlock_page-speedup.patch: mm: unlock_page speedup
  (bnc#436953).
* Wed Jan 14 2009 gregkh@suse.de
- Update config files.
- patches.drivers/add-via-chrome9-drm-support.patch: add Via
  chrome9 drm support.
* Wed Jan 14 2009 gregkh@suse.de
- patches.drivers/pata_via.c-support-vx855-and-future-chips-whose-ide-controller-use-0x0571.patch:
  pata_via.c: Support VX855 and future chips whose IDE controller
  use 0x0571..
* Tue Jan 13 2009 hare@suse.de
- patches.fixes/scsi-restart-lookup-by-target: Modify patch
  after suggestions from James Bottomley (bnc#465346).
* Tue Jan 13 2009 hare@suse.de
- patches.fixes/scsi-restart-lookup-by-target: Restart
  scsi_device_lookup_by_target() (bnc#465346).
* Tue Jan 13 2009 olh@suse.de
- update patches.drivers/cxgb3-Allocate-multiqueues-at-init-time:
  Allow multiqueue setting in MSI-X mode only (bnc#464351 - LTC50966)
* Tue Jan 13 2009 olh@suse.de
- patches.drivers/cxgb3i-mainline.patch: fixes bug in tag release
  and sync-up cxgb3i with mainline state (bnc#464508 - LTC50816)
* Tue Jan 13 2009 gregkh@suse.de
- Update to 2.6.27.11-rc1:
  - lots of minor fixes
  - obsoletes:
  - patches.fixes/md-bitmap-read-do-not-overflow
  - patches.suse/scsi-scsi_transport_srp-shost_data.patch
* Mon Jan 12 2009 gregkh@suse.de
- supported.conf: add kernel/drivers/acpi/acpi_memhotplug as supported
* Mon Jan 12 2009 mmarek@suse.cz
- rpm/kernel-source.spec.in, rpm/source-post.sh: handle arch
  symlinks like i586 -> i386 in /usr/src/linux-obj.
* Mon Jan 12 2009 gregkh@suse.de
- supported.conf: updated staging and other drivers
* Mon Jan 12 2009 kkeil@suse.de
- patches.drivers/r8169-Tx-performance-tweak-helper: r8169:
  Tx performance tweak helper.
- patches.drivers/r8169-add-8168-8101-registers-description:
  r8169: add 8168/8101 registers description.
- patches.drivers/r8169-add-hw-start-helpers-for-the-8168-and-the-8101:
  r8169: add hw start helpers for the 8168 and the 8101.
- patches.drivers/r8169-additional-8101-and-8102-support: r8169:
  additional 8101 and 8102 support.
- patches.drivers/r8169-use-pci_find_capability-for-the-PCI-E-features:
  r8169: use pci_find_capability for the PCI-E features.
  (bnc#448168)
* Mon Jan 12 2009 dgollub@suse.de
- scripts/tar-up_and_run_mbuild.sh: use $BUILD_DIR instead of fixed
  "kernel-source" string, to stay in sync with with differet kernel
  variants.
* Mon Jan 12 2009 mmarek@suse.cz
- rpm/kernel-source.spec.in, rpm/source-post.sh, rpm/source-pre.sh:
  replace the /usr/src/linux-obj symlink with a directory containing
  per-flavor symlinks instead. This allows us to install kernel-source /
  syms and kernel-source-rt / syms-rt in parallel and still find
  everything below /usr/src/linux-obj/.
- rpm/kernel-binary.spec.in: for -rt, install into
    /usr/src/linux-$version-rt-obj.
- rpm/kernel-syms.spec.in: fix kernel-source requires for -rt.
* Mon Jan 12 2009 jkosina@suse.de
- patches.drivers/input-usbtouchscreen-hw-calibration.patch:
  Input: usbtouchscreen - allow reporting calibrated data
  (bnc#444814).
* Fri Jan  9 2009 mmarek@suse.cz
- patches.suse/file-capabilities-add-file_caps-switch.diff:
  fix parsing of the file_caps commandline option (bnc#264075)
* Fri Jan  9 2009 trenn@suse.de
- patches.arch/x86_fix_llc_shared_map__cpu_llc_id_anomolies.patch:
  x86: fix intel x86_64 llc_shared_map/cpu_llc_id anomolies
  (bnc#464329).
* Fri Jan  9 2009 olh@suse.de
- patches.arch/ppc-cmm_no_kdump.patch:
  Disable Collaborative Memory Manager for kdump (bnc#460552 - LTC50789)
* Fri Jan  9 2009 jslaby@suse.cz
- patches.suse/cgroup-disable-memory.patch: memcg: disable the
  memory controller by default.
- patches.suse/add-enable_cgroup-parameter.patch: Delete.
- patches.suse/disable-cgroups.patch: Delete.
* Fri Jan  9 2009 olh@suse.de
- patches.suse/radeon-monitor-jsxx-quirk.patch
  fix compile errors
* Fri Jan  9 2009 jslaby@suse.de
- patches.fixes/ath5k-ignore-calibration-return-value.patch:
  ath5k: ignore the return value of
  ath5k_hw_noise_floor_calibration (bnc#446541).
* Fri Jan  9 2009 jslaby@suse.de
- patches.fixes/cgroups-suppress-cloning-warning.patch: cgroups:
  suppress bogus warning messages (bnc#460961).
* Fri Jan  9 2009 olh@suse.de
- patches.suse/radeon-monitor-jsxx-quirk.patch: Add quirk for
  the graphics adapter in some JSxx (bnc#461002 - LTC50817)
* Fri Jan  9 2009 trenn@suse.de
- patches.fixes/acpi_irq_quirk_pci_irq_derive.patch: ACPI: Do not
  derive IRQ from parent bridge/device via boot param/dmi list
  (bnc#437211).
- patches.suse/acpi_osi_sle11_ident.patch: Provide possibility
  for vendors to fix BIOS issues for SLE11 only (none).
* Fri Jan  9 2009 hare@suse.de
- patches.drivers/blk-request-based-multipath-update: Rediff.
- patches.fixes/scsi-refactor-busy-processing: refactor
  sdev/starget/shost busy checking; break out from
  blk-request-based-multipath-update.
* Fri Jan  9 2009 hare@suse.de
- patches.drivers/lpfc-8.2.8.11-update: Update lpfc from 8.2.8.10
  to 8.2.8.11 (bnc#464662).
- patches.fixes/scsi-call-unprep_request-under-lock: scsi_lib:
  only call scsi_unprep_request() under queue lock (bnc#464155).
- patches.fixes/scsi-fix-hang-in-starved-list-processing: Fix
  hang in starved list processing (bnc#464155).
* Fri Jan  9 2009 kkeil@suse.de
- patches.drivers/bnx2-Add-PCI-ID-for-5716S: bnx2: Add PCI ID
  for 5716S
- patches.drivers/bnx2-Fix-bug-in-bnx2_free_rx_mem_: bnx2:
  Fix bug in bnx2_free_rx_mem() (bnc#464130)
* Fri Jan  9 2009 jslaby@suse.cz
- patches.suse/disable-cgroups.patch: Disable all cgroups
  (bnc#436025).
* Fri Jan  9 2009 hare@suse.de
- Backporting block layer fixes (bnc#464155):
  * patches.fixes/block-add-comment-in-blk_rq_timed_out: add
    comment in blk_rq_timed_out() about why next can not be 0
  * patches.fixes/block-fix-blk_start_queueing: block: Fix
    blk_start_queueing() to not kick a stopped queue.
  * patches.fixes/block-leave-the-request-timeout-timer-running:
    block: leave the request timeout timer running even on an
    empty list.
  * patches.fixes/block-optimizations-in-blk_rq_timed_out_timer:
    block: optimizations in blk_rq_timed_out_timer().
  * patches.fixes/block-suppress-buffer-IO-errors: block: Supress
    Buffer I/O errors when SCSI REQ_QUIET flag set.
  * patches.fixes/block-use-round_jiffies_up: Block: use
    round_jiffies_up().
  * patches.fixes/round-jiffies-up: Add round_jiffies_up and
    related routines.
* Fri Jan  9 2009 jbeulich@novell.com
- patches.xen/xen3-acpi-pci-pci-msi-_osc-support-capabilities-called-when-root-bridge-added.patch:
  ACPI/PCI: PCI MSI _OSC support capabilities called when root
  bridge added (bnc#438941).
* Fri Jan  9 2009 hare@suse.de
- patches.fixes/scsi_dh-retry-on-UNIT_ATTENTION: scsi_dh_rdac
  does not retry MODE SENSE on UNIT ATTENTION (bnc#464155).
- patches.suse/scsi-check-removed-device-for-offline: Only check
  for SDEV_OFFLINE and SDEV_DEL, not SDEV_CANCEL.
* Fri Jan  9 2009 jslaby@suse.cz
- patches.suse/add-enable_cgroup-parameter.patch: Add
  cgroup_enable parameter (bnc#436025).
* Fri Jan  9 2009 gregkh@suse.de
- patches.drivers/acpi-pci-include-missing-acpi.h-file-in-pci-acpi.h.patch:
  ACPI/PCI: include missing acpi.h file in
  pci-acpi.h. (bnc#438941).
* Fri Jan  9 2009 gregkh@suse.de
- clean up patch fuzz
* Fri Jan  9 2009 gregkh@suse.de
- patches.drivers/acpi-pci-pci-msi-_osc-support-capabilities-called-when-root-bridge-added.patch:
  ACPI/PCI: PCI MSI _OSC support capabilities called when root
  bridge added (bnc#438941).
- patches.drivers/acpi-pci-pcie-aer-_osc-support-capabilities-called-when-root-bridge-added.patch:
  ACPI/PCI: PCIe AER _OSC support capabilities called when root
  bridge added (bnc#438941).
- patches.drivers/acpi-pci-pcie-aspm-_osc-support-capabilities-called-when-root-bridge-added.patch:
  ACPI/PCI: PCIe ASPM _OSC support capabilities called when root
  bridge added (bnc#438941).
- patches.drivers/acpi-pci-remove-obsolete-_osc-capability-support-functions.patch:
  ACPI/PCI: remove obsolete _OSC capability support functions
  (bnc#438941).
* Fri Jan  9 2009 gregkh@suse.de
- patches.drivers/acpi-pci-call-_osc-support-during-root-bridge-discovery.patch:
  ACPI/PCI: call _OSC support during root bridge discovery
  (bnc#438941).
- patches.drivers/acpi-pci-change-pci_osc_control_set-to-query-control-bits-first.patch:
  ACPI/PCI: Change pci_osc_control_set() to query control bits
  first (bnc#438941).
- patches.drivers/acpi-pci-fix-possible-race-condition-on-_osc-evaluation.patch:
  ACPI/PCI: Fix possible race condition on _OSC evaluation
  (bnc#438941).
- patches.drivers/acpi-pci-include-missing-acpi.h-file-in-pci-acpi.h.patch:
  ACPI/PCI: include missing acpi.h file in
  pci-acpi.h. (bnc#438941).
- patches.drivers/acpi-pci-pci-extended-config-_osc-support-called-when-root-bridge-added.patch:
  ACPI/PCI: PCI extended config _OSC support called when root
  bridge added (bnc#438941).
* Thu Jan  8 2009 gregkh@suse.de
- patches.drivers/bnx2x-version-update.patch: bnx2x: Version
  Update (bnc#439679).
* Thu Jan  8 2009 jjolly@suse.de
- patches.arch/s390-07-01-zfcp-port-failed-message.diff: zfcp:
  Remove message for failed port (bnc#464466).
- patches.arch/s390-07-02-zfcp-unchained-fsf.diff: zfcp: Add
  support for unchained FSF requests (bnc#464466).
- patches.arch/s390-07-03-topology-fix.diff: kernel: fix cpu
  topology support (bnc#464466).
- patches.arch/s390-07-04-dasd-failfast.patch: dasd: Add
  'failfast' device feature. (bnc#464466,LTC#43066).
* Thu Jan  8 2009 tiwai@suse.de
- patches.drivers/alsa-caiaq-midi-oops-fix: ALSA: caiaq - Fix
  Oops with MIDI.
* Thu Jan  8 2009 knikanth@suse.de
- patches.fixes/dm-avoid-put-table-dm_any_congested: dm: avoid
  destroying table in dm_any_congested (bnc#457205).
- patches.fixes/dm-table-ref-count: dm table: rework reference
  counting (bnc#457205).
- patches.fixes/dm-unbind-drop-ref: dm table: drop reference at
  unbind (bnc#457205).
* Thu Jan  8 2009 olh@suse.de
- update kdump config, disable some unused drivers
* Thu Jan  8 2009 olh@suse.de
- refresh config files, no functional changes
* Thu Jan  8 2009 olh@suse.de
- patches.drivers/ehea-modinfo.patch:
  use separate table for module alias (bnc#435215 - LTC48564)
* Thu Jan  8 2009 tiwai@suse.de
  Backport fixes for HD-audio from the upstream:
- patches.drivers/alsa-hda-ad1882-id-typo-fix: ALSA: hda -
  Fix typos for AD1882 codecs.
- patches.drivers/alsa-hda-ad1986a-laptop-eapd-model-back: ALSA:
  hda - make laptop-eapd model back for AD1986A.
- patches.drivers/alsa-hda-hp2230s-quirk: ALSA: hda - Add quirk
  for HP 2230s (bnc#461660).
- patches.drivers/alsa-hda-sigmatel-add-missing-terminators:
  ALSA: hda - Add missing terminators in patch_sigmatel.c.
* Thu Jan  8 2009 bwalle@suse.de
- Update config files: Enable CONFIG_EHEA=m (and CONFIG_IBMEBUS=y)
  for ppc/kdump and ppc64/kdump (bnc #459119).
* Thu Jan  8 2009 jblunck@suse.de
- Make kernel-source.changes incremental again
* Thu Jan  8 2009 olh@suse.de
- supported.conf: rename dm-leastpending-path to dm-leastpending
* Thu Jan  8 2009 olh@suse.de
- patches.drivers/ehea-modinfo.patch:
  add alias entry for portN properties (bnc#435215 - LTC48564)
* Thu Jan  8 2009 olh@suse.de
- patches.drivers/ibmvfc-abort-response.patch:
  Fixup command response translation (bnc#459383 - LTC50695)
* Thu Jan  8 2009 olh@suse.de
- patches.drivers/ibmvfc-improve_sync_events.patch:
  Improve async event handling (bnc#460567 - LTC50778)
* Thu Jan  8 2009 gregkh@suse.de
- patches.drivers/via-unichrome-drm-bugfixes.patch: via: Unichrome
  DRM bugfixes.
* Thu Jan  8 2009 coly.li@suse.de
- Move patch from patches.suse/dlm-fix-shutdown-cleanup.patch to
  patches.fixes/dlm-fix-shutdown-cleanup.patch
* Thu Jan  8 2009 coly.li@suse.de
- Fixes a regression from commit
  0f8e0d9a317406612700426fad3efab0b7bbc467,
  "dlm: allow multiple lockspace creates".
* Wed Jan  7 2009 olh@suse.de
- patches.arch/ppc-pseries-cpu-migrate.patch: Update
  default_server during migrate_irqs_away (bnc#460566 - LTC50723)
* Wed Jan  7 2009 jack@suse.cz
- patches.suse/mm-increase-dirty-limits.patch: Increase limits
  for starting writeback of dirty data (bnc#449662).
* Wed Jan  7 2009 ghaskins@suse.de
- Update config files (part of bnc#448412).
* Wed Jan  7 2009 ghaskins@suse.de
- patches.fixes/ia64-configure-HAVE_UNSTABLE_SCHED_CLOCK-for-SGI_SN.patch:
  configure HAVE_UNSTABLE_SCHED_CLOCK for SGI_SN systems (bnc#448412).
* Wed Jan  7 2009 hare@suse.de
- patches.drivers/lpfc-8.2.8.10-update: Emulex 8.2.8.10 driver
  patches for SLE11 (bnc#460775).
* Wed Jan  7 2009 knikanth@suse.de
- patches.suse/dm-barrier-single-device: Update Patch-mainline
  header. Patch is not refreshed as it breaks kabi (FATE#304489).
* Wed Jan  7 2009 hare@suse.de
- patches.drivers/cciss-driver-panic-on-volume-delete: cciss
  driver may panic if a logical volume is deleted (bnc#459553).
* Wed Jan  7 2009 hare@suse.de
- patches.suse/scsi-netlink-ml: Use GFP_ATOMIC to avoid deadlocks
  (bnc#461747).
* Wed Jan  7 2009 hare@suse.de
- patches.fixes/fc_transport-devloss-callback-restore: FC devloss
  callback not called when devloss timer fires (bnc#463289).
* Wed Jan  7 2009 hare@suse.de
- patches.suse/dm-mpath-leastpending-path-update: Update
  least-pending-IO dynamic load balancer (bnc#444199).
- patches.suse/dm-mpath-queue-length-load-balancing: Rediff.
- patches.suse/dm-mpath-service-time-load-balancing: Rediff.
- patches.suse/dm-mpath-tracking-nr-bytes: Rediff.
- patches.suse/dm-mpath-leastpending-path: Delete.
* Tue Jan  6 2009 jeffm@suse.de
- patches.fixes/uv-remove-erroneous-BAU-init: UV: remove erroneous
  BAU initialization (bnc#463313).
* Tue Jan  6 2009 jjolly@suse.de
- patches.arch/s390-06-01-qeth-ext-src-mac-addr.patch: qeth:
  exploit source MAC address for inbound layer3 packets
  (bnc#458339).
- patches.arch/s390-06-02-qeth-layercrash.patch: qeth: avoid
  crash in case of layer mismatch for VSWITCH (bnc#458339).
- patches.arch/s390-06-03-dasd_sim_sense_condition.patch: Fix
  unsolicited SIM sense condition. (bnc#458339).
- patches.arch/s390-06-04-qdio_ssqd_memcpy.patch: qdio: fix
  broken memcpy (bnc#458339).
- patches.arch/s390-06-05-qdio_s390dbf.patch: qdio: rework
  s390dbf usage  (bnc#458339).
- patches.arch/s390-06-06-qdio_inbound_ack.patch: qdio: rework
  inbound buffer acknowledgement (bnc#458339).
- patches.arch/s390-06-07-cio-attach_detach.patch: cio: Crashes
  when repeatetly attaching/detaching devices. (bnc#458339).
* Tue Jan  6 2009 npiggin@suse.de
- patches.arch/x86-fix-kmap-contig.patch: x86: Jan's comments for
  contiguous kmap fix (bnc#449812).
* Tue Jan  6 2009 npiggin@suse.de
- patches.fixes/mm-lockless-pagecache-barrier.patch: update.
* Mon Jan  5 2009 mmarek@suse.cz
- patches.suse/modpost-filter-out-built-in-depends: modpost:
  filter out "built-in" depends (bnc#450085).
- patches.drivers/0002-Staging-add-TAINT_CRAP-flag-to-drivers-staging-modu.patch:
  refresh.
* Mon Jan  5 2009 npiggin@suse.de
- Fix ps3 config.
* Mon Jan  5 2009 npiggin@suse.de
- patches.fixes/mm-lockless-pagecache-barrier.patch: mm lockless
  pagecache barrier fix.
* Mon Jan  5 2009 npiggin@suse.de
- patches.fixes/fs-symlink-write_begin-allocation-context-fix.patch:
  fs symlink write_begin allocation context fix.
* Mon Jan  5 2009 npiggin@suse.de
- Update config files.
* Mon Jan  5 2009 npiggin@suse.de
- patches.suse/cgroup-freezer.patch: cgroup freezer update (bnc#417294,
  fate#304191, fate#201036).
* Wed Dec 31 2008 npiggin@suse.de
- patches.fixes/s390-lru_add_drain_all.patch: mm: remove UP
  version of lru_add_drain_all() (bnc#458380).
* Wed Dec 31 2008 npiggin@suse.de
- patches.arch/x86-fix-kmap-contig.patch: x86: contiguous kmap
  fix (bnc#449812).
* Tue Dec 30 2008 jeffm@suse.de
- patches.arch/thinkpad_acpi-hotkey-notify-fix: thinkpad_acpi:
  Fix oops with incompatible backlight interface.
* Mon Dec 22 2008 olh@suse.de
- update patches.arch/ppc-memoryless-nodes.patch:
  fix bootmem reservation on uninitialized node (bunc#457029 - LTC50483)
* Mon Dec 22 2008 olh@suse.de
- patches.fixes/scsi-ibmvscsi-can_queue_fix.patch: Make
  max_requests module parameter more accurate (bnc#458499 - LTC50637)
* Sat Dec 20 2008 tiwai@suse.de
- patches.drivers/alsa-hda-hp-dv7-quirk: ALSA: hda - Add quirk
  for another HP dv7 (bnc#461108).
* Sat Dec 20 2008 tiwai@suse.de
- patches.drivers/alsa-ca0106-pm-support: More fixes (bnc#447624).
* Fri Dec 19 2008 jeffm@suse.de
- patches.fixes/reiserfs-debug-1036: Print more info.
* Fri Dec 19 2008 tiwai@suse.de
- patches.drivers/alsa-ca0106-capture-no-44khz: ALSA: disable
  44.1kHz capture on CA0106 (bnc#447624).
- patches.drivers/alsa-ca0106-pm-support: ALSA: ca0106 - Add
  power-amangement support (bnc#447624).
- patches.drivers/alsa-hda-92hd73x-desktop-fixes: ALSA: Fix
  plaback problems on Intel desktops with IDT codecs.
* Fri Dec 19 2008 jbeulich@novell.com
- patches.arch/x86_sgi-uv-scir.patch,
  patches.suse/e1000e_ioremap_sanity_check,
  patches.suse/perfmon2-remove_get_base_syscall_attr.patch,
  patches.suse/perfmon2.patch,
  patches.suse/silent-stack-overflow-2.patch: eliminate build warnings.
* Fri Dec 19 2008 gregkh@suse.de
- Update config files.
- patches.drivers/staging-add-rt2870-wireless-driver.patch:
  Staging: add rt2870 wireless driver.
* Fri Dec 19 2008 nfbrown@suse.de
- patches.fixes/md-bitmap-read-do-not-overflow: md: Don't read
  past end of bitmap when reading bitmap. (bnc#459557).
* Thu Dec 18 2008 jeffm@suse.de
- patches.fixes/reiserfs-debug-1036: Fixed ordering.
* Thu Dec 18 2008 jeffm@suse.de
- patches.fixes/reiserfs-ensure-nonzero-transaction: Delete.
* Thu Dec 18 2008 gregkh@suse.de
- Updated to final 2.6.27.10 release
* Thu Dec 18 2008 trenn@suse.de
- patches.arch/x86-apic-force-bigsmp-apic-on-IBM-EXA3-4.patch:
  Use apic=bigsmp on specific xseries machines (bnc#440497).
* Thu Dec 18 2008 trenn@suse.de
- patches.arch/x86_restrict_pci_early_quirks_to_root_bridges.patch:
  Only scan the root bus in early PCI quirks. (bnc#57886).
* Thu Dec 18 2008 jbeulich@novell.com
- patches.xen/746-pirq-status-page.patch: Merge in c/s 751.
- patches.xen/761-highpte.patch: blktap, gntdev: fix highpte handling.
- patches.xen/762-xencons-hvc.patch: add hvc compatibility mode to xencons.
- patches.xen/xen3-patch-2.6.27.7-8: Linux 2.6.27.8.
- patches.xen/xen3-patch-2.6.27.8-9: Linux 2.6.27.9.
- patches.xen/xen-x86-exports: export a few more symbols
  (bnc#458222).
- patches.xen/xen3-perfmon2_remove_syscalls.patch: Rename to ...
- patches.xen/xen3-perfmon2-remove_syscalls.patch: ... this.
* Thu Dec 18 2008 nfbrown@suse.de
- patches.fixes/md-disable-recovery-on-faulty-degraded-array:
  Disable recovery when degraded RAID1 array appears to be
  faulty. (bnc#447835).
* Wed Dec 17 2008 mmarek@suse.cz
- rpm/symsets.pl: fix uninitialized variable
* Wed Dec 17 2008 mmarek@suse.cz
- rpm/kernel-binary.spec.in:
  - add genksyms reference files so that genksyms can explain why
    did checksums change
* Wed Dec 17 2008 gregkh@suse.de
- patches.drivers/via-framebuffer-driver.patch: Delete.  It
  oopses badly and is not needed for the HP2133 hardware, as
  it has switched to Intel chipsets.
* Wed Dec 17 2008 gregkh@suse.de
- Upate to 2.6.27.10-rc1, fixing lots of problems.
  - obsoletes:
  - patches.drivers/libata-update-ST-FLUSH-blacklist
  - patches.fixes/iwlwifi_fix_oops.patch
  - patches.fixes/v4l-dvb-avoid-writing-outside-array
* Wed Dec 17 2008 jeffm@suse.de
- patches.suse/reiserfs-barrier-default: Make reiserfs default
  to barrier=flush.
* Tue Dec 16 2008 mmarek@suse.cz
- addded symtypes-* files to the RC1 reference kabi
* Tue Dec 16 2008 jeffm@suse.de
- patches.fixes/ext3-mark-super-uptodate: ext3: always mark
  super uptodate before dirty (bnc#457043).
* Tue Dec 16 2008 hare@suse.de
- patches.fixes/blk-dont-invoke-request_fn-on-stopped-queue:
  block: only call ->request_fn when the queue is not stopped
  (bnc#457041).
- patches.fixes/blk-get-extra-reference-before-unmap: block:
  hold extra reference to bio in blk_rq_map_user_iov().
- patches.fixes/blk-move-unplug_work-init: block: move
  q->unplug_work initialization.
- patches.fixes/blk-set-segment-boundary-mask: block: fix setting
  of max_segment_size and seg_boundary mask.
- patches.fixes/dm-mpath-send-activate-to-every-path: Handle
  multiple paths in a path group properly during pg_init.
- patches.fixes/scsi_dh-add-lsi-ids-to-rdac: Adding LSI vendor
  and product IDs to RDAC device handler.
- patches.suse/dm-mpath-accept-failed-paths: Accept failed paths
  for multipath maps (bnc#458037,bnc#458393).
- patches.suse/scsi-check-removed-device-for-offline: Check if
  device is removed in scsi_device_online() (bnc#456747).
* Tue Dec 16 2008 hare@suse.de
- Enable 3270 console (bnc#457039)
* Tue Dec 16 2008 rjw@suse.de
- Update config files.
- patches.suse/mm-do-not-disable-memory-hotplug-when-hibernation-is-enabled.patch:
  mm: Do not disable memory hotplug when hibernation is enabled
  (bnc#438914).
* Tue Dec 16 2008 jeffm@suse.de
- patches.fixes/iwlwifi_fix_oops.patch: iwlwifi: clean key table
  in iwl_clear_stations_table function (bnc#457062).
* Mon Dec 15 2008 jjolly@suse.de
- patches.drivers/cxgb3i_ddp.patch: cxgb3i - added pdu size
  check and fixed ddp page setup (bnc#449519).
* Mon Dec 15 2008 hare@suse.de
- patches.drivers/qla4xxx-5.01.00-k8_sles11-04-update: qla4xxx
  driver SLES 11 Beta6 update (bnc#458186).
* Mon Dec 15 2008 oneukum@suse.de
- patches.suse/usb_correct_config_ti_04b3_4543.diff: fix
  ti_usb_3410_5052 driver for device 04b3:4543 (bnc#395775).
* Sun Dec 14 2008 gregkh@suse.de
- Update to 2.6.27.9
  - obsoleted:
  - patches.fixes/applicom-fix-unchecked-ioctl-range
  - patches.fixes/watchdog-ib700wdt-buffer-underflow
* Fri Dec 12 2008 jeffm@suse.de
- patches.fixes/reiserfs-ensure-nonzero-transaction: reiserfs:
  ensure nonzero transaction (bnc#447406).
* Fri Dec 12 2008 jeffm@suse.de
- patches.fixes/reiserfs-debug-1036: Update to print accurate refcount.
* Fri Dec 12 2008 jblunck@suse.de
- .gitignore: Ignore backup files.
* Fri Dec 12 2008 hare@suse.de
- patches.fixes/scsi-check-host-lookup-failure: Correct
  scsi_host_lookup return value (bnc#456532).
- patches.suse/dm-mpath-accept-failed-paths: Accept failed paths
  for multipath maps (bnc#458037).
* Fri Dec 12 2008 fseidel@suse.de
- patches.fixes/hso_killswitch.patch: hso: rfkill type should
  be WWAN (bnc#458625).
* Fri Dec 12 2008 fseidel@suse.de
- patches.fixes/hso_killswitch.patch:
  fix hso rfkillswitch type to WWAN (bnc#458625)
* Fri Dec 12 2008 mmarek@suse.cz
- import SLE11 RC1 reference kabi
* Fri Dec 12 2008 gregkh@suse.de
- refresh patches to apply cleanly due to 2.6.27.9-rc addition.
* Fri Dec 12 2008 gregkh@suse.de
- remove patches that were obsoleted by 2.6.27.9-rc2
  - patches.arch/ppc-mpic-dont-reset-affinity-for-secondary-MPIC-on-boot.patch
  - patches.arch/x86-hpet-use-WARN_ON_ONCE
  - patches.drivers/alsa-hda-acer-quirk
  - patches.drivers/alsa-hda-alc888-medion-add
  - patches.drivers/alsa-hda-dell-studio-15-quirk
  - patches.drivers/alsa-hda-dell-studio-1535-quirk
  - patches.drivers/alsa-hda-hp-6730s-quirk
  - patches.drivers/alsa-hda-hp-elitebook-8530p-quirk
  - patches.drivers/alsa-hda-hp-mobile-fix
  - patches.drivers/alsa-hda-stac-no-hp-as-line-out-switch
  - patches.drivers/cell_edac.patch
  - patches.fixes/acpi-set-SCI_EN-on-MacBook.patch
  - patches.fixes/atm-duplicate-listen-on-socket-corrupts-the-vcc-table.patch
  - patches.fixes/block-enforce-minimum-SG_IO-timeout
  - patches.fixes/cxgb3-remove-duplicate-tests-in-lro
  - patches.fixes/cxgb3_fix_race_in_EEH
  - patches.fixes/hibernate-x86-fix-breakage-on-x86_32-with-PAE.patch
  - patches.fixes/pci_aspm_check_endless_loop_safe.patch
  - patches.fixes/sched-fix-bug-in-sched-domain-degenerate.patch
  - patches.fixes/x86-arch_add_memory-remove-debug
  - patches.fixes/x86-memory-hotplug-off-by-one
* Fri Dec 12 2008 gregkh@suse.de
- update to 2.6.27.9-rc2:
  - lots of bugfixes
  - some security updates
* Fri Dec 12 2008 gregkh@suse.de
- intermediate commit as part of adding 2.6.27.9-rc1 to the tree.
* Thu Dec 11 2008 hare@suse.de
- Compile in zfcpdump module for S/390 (bnc#446367).
* Thu Dec 11 2008 mmarek@suse.cz
- rpm/kernel-binary.spec.in: one more fix to make kabi checks work
* Thu Dec 11 2008 teheo@suse.de
- patches.drivers/libata-update-ST-FLUSH-blacklist: libata:
  fix Seagate NCQ+FLUSH blacklist (bnc#458192).
* Thu Dec 11 2008 nfbrown@suse.de
- patches.suse/SoN-fix-sync: Cope with racy nature of sync_page
  in swap_sync_page (441793).
* Wed Dec 10 2008 jjolly@suse.de
- patches.arch/s390-05-09-cleanup-of-portopen-requests.patch:
  zfcp: fix erp timeout cleanup for port open requests
  (bnc#450096).
* Wed Dec 10 2008 jeffm@suse.de
- patches.fixes/watchdog-ib700wdt-buffer-underflow: ib700wdt.c -
  fix buffer_underflow bug (bnc#457898).
* Wed Dec 10 2008 jeffm@suse.de
- patches.fixes/applicom-fix-unchecked-ioctl-range: applicom: Fix
  an unchecked user ioctl range and an error return (bnc#457897).
* Wed Dec 10 2008 jeffm@suse.de
- patches.fixes/block-enforce-minimum-SG_IO-timeout: Enforce a
  minimum SG_IO timeout (bnc#457896).
* Wed Dec 10 2008 mmarek@suse.cz
- rpm/find-provides: don't fail if a subpackage doesn't contain
  any modules (such as the -man subpackage on s390x)
* Wed Dec 10 2008 tiwai@suse.de
- patches.drivers/alsa-hda-hp-6730b-quirk: ALSA: hda - Add quirk
  for HP6730B laptop (bnc#457909).
- patches.drivers/alsa-hda-hp-6730s-quirk: ALSA: hda - Add
  another HP model (6730s) for AD1884A.
- patches.drivers/alsa-hda-hp-elitebook-8530p-quirk: ALSA: hda -
  Make the HP EliteBook 8530p use AD1884A model laptop.
* Wed Dec 10 2008 olh@suse.de
- patches.drivers/ibmvfc-add_sync.patch:
  Fix errors due to inconsistent command data (bnc#456654 - LTC50451)
- patches.drivers/ibmvfc-host_init_delay.patch:
  Delay NPIV login retry and add retries (bnc#456654 - LTC50451)
* Wed Dec 10 2008 teheo@suse.de
- patches.drivers/libata-pata_hpt366-fix-cable-detection:
  pata_hpt366: fix cable detection, (bnc#362159).
- patches.drivers/libata-pata_hpt366-fix-clock-detection:
  pata_hpt366: fix clock detection (bnc#362159).
- patches.drivers/libata-pata_hpt366-no-ATAPI-DMA: pata_hpt366:
  no ATAPI DMA (bnc#362159).
- patches.drivers/libata-pata_hpt366-reimplement-mode-programming:
  pata_hpt366: reimplement mode programming (bnc#362159).
* Tue Dec  9 2008 agruen@suse.de
- supported.conf: Mark xfs_dmapi as supported (bnc#457668).
* Tue Dec  9 2008 jeffm@suse.de
- patches.fixes/x86-arch_add_memory-remove-debug: x86: remove
  debug code from arch_add_memory() (bnc#457526).
- patches.fixes/x86-memory-hotplug-off-by-one: x86, memory
  hotplug: remove wrong -1 in calling init_memory_mapping()
  (bnc#457526).
* Tue Dec  9 2008 agruen@suse.de
- rpm/{kernel-module-subpackage,macros.kernel-source}: Remove
  a leftover hardcoded dependency on the kernel-source package so
  that KMPs can alternatively be built against a kernel other
  than (kernel-source + kernel-syms), such as (kernel-source-rt +
  kernel-syms-rt).
* Tue Dec  9 2008 trenn@suse.de
- patches.fixes/pci_aspm_check_endless_loop_safe.patch: PCIe:
  ASPM: Break out of endless loop waiting for PCI config bits
  to switch (bnc#449799).
* Tue Dec  9 2008 mmarek@suse.cz
- rpm/symsets.pl:
  - add --required-modules option to tell which modules this
    subpackage requires via dependencies. This is needed to
    preserve symsets when modules move from one subpackage to
    another.
  - add POD help and --help option.
- rpm/kernel-binary.spec.in: make use of --required-modules
* Tue Dec  9 2008 nfbrown@suse.de
- patches.fixes/xfs-barrier-fix.patch: Fix propagation of
  EOPNOTSUPP when barriers are not supported. (bnc#438608).
* Tue Dec  9 2008 rjw@suse.de
- patches.fixes/tg3-fix-default-wol.patch: net (tg3): Fix failure
  to enable WoL by default when possible (bnc#447371).
* Mon Dec  8 2008 olh@suse.de
- patches.arch/ppc-valid-hugepage-size-hugetlb_get_unmapped_area.patch:
  Check for valid hugepage size in hugetlb_get_unmapped_area
  (bnc#456433 - LTC50170).
* Mon Dec  8 2008 trenn@suse.de
- patches.fixes/pci_aspm_check_endless_loop.patch: Delete.
* Mon Dec  8 2008 rw@suse.de
- patches.drivers/sgi-xp-no-uv:
  SGI SN: Eliminate dependency of the XP/XPC drivers on GRU. (bnc#442442)
* Mon Dec  8 2008 rw@suse.de
- Update config files for ia64:
  Disable PERMIT_BSP_REMOVE.  (bnc#386714)
* Mon Dec  8 2008 mmarek@suse.cz
- rpm/find-provides, rpm/kernel-binary.spec.in: figure out what
  subpackage is being processed in find-provides and just print
  the symsets computed in the spec.
* Mon Dec  8 2008 olh@suse.de
- rpm/post.sh: use flavor-rpmarch to match boards on powerpc
* Mon Dec  8 2008 mmarek@suse.cz
- rpm/kernel-module-subpackage: skip empty KMPs with a warning in
  the kmp %%%%postun
* Mon Dec  8 2008 jjohansen@suse.de
- Update config files.
- patches.apparmor/fix-complain.diff: fix enforcement of deny
  rules in complain mode (bnc#426159).
- patches.apparmor/fix-security-param.diff: fix recognition of
  security= boot parameter (bnc#442668).
- patches.apparmor/fork-tracking.diff: fix log messages to enable
  tools profile learning (bnc#447564).
* Mon Dec  8 2008 olh@suse.de
- rpm/post.sh: update board detection to use rpmarch instead flavor
* Mon Dec  8 2008 hare@suse.de
- patches.fixes/block-integrity-update: Block integrity update
  (FATE#304345).
- patches.suse/dm-block-integrity: Block integrity support for
  DM and MD (FATE#304345).
- patches.suse/dm-mpath-add-start-io: dm-mpath: add a path
  selector interface (FATE#303862,FATE#302108).
- patches.suse/dm-mpath-queue-length-load-balancing: dm-mpath: add
  queue-length dynamic load balancer (FATE#303862,FATE#302108).
- patches.suse/dm-mpath-service-time-load-balancing:
  dm-mpath: add service-time oriented dynamic load balancer
  (FATE#303862,FATE#302108).
- patches.suse/dm-mpath-tracking-nr-bytes: dm-mpath:
  interface change for service-time dynamic load balancer
  (FATE#303862,FATE#302108).
- supported.conf: Update to correctly reference dynamic load
  balancer modules (bnc#444199)
* Mon Dec  8 2008 tonyj@suse.de
- patches.suse/perfmon2-add_ioctl_interface.patch: switch to
  ioctl interface for perfmon2.
- patches.suse/perfmon2-fix_disabled.patch: fix initializion of
  perfmon disabled.
- patches.suse/perfmon2-remove_get_base_syscall_attr.patch:
  remove perfmon syscall_base attribyute.
- patches.suse/perfmon2-remove_syscalls.patch: drop additional
  perfmon2 syscalls.
- patches.xen/xen3-perfmon2_remove_syscalls.patch: drop additional
  perfmon2 syscalls.
* Sat Dec  6 2008 trenn@suse.de
- patches.arch/acpi_ec_provide_non_interrupt_mode_boot_param.patch:
  ACPI: EC: Don't degrade to poll mode at storm
  automatically. (bnc#446142).
- patches.fixes/pci_aspm_check_endless_loop.patch: PCIE Break
  out of endless loop waiting for PCI config bits to switch
  (bnc#449799).
* Sat Dec  6 2008 gregkh@suse.de
- refresh patches to apply cleanly.
* Sat Dec  6 2008 gregkh@suse.de
- Update to final 2.6.27.8 release
  - contains 2 changes from 2.6.27.8-rc1
* Fri Dec  5 2008 jbeulich@novell.com
- patches.xen/xen-configurable-guest-devices: fix a typo.
* Fri Dec  5 2008 olh@suse.de
- patches.suse/scsi-scsi_transport_srp-shost_data.patch:
  move crq_queue_create at the end of initialization (bnc#455929).
* Fri Dec  5 2008 hare@suse.de
- patches.drivers/open-fcoe-fnic-patches: Open-FCoE bugfixes
  for fnic.
- patches.drivers/open-fcoe-rc1-update: Update open-FCoE with
  latest patches from Intel (bnc#438954).
* Fri Dec  5 2008 jbeulich@novell.com
- Update Xen x86-64 config (2k guest devices, 1k outstanding transmits
  in netback).
* Fri Dec  5 2008 hare@suse.de
- patches.arch/s390-zfcp-synchronize-scsi-register: No udev
  events for zfcp online / offline (bnc#443667).
- patches.fixes/scsi-remove-scmd-timeout: Fix block timeout
  residue problems (bnc#447249,bnc#441335).
- patches.fixes/scsi-eh_stu-timeout: Delete obsolet patch.
* Fri Dec  5 2008 bphilips@suse.de
- patches.fixes/saa7134-fix-resource-map-sanity-check-conflict.patch:
  saa7134: fix resource map sanity check conflict (bnc#446733).
* Fri Dec  5 2008 gregkh@suse.de
- Update config files.
- patches.drivers/staging-add-rtl8187se-driver.patch: Staging:
  add rtl8187se driver.  Needed for MSI Wind and other netbooks.
* Fri Dec  5 2008 gregkh@suse.de
- Update config files.
- patches.drivers/staging-add-serverengines-benet-10gb-ethernet-driver.patch:
  Staging: Add ServerEngines benet 10Gb ethernet driver.
* Fri Dec  5 2008 gregkh@suse.de
- update the wlan-ng driver to the latest upstream version, making
  it much more useful (it actually works now...)
* Fri Dec  5 2008 nfbrown@suse.de
- patches.fixes/sunrpc-module-refcount-fix: Add a reference to
  sunrpc in svc_addsock (443379).  This avoid a bug where
  refcount on sunrpc can go zero or negative.
* Thu Dec  4 2008 jeffm@suse.de
- patches.fixes/reiserfs-debug-1036: reiserfs: print more
  information when an empty journal list is encountered
  (bnc#447406 bnc#399966).
* Thu Dec  4 2008 gregkh@suse.de
- patches.fixes/atm-duplicate-listen-on-socket-corrupts-the-vcc-table.patch:
  ATM: duplicate listen() on socket corrupts the vcc table
  (CVE-2008-5079).
* Thu Dec  4 2008 jack@suse.cz
- Update config files.
* Thu Dec  4 2008 jack@suse.cz
  XFS update on request from SGI:
- patches.apparmor/vfs-notify_change.diff: Add a vfsmount
  parameter to notify_change(). (refreshed)
- patches.suse/xfs-account-for-allocated-blocks-when-expanding-directories:
  Account for allocated blocks when expanding directories
  (bnc#450658).
- patches.suse/xfs-check-for-valid-transaction-headers-in-recovery:
  XFS: Check for valid transaction headers in recovery
  (bnc#450658).
- patches.suse/xfs-dmapi-enable: VFS changes to support DMAPI
  (bnc#450658).
- patches.suse/xfs-dmapi-src: DMAPI Source  (bnc#450658).
- patches.suse/xfs-dmapi-xfs-enable: DMAPI support for xfs
  (bnc#450658).
- patches.suse/xfs-handle-memory-allocation-failures-during-log-initialisation:
  handle memory allocation failures during log initialisation
  (bnc#450658).
- patches.suse/xfs-nfsd-dmapi-aware: Make NFSD DMAPI aware
  (74107, 173874, bnc#450658).
- patches.suse/xfs-wait-for-all-IO-on-truncate-to-zero: Wait
  for all I/O on truncate to zero file size (bnc#450658).
- patches.suse/xfs-dmapi-2.6.27: Delete.
- patches.suse/xfs-dmapi-xfs-2.6.27: Delete.
* Thu Dec  4 2008 olh@suse.de
- patches.arch/ppc-mpic-dont-reset-affinity-for-secondary-MPIC-on-boot.patch:
  Don't reset affinity for secondary MPIC on boot (bnc#456408 - LTC50397).
* Thu Dec  4 2008 jjolly@suse.de
- Update config files.
- patches.arch/s390-05-04-fix_rport_status_check.patch: zfcp:
  fix remote port status check (bnc#450096).
- patches.arch/s390-05-05-stp-etr-stop-machine.patch: stp/etr:
  smp_call_function races. (bnc#450096).
- patches.arch/s390-05-06-stp-etr-mutex.patch: stp/etr: serialize
  work. (bnc#450096).
- patches.arch/s390-05-07-generic-ipi.patch: kernel:
  smp_call_function races. (bnc#450096).
- patches.arch/s390-05-08-topology.patch: kernel: disable cpu
  topology support by default (bnc#450096,LTC#50392).
* Thu Dec  4 2008 olh@suse.de
- patches.arch/ppc-cell-gdb-watchpoints.patch:
  Fix GDB watchpoints on Cell (bnc#456405 - LTC50396).
* Thu Dec  4 2008 olh@suse.de
- patches.arch/ppc-syscall-xer.so.1.patch: Fix system calls on
  Cell entered with XER.SO=1 (bnc#456406 - LTC50395).
* Thu Dec  4 2008 hare@suse.de
- patches.suse/genhd-disk-ro-uevents: Send uevents for
  write_protect changes (bnc#440959).
* Thu Dec  4 2008 mmarek@suse.cz
- supported.conf: mark kernel/net/ipv4/ipvs/ip_vs/* and
  kernel/net/ipv4/netfilter/ipt_CLUSTERIP as unsupported,
  a supported variant will be provided in a separate KMP
  (bnc#455959)
* Thu Dec  4 2008 schwab@suse.de
- Set CONFIG_IA64_CPE_MIGRATE=m.
* Thu Dec  4 2008 jbeulich@novell.com
- supported.conf: Mark pciback as support, sfc_resource, sfc_netback,
  and sfc_netutil as externally supported, add sfc_netfront, and mark
  xenscsi and xen-scsibk as unsupported.
* Thu Dec  4 2008 mszeredi@suse.de
- patches.suse/SoN-fix-uninitialized-variable.patch: Fix use of
  uninitialized variable in cache_grow() (bnc#444597).
* Thu Dec  4 2008 hare@suse.de
- patches.fixes/scsi-eh_stu-timeout: make scsi_eh_try_stu use
  block timeout (bnc#447249,bnc#441335).
* Thu Dec  4 2008 gregkh@suse.de
- patches.fixes/jbd2-create-proc-entry-fix.patch: Delete. It's not needed
  anymore now that 2.6.27.8-rc1 has a similar fix.
* Thu Dec  4 2008 gregkh@suse.de
- Update to 2.6.27.8-rc1:
  - lots of bugfixes
  - some security fixes as well.
  - obsoletes lots of existing patches:
  - patches.arch/ppc-spufs-02-add-a-missing-mutex_unlock.patch
  - patches.arch/ppc-spufs-11-Fix-spinning-in-spufs_ps_fault-on-sig.patch
  - patches.drivers/libata-fix-ata_tf_read_block-overflow
  - patches.drivers/libata-fix-ata_tf_to_lba48-overflow
  - patches.drivers/libata-seagate-firmware-bug
  - patches.drivers/parport-serial-array-overflow-fix
  - patches.fixes/af_unix-soft-lockup-fix.patch
  - patches.fixes/cifs-add-cifs_sock_list
  - patches.fixes/cifs-cleanup-cifs_mount
  - patches.fixes/cifs-cleanup-proto-handling
  - patches.fixes/cifs-disable-sess-sharing
  - patches.fixes/cifs-fix-build-breakage
  - patches.fixes/cifs-fix-data-corruption
  - patches.fixes/cifs-fix-dead-tcon-check
  - patches.fixes/cifs-fix-oops-on-failed-mount
  - patches.fixes/cifs-fix-reconnection-flags
  - patches.fixes/cifs-fix-smb-send2
  - patches.fixes/cifs-fix-writepages
  - patches.fixes/cifs-reinstate-sess-sharing-sans-races
  - patches.fixes/cifs-reinstate-treecon-sharing
  - patches.fixes/ext4_add-missing-unlock-to-ext4-check-descriptors
  - patches.fixes/ext4_create-proc-ext4-stats-file-more-carefully
  - patches.fixes/ext4_fix_whitespace_checkpatch_issues
  - patches.fixes/ext4_update-flex-bg-counters-when-resizing
  - patches.fixes/fix-inotify-watch-removal-umount-races
  - patches.fixes/hpwdt-execute-page.diff
  - patches.fixes/hpwdt-kdump.diff
  - patches.fixes/ia64-fix-boot-panic-caused-by-offline-CPUs.patch
  - patches.fixes/x86_cpufreq_powernow-k8_handle_invalid_state_gracefully.patch
* Wed Dec  3 2008 jbeulich@novell.com
- patches.xen/xen3-patch-2.6.19: Fix a kernel warning during shutdown.
- patches.xen/xen3-patch-2.6.27,
  patches.xen/xen-netback-notify-multi,
  patches.xen/xen-virq-per-cpu-irq: Refresh.
* Wed Dec  3 2008 olh@suse.de
- patches.suse/scsi-scsi_transport_srp-shost_data.patch: change
  init order to fill in shost_data (bnc#455929).
* Wed Dec  3 2008 hare@suse.de
- patches.suse/scsi-netlink-ml: Use GFP_ATOMIC for
  skb allocation.
* Wed Dec  3 2008 olh@suse.de
- patches.suse/scsi-scsi_transport_srp-shost_data.patch:
  add debug for Scsi_Host->shost_data (bnc#455929).
* Wed Dec  3 2008 hare@suse.de
- supported.conf: mark dm-leastpending-path as supported
  (bnc#444199)
* Wed Dec  3 2008 teheo@suse.de
  Patch updated to remove strcmp() on NULL strings.
- patches.drivers/libata-ata_piix-borked-tecra-m4-broken-suspend:
  ata_piix: add borked Tecra M4 to broken suspend list
  (bnc#398270).
* Wed Dec  3 2008 jbeulich@novell.com
- Update Xen patches to c/s 728 (plus several indivual ones)
- patches.xen/735-balloon-exit.patch: remove sysfs files during balloon
  module exit.
- patches.xen/737-kexec-free.patch: kexec: Don't pass
  limit_pages_to_max_mfn() regions to xen_destroy_contiguous_region().
- patches.xen/740-blkback-resource-leak.patch: blkback, blktap: Fix
  potential resource leak.
- patches.xen/746-pirq-status-page.patch: use shared page indicating
  the need for an EOI notification
- patches.xen/747-x86-undo-mfn-limit.patch: revert the effect of
  xen_limit_pages_to_max_mfn()
- patches.xen/748-x86-ioapic-cleanup.patch: cleanup IO-APIC code
- patches.xen/panic-on-io-nmi-xen.diff: Rename to ...
- patches.xen/xen3-panic-on-io-nmi.diff: ... this.
- patches.xen/uv-sysfs-no-xen.diff: Replace by ...
- patches.xen/xen3-uv_setup_irq.diff: ... this.
- patches.xen/xen3-x86_sgi_uv_early_detect_oem.patch: x86, uv:
  add early detection of UV system types (bnc#429984).
- patches.xen/xen-fb-bad-irq: Delete.
* Wed Dec  3 2008 hare@suse.de
- patches.drivers/lpfc-8.2.8.9-update: Update Emulex lpfc driver
  to 8.2.8.9 (bnc#420767).
* Wed Dec  3 2008 knikanth@suse.de
- patches.suse/cfq-ioc-race: Exiting queue and task might race
  to free cic (bnc#444346).
* Wed Dec  3 2008 sjayaraman@suse.de
- patches.fixes/cifs-reinstate-sess-sharing-sans-races: Adjust as it
  didn't apply cleanly.
* Wed Dec  3 2008 sjayaraman@suse.de
- Fix data corruption issues (411655).
  patches.fixes/cifs-fix-data-corruption
  patches.fixes/cifs-fix-smb-send2
- Fix multiple oopses, memory corruption due to mount/umount races
  (https://bugzilla.samba.org/show_bug.cgi?id=5720).
  patches.fixes/cifs-add-cifs_sock_list
  patches.fixes/cifs-cleanup-cifs_mount
  patches.fixes/cifs-cleanup-proto-handling
  patches.fixes/cifs-disable-sess-sharing
  patches.fixes/cifs-fix-build-breakage
  patches.fixes/cifs-fix-dead-tcon-check
  patches.fixes/cifs-fix-oops-on-failed-mount
  patches.fixes/cifs-fix-reconnection-flags
  patches.fixes/cifs-fix-writepages
  patches.fixes/cifs-reinstate-sess-sharing-sans-races
  patches.fixes/cifs-reinstate-treecon-sharing
* Wed Dec  3 2008 jeffm@suse.de
- scripts/git-create-branch: Helper script to create a new
  branch.
* Tue Dec  2 2008 mmarek@suse.cz
- rpm/get_release_number.sh.in, scripts/tar-up.sh: append first
  eight digits of the commit id to the release string. This makes
  it easier to match rpm release numbers with commits.
* Tue Dec  2 2008 mszeredi@suse.de
- patches.fixes/af_unix-soft-lockup-fix.patch: net: Fix soft
  lockups/OOM issues w/ unix garbage collector (bnc#449739
  CVE-2008-5300).
* Tue Dec  2 2008 hare@suse.de
- patches.drivers/qla2xxx-8.02.01.02.11.0-k9-update: qla2xxx:
  additional fixes/updates for SLES11 (bnc#450197).
- patches.fixes/scsi-fixup-failfast-definitions: fc_transport:
  fix old bug on bitflag definitions (bnc#447814).
* Tue Dec  2 2008 goldwyn@suse.de
- patches.suse/novfs-map-drives-correctly.diff
- patches.suse/novfs-merge-changes.diff: Modified to revert
  some changes in novfs_set_map_drive()
- patches.suse/novfs-clear-mappeddrives.patch: Unlink mapped
  drives on exit (bnc#449451).
* Tue Dec  2 2008 mmarek@suse.cz
- supported.conf: mark ocfs2 as unsupported, a supported variant
  will be provided in a separate KMP (bnc#449824)
* Tue Dec  2 2008 olh@suse.de
- patches.drivers/ehca-rejecting-dynamic-mem-add-remove.patch:
  update error message (bnc#448301 - LTC50134)
* Tue Dec  2 2008 hare@suse.de
- Update config files for S/390: Disable FCoE and sync
  default and s390.
- supported.conf: Mark KVM as supported.
* Tue Dec  2 2008 jjolly@suse.de
- ...and added the patches to the series.conf (bnc#450096)
* Tue Dec  2 2008 jjolly@suse.de
- patches.arch/s390-05-01-zfcp-message-linebreak.patch: zfcp:
  Wrong placement of linebreak in message (bnc#450096).
- patches.arch/s390-05-02-zfcp-invalid-non-null-return.patch:
  zfcp: invalid return value on failing fsf_req creation
  (bnc#450096).
- patches.arch/s390-05-03-zfcp-wka-port.patch: zfcp: Fix opening
  of wka ports (bnc#450096).
* Mon Dec  1 2008 kkeil@suse.de
- patches.drivers/cxgb3-Add-1G-fiber-support: cxgb3: Add 1G
  fiber support.
- patches.drivers/cxgb3-Allocate-multiqueues-at-init-time: cxgb3:
  Allocate multiqueues at init time.
- patches.drivers/cxgb3-More-flexible-support-for-PHY-interrupts:
  cxgb3: More flexible support for PHY interrupts..
- patches.drivers/cxgb3-Support-for-Aeluros-2005-PHY: cxgb3:
  Support for Aeluros 2005 PHY.
- patches.drivers/cxgb3-allow-for-PHY-reset-status: cxgb3:
  allow for PHY reset status.
- patches.drivers/cxgb3-commnonize-LASI-phy-code: cxgb3:
  commnonize LASI phy code.
- patches.drivers/cxgb3-eeprom-read-fixes.patch:
  cxgb3 - eeprom read fixes.
- patches.drivers/cxgb3-enable-lro-through-ethtool: cxgb3 -
  enable lro control through ethtool.
- patches.drivers/cxgb3-simplify-port-type-struct-and-usage:
  cxgb3: simplify port type struct and usage.
- patches.drivers/cxgb3-update-driver-version: cxgb3: update
  driver version. (bnc#446739)
* Mon Dec  1 2008 mmarek@suse.cz
- rpm/macros.kernel-source: one more fix to the flavor selection
  code (for some reason %%* contained a newline)
* Mon Dec  1 2008 trenn@suse.de
- patches.arch/acpi_x2APIC_madt_enhancements.patch: ACPICA:
  x2APIC support: changes for MADT and SRAT ACPI tables (fate
  303948 and fate 303984).
- patches.fixes/acpi_check_for_invalid_handle.patch: ACPICA:
  Add check for invalid handle in acpi_get_object_info
  (http://www.acpica.org/bugzilla/show_bug.cgi?id=474).
- patches.fixes/acpi_dereference_object_if_possible.patch:
  ACPICA: Add function to dereference returned reference objects
  (http://bugzilla.kernel.org/show_bug.cgi?id=11105).
- patches.fixes/acpi_do_not_load_acpi_cpufreq_acpioff.patch:
  ACPI: don't load acpi_cpufreq if acpi=off (no reference).
* Mon Dec  1 2008 trenn@suse.de
- patches.fixes/acpi_copy_tables_fix_suspend.patch: ACPICA:
  Copy dynamically loaded tables to local buffer (bnc#410726).
* Sat Nov 29 2008 nfbrown@suse.de
- patches.fixes/SUNRPC-Fix-autobind-on-cloned-rpc-clients.patch:
  SUNRPC: Fix autobind on cloned rpc clients.
  Importantly, this removes a 'BUG_ON' that fires. (450083).
* Sat Nov 29 2008 teheo@suse.de
- patches.drivers/libata-ata_piix-borked-tecra-m4-broken-suspend:
  ata_piix: add borked Tecra M4 to broken suspend list
  (bnc#398270).
* Sat Nov 29 2008 bwalle@suse.de
- UV updates from SGI (bnc#442455, #442455).
  o patches.fixes/ia64_uv_partition_id.diff:
    Add partition id, coherence id, and region size to UV
  o patches.fixes/ia64_uv_watchlist.diff:
    Add UV watchlist suppor
  o patches.fixes/null_irq_desc_name.diff:
    genirq: NULL struct irq_desc's member 'name' in
    dynamic_irq_cleanup()
  o patches.fixes/uv-bios_call_memprotect.diff:
    Add UV bios call to change memory protections
  o patches.fixes/uv-bios_call_partition.diff:
    x86: Add UV partition call
  o patches.fixes/uv-bios_call_reserve_page.diff:
    Add UV bios call to get the address of the reserved page
  o patches.fixes/uv-bios_call_watchlist.diff:
    Add UV bios calls to allocate and free watchlists
  o patches.fixes/uv-bios_common.diff:
    x86: Add UV bios call infrastructure
  o patches.fixes/uv-efi_bios.diff:
    x86: Add UV EFI table entry
  o patches.fixes/uv-sn_region_size.diff:
    Use consistent names for region size and conherence id on x86
    and ia64
  o patches.fixes/uv-sysfs.diff:
    x86: Add UV sysfs entries
  o patches.fixes/uv-xp-change_memprotect.diff:
    Define xp_expand_memprotect() and xp_restrict_memprotect()
  o patches.fixes/uv-xpc-get_sn_info.diff:
    Define xp_partition_id and xp_region_size
  o patches.fixes/uv-xpc_create_gru_mq_uv.diff:
    Add the code to create the activate and notify gru message
    queues
  o patches.fixes/uv-xpc_get_part_rsvd_page.diff:
    Add support for getting the address of a partition's reserved
    page
  o patches.fixes/uv_setup_irq.diff:
    x86, UV: add uv_setup_irq() and uv_teardown_irq() functions, v3
- Refresh Xen patches
  o patches.xen/xen3-auto-arch-x86.diff
  o patches.xen/xen3-patch-2.6.19
- patches.xen/xen-x86-no-lapic: Add uv_irq.o
- patches.xen/uv-sysfs-no-xen.diff:
  Don't build UV sysfs support on Xen.
* Sat Nov 29 2008 trenn@suse.de
- patches.fixes/x86_cpufreq_powernow-k8_handle_invalid_state_gracefully.patch:
  powernow-k8: ignore out-of-range PstateStatus value (no
  bug avail).
* Fri Nov 28 2008 sassmann@suse.de
- Update config files.
  activate ALTIVEC in ps3 config
* Fri Nov 28 2008 hare@suse.de
- patches.drivers/open-fcoe-beta4-update: rediff.
- patches.drivers/open-fcoe-beta6-update: Incremental Open-FCoE
  for Beta6 (bnc#438954).
* Fri Nov 28 2008 tiwai@suse.de
- patches.drivers/alsa-hda-sony-vaio-vgn-sr19xn-quirk: ALSA:
  hda - Add quirk for Sony VAIO VGN-SR19XN (bnc#450080).
* Fri Nov 28 2008 olh@suse.de
- rpm/kernel-binary.spec.in: move Module.symvers creation into
  CONFIG_MODULES section, a static kernel exports nothing
* Fri Nov 28 2008 olh@suse.de
- rpm/post*.sh: kernel-vanilla has now vmlinux-vanilla symlink
* Fri Nov 28 2008 teheo@suse.de
  Block layer timer bug fixed.  Multipath patch update is just patch
  refresh.
- patches.drivers/block-internal-dequeue-shouldnt-start-timer:
  block: internal dequeue shouldn't start timer (bnc#449880).
- patches.drivers/blk-request-based-multipath-update: Block layer
  fixes for request-based multipathing (References: FATE#302108).
* Thu Nov 27 2008 olh@suse.de
- patches.suse/8250-sysrq-ctrl_o.patch: fix no-op macro args
* Thu Nov 27 2008 olh@suse.de
- patches.suse/8250-sysrq-ctrl_o.patch: fix compile on ppc32
* Thu Nov 27 2008 olh@suse.de
- rpm/kernel-binary.spec.in: always create a dummy initrd because
  mkinitrd is called unconditionally
* Thu Nov 27 2008 olh@suse.de
- rpm/kernel-binary.spec.in: kernel-ps3 needs a suffix
* Thu Nov 27 2008 olh@suse.de
- remove last traces of kernel-um handling
* Thu Nov 27 2008 hare@suse.de
- patches.fixes/qla2xxx-disable-automatic-queue-tracking: qla2xxx:
  Conditionally disable queue_full tracking (bnc#449386).
* Thu Nov 27 2008 olh@suse.de
- patches.suse/8250-sysrq-ctrl_o.patch: no sysrq on Cell QS21/QS22
  serial console (bnc#422987,bnc#96313 - LTC47675/LTC16841).
* Thu Nov 27 2008 olh@suse.de
- patches.arch/ppc-memoryless-nodes.patch: fix booting with
  memoryless nodes (443280 - LTC49675)
* Thu Nov 27 2008 teheo@suse.de
- patches.drivers/libata-seagate-firmware-bug: libata: blacklist
  Seagate drives which time out FLUSH_CACHE when used with NCQ
  (bnc#449531).
* Wed Nov 26 2008 agruen@suse.de
- rpm/macros.kernel-source: Fix the kernel flavor selection logic
  for the %%kernel_module_package macro.
* Wed Nov 26 2008 hare@suse.de
- patches.fixes/blk-leave-sync-timer-running: move to
  correct place in series.conf and rediff
- patches.drivers/cciss-newids.patch: Delete.
* Wed Nov 26 2008 hare@suse.de
- patches.drivers/cciss-newids.patch: Support for newcciss
  controller (bnc#448416).
- patches.fixes/blk-leave-sync-timer-running: block: leave
  request timeout timer running on an empty list (bnc#447249).
* Tue Nov 25 2008 mszeredi@suse.de
- patches.fixes/slab-alloc_slabmgmt-fix.patch: slab: remove
  GFP_THISNODE clearing from alloc_slabmgmt() (bnc#444597).
* Tue Nov 25 2008 sjayaraman@suse.de
- patches.suse/SoN-11-mm-page_alloc-emerg.patch: Fix accidental side-effect
  that this patch introduced by reverting patches.fixes/oom-warning
  (bnc #444597).
* Tue Nov 25 2008 tiwai@suse.de
- patches.drivers/alsa-ca0106-pm-support: ALSA: ca0106 - Add
  power-amangement support (bnc#447624).
- patches.drivers/alsa-hda-dell-92hd73xx-models: ALSA: hda -
  Check model for Dell 92HD73xx laptops (bnc#446025).
- patches.drivers/alsa-hda-dell-studio-1535-quirk: ALSA: hda -
  mark Dell studio 1535 quirk (bnc#446025).
- patches.drivers/alsa-hda-spdif-bits-cache-fix: ALSA: hda -
  Fix caching of SPDIF status bits.
- patches.drivers/alsa-hda-stac-no-hp-as-line-out-switch: ALSA:
  hda - No 'Headphone as Line-out' swich without line-outs
  (bnc#446025).
- patches.drivers/alsa-hda-stac-yet-more-fixes: ALSA: hda -
  Fix AFG power management on IDT 92HD* codecs (bnc#446025).
* Tue Nov 25 2008 jeffm@suse.de
- patches.fixes/fix-inotify-watch-removal-umount-races: Fix
  inotify watch removal/umount races (bnc#446973 CVE-2008-5182).
* Tue Nov 25 2008 jeffm@suse.de
- patches.fixes/uv-redundant-creation-of-proc-dir: UV: redundant
  creation of sgi_uv (bnc#444799).
* Mon Nov 24 2008 agruen@suse.de
- supported.conf: dm-raid45 depends on a few more modules
  (bnc#440208, bnc#441310).
* Mon Nov 24 2008 agruen@suse.de
- Switch from a no_file_caps command line switch to file_caps={0,1}
  for enabling/disabling file capabilities, and make file_caps=0
  the default: we cannot get the no_file_caps option added to the
  kernel command line anymore (perl-Bootloader, bnc#418366).
* Mon Nov 24 2008 agruen@suse.de
- supported.conf: dm-raid4-5 was renamed to dm-raid45 (bnc#440208,
  bnc#441310).
* Mon Nov 24 2008 agruen@suse.de
- Update config files: switch from CONFIG_PREEMPT_VOLUNTARY to
  CONFIG_PREEMPT_NONE.
* Mon Nov 24 2008 ghaskins@suse.de
- patches.fixes/sched-fix-bug-in-sched-domain-degenerate.patch:
  sched: fix a bug in sched domain degenerate (bnc#442464).
* Mon Nov 24 2008 mmarek@suse.cz
- doc/README.SUSE: document that setting allow_unsupported_modules
  to 1 in /etc/modprobe.d/unsupported-modules is required to make
  self-compiled kernels work.
* Mon Nov 24 2008 bwalle@suse.de
- patches.fixes/hpwdt-kdump.diff: Sync with latest upstream
  submission.
* Sun Nov 23 2008 trenn@suse.de
- patches.arch/x86_sgi_uv_early_detect_oem.patch: x86, uv:
  add early detection of UV system types (bnc#429984).
* Sat Nov 22 2008 olh@suse.de
- enable CONFIG_CGROUP_NS on ia64, s390 and powerpc (bnc#447507 - LTC50053)
* Sat Nov 22 2008 rjw@suse.de
- patches.fixes/ia64-fix-boot-panic-caused-by-offline-CPUs.patch:
  fix boot panic caused by offline CPUs (bnc#440386).
* Fri Nov 21 2008 agruen@suse.de
- config/x86_64/maxcpus: Delete.
* Fri Nov 21 2008 mmarek@suse.cz
- rpm/kernel-binary.spec.in: s/CVS/GIT/
* Fri Nov 21 2008 mmarek@suse.cz
- rpm/symsets.pl: fix module names in export lists
  (kernel/irq/built-in was printed as irq/built-in)
* Fri Nov 21 2008 agruen@suse.de
- Update x86_64/{debug,default,trace,vanilla} config files:
  increase NR_CPUS to 512.
* Fri Nov 21 2008 mmarek@suse.cz
- rpm/symsets.pl: Replace the bash and awk scripts around symsets
  and kabi checking with a single script that generates symsets,
  reuses symsets from older kernels and checks for kabi changes for
  each of the split packages (kabi checking and symset reuse
  require a set of reference files, which does not exist yet)
- rpm/list-exported-symbols: Delete.
- rpm/split-into-symsets: Delete.
- scripts/kabi-checks: Delete.
- kabi/severities: table of kabi change severities
- rpm/built-in-where, rpm/find-provides,
  rpm/kernel-binary.spec.in, rpm/kernel-source.spec.in,
  scripts/tar-up.sh: update to use symsets.pl
* Fri Nov 21 2008 kkeil@suse.de
- patches.drivers/ixgbe-sfp.patch: include additional fixes from
  Intel (bnc#442411)
* Fri Nov 21 2008 kkeil@suse.de
- patches.fixes/igb_ethtool.patch: add missing ethtool hooks
  (bnc#435551)
* Fri Nov 21 2008 jjolly@suse.de
- patches.arch/s390-04-08-cio-ungroup-race-fix.patch:
  cio: ccwgroup online vs. ungroup race condition
  (bnc#445100,LTC#50092).
- patches.arch/s390-04-09-zfcp-host-busy-count-fix.patch: zfcp:
  prevent double decrement on host_busy counter (bnc#445100).
* Fri Nov 21 2008 agruen@suse.de
- rpm/macros.kernel-source:
  + Rename the -s option to -t in the %%kernel_module_package macro
    for improved cross-distro compatibility.
  + Define %%kernel_module_package_release as 1 for feature tests.
  + Define %%kernel_module_package_buildreqs for use by KMPs: that
    way, KMPs can either use this macro for compatibility, or
    they can substitute other packages for special cases.
* Fri Nov 21 2008 hare@suse.de
- patches.drivers/cxgb3i: add cxgb3i iscsi driver
  (FATE#304154,bnc#433500).
- patches.drivers/cxgb3i-fixed-offload-array-size: cxgb3i -
  fixed offload wr array size (bnc#447409).
- patches.fixes/dm-table-switch-to-readonly: dm multipath devices
  are not getting created for readonly devices (bnc#382705).
- patches.suse/dm-mpath-null-pgs: Allow zero paths for multipath
  priority groups (bnc#372684).
- patches.suse/scsi-netlink-ml: Netlink interface for SCSI
  sense codes (FATE#303789).
* Fri Nov 21 2008 goldwyn@suse.de
- patches.suse/novfs-map-drives-correctly.diff: Fix oops in
  set_map_drive (bnc#446824, bnc#444469).
* Fri Nov 21 2008 jbeulich@novell.com
- patches.xen/xen3-x86-vmware-tsc-03-detect-from-hypervisor:
  Fix Xen pv driver build.
* Fri Nov 21 2008 olh@suse.de
- patches.arch/ppc-spufs-01-use-inc_nlink.patch: use inc_nlink
- patches.arch/ppc-spufs-02-add-a-missing-mutex_unlock.patch
- patches.arch/ppc-spufs-03-sputrace-Only-enable-logging-on-open.patch
- patches.arch/ppc-spufs-04-sputrace-Don-t-block-until-the-read.patch
- patches.arch/ppc-spufs-05-Use-state_mutex-for-switch_log-lockin.patch
- patches.arch/ppc-spufs-06-Don-t-require-full-buffer-in-switch_l.patch
- patches.arch/ppc-spufs-07-Don-t-spu_acquire_saved-unnecessarily.patch
- patches.arch/ppc-spufs-08-Use-kmalloc-rather-than-kzalloc-for-s.patch
- patches.arch/ppc-spufs-09-Improve-search-of-node-for-contexts-w.patch
- patches.arch/ppc-spufs-10-Explain-conditional-decrement-of-aff_.patch
- patches.arch/ppc-spufs-11-Fix-spinning-in-spufs_ps_fault-on-sig.patch
  update spufs to current mainline state (bnc#447133 - LTC50070)
* Fri Nov 21 2008 tiwai@suse.de
- patches.drivers/parport-serial-array-overflow-fix: Fix array
  overflow in parport_serial.c (bnc#447067).
* Fri Nov 21 2008 tiwai@suse.de
- patches.drivers/alsa-hda-dell-studio-15-quirk: ALSA: hda -
  Add a quirk for Dell Studio 15 (bnc#446025).
- patches.drivers/alsa-hda-stac-dell-m4-3-quirk: ALSA: hda:
  Add STAC_DELL_M4_3 quirk (bnc#446025).
* Fri Nov 21 2008 npiggin@suse.de
- patches.suse/silent-stack-overflow-2.patch: avoid silent stack
  overflow over the heap. Try again.
* Fri Nov 21 2008 gregkh@suse.de
- Refresh patches to apply cleanly after 2.6.27.7 update.
* Fri Nov 21 2008 gregkh@suse.de
- Update to 2.6.27.7
  - lots of bugfixes and security updates.
  - obsoletes:
  - patches.arch/s390-04-05-topology-lock.diff
  - patches.drivers/bnx2x-zero-PMF
  - patches.drivers/input-alps-add-signature-for-dualpoint-found-in-dell-latitude-e6500.patch
  - patches.fixes/cdc-acm.c-fix-recursive-lock-in-acm_start_wb-error-path.patch
  - patches.fixes/sony_laptop_fix_suspend.patch
  - patches.kernel.org/iwlagn-avoid-sleep-in-softirq-context.patch
  - patches.kernel.org/memory-hotplug-fix-page_zone-calculation-in-test_pages_isolated.patch
  - patches.kernel.org/touch_mnt_namespace-when-the-mount-flags-change.patch:
* Fri Nov 21 2008 teheo@suse.de
- patches.drivers/libata-ata_piix-clear-spurious-IRQ: ata_piix:
  detect and clear spurious IRQs (bnc#445872).
* Fri Nov 21 2008 npiggin@suse.de
- patches.fixes/mm-madvise-fix.patch: mm: madvise correct return
  code (bnc#352998).
* Thu Nov 20 2008 jack@suse.cz
- patches.suse/ocfs2-Change-quotafile-names.patch: ocfs2: Change
  file names of local quota files to be consistent (fate#302681).
- patches.suse/ocfs2-Fix-hang-in-quota-recovery-code.patch:
  ocfs2: Fix hang in quota recovery code (fate#302681).
- patches.suse/ocfs2-Fix-oops-when-one-quotatype-enabled: ocfs2:
  Fix oops when only usrquota or grpquota feature is enabled
  (fate#302681).
* Thu Nov 20 2008 garloff@suse.de
- patches.suse/panic-on-io-nmi.diff
  patches.xen/panic-on-io-nmi-xen.diff:
  New kernel sysctl panic-on-io-nmi, which is set will cause a
  kernel panic on receiving an IOCK NMI (bnc#427979).
* Thu Nov 20 2008 jjolly@suse.de
- patches.arch/s390-04-06-cio-sac-update.diff: cio: update sac
  values (bnc#445100).
- patches.arch/s390-04-07-als.patch: kernel: Add processor type
  march=z10 and a processor type safety check. (bnc#445100).
* Thu Nov 20 2008 tiwai@suse.de
- patches.drivers/alsa-hda-stac-hp-gpio-switch-fix: ALSA: hda:
  STAC_DELL_M6 EAPD (bnc#446025).
* Thu Nov 20 2008 jbeulich@novell.com
- Update Xen patches to 2.6.27.6 and c/s 724.
- Update Xen config files.
- patches.xen/xen-fb-bad-irq: xenfb: don't use irq before it
  gets set up (bnc#445659).
- patches.xen/xen-netback-notify-multi: netback: use multicall
  for send multiple notifications.
- patches.xen/xen-netback-nr-irqs: netback: reduce overhead of
  IRQ recording.
* Thu Nov 20 2008 kkeil@suse.de
- patches.drivers/igb-pf.patch: removed (no SR-IOV) (bnc#440614)
* Thu Nov 20 2008 olh@suse.de
- disable patches.arch/ppc-efika-bestcomm-ata-dma.patch
  crashes the sound driver
* Thu Nov 20 2008 jjolly@suse.de
- rpm/kernel-binary.spec.in: excluded vanilla build from creating
  the man package
* Thu Nov 20 2008 hare@suse.de
- patches.drivers/ibmvfc-async-events-oops: ibmvfc oops while
  processing async events (bnc#445541).
- patches.drivers/mpt-fusion-4.16.00.00-update: MPT fusion driver
  update to 4.16.00.00 (bnc#425660).
- patches.fixes/dm-mpath-NULL-pgpath-in-activate_path: Do not
  call activate_path() if pgpath is NULL (bnc#442676).
- patches.fixes/scsi-dh-rdac-initialize-passive-path: Initialize
  path state to be passive when path is not owned (bnc#442676).
- patches.suse/dm-mpath-leastpending-path: Dynamic load balancing
  policy for device mapper multipath (bnc#444199).
* Thu Nov 20 2008 olh@suse.de
- patches.fixes/bug-437171_1_sched_clock_lock.patch: sched: only
  update rq->clock while holding rq->lock (437171 - LTC47404).
- patches.fixes/bug-437171_2_sched_delta_weight.patch: sched:
  revert back to per-rq vruntime (437171 - LTC47404).
- patches.fixes/bug-437171_3_rework_wakeup_preemption.patch:
  sched: rework wakeup preemption (437171 - LTC47404).
- patches.fixes/bug-437171_4_sched_reinstate_vruntime_wakeup.patch:
  sched: re-instate vruntime based wakeup preemption (437171 -
  LTC47404).
* Thu Nov 20 2008 trenn@suse.de
- Update config files.
  Fixed debug build, added dependent config option.
* Thu Nov 20 2008 trenn@suse.de
- Update config files.
  - > unified i386/x86_64 debug kernels:
  - added CONFIG_NO_HZ=y to i386-debug
  - added CONFIG_DEBUG_INFO to x86_64-debug
  Differ method to receive processor_id depending whether the processor
  got declared as a regular ACPI device or as a processor object:
- patches.arch/acpi_behave_uniquely_based_on_processor_declaration.patch:
  ACPI: Behave uniquely based on processor declaration definition
  type (bnc#440062).
- patches.arch/acpi_disambiguate_processor_declaration_type.patch:
  ACPI: Disambiguate processor declaration type (bnc#440062).
- patches.arch/acpi_processor_cleanups.patch: ACPI: 80 column
  adherence and spelling fix (no functional change) (bnc#440062).
- patches.xen/xen3-auto-common.diff: xen3 common.
  Fix missing bit for ThinkPad brightness switching:
- patches.arch/acpi_video_thinkpad_exclude_IGD_devices.patch:
  Do not use video backlight switching for Lenovo ThinkPads.
- patches.fixes/sony_laptop_fix_suspend.patch: sony-laptop:
  Ignore missing _DIS method on pic device (bnc#446487).
* Thu Nov 20 2008 hare@suse.de
- patches.fixes/dm-mpath-reattach-dh: Do not detach hardware
  handler when removing multipath maps (bnc#435688).
- patches.fixes/scsi-dh-alua-send-stpg: Always send STPG for
  explicit tgps mode.
* Thu Nov 20 2008 jjolly@suse.de
- rpm/kernel-binary.spec.in: Added kernel man package for s390x
* Thu Nov 20 2008 olh@suse.de
- patches.arch/ppc-of-irq-map.patch: fix IRQ assignment if
  interrupts property is missing (bnc#446610 - LTC50006)
* Thu Nov 20 2008 rjw@suse.de
- patches.fixes/acpi-set-SCI_EN-on-MacBook.patch: ACPI suspend:
  Blacklist boxes that require us to set SCI_EN directly on resume
  (bnc#444786).
* Wed Nov 19 2008 tiwai@suse.de
- patches.arch/x86-hpet-pre-read: x86: workaround for mccreary
  HPET read problem (bnc#433746).
* Wed Nov 19 2008 trenn@suse.de
- patches.arch/0008-sony-laptop-fingers-off-backlight.patch:
  sony-laptop: fingers off backlight if video.ko is serving
  this functionality.
  - > Fix typo, must not invert logic at this point
* Wed Nov 19 2008 kkeil@suse.de
- patches.drivers/e1000e_add_ECC: e1000e: enable ECC (bnc#445829)
* Wed Nov 19 2008 mmarek@suse.cz
- scripts/tar-up.sh: record the git branch name in the spec files
  (no branch name means master)
* Wed Nov 19 2008 jkosina@suse.de
- patches.drivers/elousb.patch: fix values of maximum X and Y
  coordinates so that they are compliant with the values that
  the device contains in its descriptor (bnc#442865)
* Wed Nov 19 2008 goldwyn@suse.de
- patches.suse/novfs-merge-changes.diff: Merge changes left out
  during code pull (bnc#445000).
* Wed Nov 19 2008 olh@suse.de
- patches.arch/ppc-pseries-bsr-multinode.patch: Add support for
  multiple BSR nodes in the device tree. (bnc#443665 - LTC49817)
* Wed Nov 19 2008 olh@suse.de
- patches.arch/ppc-pseries-cmm-pagecounter.patch:
  Update page in counter for CMM (bnc#445540 - LTC49942)
* Wed Nov 19 2008 olh@suse.de
- patches.arch/ppc-pseries-bsr-4k.patch: Unable to Use Small
  BSR register on Power LPAR (bnc#443673 - LTC49749)
* Wed Nov 19 2008 jjolly@suse.de
- config/s390/s390: Update config files: added CONFIG_UTRACE=y and
  CONFIG_HAVE_ARCH_TRACEHOOK=y
* Wed Nov 19 2008 jjolly@suse.de
- patches.drivers/ehca-fix-possible-nullpointer-access-v2.patch:
  ehca: fix a possible nullpointer access (bnc#441966).
* Wed Nov 19 2008 jjolly@suse.de
- patches.arch/ppc-axon-missing-msi-workaround-5.diff:
  powerpc/cell/axon-msi: retry on missing interrupt (bnc#445964).
* Wed Nov 19 2008 jjolly@suse.de
- patches.drivers/0001-IB-ehca-Fix-problem-with-max-number-of-QPs-and-CQs.patch:
  Fix problem with max number of QPs and CQs (bnc#441619).
* Tue Nov 18 2008 bwalle@suse.de
- Disable CONFIG_STRICT_DEVMEM for i386 and x86_64 (bnc#443852).
* Tue Nov 18 2008 jjolly@suse.de
- Update config files.
- patches.trace/s390-syscall-get-nr.diff: fix syscall_get_nr..
- patches.trace/s390-utrace-enablement.patch: Backport s390
  kernel components required for utrace enablement.
* Tue Nov 18 2008 jblunck@suse.de
- rpm/kernel-binary.spec.in: on s390(x) call dwarfextract to create the
  Kerntypes file for use with old lcrash debuggers.
* Tue Nov 18 2008 tiwai@suse.de
- patches.drivers/alsa-hda-stac-92hd71bxx-gpio-fix: ALSA:
  hda - Fix GPIO initialization in patch_stac92hd71bxx()
  (bnc#445321,bnc#445161).
- patches.drivers/alsa-hda-stac-gpio-unsol-resume-fix:
  ALSA: hda - Fix resume of GPIO unsol event for STAC/IDT
  (bnc#445321,bnc#445161).
- patches.drivers/alsa-hda-stac-hp-pavilion-quirks: ALSA: hda -
  Add quirks for HP Pavilion DV models (bnc#445321,bnc#445161).
* Tue Nov 18 2008 tiwai@suse.de
- patches.arch/x86-hpet-use-WARN_ON_ONCE: x86: HPET: convert
  WARN_ON to WARN_ON_ONCE (bnc#433746).
* Tue Nov 18 2008 sdietrich@suse.de
  RT development has moved to slert-devel branch.
- Remove RT patches from master branch.
  (itemized RT patch list suppressed)
* Tue Nov 18 2008 olh@suse.de
- patches.arch/ppc-efika-bestcomm-ata-dma.patch: use ATA DMA (bnc#445856)
* Tue Nov 18 2008 olh@suse.de
- config/ppc/ppc64: reenable 64k PAGE_SIZE to keep the config
  flavor on ppc and ppc64 in sync
  the last change had also no bug number to fix the possible bug
  in the Xserver.
* Tue Nov 18 2008 tiwai@suse.de
- patches.drivers/alsa-hda-realtek-acer-dmic: ALSA: hda - Split
  ALC268 acer model (bnc#420048).
* Tue Nov 18 2008 jjolly@suse.de
- patches.arch/s390-04-01-qdio_prevent_double_shutdown.patch:
  qdio: prevent double qdio shutdown in case of I/O
  errors. (bnc#445100).
- patches.arch/s390-04-02-qdio-osa-port-count.patch: qdio:
  fix qeth port count detection. (bnc#445100).
- patches.arch/s390-04-03-kmsg.patch: kmsg: do not change pr_xyz
  messages without KMSG_COMPONENT (bnc#445100).
- patches.arch/s390-04-04-dasd_fatal_error_log_sense.patch:
  dasd: log sense for fatal errors. (bnc#445100).
- patches.arch/s390-04-05-topology-lock.diff: kernel: Fix locking
  in cpu topology code. (bnc#445100).
* Tue Nov 18 2008 jjolly@suse.de
- patches.arch/s390-personality-mask.patch: fix s390x_newuname.
* Tue Nov 18 2008 gregkh@suse.de
- patches.drivers/staging-rt2860-enable-wpa_supplicant-support.patch:
  Staging: rt2860: enable WPA_SUPPLICANT support (bnc#437959).
* Mon Nov 17 2008 hare@suse.de
- patches.drivers/lpfc-8.2.8.7-update: Update lpfc to 8.2.8.7
  (bnc#420767).
- patches.drivers/qla4xxx-5.01.00-k8_sles11-03-update: Update
  qla4xxx to 5.01.00-k8_sles11-03     (bnc#444884).
- patches.fixes/dm-mpath-reattach-dh: Reattach device handler
  for multipath devices (bnc#435688).
- patches.fixes/scsi-add-tgps-setting: Add TGPS setting to
  scsi devices.
- patches.fixes/scsi-dh-alua-retry-UA: Retry ALUA device handler
  initialization on Unit Attention.
* Mon Nov 17 2008 jeffm@suse.de
- patches.fixes/v4l-dvb-avoid-writing-outside-array: V4L/DVB
  (9621): Avoid writing outside shadow.bytes array (bnc#445569).
* Mon Nov 17 2008 fseidel@suse.de
- patches.fixes/ipw2200-send-noassoc.patch: ipw2200: fix oops
  in ipw_tx_skb (bnc#397390).
* Sat Nov 15 2008 rjw@suse.com
- patches.fixes/hibernate-x86-fix-breakage-on-x86_32-with-PAE.patch:
  x86: Hibernate: Fix breakage on x86_32 with CONFIG_NUMA set
  (bnc#439126).
* Sat Nov 15 2008 tiwai@suse.de
- patches.drivers/alsa-hda-sigmatel-hp-m4-check-fix: ALSA:
  hda - Check model type instead of SSID in patch_92hd71bxx()
  (bnc#444349).
- patches.drivers/alsa-hda-sigmatel-vref-event-fix: ALSA: hda:
  STAC_VREF_EVENT value change (bnc#444349).
* Sat Nov 15 2008 gregkh@suse.de
- patches.kernel.org/memory-hotplug-fix-page_zone-calculation-in-test_pages_isolated.patch:
  memory hotplug: fix page_zone() calculation in
  test_pages_isolated() (bnc#445163).
* Fri Nov 14 2008 gregkh@suse.de
- patches.drivers/input-alps-add-signature-for-dualpoint-found-in-dell-latitude-e6500.patch:
  Input: ALPS - add signature for DualPoint found in Dell Latitude
  E6500 (bnc#436719).
* Fri Nov 14 2008 hare@suse.de
- patches.fixes/scsi-eh-timed-out-missing-braces: scsi_error:
  fix indentation and braces disagreement - add braces.
- patches.fixes/scsi-retry-TASK_ABORTED: scsi_error: TASK ABORTED
  status handling improvement.
- patches.fixes/scsi-retry-transport-error: scsi_error regression:
  Fix idempotent command handling.
* Fri Nov 14 2008 hare@suse.de
- patches.fixes/scsi-eh-timed-out-missing-braces: scsi_error:
  fix indentation and braces disagreement - add braces.
- patches.fixes/scsi-retry-TASK_ABORTED: scsi_error: TASK ABORTED
  status handling improvement.
- patches.fixes/scsi-retry-transport-error: scsi_error regression:
  Fix idempotent command handling.
* Fri Nov 14 2008 bwalle@suse.de
- patches.fixes/hpwdt-execute-page.diff:
  [WATCHDOG] [hpwdt] Set the mapped BIOS address space as
  executable (bnc#430680).
* Fri Nov 14 2008 tiwai@suse.de
- patches.arch/x86-vmware-tsc-01-add-TSC_RELIABLE,
  patches.arch/x86-vmware-tsc-02-add-X86_FEATURE_HYPERVISOR,
  patches.arch/x86-vmware-tsc-03-detect-from-hypervisor,
  patches.arch/x86-vmware-tsc-04-use-TSC_RELIABLE,
  patches.arch/x86-vmware-tsc-05-skip-tsc-clocksource,
  patches.arch/x86-vmware-tsc-06-fix-vmware_get_tsc,
  patches.arch/x86-vmware-tsc-07-DMI-product-serial-key,
  patches.xen/xen-x86-vmware-tsc-fix:
    VMware tsc clocksource workaround (bnc#441338).
* Fri Nov 14 2008 tiwai@suse.de
- Fixed a typo in definition of X86_FEATURE_XTOPOLOGY (bnc#443293)
  in patches.arch/x2APIC_PATCH_40_of_41_bbb65d2d365efe9951290e61678dcf81ec60add4
* Fri Nov 14 2008 agruen@suse.de
- Update CONFIG_X86_RESERVE_LOW_64K in config/x86_64/maxcpus as
  well.
- patches.suse/bug-425240_nr_cpus-mem_cgroup_stat-fix.diff:
  rename to patches.suse/mem_cgroup_stat-dynamic-alloc, and update
  to newer version.
* Fri Nov 14 2008 bwalle@suse.de
- patches.fixes/kdump-x86-sparsemem.diff: x86, kdump: fix invalid
  access on i386 sparsemem (bnc#440525).
- patches.xen/linux-2.6.19-rc1-kexec-move_segment_code-i386.patch:
  Refresh.
* Fri Nov 14 2008 gregkh@suse.de
- patches.kernel.org/iwlagn-avoid-sleep-in-softirq-context.patch:
  iwlagn: avoid sleep in softirq context (bnc#444382).
* Fri Nov 14 2008 philips@suse.de
- patches.fixes/cdc-acm.c-fix-recursive-lock-in-acm_start_wb-error-path.patch:
  cdc-acm.c: fix recursive lock in acm_start_wb error path.
* Thu Nov 13 2008 gregkh@suse.de
- enable CONFIG_X86_RESERVE_LOW_64K for i386 and x86-64 vanilla
  configs.
* Thu Nov 13 2008 gregkh@suse.de
- enable CONFIG_X86_RESERVE_LOW_64K on i386 and x86-64 to fix some
  suspend/resume issues (option added in 2.6.27.6)
* Thu Nov 13 2008 gregkh@suse.de
- refresh patches so that everything applies cleanly.
* Thu Nov 13 2008 gregkh@suse.de
- Update to 2.6.27.6:
  - fixes some security issues
  - lots of bugfixes
  - obsoletes:
  - patches.arch/acpi-dock-avoid-check-_STA-method.patch:
  - patches.arch/ppc-gigantic-page-fix2.patch:
  - patches.arch/ppc-gigantic-page-fix3.patch:
  - patches.drivers/alsa-hda-dell-eq-option:
  - patches.drivers/cciss-fix-procfs-firmware-regression.patch:
  - patches.drivers/cciss-fix-sysfs-symlink.patch:
  - patches.drivers/libata-fix-last_reset-timestamp-handling:
  - patches.kernel.org/md-raid10-recovoery-fix.path:
* Thu Nov 13 2008 mmarek@suse.cz
- rpm/kernel-binary.spec.in: package modules.order (bnc#441384)
* Thu Nov 13 2008 agruen@suse.de
- config.conf: Add x86_64/maxcpus as the 4096-cpu configuration
  and switch back to at most 128 cpus in the other configs. This
  avoids wasting memory on all but the most extreme x86_64
  systems.
- rpm/kernel-binary.spec.in: define a kernel-$flavor symbol to
  allow per-flavor patches. (Use this for testing only!)
- patches.suse/bug-425240_nr_cpus-mem_cgroup_stat-fix.diff: Add
  this patch conditionally for x86_64/maxcpus for now pending
  test results from bnc#425240.
* Thu Nov 13 2008 tiwai@suse.de
- patches.drivers/alsa-hda-beep-dig-switch: ALSA: hda - Add
  digital beep playback switch for STAC/IDT codecs (#444572).
- patches.drivers/alsa-hda-beep-null-check-fix: ALSA: hda -
  Missing NULL check in hda_beep.c.
* Thu Nov 13 2008 hare@suse.de
- patches.fixes/scsi-skip-nonscsi-device-for-dma: fix to
  make it work with iSCSI (bnc#444234)
* Thu Nov 13 2008 olh@suse.de
- mark some powerpc device drivers as supported to move them out of
  kernel-extra, otherwise installation-images will not pick them up
- ps3vram, mtd, mtdblock, mtd_blkdevs (bnc#444220)
- PowerMac, Efika and Pegasos2 storage and network drivers
* Wed Nov 12 2008 bwalle@suse.de
- patches.fixes/firmware-memmap-64bit.diff: Always use 64 bit
  addresses for the firmware memory map.
* Wed Nov 12 2008 tiwai@suse.de
- patches.drivers/alsa-powermac-ibook-g4-mic-fix: ALSA: powermac -
  Rename mic-analog loopback mixer element (bnc#444194).
* Wed Nov 12 2008 tiwai@suse.de
- patches.drivers/alsa-hda-stac-hp-detect-fix: ALSA: hda -
  Fix IDT/STAC multiple HP detection (bnc#443267).
* Wed Nov 12 2008 agruen@suse.de
- patches.suse/module-ref-dynamic-alloc: fall back to vmalloc if
  kmalloc fails (bnc#425240).
* Wed Nov 12 2008 tiwai@suse.de
- patches.drivers/alsa-hda-stac9200-missing-mux-capture: ALSA:
  hda - Add missing analog-mux mixer creation for STAC9200
  (bnc#443738).
- patches.drivers/alsa-hda-stac92xx-mic-pin-fix: ALSA: hda -
  Fix input pin initialization for STAC/IDT codecs (bnc#443738).
* Wed Nov 12 2008 philips@suse.de
- rpm/kernel-binary.spec.in: remove Recommends: kerneloops, opt-in will
  be implemented in the 11.2 installer
* Tue Nov 11 2008 jeffm@suse.de
- patches.fixes/reiserfs-error-buffer-locking: reiserfs: add
  locking around error buffer.
- patches.fixes/reiserfs-varargs-fix: reiserfs: prepare_error_buf
  wrongly consumes va_arg.
* Tue Nov 11 2008 tiwai@suse.de
- patches.suse/module-ref-dynamic-alloc: Allocate module.ref
  array dynamically (bnc#425240).
- Update config files: back to NR_CPUS=4096
* Tue Nov 11 2008 jblunck@suse.de
- Update config files: Set NR_CPUS on x86_64 back to 128 again for
  now: with NR_CPUS=4096, the size of eack .ko file increases by
  496 KiB because of the static struct module in
  .gnu.linkonce.this_module.
* Tue Nov 11 2008 schwab@suse.de
- patches.arch/ppc-select: Fix wrong error code from ppc32 select.
* Tue Nov 11 2008 mmarek@suse.cz
- rpm/kernel-binary.spec.in: also encode the architecture into the
  packageand supplements.
* Tue Nov 11 2008 teheo@suse.de
- patches.drivers/libata-fix-ata_tf_read_block-overflow: libata:
  Avoid overflow in ata_tf_read_block() when tf->hba_lbal > 127
  (bnc#443661).
- patches.drivers/libata-fix-ata_tf_to_lba48-overflow: libata:
  Avoid overflow in ata_tf_to_lba48() when tf->hba_lbal > 127
  (bnc#443661).
* Tue Nov 11 2008 teheo@suse.de
- patches.drivers/libata-pata_sch-slave-poss: pata_sch: slave
  devices (bnc#443657).
* Mon Nov 10 2008 schwab@suse.de
- config/ppc/ppc64: Disable 64k pages to work around X server bug.
* Mon Nov 10 2008 olh@suse.de
- rpm/kernel-binary.spec.in: fix variable assignment in last change
* Mon Nov 10 2008 mmarek@suse.cz
- rpm/kernel-binary.spec.in: encode the architecture into
  subpackage dependencies (bnc#440961)
* Mon Nov 10 2008 olh@suse.de
- handle arch differences for cpu and kbuild correctly
* Mon Nov 10 2008 schwab@suse.de
- patches.arch/ia64-page-migration. patches.arch/mm-avoid-bad-page-on-lru:
  migrade pages off of pages with correctable errors.
* Mon Nov 10 2008 mmarek@suse.cz
- scripts/tar-up.sh: do not generate kernel-source-rt.spec and
  kernel-syms-rt.spec if RT is not enabled.
* Mon Nov 10 2008 sdietrich@suse.de
- config.conf: Suppress RT configurations.
* Sun Nov  9 2008 jeffm@suse.de
- config.conf: Removed previous workaround.
- rpm/kernel-binary.spec.in: Remove @FLAVOR@ from %%symbols.
* Sat Nov  8 2008 jeffm@suse.de
- config.conf: Workaround for kernel-ppc64 on head-ppc.
* Sat Nov  8 2008 gregkh@suse.de
- Update to the "real" 2.6.27.5.  No code changes from what we had
  in our tree previously, with the exception for the version number
  change.
* Fri Nov  7 2008 bwalle@suse.de
- patches.fixes/kdb-read-CR.diff:
  Support '\n' in KDB (bnc#442808).
* Fri Nov  7 2008 gregkh@suse.de
- disable perfmon support in the -trace kernels as it doesn't build
  properly.
* Fri Nov  7 2008 schwab@suse.de
- patches.arch/compat-sys-swapcontext: Fix msr check in sys_swapcontext.
* Fri Nov  7 2008 hare@suse.de
- patches.drivers/ixgbe-add-bcna-support: DCB: Add BCNA support
  to ixgbe.
- patches.drivers/open-fcoe-beta3-update: Open-FCoE update for
  Beta3 (bnc#438954).
- patches.drivers/open-fcoe-beta4-update: Open-FCoE: Update for
  Beta4 (bnc#438954).
- patches.drivers/open-fcoe-beta5-update: Open-FCoE: Update for
  Beta5 (bnc#438954).
- patches.fixes/dcb-fix-setpfcstate: Fix setpfcstate (bnc#438954).
- patches.fixes/dcb-setting-pg-will-cause-tx-hang: DCB: setting
  pg will cause tx unit hangs (bnc#438954).
- patches.fixes/multiq-requeue-should-rewind-current_band:
  multiq: requeue should rewind the current_band (bnc#438954).
- patches.fixes/scsi-dh-rdac-retry-mode-select: Retry mode select
  in RDAC device handler (bnc#441337).
- patches.fixes/scsi-dh-rdac-set-default-ownership: scsi_dh_rdac:
  make sure the ownership is set correctly (bnc#441337).
- patches.fixes/scsi-skip-nonscsi-device-for-dma: Update patch
  to check for ->bus instead of ->type (bnc#431294).
* Fri Nov  7 2008 tiwai@suse.de
- patches.drivers/alsa-hda-dell-studio-probe-fix: ALSA: hda -
  Fix probe errors on Dell Studio Desktop (bnc#440907).
- patches.drivers/alsa-hda-hp-3013-master-fix: ALSA: hda -
  Fix ALC260 hp3013 master switch (bnc#441068).
* Fri Nov  7 2008 jjolly@suse.de
- patches.arch/s390-03-07-qeth_hsi_mcl_string.patch:
  qeth: pre z9 systems return HiperSocket version string
  different. (bnc#440610,LTC#49052).
- patches.arch/s390-03-08-zfcp-abort-race.patch: zfcp: eliminate
  race between validation and locking. (bnc#440610).
- patches.arch/s390-03-09-zfcp-oops-during-target-scan.patch:
  zfcp: prevent SCSI target scan for vanished rport
  (bnc#440610,LTC#49373).
* Fri Nov  7 2008 olh@suse.de
- Update config files for RT
* Fri Nov  7 2008 olh@suse.de
- build a kernel-default in dist ppc64, its identical to kernel-ppc64
  otherwise unused
* Fri Nov  7 2008 olh@suse.de
- rpm/kernel-source.spec.in: map ppc/ppc64 to powerpc
* Fri Nov  7 2008 kkeil@suse.de
- patches.drivers/igb-pf.patch: VF enabled igb driver (fate#305004)
* Fri Nov  7 2008 olh@suse.de
- stop building kernel-default and kernel-ps3 in dist ppc64,
  they are openSuSE only packages
* Fri Nov  7 2008 olh@suse.de
- rpm/kernel-binary.spec.in: extracting debuginfo from vdso fails
  on powerpc, disable vdso_install for the time being
* Fri Nov  7 2008 jbeulich@novell.com
- patches.xen/xen3-intel-ibex-peak-device-ids.patch: x86/PCI: irq
  and pci_ids patch for Intel Ibex Peak DeviceIDs (bnc#415383).
* Fri Nov  7 2008 olh@suse.de
- rpm/post.sh: reject legacy iSeries again
* Fri Nov  7 2008 olh@suse.de
- build a 32bit and a 64bit vanilla kernel on powerpc
* Fri Nov  7 2008 olh@suse.de
- rpm/kernel-binary.spec.in: no vdso in vanilla and ps3 kernel
* Fri Nov  7 2008 gregkh@suse.de
- patches.kernel.org/net-fix-recursive-descent-in-__scm_destroy.patch:
  net: Fix recursive descent in __scm_destroy()..
* Fri Nov  7 2008 olh@suse.de
- remove patches.arch/ppc64-rpanote-relocate-firmware.patch
  older firmware versions can handle relocation properly (bnc#427960)
* Fri Nov  7 2008 jjolly@suse.de
- patches.drivers/cxgb3-get_drvinfo-deadlock.patch: RDMA/cxgb3:
  deadlock in iw_cxgb3 can cause hang when configuring
  interface. (bnc#430998).
* Fri Nov  7 2008 gregkh@suse.de
- patches.suse/perfmon2.patch: perfmon2 (bnc#430298).
* Fri Nov  7 2008 nfbrown@suse.de
- patches.fixes/nfs-write.c-bug-removal.patch: Revert "NFS:
  Allow redirtying of a completed unstable write." (442267).
  It causes a BUG().
* Fri Nov  7 2008 nfbrown@suse.de
- patches.kernel.org/md-raid10-recovoery-fix.path: md: fix bug
  in raid10 recovery..
- patches.suse/md-notify-when-stopped: md: notify udev when an
  md array is stopped..:  Removed much of this patch as it turned out
  to be both buggy and unnecessary (the ioctl can be done from
  mdadm).
* Thu Nov  6 2008 kkeil@suse.de
- patches.drivers/ixgbe-sfp.patch: ixgbe driver update to add
  Longcove (SFP+) NIC support for FCoE needs (bnc#442411)
* Thu Nov  6 2008 gregkh@suse.de
- enable CONFIG_X86_SUMMIT, CONFIG_X86_ES7000, and CONFIG_X86_BIGSMP
  for the i386 default kernel, so that the installer can actually
  boot on "modern" multiprocessor i386 boxes (bnc#428247)
* Thu Nov  6 2008 jblunck@suse.de
- rpm/kernel-binary.spec.in: Call make vdso_install only on x86 and ppc.
* Thu Nov  6 2008 jblunck@suse.de
- rpm/kernel-binary.spec.in: Call make vdso_install to install the
  vdso shared objects for debugging.
* Thu Nov  6 2008 jjolly@suse.de
- patches.drivers/intel-ibex-peak-device-ids.patch: x86/PCI: irq
  and pci_ids patch for Intel Ibex Peak DeviceIDs (bnc#415383).
- patches.drivers/intel-ibex-peak-device-support.patch: i2c-i801:
  Add support for Intel Ibex Peak (bnc#415383).
* Thu Nov  6 2008 jjolly@suse.de
- patches.arch/s390-03-01-stp-init.patch: Fixed patch for build
- patches.arch/s390-03-04-qdio_multicast_performance.patch: dasd:
  fix  message flood for unsolicited interrupts (bnc#440610).
- patches.arch/s390-03-05-dasd-block-uevent.patch: dasd: DASD
  uevents are not sent correctly (bnc#440610,LTC#49429).
- patches.arch/s390-03-06-zfcp-hexdump.patch: zfcp: fix hexdump
  data in s390dbf traces (bnc#440610).
* Thu Nov  6 2008 jjolly@suse.de
- patches.arch/s390-03-01-stp-init.patch: kernel: Fix
  initialization of stp. (bnc#440610,LTC#49639).
- patches.arch/s390-03-02-setup_memory.patch: kernel: Fix range
  for add_active_range() in setup_memory() (bnc#440610,LTC#49639).
- patches.arch/s390-03-03-dasd_unsolicited_interrupt.patch:
  dasd: fix  message flood for unsolicited interrupts
  (bnc#440610,LTC#49639).
* Thu Nov  6 2008 jjolly@suse.de
- patches.arch/s390-02-10-zfcp-scan-online.patch: wait for port
  scan when setting FCP device online (bnc#434333).
* Thu Nov  6 2008 jbeulich@novell.com
- Update Xen patches to 2.6.27.4 and c/s 718.
- Update Xen config files.
- patches.arch/x86_sgi_cpus4096-05-update-send_IPI_mask.patch: Include
  pv-ops-Xen changes here
- patches.xen/x86_sgi_xen-x86-cpus4096.patch: Delete.
- patches.xen/xen-configurable-guest-devices: allow number of
  guest devices to be configurable.
- patches.xen/xen-cpufreq-report: make /proc/cpuinfo track
  CPU speed.
- patches.xen/xen-ipi-per-cpu-irq: fold IPIs onto a single
  IRQ each.
- patches.xen/xen-rtl2860-build: Rename to ...
- patches.xen/xen-rt2860-build: ... this.
- patches.xen/xen-sysdev-suspend: use base kernel suspend/resume
  infrastructure.
- patches.xen/xen-virq-per-cpu-irq: fold per-CPU VIRQs onto a
  single IRQ each.
- patches.xen/xen-x86-mmu-batching: Delete.
- patches.xen/xen3-patch-2.6.27.3-4: Linux 2.6.27.4.
- patches.xen/xen3-x2APIC_PATCH_20_of_41_cff73a6ffaed726780b001937d2a42efde553922:
  x64, x2apic/intr-remap: introcude self IPI to genapic routines
  (fate #303948 and fate #303984).
- patches.xen/xen3-x86_sgi_cpus4096-02-fix-send_call_func_ip.patch:
  x86: reduce stack requirements for send_call_func_ipi
  (bnc#425240 FATE304266).
- patches.xen/xen3-x86_sgi_cpus4096-05-update-send_IPI_mask.patch:
  x86 cpumask: Updates to support NR_CPUS=4096 (bnc#425240
  FATE304266).
* Thu Nov  6 2008 sassmann@suse.de
- patches.arch/ppc-ps3-introduce-ps3_gpu_mutex.patch: required for
  new ps3vram patch
- patches.arch/ppc-ps3-ps3vram-mtd.patch: updated ps3vram patch
  that works with firmware 2.50 (bnc#442227)
* Thu Nov  6 2008 olh@suse.de
- remove unneeded BuildRequires for dtc
* Thu Nov  6 2008 jjolly@suse.de
- patches.arch/s390-01-01-self-ptrace-v3.patch: Feature removed
  (bnc#417299)
* Thu Nov  6 2008 gregkh@suse.de
- patches.suse/file-capabilities-add-no_file_caps-switch.patch:
  file capabilities: add no_file_caps switch (v4).
  add the patch back into the tree.
* Wed Nov  5 2008 jblunck@suse.de
- patches.suse/coredump_filter-add-elfhdr-default.patch: Dump
  elf headers to core per default.
* Wed Nov  5 2008 teheo@suse.de
  Fix !CONFIG_DMI case.
- patches.drivers/dmi-introduce-dmi_first_match: DMI:
  Introduce dmi_first_match to make the interface more flexible
  (bnc#441721).
* Wed Nov  5 2008 hare@suse.de
- patches.fixes/scsi-skip-nonscsi-device-for-dma: update patch
  to skip all devices with no dma_parms (bnc#431294)
* Wed Nov  5 2008 agruen@suse.de
- rpm/kernel-module-subpackage: Remove the obsolete kernel-$flavor
  dependency (bnc#440961).
* Wed Nov  5 2008 jjolly@suse.de
- patches.arch/s390-01-05-kmsg-v2.patch: Removed and replaced with
  v3 of the patch from IBM (bnc#417300)
- patches.arch/s390-01-05-kmsg-v3.patch: Kernel message catalog
  infrastucture and message generation (bnc#417300).
- patches.drivers/driver-core-basic-infrastructure-for-per-module-dynamic-debug-messages.patch:
  Patch edited to allow new kmsg patch
* Wed Nov  5 2008 agruen@suse.de
- Update config files: set CONFIG_MODULE_FORCE_LOAD=y to allow
  ignoring ABI mismatches. (This is still unsafe to do!)
* Wed Nov  5 2008 tiwai@suse.de
  Backport fixes from 2.6.28-rc.
- patches.drivers/alsa-hda-acer-quirk: ALSA: hda - Add a quirk
  for another Acer Aspire (1025:0090) (bnc#426935).
- patches.drivers/alsa-hda-alc888-medion-add: ALSA: hda - Add
  a quirk for MEDION MD96630 (bnc#412548).
- patches.drivers/alsa-hda-dell-eq-option: ALSA: hda: make a
  STAC_DELL_EQ option.
- patches.drivers/alsa-hda-proc-gpio-fix: ALSA: hda - Limit the
  number of GPIOs show in proc.
* Wed Nov  5 2008 gregkh@suse.de
- refresh -rt patches to remove fuzz.
* Wed Nov  5 2008 teheo@suse.de
  Backport two more device specific workarounds from 2.6.28-rc.
- patches.drivers/libata-add-and-use-HORKAGE_ATAPI_MOD16_DMA:
  libata: implement ATA_HORKAGE_ATAPI_MOD16_DMA and apply it.
- patches.drivers/libata-whitelist-good-bridges: libata: add
  whitelist for devices with known good pata-sata bridges.
* Wed Nov  5 2008 gregkh@suse.de
- refresh patches to remove fuzz
* Wed Nov  5 2008 teheo@suse.de
  Backport double spin off workaround.
- patches.drivers/dmi-introduce-dmi_first_match: DMI:
  Introduce dmi_first_match to make the interface more flexible
  (bnc#441721).
- patches.drivers/libata-ahci-blacklist-double-spin-off: SATA
  AHCI: Blacklist system that spins off disks during ACPI power
  off (bnc#441721).
- patches.drivers/libata-ata_piix-blacklist-double-spin-off:
  SATA PIIX: Blacklist system that spins off disks during ACPI
  power off (bnc#441721).
- patches.drivers/libata-implement-NO_SPINDOWN: SATA: Blacklisting
  of systems that spin off disks during ACPI power off (rev. 2)
  (bnc#441721).
- patches.drivers/libata-sata_sil-blacklist-double-spin-off:
  SATA Sil: Blacklist system that spins off disks during ACPI
  power off (bnc#441721).
- patches.drivers/power-introduce-system_entering_hibernation:
  Hibernation: Introduce system_entering_hibernation (bnc#441721).
* Wed Nov  5 2008 gregkh@suse.de
- fix rt tree that was broken by 2.6.27.5-rc1
* Wed Nov  5 2008 olh@suse.de
- update patches.arch/ppc-powerpc-debug-pci-hotplug.patch
  fix booting on ppc32 (bnc#439491 - LTC48584)
* Wed Nov  5 2008 teheo@suse.de
  Backport sata_via fixes from 2.6.28-rc.
- patches.drivers/libata-sata_via-fix-support-for-5287: sata_via:
  fix support for 5287 (bnc#441718).
- patches.drivers/libata-sata_via-load-DEVICE-register-when-CTL-changes:
  sata_via: load DEVICE register when CTL changes (bnc#441718).
- patches.drivers/libata-sata_via-restore-vt-_prepare_host-error-handling:
  sata_via: restore vt*_prepare_host error handling (bnc#441718).
* Wed Nov  5 2008 teheo@suse.de
  Backport laptop table and pci device ID table entries from 2.6.28-rc.
- patches.drivers/libata-ata_piix-add-Hercules-EC-900-mini-to-laptop-tbl:
  ata_piix: add Hercules EC-900 mini-notebook to ich_laptop
  short cable list.
- patches.drivers/libata-ata_piix-add-intel-ibex-pci-ids:
  ata_piix: IDE Mode SATA patch for Intel Ibex Peak DeviceIDs.
* Wed Nov  5 2008 teheo@suse.de
  Backport slave_link from 2.6.28-rc to fix ata_piix probing problem.
- patches.drivers/libata-ata_piix-use-slave_link: ata_piix:
  drop merged SCR access and use slave_link instead (bnc#441420).
- patches.drivers/libata-eh-fix-slave-link-EH-action-mask-handling:
  libata-eh: fix slave link EH action mask handling (bnc#441420).
- patches.drivers/libata-implement-slave_link: libata: implement
  slave_link (bnc#441420).
- patches.drivers/libata-make-SCR-access-ops-per-link: libata:
  make SCR access ops per-link (bnc#441420).
- patches.drivers/libata-misc-updates-to-prepare-for-slave-link:
  libata: misc updates to prepare for slave link (bnc#441420).
- patches.drivers/libata-reimplement-link-iterator: libata:
  reimplement link iterator (bnc#441420).
- patches.drivers/libata-set-device-class-to-NONE-if-phys_offline:
  libata: set device class to NONE if phys_offline (bnc#441420).
- patches.drivers/libata-transfer-EHI-control-flags-to-slave-ehc.i:
  libata: transfer EHI control flags to slave ehc.i (bnc#441420).
* Wed Nov  5 2008 gregkh@suse.de
- Update to 2.6.27.5-rc1:
  - fixes lots of things, including a few CVE entries
  - obsoletes, and caused to be deleted:
  - patches.arch/ppc-pseries_16g-numa.patch
  - patches.arch/ppc-pseries_hugepage_pagetable_allocation.patch
  - patches.arch/ppc-pseries_mem-limit-16g.patch
  - patches.arch/s390-02-02-smp-sysdev.patch
  - patches.drivers/alsa-hda-reboot-notifier
  - patches.drivers/libata-sata_nv-hardreset-fix
  - patches.fixes/acpi-clear-wake-status.patch
  - patches.fixes/agp-fix-stolen-memory-counting-on-g4x.patch
  - patches.suse/file-capabilities-add-no_file_caps-switch.diff
  - patches.suse/file-capabilities-turn-on-by-default.diff
- Update config files.
* Wed Nov  5 2008 kkeil@suse.de
- patches.drivers/bnx2-Add-bnx2_shutdown_chip: bnx2: Add
  bnx2_shutdown_chip()
- patches.drivers/bnx2-check-running.patch: Check netif_running
  in most ethtool operations    (bnc#440052)
* Wed Nov  5 2008 kkeil@suse.de
- patches.drivers/ixgbe-copper_pond.patch: ixgbe: add device
  support for 82598AT (copper 10GbE) adapters (bnc#441471)
* Tue Nov  4 2008 tonyj@suse.de
- patches.rt/fork_init_nrcpus.patch: Fix oops in fork_init.
* Tue Nov  4 2008 mmarek@suse.cz
- rpm/kernel-binary.spec.in: fix typo
* Tue Nov  4 2008 rw@suse.de
- patches.drivers/bnx2x-zero-PMF:
  bnx2x: Removing the PMF indication when unloading.  (bnc#439679)
* Tue Nov  4 2008 mmarek@suse.cz
- rpm/kernel-binary.spec.in: make also -base and -extra x86
  subpackages not installable on x86_64
* Tue Nov  4 2008 jjolly@suse.de
- patches.arch/s390-01-04-fcpperf-3-v2.patch: (kernel):FCP -
  Performance Data colletion & analysis patch update (bnc#417243).
- patches.arch/s390-01-04-fcpperf-3.patch: Removed for update
* Tue Nov  4 2008 miklos@szeredi.hu
- patches.apparmor/d_namespace_path_oops_fix.diff: fix oops in
  d_namespace_path (bnc#433504).
* Tue Nov  4 2008 hare@suse.de
- patches.fixes/scsi-skip-nonscsi-device-for-dma: scsi_lib_dma.c :
  fix bug w/ dma on virtual fc ports (bnc#431294).
* Tue Nov  4 2008 sdietrich@suse.de
- Update RT config files: Enable CONFIG_NO_HZ on i386/rt_debug.
  - Refresh config files.
* Tue Nov  4 2008 teheo@suse.de
- patches.drivers/libata-fix-last_reset-timestamp-handling:
  libata: fix last_reset timestamp handling (bnc#441340).
* Tue Nov  4 2008 hare@suse.de
- patches.drivers/qla2xxx-8.02.01-k9-update: Update qla2xxx to
  8.02.01-k9 (bnc#439208).
* Tue Nov  4 2008 gregkh@suse.de
- refresh patches to apply cleanly.
* Mon Nov  3 2008 jeffm@suse.de
- patches.suse/dm-raid45_2.6.27_20081027.patch: Compile fix.
* Mon Nov  3 2008 tiwai@suse.de
- patches.drivers/alsa-emu10k1-audigy-fixes: ALSA: emu10k1 -
  Add more invert_shared_spdif flag to Audigy models (bnc#440862).
- patches.drivers/alsa-hda-alc269-fsc-amilo: ALSA: hda - Add
  ALC269 fujitsu model (bnc#440626).
* Mon Nov  3 2008 jeffm@suse.de
- patches.suse/dm-raid45_2.6.27_20081027.patch: Update dmraid45.
* Mon Nov  3 2008 knikanth@suse.de
- patches.suse/dm-barrier-single-device: Fix dm table
  ref count (FATE#304489).
* Mon Nov  3 2008 teheo@suse.de
  BNC reference added.
- patches.drivers/libata-dont-restore-DET-on-detach: libata:
  mask off DET when restoring SControl for detach (bnc#440980).
* Mon Nov  3 2008 teheo@suse.de
- patches.drivers/libata-dont-restore-DET-on-detach: libata:
  mask off DET when restoring SControl for detach.
* Mon Nov  3 2008 olh@suse.de
- add patches.arch/ppc-clock_gettime-nanoseconds.patch
  update also nanoseconds (bnc#439908 - LTC49499)
* Mon Nov  3 2008 teheo@suse.de
- scripts/vc: s/GIT_COMMITER_EMAIL/GIT_COMMITTER_EMAIL and add
  SUSE_COMMITTER_EMAIL.
* Mon Nov  3 2008 teheo@suse.de
  BNC reference added.
- patches.drivers/libata-sata_nv-hardreset-fix: sata_nv: fix
  generic, nf2/3 detection regression (bnc#429344).
* Mon Nov  3 2008 teheo@suse.de
- patches.drivers/libata-sata_nv-hardreset-fix: sata_nv: fix
  generic, nf2/3 detection regression.
* Sun Nov  2 2008 sdietrich@suse.de
- Update RT config files: enable more lock debugging,
  latency features, make x86_64 and i386 consistent.
* Sun Nov  2 2008 sdietrich@suse.de
- patches.rt/kprobes_make_pointer_decl_consistent.patch: Make
  kprobe locking consistent with lock-type declarations
* Sun Nov  2 2008 sdietrich@suse.de
- patches.rt/mem_cgroup_charge_statistics-smp_processor_id.patch:
  Use raw_smp_processor_id in __mem_cgroup_stat_add_safe.
* Sun Nov  2 2008 sdietrich@suse.de
- patches.rt/mem_cgroup_charge_statistics-smp_processor_id.patch:
* Sun Nov  2 2008 sdietrich@suse.de
- patches.rt/workqueue-introduce-create_rt_workqueue.patch:
  workqueue: introduce create_rt_workqueue. (from 2.6.28)
  Refresh to eliminate fuzz:
  - patches.rt/preempt-realtime-core.patch: Linux-RT 2.6.27-RT.
* Sun Nov  2 2008 sdietrich@suse.de
- Update RT config files:
  - Sync with SLES 11 default/debug configs
  - Limit CPUS to 32
  - Disable CONFIG_RADIX_TREE_CONCURRENT
  - Disable CONFIG_RADIX_TREE_OPTIMISTIC
  - Disable CONFIG_PREEMPT_RCU_BOOST
  - Enable CONFIG_RTMUTEX_CHECK
- Adapt RT patches to changes made by:
  x86_sgi_cpus4096-05-update-send_IPI_mask.patch
  - patches.rt/mitigate-resched-flood-update.patch: Update
    smp_send_reschedule_allbutself_cpumask mask parameter.
  - patches.rt/x86-nmi-send_IPI_mask-pointer-fix.patch: Update
    smp_send_nmi_allbutself  mask parameter.
  Resolve conflicts introduced by:
  x86_sgi_cpus4096-05-update-send_IPI_mask.patch
  - patches.rt/nmi-profiling-base.patch
  - patches.rt/send-nmi-all-preempt-disable.patch
  Refresh to eliminate fuzz
- patches.rt/apic-dumpstack.patch: Linux-RT 2.6.27-RT.
- patches.rt/mitigate-resched-flood.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-x86_64.patch: Linux-RT 2.6.27-RT.
* Sat Nov  1 2008 bwalle@suse.de
- patches.fixes/kdb-fix-stack-overflow.patch:
  kdb: fix stack overflow for large NR_CPUS count (bnc#440361).
* Fri Oct 31 2008 trenn@suse.de
  Fate 304268 and 304266. SGI scir driver (replaces the more intrusive
  leds one) and the rather intrusive x86_64 4096 CPU support patches:
- Update config files.
- patches.arch/x86_uv_early_detect.patch: Delete hacks that were
  necessary while waiting for x2apic code. (bnc#429984).
- patches.arch/x86_sgi-uv-scir.patch: SGI X86 UV: Provide a
  System Activity Indicator driver (FATE304268 bnc#426066).
- patches.arch/x86_sgi_cpus4096-01-fix-smp_call_function.patch:
  smp: reduce stack requirements for smp_call_function_mask
  (bnc#425240 FATE304266).
- patches.arch/x86_sgi_cpus4096-02-fix-send_call_func_ip.patch:
  x86: reduce stack requirements for send_call_func_ipi
  (bnc#425240 FATE304266).
- patches.arch/x86_sgi_cpus4096-05-update-send_IPI_mask.patch:
  x86 cpumask: Updates to support NR_CPUS=4096 (bnc#425240
  FATE304266).
- patches.arch/x86_sgi_cpus4096-06-optimize-cpumask-in-sched_c.patch:
  Additional cpumask fixups (bnc#425240 FATE304266).
- patches.arch/x86_sgi_cpus4096-04-add-for_each_cpu_mask_and.patch:
  Add for_each_cpu_mask_and (bnc#425240 FATE304266).
- patches.arch/x86_sgi_cpus4096-07_pae_compile_fixups.patch:
  more cpumask cleanups for previous (x86_sgi_cpu4096..) patches
  (Additional cpumask fixups).
- patches.suse/kdb-x86: kdb-v4.4-2.6.27-rc8-x86-1 (FATE#303971).
- patches.xen/xen3-patch-2.6.27: Linux: Update to 2.6.27.
- patches.xen/x86_sgi_xen-x86-cpus4096.patch: x86 cpumask xen:
  Updates to support NR_CPUS=4096 (Additional cpumask fixups).
* Fri Oct 31 2008 tiwai@suse.de
- patches.drivers/alsa-hda-realtek-alc269-dmic: ALSA: hda -
  Add digital-mic for ALC269 auto-probe mode (bnc#440626).
- patches.drivers/alsa-hda-realtek-mic-automute-fix: ALSA: hda -
  Disable broken mic auto-muting in Realtek codes (bnc#440626).
* Fri Oct 31 2008 hare@suse.de
- Update config files.
- patches.drivers/cxgb3i: add cxgb3i iscsi driver
  (FATE#304154,bnc#433500).
- patches.drivers/cxgb3-private-iscsi-ip-addresses: cxgb3 -
  manage private iSCSI IP addresses (FATE#304154,bnc#433500).
- patches.drivers/open-iscsi-offloading-support: support for iscsi
  pdu digest offload and payload DDP. (FATE#304154,bnc#433500).
- patches.fixes/cxgb3-remove-duplicate-tests-in-lro: cxgb3 -
  remove duplicate tests in lro (FATE#304154, bnc#430538).
- supported.conf: Mark cxgb3i as supported.
* Fri Oct 31 2008 bwalle@suse.de
- patches.suse/kdb-resolve-uv-conflict.diff:
  Resolve KDB conflicts with UV (bnc#440376).
* Fri Oct 31 2008 tiwai@suse.de
- patches.drivers/alsa-hda-sigmatel-spdif-fix: ALSA: hda -
  Fix SPDIF mute on IDT/STAC codecs.
- patches.drivers/alsa-hda-reboot-notifier: ALSA: hda - Add
  reboot notifier.
* Fri Oct 31 2008 jack@suse.cz
- patches.suse/ocfs2-Fix-mount-cleanup-after-quota-failure.patch:
  ocfs2: Fix mount cleanup after quota failure (fate#302681).
- patches.suse/ocfs2-Fix-oop-in-recovery-without-quotas:
  ocfs2: Fix recovery of nodes when quota feature is disabled
  (fate#302681).
- patches.suse/ocfs2-Fix-grace-time-syncing.patch: ocfs2: Fix
  grace time syncing (fate#302681).
* Fri Oct 31 2008 teheo@suse.de
- patches.drivers/block-del-timer-after-dequeue: blk: move
  blk_delete_timer call in end_that_request_last (bnc#440076
  bnc#440173).
* Fri Oct 31 2008 trenn@suse.de
- patches.arch/x86_agpgart-g33-stoeln-fix-2.patch: Avoid oops
  on G33 in 1MB stolen Mem case (bnc#391261).
* Thu Oct 30 2008 gregkh@suse.de
- patches.fixes/agp-fix-stolen-memory-counting-on-g4x.patch:
  agp: Fix stolen memory counting on G4X. (bnc#437618).
* Thu Oct 30 2008 oneukum@suse.de
- patches.fixes/sd_liberal_28_sense_invalid.diff: fix medium
  presence misdetection in usb storage device  (bnc#362850).
* Thu Oct 30 2008 olh@suse.de
- add patches.fixes/scsi-ibmvscsi-show-config.patch
  use 4k buffer to transfer config data (439970 - LTC49349)
* Thu Oct 30 2008 teheo@suse.de
- patches.drivers/block-add-timeout-on-dequeue: block: add timer
  on blkdev_dequeue_request() not elv_next_request() (bnc#440076).
* Wed Oct 29 2008 sdietrich@suse.de
  Refresh RT patches:
- patches.rt/adaptive-spinlock-lite-v2.patch: Linux-RT 2.6.27-RT
  adaptive spinlocks lite.
- patches.rt/adaptive-task-oncpu.patch: Linux-RT 2.6.27-RT.
- patches.rt/apic-level-smp-affinity.patch: Linux-RT 2.6.27-RT.
- patches.rt/bh-state-lock.patch: Linux-RT 2.6.27-RT.
- patches.rt/bh-uptodate-lock.patch: Linux-RT 2.6.27-RT.
- patches.rt/bz235099-idle-load-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/check-for-migration-during-push.patch: RT: fix
  push_rt_task() to handle dequeue_pushable properly.
- patches.rt/cond_resched_softirq-WARN-fix.patch: Linux-RT
  2.6.27-RT
  WARNING: at kernel/sched.c:5071 2.6.23-rc1-rt7.
- patches.rt/cputimer-thread-rt_A0.patch: Linux-RT 2.6.27-RT.
- patches.rt/dev-queue-xmit-preempt-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/disable-ist-x86_64.patch: Linux-RT 2.6.27-RT.
- patches.rt/disable-run-softirq-from-hardirq-completely.patch:
  Linux-RT 2.6.27-RT
  Disable running softirqs from hardirqs completely!.
- patches.rt/dont-disable-preemption-without-IST.patch: Linux-RT
  2.6.27-RT.
- patches.rt/dont-unmask-io_apic.patch: Linux-RT 2.6.27-RT.
- patches.rt/drain-all-local-pages-via-sched.patch: Linux-RT
  2.6.27-RT.
- patches.rt/event-trace-hrtimer-trace.patch: Linux-RT 2.6.27-RT
  event-tracer: add clockevent trace.
- patches.rt/event-tracer-syscall-x86_64.patch: Linux-RT
  2.6.27-RT.
- patches.rt/filemap-dont-bug-non-atomic.patch: Linux-RT
  2.6.27-RT.
- patches.rt/fix-bug-on-in-filemap.patch: Linux-RT 2.6.27-RT
  Change bug_on for atomic to pagefault_disabled..
- patches.rt/fix-compilation-for-non-RT-in-timer.patch: Linux-RT
  2.6.27-RT.
- patches.rt/fix-config-debug-rt-mutex-lock-underflow-warnings.patch:
  Linux-RT 2.6.27-RT
  Fix CONFIG_DEBUG_RT_MUTEX lock underflow warnings.
- patches.rt/fix-migrating-softirq.patch: Linux-RT 2.6.27-RT.
- patches.rt/fix-net-bug-fixes.patch: Linux-RT 2.6.27-RT.
- patches.rt/fix-softirq-checks-for-non-rt-preempt-hardirq.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/fix-up-comment.patch: RT: Remove comment that is
  no longer true.
- patches.rt/ftrace-stop-trace-on-crash.patch: Linux-RT 2.6.27-RT
  fix-tracer-wreckage-wtf-is-this-code-all-features.patch.
- patches.rt/futex-fifo-warn-sysctl.patch: Linux-RT 2.6.27-RT.
- patches.rt/genhd-protect-percpu-var.patch: Linux-RT 2.6.27-RT.
- patches.rt/genirq-soft-resend.patch: Linux-RT 2.6.27-RT
  x86: activate HARDIRQS_SW_RESEND.
- patches.rt/gtod-optimize.patch: Linux-RT 2.6.27-RT.
- patches.rt/hack-convert-i_alloc_sem-for-direct_io-craziness.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/handle-pending-in-simple-irq.patch: Linux-RT
  2.6.27-RT
  handle IRQ_PENDING for simple irq handler.
- patches.rt/highmem_rewrite.patch: Linux-RT 2.6.27-RT
  mm: remove kmap_lock.
- patches.rt/hrtimer-no-printk.patch: Linux-RT 2.6.27-RT.
- patches.rt/hrtimers-overrun-api.patch: Linux-RT 2.6.27-RT.
- patches.rt/hrtimers-stuck-in-waitqueue.patch: Linux-RT
  2.6.27-RT.
- patches.rt/ioapic-fix-too-fast-clocks.patch: Linux-RT 2.6.27-RT.
- patches.rt/kdb-rtmisc.patch: Misc KDB fixes for RT (debug
  builds).
- patches.rt/kstat-add-rt-stats.patch: Linux-RT 2.6.27-RT
  add rt stats to /proc/stat.
- patches.rt/kstat-fix-spurious-system-load-spikes-in-proc-loadavgrt.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/loadavg_fixes_weird_loads.patch: Linux-RT 2.6.27-RT.
- patches.rt/lock_page_ref.patch: Linux-RT 2.6.27-RT
  mm: lock_page_ref.
- patches.rt/lockdep-show-held-locks.patch: Linux-RT 2.6.27-RT
  lockdep: show held locks when showing a stackdump.
- patches.rt/mitigate-resched-flood.patch: Linux-RT 2.6.27-RT.
- patches.rt/mm-fix-latency.patch: Linux-RT 2.6.27-RT
  reduce pagetable-freeing latencies.
- patches.rt/multi-reader-account.patch: Linux-RT 2.6.27-RT
  map tasks to reader locks held.
- patches.rt/multi-reader-limit.patch: Linux-RT 2.6.27-RT
  implement reader limit on read write locks.
- patches.rt/multi-reader-lock-account.patch: Linux-RT 2.6.27-RT
  map read/write locks back to their readers.
- patches.rt/multi-reader-pi.patch: Linux-RT 2.6.27-RT
  read lock Priority Inheritance implementation.
- patches.rt/neptune-no-at-keyboard.patch: Linux-RT 2.6.27-RT.
- patches.rt/net-core-preempt-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/new-softirq-code.patch: Linux-RT 2.6.27-RT
  softirq preemption: optimization.
- patches.rt/nmi-profiling-base.patch: Linux-RT 2.6.27-RT
  nmi-driven profiling for /proc/profile.
- patches.rt/numa-slab-freeing.patch: Linux-RT 2.6.27-RT.
- patches.rt/only-run-softirqs-from-irq-thread-when-irq-affinity-is-set.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/pagefault-disable-cleanup.patch: Linux-RT 2.6.27-RT
  clean up the page fault disabling logic.
- patches.rt/panic-dont-stop-box.patch: Linux-RT 2.6.27-RT.
- patches.rt/paravirt-function-pointer-fix.patch: Linux-RT
  2.6.27-RT.
- patches.rt/partreadd-lttng-instrumentation-irq.patch: readd
  RT compatible version of lttng-instrumentation-irq.
- patches.rt/pause-on-oops-head-tail.patch: Linux-RT 2.6.27-RT
  introduce pause_on_oops_head/tail boot options.
- patches.rt/powerpc-count_active_rt_tasks-is-undefined-for-non-preempt-rt.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/ppc-hacks-to-allow-rt-to-run-kernbench.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-core.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-direct-debug-keyboard.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-irqs-hrtimer.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-i386-ioapic-mask-quirk.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-irqs-i386.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-timer.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-acpi.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-console.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-core.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-debug-sysctl.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-ftrace-disable-ftraced.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-i386.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-ia64.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-init-show-enabled-debugs.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-ipc.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-irqs.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-mm.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-mmdrop-delayed.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-net-drivers.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-net-softirq-fixups.patch: Linux-RT
  2.6.27-RT
  NOHZ: local_softirq_pending with tickless.
- patches.rt/preempt-realtime-net.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-powerpc-b4.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-powerpc-update.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-prevent-idle-boosting.patch:
  Linux-RT 2.6.27-RT
  Premmpt-RT: Preevent boosting of idle task.
- patches.rt/preempt-realtime-printk.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-rawlocks.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-sched.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-timer.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-x86_64.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-rt-no-slub.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-softirqs-core.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-trace.patch: Linux-RT 2.6.27-RT.
- patches.rt/print-might-sleep-hack.patch: Linux-RT 2.6.27-RT.
- patches.rt/printk-in-atomic.patch: Linux-RT 2.6.27-RT.
- patches.rt/prof-sysctl-compile.patch: Linux-RT 2.6.27-RT.
- patches.rt/radix-tree-concurrent.patch: Linux-RT 2.6.27-RT
  radix-tree: concurrent write side support.
- patches.rt/radix-tree-optimistic-hist.patch: Linux-RT 2.6.27-RT
  debug: optimistic lock histogram.
- patches.rt/radix-tree-optimistic.patch: Linux-RT 2.6.27-RT
  radix-tree: optimistic locking.
- patches.rt/rcu-preempt-boost-sdr.patch: Linux-RT 2.6.27-RT.
- patches.rt/rcu-preempt-hotplug-hackaround.patch: Linux-RT
  2.6.27-RT.
- patches.rt/realtime-preempt-warn-about-tracing.patch: Linux-RT
  2.6.27-RT.
- patches.rt/revert-preempt-bkl-revert.patch: Linux-RT 2.6.27-RT.
- patches.rt/root-domain-kfree-in-atomic.patch: Linux-RT
  2.6.27-RT.
- patches.rt/rt-kmap-scale-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-move-update-wall-time-back-to-do-timer.patch:
  Linux-RT 2.6.27-RT
  rt: move update_wall_time back to do timer.
- patches.rt/rt-mutex-compat-semaphores.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-mutex-i386.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-mutex-mips.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-mutex-preempt-debugging.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-mutex-trivial-route-cast-fix.patch: Linux-RT
  2.6.27-RT.
- patches.rt/rt-mutex-trivial-tcp-preempt-fix.patch: Linux-RT
  2.6.27-RT.
- patches.rt/rt-mutex-x86-64.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-s_files-kill-a-union.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-shorten-softirq-thread-names.patch: Linux-RT
  2.6.27-RT.
- patches.rt/rt_mutex_setprio.patch: Linux-RT 2.6.27-RT
  rt: rename rt_mutex_setprio to task_setprio.
- patches.rt/s_files.patch: Linux-RT 2.6.27-RT
  remove global files_lock.
- patches.rt/sched-add-needs_post_schedule.patch: Linux-RT
  2.6.27-RT.
- patches.rt/sched-enable-irqs-in-preempt-in-notifier-call.patch:
  Linux-RT 2.6.27-RT
  CFS: enable irqs in fire_sched_in_preempt_notifier.
- patches.rt/sched-fix-dequeued-race.patch: Linux-RT 2.6.27-RT
  sched-fix-dequeued-race.patch.
- patches.rt/sched-make-double-lock-balance-fair.patch: Linux-RT
  2.6.27-RT.
- patches.rt/sched-nr-migrate-lower-default-preempt-rt.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/sched-only-push-once-per-queue.patch: Linux-RT
  2.6.27-RT.
- patches.rt/sched-properly-account-irq-and-rt-load.patch:
  Linux-RT 2.6.27-RT
  sched: properly account IRQ and RT load in .
- patches.rt/sched-rt-runtime-lock-raw.patch: Linux-RT 2.6.27-RT.
- patches.rt/sched-wake_up_idle_cpu-rt.patch: Linux-RT 2.6.27-RT.
- patches.rt/select-error-leak-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/serial-locking-rt-cleanup.patch: Linux-RT 2.6.27-RT.
- patches.rt/serial-slow-machines.patch: Linux-RT 2.6.27-RT.
- patches.rt/slab-irq-nopreempt-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/smp-processor-id-fixups.patch: Linux-RT 2.6.27-RT.
- patches.rt/softirq-per-cpu-assumptions-fixes.patch: Linux-RT
  2.6.27-RT.
- patches.rt/start_irq_thread.patch: Linux-RT 2.6.27-RT.
- patches.rt/sub-dont-disable-irqs.patch: Linux-RT 2.6.27-RT
  rt: dont disable irqs in usb.
- patches.rt/tasklet-busy-loop-hack.patch: Linux-RT 2.6.27-RT.
- patches.rt/tasklet-redesign.patch: Linux-RT 2.6.27-RT.
- patches.rt/timer-freq-tweaks.patch: Linux-RT 2.6.27-RT.
- patches.rt/timer-warning-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/trace-events-handle-syscalls.patch: Linux-RT
  2.6.27-RT.
- patches.rt/trace-histograms.patch: Linux-RT 2.6.27-RT.
- patches.rt/tracer-add-event-markers.patch: Linux-RT 2.6.27-RT.
* Wed Oct 29 2008 gregkh@suse.de
- s/rtl2860/rt2860/
- remove driver from the Xen build as it's dying for some reason.
- add obsoletes for ralink-rt2860-kmp
* Wed Oct 29 2008 olh@suse.de
- update patches.arch/ppc-oprofile-spu.patch
  add missing ARRAY_SIZE(pm_signal_local)
* Wed Oct 29 2008 hare@suse.de
- patches.arch/s390-symmetrix-ioctl.patch: Add ioctl support
  for EMC Symmetrix Subsystem Control I/O (bnc#439221)
* Wed Oct 29 2008 jbeulich@suse.de
- patches.xen/xen-rtl2860-build: fix issue with Windows-style
  types used in rtl2680.
* Wed Oct 29 2008 olh@suse.de
- build af_packet as a module on powerpc (bnc#433540)
* Wed Oct 29 2008 olh@suse.de
- add patches.arch/ppc-oprofile-spu-mutex-locking.patch
  Fix mutex locking for cell spu-oprofile (bnc#422501 - LTC47617)
* Wed Oct 29 2008 olh@suse.de
- add patches.arch/ppc-oprofile-spu.patch
  fix local array size in activate spu profiling function (bnc#439553 - LTC48925)
* Wed Oct 29 2008 olh@suse.de
- update patches.drivers/ehea.patch
  Add hugepage detection (bnc#439599 - LTC48958)
* Wed Oct 29 2008 gregkh@suse.de
- patches.drivers/staging-add-agnx-wireless-driver.patch: Staging:
  add agnx wireless driver.
- patches.drivers/staging-add-otus-atheros-wireless-network-driver.patch:
  Staging: add otus Atheros wireless network driver.
- patches.drivers/staging-add-rtl2860-wireless-driver.patch:
  Staging: add rtl2860 wireless driver (bnc#437959).
- Update config files.
* Tue Oct 28 2008 jkosina@suse.de
- patches.suse/silent-stack-overflow-2.patch: disabled, as it
  causes kernel hangs triggered by grub (bnc#439448).
* Tue Oct 28 2008 kkeil@suse.de
- update patches.suse/SoN-17-net-ps_rx.patch
  fix i/o corruption on rx in ixgbe (bnc#438929)
* Tue Oct 28 2008 jdelvare@suse.de
- config/powerpc/*: Fixup configuration files after last change.
* Tue Oct 28 2008 jdelvare@suse.de
- config/*: Include many multimedia drivers which has been dropped
  accidentally. This includes the pwc, ivtv, zr36067 drivers and
  many old webcam drivers (bnc#439489).
- supported.conf: Add all these drivers again.
* Tue Oct 28 2008 tiwai@suse.de
- patches.drivers/alsa-hda-analog-update,
  patches.drivers/alsa-hda-atihdmi-update,
  patches.drivers/alsa-hda-beep,
  patches.drivers/alsa-hda-hp-mobile-fix,
  patches.drivers/alsa-hda-nvidia-hdmi,
  patches.drivers/alsa-hda-probe-fix,
  patches.drivers/alsa-hda-proc-fix,
  patches.drivers/alsa-hda-realtek-update,
  patches.drivers/alsa-hda-sigmatel-update,
  patches.drivers/alsa-hda-spdif-slave,
  patches.drivers/alsa-hda-via-rec-fix,
  patches.drivers/alsa-hda-via-update:
    ALSA updates, mostly taken from 2.6.28-rc1 patches
- Update config files.
* Tue Oct 28 2008 jdelvare@suse.de
- Actually CONFIG_SND_HDA_HWDEP is a boolean, sorry.
* Tue Oct 28 2008 jdelvare@suse.de
- config/ia64/vanilla, config/x86_64/vanilla: fix configuration
  discrepancy, CONFIG_SND_HDA_HWDEP=m.
* Tue Oct 28 2008 olh@suse.de
- add patches.arch/ppc-pcibios_allocate_bus_resources.patch
  add patches.arch/ppc-powerpc-debug-pci-hotplug.patch
  fix DLPAR on pseries (bnc#439491 - LTC48584)
* Tue Oct 28 2008 olh@suse.de
- add patches.arch/ppc-powerpc-fix-pci-unmap-io.patch
  Fix unmapping of IO space on 64-bit (bnc#439491 - LTC48584)
* Tue Oct 28 2008 olh@suse.de
- update ps3 config, remove unneeded options to reduce vmlinux size
* Tue Oct 28 2008 neilb@suse.de
- patches.suse/md-notify-when-stopped: md: notify udev when an
  md array is stopped. (fate#303894).
* Tue Oct 28 2008 gregkh@suse.de
- use the panasonic laptop driver that was accepted by upstream, not the
  pcc-acpi driver, which was rejected:
  - patches.drivers/staging-add-pcc-acpi-driver.patch: Delete.
  - patches.drivers/panasonic-laptop-add-panasonic-let-s-note-laptop-extras-driver-v0.94.patch:
    panasonic-laptop: add Panasonic Let's Note laptop extras
    driver v0.94.
- Update config files.
* Tue Oct 28 2008 gregkh@suse.de
- patches.drivers/via-framebuffer-driver.patch: Via Framebuffer
  driver.
- Update config files.
* Mon Oct 27 2008 bwalle@suse.de
- patches.fixes/hpwdt-kdump.diff:
  Don't change permission of sysfs file (did that accidentally
  when changing the default value).
* Mon Oct 27 2008 trenn@suse.de
- patches.arch/x86_uv_early_detect.patch: Delete hacks that were
  necessary while waiting for x2apic code. (bnc#429984).
* Mon Oct 27 2008 tj@suse.de
  Refresh the govault patch.
- patches.drivers/libata-add-waits-for-govault: libata: add
  waits for GoVault (bnc#246451).
* Sun Oct 26 2008 bwalle@suse.de
- patches.fixes/kdb-oops-panic.diff:
  Fix NULL pointer dereference when regs == NULL (bnc#439007).
- patches.fixes/hpwdt-kdump.diff:
  Fix kdump when using hpwdt (bnc#436786).
* Sun Oct 26 2008 gregkh@suse.de
- refresh patches to apply cleanly and properly.
* Sun Oct 26 2008 gregkh@suse.de
- Update to 2.6.27.4
* Sat Oct 25 2008 agruen@suse.de
- Fix the dependencies between the split kernel packages and KMPs
  (FATE 303631).
- Fix for kernel paclages which are not split.
- rpm/kernel-source.spec.in: Update list of scripts to include.
* Sat Oct 25 2008 jjolly@suse.de
- patches.arch/s390-02-02-smp-sysdev.patch: kernel: sysdev class
  file creation (bnc#434333)
- patches.arch/s390-02-03-zfcp.patch: Fix zfcp problems that have
  been found (bnc#434333)
- patches.arch/s390-02-04-qeth-mac.patch: qeth: use firmware
  MAC-address for layer2 hsi-devices (bnc#434333)
- patches.arch/s390-02-05-qeth-recovery.patch: qeth: qeth recovery
  fails (bnc#434333)
- patches.arch/s390-02-06-qeth-offset.patch: qeth: fix offset error
  in non prealloc header path (bnc#434333,LTC#48840)
- patches.arch/s390-02-07-qeth-ipv6check.patch: qeth: remove
  unnecessary support ckeck in sysfs route6 (bnc#434333)
- patches.arch/s390-02-08-qeth-panic.patch: qeth: avoid
  skb_under_panic for malformatted inbound data (bnc#434333)
- patches.arch/s390-02-09-tape-lock.patch: tape device driver:
  improve locking (bnc#434333)
* Sat Oct 25 2008 neilb@suse.de
- patches.kernel.org/touch_mnt_namespace-when-the-mount-flags-change.patch:
  touch_mnt_namespace when the mount flags change (FATE#304218).
* Fri Oct 24 2008 gregkh@suse.de
- Updated to 2.6.27.4-rc3:
  - fixed ath5k suspend/resume regression
  - fixed pvrusb2 so it actually works
* Fri Oct 24 2008 jack@suse.cz
- patches.suse/ocfs2-Implementation-of-local-and-global-quota-file.patch:
  ocfs2: Implementation of local and global quota file handling
  (fate#302681). - fixed 64-bit division
* Fri Oct 24 2008 jeffm@suse.de
- Update config files for -rt.
* Fri Oct 24 2008 hare@suse.de
- patches.suse/cgroup-freezer.patch: Add TIF_FREEZE for s390.
* Fri Oct 24 2008 olh@suse.de
- move patches.suse/md-raid-metadata-PAGE_SIZE.patch
  to patches.kernel.org/md-raid-metadata-PAGE_SIZE.patch
  to allow raid0 with 64k PAGE_SIZE
* Fri Oct 24 2008 jack@suse.cz
- Update config files.
- supported.conf: Added new quota module
- patches.suse/xfs-dmapi-enable: Enable XFS DMAPI. - Refreshed
  Quotas for OCFS2:
- patches.suse/quota-Add-callbacks-for-allocating-and-destroying-d.patch:
  quota: Add callbacks for allocating and destroying dquot
  structures (fate#302681).
- patches.suse/quota-Increase-size-of-variables-for-limits-and-ino.patch:
  quota: Increase size of variables for limits and inode usage
  (fate#302681).
- patches.suse/quota-Remove-bogus-optimization-in-check_idq-an.patch:
  quota: Remove bogus 'optimization' in check_idq() and
  check_bdq() (fate#302681).
- patches.suse/quota-Make-_SUSPENDED-just-a-flag.patch: quota:
  Make _SUSPENDED just a flag (fate#302681).
- patches.suse/quota-Allow-to-separately-enable-quota-accounting-a.patch:
  quota: Allow to separately enable quota accounting and enforcing
  limits (fate#302681).
- patches.suse/ext3-Use-sb_any_quota_loaded-instead-of-sb_any_qu.patch:
  ext3: Use sb_any_quota_loaded() instead of
  sb_any_quota_enabled() (fate#302681).
- patches.suse/ext4-Use-sb_any_quota_loaded-instead-of-sb_any_qu.patch:
  ext4: Use sb_any_quota_loaded() instead of
  sb_any_quota_enabled() (fate#302681).
- patches.suse/reiserfs-Use-sb_any_quota_loaded-instead-of-sb_an.patch:
  reiserfs: Use sb_any_quota_loaded() instead of
  sb_any_quota_enabled(). (fate#302681).
- patches.suse/quota-Remove-compatibility-function-sb_any_quota_en.patch:
  quota: Remove compatibility function sb_any_quota_enabled()
  (fate#302681).
- patches.suse/quota-Introduce-DQUOT_QUOTA_SYS_FILE-flag.patch:
  quota: Introduce DQUOT_QUOTA_SYS_FILE flag (fate#302681).
- patches.suse/quota-Move-quotaio_v-12-.h-from-include-linux-to-f.patch:
  quota: Move quotaio_v[12].h from include/linux/ to fs/
  (fate#302681).
- patches.suse/quota-Split-off-quota-tree-handling-into-a-separate.patch:
  quota: Split off quota tree handling into a separate file
  (fate#302681).
- patches.suse/quota-Convert-union-in-mem_dqinfo-to-a-pointer.patch:
  quota: Convert union in mem_dqinfo to a pointer (fate#302681).
- patches.suse/quota-Allow-negative-usage-of-space-and-inodes.patch:
  quota: Allow negative usage of space and inodes (fate#302681).
- patches.suse/quota-Keep-which-entries-were-set-by-SETQUOTA-quota.patch:
  quota: Keep which entries were set by SETQUOTA quotactl
  (fate#302681).
- patches.suse/quota-Add-helpers-to-allow-ocfs2-specific-quota-ini.patch:
  quota: Add helpers to allow ocfs2 specific quota initialization,
  freeing and recovery (fate#302681).
- patches.suse/quota-Implement-function-for-scanning-active-dquots.patch:
  quota: Implement function for scanning active dquots
  (fate#302681).
- patches.suse/ocfs2-Fix-check-of-return-value-of-ocfs2_start_tran.patch:
  ocfs2: Fix check of return value of ocfs2_start_trans()
  (fate#302681).
- patches.suse/ocfs2-Support-nested-transactions.patch: ocfs2:
  Support nested transactions (fate#302681).
- patches.suse/ocfs2-Fix-checking-of-return-value-of-new_inode.patch:
  ocfs2: Fix checking of return value of new_inode()
  (fate#302681).
- patches.suse/ocfs2-Let-inode-be-really-deleted-when-ocfs2_mknod_.patch:
  ocfs2: Let inode be really deleted when ocfs2_mknod_locked()
  fails (fate#302681).
- patches.suse/ocfs2-Assign-feature-bits-and-system-inodes-to-quot.patch:
  ocfs2: Assign feature bits and system inodes to quota feature
  and quota files (fate#302681).
- patches.suse/ocfs2-Mark-system-files-as-not-subject-to-quota-acc.patch:
  ocfs2: Mark system files as not subject to quota accounting
  (fate#302681).
- patches.suse/ocfs2-Implementation-of-local-and-global-quota-file.patch:
  ocfs2: Implementation of local and global quota file handling
  (fate#302681).
- patches.suse/ocfs2-Add-quota-calls-for-allocation-and-freeing-of.patch:
  ocfs2: Add quota calls for allocation and freeing of inodes
  and space (fate#302681).
- patches.suse/ocfs2-Enable-quota-accounting-on-mount-disable-on.patch:
  ocfs2: Enable quota accounting on mount, disable on umount
  (fate#302681).
- patches.suse/ocfs2-Implement-quota-syncing-thread.patch: ocfs2:
  Implement quota syncing thread (fate#302681).
- patches.suse/ocfs2-Implement-quota-recovery.patch: ocfs2:
  Implement quota recovery (fate#302681).
* Fri Oct 24 2008 kkeil@suse.de
- patches.fixes/cxgb3_fix_race_in_EEH: cxgb3: fix race in EEH.
  (bnc#430093)
* Fri Oct 24 2008 jeffm@suse.de
- Refreshed context for -RT patches so they apply again.
* Fri Oct 24 2008 rw@suse.de
- patches.drivers/sgi-ioc4-request-submodules:
  Make ioc4 request dependant modules.  (bnc#429215)
* Fri Oct 24 2008 hare@suse.de
- Update config files: Disable FAIL_MAKE_REQUEST.
* Fri Oct 24 2008 tiwai@suse.de
- patches.drivers/alsa-usb-exclude-1st-slot: Delete this old ugly
  workaround patch.
* Fri Oct 24 2008 hare@suse.de
- Include patches from upstream:
  - patches.fixes/block-use-bio_has_data: Implement bio_has_data().
  - patches.fixes/block-git-fixes: Block layer fixes for 2.6.28.
  - patches.fixes/block-rq-affinity: Implement rq affinity.
  - patches.fixes/dm-mpath-remove-is_active: dm mpath: remove
    is_active from struct dm_path.
  - patches.fixes/block-discard-requests: Implement block discard.
  - patches.drivers/dm-abort-queue-on-failed-paths: dm: Call
    blk_abort_queue on failed paths (bnc#417544).
  - patches.drivers/block-call-sync-on-cleanup: block:
    blk_cleanup_queue() should call blk_sync_queue().
- Refaktor and update request-based multipath patches:
  - patches.drivers/blk-request-based-multipath-update:
    Update request-based multipathing patches to upstream version
    (bnc#434105).
  - patches.suse/rq-based-multipath: Update to latest version
    of request-based multipathing patchset (bnc#434105)
  - patches.drivers/block-abort-request-rq-complete-marking:
    use rq complete marking in blk_abort_request (bnc#434105).
  - patches.fixes/scsi-atomic-blk-timer-deletes: Delete.
  - patches.fixes/dm-mpath-abort-queue: Delete.
  - patches.suse/rq-based-block-layer: Delete.
  - patches.suse/rq-based-dm-interface: Delete.
  - patches.suse/rq-based-multipath-functions: Delete.
  - patches.suse/rq-based-init-crash: Delete.
- Update patches to upstream version:
  - patches.drivers/bdev-resize-check-for-device-resize
  - patches.drivers/bdev-resize-added-flush_disk
  - patches.drivers/bdev-resize-call-flush_disk
  - patches.drivers/bdev-resize-sd-driver-calls
  - patches.drivers/block-timeout-handling
  - patches.drivers/bdev-resize-adjust-block-device-size
  - patches.drivers/bdev-resize-wrapper-for-revalidate_disk
  - patches.drivers/block-abort-queue
  - patches.fixes/scsi-enhance-error-codes
- Rediff patches:
  - patches.fixes/scsi-misc-git-update
  - patches.suse/dm-barrier-single-device
  - patches.suse/kdb-common
  - patches.drivers/lpfc-8.2.8-update
  - patches.drivers/lpfc-8.2.8.3-update
  - patches.drivers/mpt-fusion-4.00.43.00-update
* Fri Oct 24 2008 bwalle@suse.de
- patches.suse/kdump-dump_after_notifier.patch: Add sysctl also
  to kernel/sysctl_check.c.
* Fri Oct 24 2008 bwalle@suse.de
- Obsolete uvcvideo-kmp.
* Fri Oct 24 2008 jbeulich@suse.de
- rpm/kernel-binary.spec.in: Provide 'kernel' also for Xen (bnc#362918).
* Fri Oct 24 2008 jbeulich@suse.de
- patches.arch/x86_64-unwind-annotations: fix unwind annotations.
- patches.xen/xen3-x86_64-unwind-annotations: fix unwind
  annotations.
* Fri Oct 24 2008 jbeulich@suse.de
- Update Xen patches to 2.6.27.3 and c/s 704
- patches.xen/xen3-x2APIC_PATCH_27_of_41_9fa8c481b55e80edd8c637573f87853bb6b600f5:
  x64, x2apic/intr-remap: introduce CONFIG_INTR_REMAP (fate
  [#303948] and fate #303984).
- patches.xen/xen3-x2APIC_PATCH_40_of_41_bbb65d2d365efe9951290e61678dcf81ec60add4:
  x86: use cpuid vector 0xb when available for detecting cpu
  topology (fate #303948 and fate #303984).
- patches.xen/xen-kconfig-compat-3.2.0: add 3.2.0-compatibility
  configure option.
- patches.xen/xen-x86-exit-mmap: be more aggressive about
  de-activating mm-s under destruction.
- patches.xen/xen-x86-machphys-prediction: properly predict
  phys<->mach translations.
- patches.xen/xen-x86-mmu-batching: utilize
  arch_{enter,leave}_lazy_cpu_mode().
- patches.xen/xen-x86-no-lazy-tlb: ensure inadvertent uses of
  lazy TLB data are caught during the build.
- Update Xen config files.
* Fri Oct 24 2008 mmarek@suse.cz
- rpm/kernel-binary.spec.in:
  - do not split kernel-kdump into -base and -extra
  - fix case when a build results in no unsupported modules
* Fri Oct 24 2008 bwalle@suse.de
- patches.fixes/kdb-kdump.diff:
  Fix CONFIG_KDB_KDUMP on xSeries (bnc#436454).
* Fri Oct 24 2008 agruen@suse.de
- supported.conf: Mark dmapi as supported (by SGI).
* Fri Oct 24 2008 olh@suse.de
- disable all unsupported drivers in kernel-kdump
* Fri Oct 24 2008 npiggin@suse.de
- patches.suse/silent-stack-overflow-2.patch: avoid silent stack
  overflow over the heap (bnc#44807 bnc#211997).
* Fri Oct 24 2008 gregkh@suse.de
- Update to 2.6.27.4-rc2
* Fri Oct 24 2008 gregkh@suse.de
- disable CONFIG_SYSFS_DEPRECATED_V2 from powerpc/rt config file
* Fri Oct 24 2008 gregkh@suse.de
- Update to 2.6.27.4-rc1
  - lots of bugfixes, and obsoletes some current patches:
  - patches.fixes/ext3-avoid-printk-flood-with-dir-corruption: Delete.
  - patches.fixes/ext2-avoid-printk-flood-with-dir-corruption: Delete.
  - patches.fixes/wdm_autoload.diff: Delete.
* Fri Oct 24 2008 npiggin@suse.de
- Fix ppc and ps3 configs
* Fri Oct 24 2008 npiggin@suse.de
- Update config files.
- patches.suse/cgroup-freezer.patch: cgroup freezer (bnc#417294,
  fate#304191, fate#201036).
* Fri Oct 24 2008 npiggin@suse.de
- Update config files. Enable cgroups for all archs (bnc#417527)
* Fri Oct 24 2008 npiggin@suse.de
- patches.arch/ppc-gigantic-page-fix2.patch: powerpc gigantic
  pages fix 2 (bnc#434026).
- patches.arch/ppc-gigantic-page-fix3.patch: powerpc gigantic
  pages fix 3 (bnc#434026).
- patches.trace/lttng-instrumentation-hugetlb.patch: de-fuzz
* Fri Oct 24 2008 gregkh@suse.de
- disabled CONFIG_CALGARY_IOMMU_ENABLED_BY_DEFAULT on x86-64
  vanilla kernel.
* Fri Oct 24 2008 gregkh@suse.de
- patches.drivers/cciss-fix-procfs-firmware-regression.patch:
  cciss: fix procfs firmware regression (bnc435644).
- patches.drivers/cciss-fix-sysfs-symlink.patch: cciss: fix
  sysfs symlink (bnc435644).
* Fri Oct 24 2008 gregkh@suse.de
- disable CONFIG_CALGARY_IOMMU_ENABLED_BY_DEFAULT on x86-64.  To use
  Calgary iommu systems, you now must manually pass "iommu=calgary" to
  get this hardware support back enabled.  This is the recommended
  proceedure right now, from IBM, otherwise the hardware crashes.
  bnc#436450.
* Fri Oct 24 2008 gregkh@suse.de
- clean up all fuzz in patches to get them to apply cleanly.
* Fri Oct 24 2008 gregkh@suse.de
- delete patches.arch/s390-01-03-cmm2-v2.patch as it touched core
  kernel code and was rejected from upstream.
  - patches.arch/s390-01-03-cmm2-v2.patch: Delete.
  - patches.arch/s390-01-03-cmm2-v2a.patch: Delete.
* Fri Oct 24 2008 gregkh@suse.de
- Update to version 3.4 of squashfs:
  - patches.suse/squashfs3.3-patch: Delete.
  - patches.suse/squashfs-patch-2.6.25: Delete.
  - patches.suse/squashfs-patch-2.6.27: Delete.
  - patches.suse/squashfs-3.4.patch: squashfs v3.4.
* Thu Oct 23 2008 jeffm@suse.de
- patches.fixes/block-sanitize-invalid-partition-table-entries:
  block: sanitize invalid partition table entries (bnc#371657).
* Thu Oct 23 2008 olh@suse.de
- add patches.arch/ppc-pseries_mem-limit-16g.patch
  Don't use a 16G page if beyond mem= limits (bnc#438111 - LTC49329)
* Thu Oct 23 2008 kkeil@suse.de
- Update x86 64bit config files to include WAN support (bnc#437692)
* Thu Oct 23 2008 olh@suse.de
- add patches.drivers/cell_edac.patch
  Fix incorrect edac_mode in csrow causing oops (bnc#437757 - LTC49143)
* Thu Oct 23 2008 olh@suse.de
- update patches.suse/nameif-track-rename.patch
  print also application and pid
* Thu Oct 23 2008 jkosina@suse.de
- patches.fixes/hid-rdesc-quirk-for-sony-vaio-VGX-TP1E.patch:
  HID: Fix Sony Vaio VGX report descriptor (bnc#437758).
* Thu Oct 23 2008 olh@suse.de
- add patches.drivers/ehca-rejecting-dynamic-mem-add-remove.patch
  reject dynamic memory add/remove (bnc#434651 - LTC48744)
* Thu Oct 23 2008 npiggin@suse.de
- Update config files.
* Thu Oct 23 2008 npiggin@suse.de
- patches.suse/x86-gb-linear-map.patch: Enable GB mapped linear
  KVA on x86 (bnc#437674).
- patches.xen/xen3-patch-2.6.26: merge
* Thu Oct 23 2008 gregkh@suse.de
- update to 2.6.27.3
  - lots of bugfixes
  - CVE-2008-3831 fix
* Wed Oct 22 2008 jeffm@suse.de
- scripts/vc: Handle unset $EDITOR
* Wed Oct 22 2008 jeffm@suse.de
- patches.suse/export-release_open_intent: Export
  release_open_intent for NFS branches with aufs.
* Wed Oct 22 2008 jdelvare@suse.de
- supported.conf: Mark the ibmaem and ibmpex hwmon drivers as
  supported by IBM.
- supported.conf: Mark the i5k_amb hwmon driver as supported.
* Wed Oct 22 2008 olh@suse.de
- add patches.drivers/ehea.patch
  Fix memory hotplug support (436447 - LTC48713)
* Wed Oct 22 2008 olh@suse.de
- add patches.arch/ppc-pseries_hugepage_pagetable_allocation.patch
  Cleanup hugepage pagetable allocation (bnc# 433503 - LTC48757)
* Wed Oct 22 2008 sassmann@suse.de
  Add PS3 audio patches:
- patches.arch/ppc-ps3-add-passthrough-support-for-non-audio-streams.patch:
  ps3: Add passthrough support for non-audio streams.
- patches.arch/ppc-ps3-add-ps3av-audio-mute-analog.patch:
  ps3: Add ps3av_audio_mute_analog().
- patches.arch/ppc-ps3-add-support-for-SPDIF-HDMI-passthrough.patch:
  ps3: Add support for SPDIF/HDMI passthrough.
* Tue Oct 21 2008 sdietrich@suse.de
- patches.rt/genirq-usb.patch: Make status_cache u32
- patches.rt/genirq-ohci1394.patch: Enable ohci1394 IRQ
  threading.
* Tue Oct 21 2008 hare@suse.de
- patches.fixes/dm-mpath-abort-queue: rediff.
- patches.fixes/scsi-atomic-blk-timer-deletes: scsi: atomic blk
  timer deletes (LTC#48990, bnc#434105).
- patches.suse/rq-based-block-layer: rq-based multipathing:
  rediff.
* Tue Oct 21 2008 hare@suse.de
- patches.fixes/scsi-inquiry-too-short-ratelimit: INQUIRY result
  too short (5) message flood (bnc#432535).
* Tue Oct 21 2008 npiggin@suse.de
- patches.suse/filp-slab-rcu: Delete.
* Tue Oct 21 2008 sdietrich@suse.de
  USB IRQ threading (experimental: guarded by genirq):
- patches.rt/genirq1-make-irqreturn_t-an-enum: genirq: make
  irqreturn_t an enum.
- patches.rt/genirq2-add-quick-check-handler.patch: genirq:
  add a quick check handler.
- patches.rt/genirq3-add-threaded-irq-handler-support: genirq:
  add threaded interrupt handler support.
- patches.rt/genirq4-add-helper-to-check-whether-irq-thread-should-run:
  genirq: add a helper to check whether the irqthread should run.
- patches.rt/genirq5-make-irq-threading-robust: genirq: make
  irq threading robust.
- patches.rt/genirq-usb.patch: genirq threading for ehci, ohci
  and uhci USB hosts..
- patches.rt/genirq-wlan-ng-compat.patch: Remove redundant,
  obsolete 2.4 compatibility code in wlan-ng.
  Ack:
- patches.rt/genirq-soft-resend.patch: Linux-RT 2.6.27-RT
  x86: activate HARDIRQS_SW_RESEND.
* Mon Oct 20 2008 gregkh@suse.de
- patches.arch/x2APIC_PATCH_x86-mach_apicdef.h-need-to-include-before-smp.h.patch:
  x86: mach_apicdef.h need to include before smp.h.
  fixes build error on i386 pae kernels.
* Mon Oct 20 2008 bwalle@suse.de
- patches.suse/kdump-dump_after_notifier.patch:
  Add dump_after_notifier sysctl (bnc#436678).
* Mon Oct 20 2008 gregkh@suse.de
- scripts/wd-functions.sh: reverse git and cvs checks (check for
  cvs before git).  This solves the problem if you are using a cvs
  tree, yet it happens to live in a directory that way up the
  directory chain is in a git tree (like for people who keep portions
  of their $HOME in git).
* Mon Oct 20 2008 gregkh@suse.de
- Update config files: enable CONFIG_GENERICARCH and CONFIG_BIGSMP
  on i386-pae kernels. (bnc#428247)
* Mon Oct 20 2008 ptesarik@suse.cz
- patches.arch/x86-tracehook: fix the order of arguments in
  /proc/$pid/syscall on x86_64.
* Mon Oct 20 2008 bwalle@suse.de
- Update config files: Enable CONFIG_KVM_KMP for RT config, run
  oldconfig.
* Mon Oct 20 2008 bwalle@suse.de
- patches.arch/ppc-vmcoreinfo.diff: Correct to reflect mainline
  state.
* Mon Oct 20 2008 hare@suse.de
- Update config files.
- patches.suse/kvm-as-kmp: Allow KVM to be built as KMP
  (FATE#303679).
* Mon Oct 20 2008 jjolly@suse.de
- patches.arch/s390-01-05-kmsg-v2.patch: Instrument the kernel
  components such that a kernel message catalog as well as related
  man pages can be automatically generated. (bnc#417300)
- patches.arch/s390-01-06-zfcp-cleanup-v2.patch: Update patch to
  fit on recent kmsg patch changes. (bnc#417550)
- patches.drivers/driver-core-basic-infrastructure-for-per-module-dynamic-debug-messages.patch:
  Update patch to fit on recent kmsg patch changes.
- config/s390/{default,s390}: Added CONFIG_KMSG_IDS=y
* Mon Oct 20 2008 bwalle@suse.de
- supported.conf: Mark 'crasher' as supported to avoid installing
  the "extra" package only for that module.
* Mon Oct 20 2008 olh@suse.de
- add patches.arch/ppc-pseries_16g-numa.patch
  fix crash with more 2 numa nodes and 16G hugepage (bnc#436452 - LTC48839)
* Sat Oct 18 2008 gregkh@suse.de
- Update to 2.6.27.2.
  - lots of bugfixes
* Sat Oct 18 2008 tonyj@suse.de
- patches.rt/fix-preempt-none.patch: Fix preempt-none build
  errors
* Fri Oct 17 2008 jeffm@suse.de
- patches.suse/SoN-20-netvm-reserve-inet.patch-fix: SoN: Fix
  initialization of ipv4_route_lock (bnc#435994).
* Fri Oct 17 2008 kkeil@suse.de
- patches.drivers/tg3-Add-57780-ASIC-revision.patch: tg3: Add
  57780 ASIC revision. (bnc#434147)
- patches.drivers/broadcom-Add-support-for-the-57780-integrated-PHY.patch:
  broadcom: Add support for the 57780 integrated PHY. (bnc#434147)
- patches.drivers/bnx2x-eeh.patch: bnx2x: EEH recovery fix.(bnc#433875)
* Fri Oct 17 2008 bwalle@suse.de
- rpm/kernel-binary.spec.in: Add the auto-generated (by mkdumprd)
  kdump initrd to %%ghost so that the file gets removed when
  uninstalling the kernel.
* Fri Oct 17 2008 mfasheh@suse.com
- ocfs2 ACL / security attribute support
  - patches.suse/ocfs2-Remove-unused-function-restore_extent_block.patch
  - patches.suse/ocfs2-Merge-transactions-during-xattr-set.patch
  - patches.suse/ocfs2-xattr.-ch-definition-cleanups.patch
  - patches.suse/ocfs2-Add-security-xattr-support-in-ocfs2.patch
  - patches.suse/ocfs2-Add-POSIX-ACL-support-in-ocfs2.patch
* Fri Oct 17 2008 mfasheh@suse.com
- ocfs2 fixes / updates from 2.6.28 merge window
  - patches.suse/ocfs2-xattr.c-Fix-a-bug-when-inserting-xattr.patch
  - patches.suse/ocfs2-Add-empty-bucket-support-in-xattr.patch
  - patches.suse/ocfs2-Remove-pointless.patch
  - patches.suse/ocfs2-make-la_debug_mutex-static.patch
  - patches.suse/ocfs2-Documentation-update-for-user_xattr-nouser_.patch
  - patches.suse/ocfs2-use-smaller-counters-in-ocfs2_remove_xattr_cl.patch
  - patches.suse/ocfs2-Don-t-check-for-NULL-before-brelse.patch
  - patches.suse/ocfs2-Uninline-ocfs2_xattr_name_hash.patch
  - patches.suse/ocfs2-Move-trusted-and-user-attribute-support-into.patch
  - patches.suse/ocfs2-Calculate-EA-hash-only-by-its-suffix.patch
  - patches.suse/ocfs2-Refactor-xattr-list-and-remove-ocfs2_xattr_ha.patch
  - patches.suse/ocfs2-Separate-out-sync-reads-from-ocfs2_read_block.patch
  - patches.suse/ocfs2-Require-an-inode-for-ocfs2_read_block-s.patch
  - patches.suse/ocfs2-Simplify-ocfs2_read_block.patch
  - patches.suse/ocfs2-Move-ocfs2_bread-into-dir.c.patch
  - patches.suse/ocfs2-Kill-the-last-naked-wait_on_buffer-for-cach.patch
  - patches.suse/ocfs2-Make-cached-block-reads-the-common-case.patch
  - patches.suse/ocfs2-fix-build-error.patch
* Thu Oct 16 2008 mfasheh@suse.com
- ocfs2 dynamic local alloc patches
* Thu Oct 16 2008 jslaby@suse.de
- patches.drivers/tpm-bcm0102-workaround.patch: tpm: work around
  bug in Broadcom BCM0102 chipset (bnc#425747 FATE304221).
- patches.drivers/tpm-correct-timeouts.patch: tpm: correct tpm
  timeouts to jiffies conversion (bnc#425747 FATE304221).
* Thu Oct 16 2008 ihno@suse.de
- added patches.arch/s390-01-03-cmm2-v2a.patch
  fix the sequence of initilisations.
* Thu Oct 16 2008 agruen@suse.de
- rpm/kernel-binary.spec.in: Make the kernel-$flavor-extra packages
  supplement kernel-$flavor on openSUSE and SLED so that those
  packages will get installed by default, using the product(...)
  dependencies provided by the *-release packages.
* Thu Oct 16 2008 tonyj@suse.de
- Previous checkin was totally broken wrt rt config files.
  Revert to previous versions and incorporate any changes from
  run_oldconfig. Sole changes to previous versions is to remove
  CONFIG_DYNAMIC_FTRACE from rt_debug configs which is consistent
  with change in 2.6.27.1
* Thu Oct 16 2008 gregkh@suse.de
- Update to 2.6.27.1
  - disables a problem config option, only affected the vanilla,
    debug, and rt kernel variants.
* Wed Oct 15 2008 olh@suse.de
- add patches.arch/ppc-pseries_pfn-mem-rm.patch
  fix hotplug memory remove (bnc#435181 - LTC48640)
* Wed Oct 15 2008 mmarek@suse.cz
- rpm/post.sh, rpm/postun.sh: run weak-modules, depmod and mkinitrd
  on older distros (bnc#435246)
  Fixed fix for bnc#435104 ("/boot/" was missing in some places)
* Wed Oct 15 2008 mmarek@suse.cz
- rpm/kernel-binary.spec.in: don't recommend the -extra subpackage
  (fate#303631)
- rpm/postun.sh, rpm/post.sh: remove the temporary workaround
* Wed Oct 15 2008 olh@suse.de
- drop patches.arch/ppc-iseries-remove-AVAILABLE_VETH.patch
  not needed anymore
* Wed Oct 15 2008 nfbrown@suse.de
- patches.fixes/nfs-file-cred-context-null: nfs_file_cred should
  cope if 'file' hasn't been opened properly (bnc#431785).
* Wed Oct 15 2008 tonyj@suse.de
- Update RT patches to latest .27 Windriver version (all patches)
- Disable patches.rt/swap-spinlock-fix.patch
- Guard filp-slab-rcu for RT
* Tue Oct 14 2008 jkosina@suse.de
- patches.fixes/input-add-acer-aspire-5710-to-nomux.patch: Input:
  Add Acer Aspire 5710 to nomux blacklist (bnc#404881).
* Tue Oct 14 2008 oneukum@suse.de
- patches.fixes/ehci_sched.diff: Delete.
  in mainline now. done to the right tree.
* Tue Oct 14 2008 mmarek@suse.cz
- rpm/postun.sh, rpm/post.sh: temporarily ignore errors from
  weak-modules2 --{add,remove}-kernel-modules until
  module-init-tools has rebuilt
* Tue Oct 14 2008 jkosina@suse.de
- patches.fixes/input-add-amilo-pro-v-to-nomux.patch: Delete.
  The patch is already upstream in 2.6.27
* Tue Oct 14 2008 jeffm@suse.de
- patches.suse/osync-error: Update position after check for -EIO
  (bnc#434910).
* Tue Oct 14 2008 npiggin@suse.de
- patches.suse/rlimit-memlock-64k.patch: Increase default
  RLIMIT_MEMLOCK to 64k (bnc#329675).
* Tue Oct 14 2008 sjayaraman@suse.de
- Update config files: CIFS_EXPERIMENTAL=y and CIFS_DFS_UPCALL=y
  (FATE#303758).
* Tue Oct 14 2008 jbeulich@novell.com
- patches.xen/xen-irq-probe: restrict IRQ probing (bnc#431572).
* Tue Oct 14 2008 ptesarik@suse.cz
- patches.trace/utrace-core: undo overzealous #ifdef's, which
  removed too much code in case UTRACE_CONFIG was unset.
* Tue Oct 14 2008 jbeulich@novell.com
- patches.fixes/reiserfs-commit-ids-unsigned-ints: Remove L suffix
  from constant compared against.
* Tue Oct 14 2008 olh@suse.de
- call bootloader_entry without leading /boot/ (bnc#435104)
* Tue Oct 14 2008 mmarek@suse.cz
- rpm/kernel-source.spec.in, rpm/source-post.sh, rpm/functions.sh:
  kill functions.sh, put the relink() function to source-post.sh
  directly
- rpm/postun.sh, rpm/pre.sh, rpm/preun.sh, rpm/post.sh,
  rpm/kernel-binary.spec.in: unify generation of the scriptlets,
  switch to the new weak-modules2 script
* Tue Oct 14 2008 olh@suse.de
- disable unused ide_platform driver
* Tue Oct 14 2008 jdelvare@suse.de
- supported.conf: Remove i2c-core and i2c-piix4 from base.
* Tue Oct 14 2008 gregkh@suse.de
- supported.conf: remove ide-core and ide-cdrom from base on request
  from Tejun.
* Tue Oct 14 2008 gregkh@suse.de
- Update config files.
- patches.drivers/staging-add-pcc-acpi-driver.patch: Staging:
  add pcc-acpi driver.
- rpm/kernel-binary.spec.in: Obsoletes pcc-acpi-kmp
* Tue Oct 14 2008 gregkh@suse.de
- rpm/kernel-binary.spec.in: it's pcc-acpi and it's not obsolete, yet.
* Tue Oct 14 2008 gregkh@suse.de
- rpm/kernel-binary.spec.in: obsoletes at76_usb-kmp
* Tue Oct 14 2008 gregkh@suse.de
- rpm/kernel-binary.spec.in: obsoletes et131x-kmp, ivtv-kmp, and
  ppc-acpi-kmp
* Mon Oct 13 2008 gregkh@suse.de
- Update config files.
- patches.drivers/staging-at76_usb-wireless-driver.patch: staging:
  at76_usb wireless driver.
* Mon Oct 13 2008 gregkh@suse.de
- refresh all patches (except xen and rt) to apply cleanly
* Mon Oct 13 2008 gregkh@suse.de
- rpm/kernel-binary.spec.in: add Obsoletes: wlan-ng-kmp as the needed
  driver is now included from the staging tree.
* Mon Oct 13 2008 gregkh@suse.de
- put proper Patch-mainline: markings on staging patches
* Mon Oct 13 2008 gregkh@suse.de
- patches.drivers/staging-workaround-build-system-bug.patch:
  Staging: workaround build system bug.
* Mon Oct 13 2008 aj@suse.de
- rpm/post.sh: Fix typo that breaks script.
* Mon Oct 13 2008 gregkh@suse.de
- disabled staging drivers for -rt trees
* Mon Oct 13 2008 gregkh@suse.de
- Add -staging tree:
  - added TAINT_CRAP flag
  - added eth131x network driver
  - added slicoss network driver
  - added sgx network driver
  - added me4000 data collection driver
  - added go7007 video capture driver
  - added USB/IP host and client driver
  - added w35und wifi network driver
  - added prism2 usb wifi network driver
  - added echo cancellation driver
- only enabled these on x86 platforms
* Mon Oct 13 2008 jjolly@suse.de
- patches.arch/s390-02-01-xpram.patch: xpram: per device block
  request queues (bnc#434333,LTC#49030)
* Mon Oct 13 2008 jeffm@suse.de
- rpm/kernel-binary.spec.in: Updated supported.conf checker to
  eliminate false positives.
* Mon Oct 13 2008 sjayaraman@suse.de
- patches.suse/SoN-14-mm-reserve.patch: Fix a compiler warning.
* Mon Oct 13 2008 jbenc@suse.cz
- supported.conf: mark drivers/net/wireless/b43* and
  driver/net/wireless/rt2x00/* as unsupported because of known
  problems we cannot fix.
* Mon Oct 13 2008 oneukum@suse.de
- patches.fixes/wdm_autoload.diff:  add MODULE_DEVICE_TABLE to
  cdc-wdm driver to compute a proper alias (bnc#433817).
* Mon Oct 13 2008 ptesarik@suse.cz
- Update config files (CONFIG_UTRACE for rt flavours).
* Mon Oct 13 2008 jbeulich@novell.com
- patches.xen/xen3-patch-2.6.27-rc3: Fix uninitialized data issue.
* Mon Oct 13 2008 ptesarik@suse.cz
- patches.trace/utrace-core: utrace core (FATE#304321).
  CONFIG_UTRACE enabled only for kernel-trace.
- Update config files.
* Mon Oct 13 2008 aj@suse.de
- patches.suse/SoN-14-mm-reserve.patch: Add cast to fix compiler warning.
* Mon Oct 13 2008 sjayaraman@suse.de
- Remove another stale swap-over-nfs patch.
  patches.suse/SoN-29-nfs-alloc-recursions.patch: Delete.
* Fri Oct 10 2008 jeffm@suse.de
- Updated to 2.6.27 final.
* Fri Oct 10 2008 tonyj@suse.de
- Update config files
- Fix conflicts, remove most -RT guards added in recent RT update
  patches.rt/apic-dumpstack.patch: refresh
  patches.rt/preempt-irqs-core.patch: refresh
  patches.rt/print-might-sleep-hack.patch: refresh
  patches.rt/partrevert-lttng-instrumentation-irq.patch: add
  patches.rt/partreadd-lttng-instrumentation-irq.patch: add
- Drop unused RT patches
  patches.rt/mips-change-raw-spinlock-type.patch
  patches.rt/nmi-watchdog-disable.patch
  patches.rt/Add-dev-rmem-device-driver-for-real-time-JVM-testing.patch
  patches.rt/lockstat-fix-contention-points.patch
  patches.rt/sched-cpupri-priocount.patch
  patches.rt/nmi-watchdog-fix-1.patch
  patches.rt/cache_pci_find_capability.patch
  patches.rt/fix-emac-locking-2.6.16.patch
  patches.rt/2.6.21-rc6-lockless5-lockless-probe.patch
  patches.rt/watchdog_use_timer_and_hpet_on_x86_64.patch
  patches.rt/tie-pi-into-task.patch
  patches.rt/idle2-fix.patch
  patches.rt/2.6.21-rc6-lockless6-speculative-get-page.patch
  patches.rt/rtmutex-initialize-waiters.patch
  patches.rt/Allocate-RTSJ-memory-for-TCK-conformance-test.patch
  patches.rt/add-generalized-pi-interface.patch
  patches.rt/warn-on-rt-scatterlist.patch
  patches.rt/2.6.21-rc6-lockless7-lockless-pagecache-lookups.patch
  patches.rt/trace-eip2ip.patch
  patches.rt/sched_rt-fixup.patch
  patches.rt/2.6.21-rc6-lockless3-radix-tree-gang-slot-lookups.patch
  patches.rt/trace_hist-latediv.patch
  patches.rt/sched-cpupri-hotplug-support.patch
  patches.rt/idle-fix.patch
  patches.rt/ftrace-fix-get-kprobe-wreckage.patch
  patches.rt/no-warning-for-irqs-disabled-in-local-bh-enable.patch
  patches.rt/ftrace-function-record-nop.patch
  patches.rt/ftrace-document-update1.patch
  patches.rt/26-rt1-chirag.patch
  patches.rt/trace_hist-divzero.patch
  patches.rt/latency-tracing-ppc.patch
  patches.rt/rtmutex-defer-pi-until-sleepy.patch
  patches.rt/pmtmr-override.patch
  patches.rt/sched-prioritize-non-migrating-rt-tasks.patch
  patches.rt/rtmutex-use-runtime-init.patch
  patches.rt/ftrace-fix-elevated-preempt-count-in-wakeup-tracer.patch
  patches.rt/2.6.21-rc6-lockless8-spinlock-tree_lock.patch
  patches.rt/lockdep-lock_set_subclass.patch
  patches.rt/seqlock-make-raw-seqlocks-spin-during-write.patch
  patches.rt/rt-mutex-irq-flags-checking.patch
  patches.rt/ftrace-upstream.patch
  patches.rt/sched-use-a-2d-bitmap-search-prio-cpu.patch
  patches.rt/ftrace-preempt-trace-check.patch
  patches.rt/rtmutex-add_readers.patch
  patches.rt/lockdep-avoid-fork-waring.patch
  patches.rt/arm-omap-02.patch
  patches.rt/fix-acpi-build-weirdness.patch
  patches.rt/cycles-to-ns-trace-fix.patch
  patches.rt/ftrace-compile-fixes.patch
  patches.rt/ftrace-wakeup-rawspinlock.patch
  patches.rt/rtmutex-convert-to-libpi.patch
  patches.rt/m68knommu_fixes_ontop_of_v2.6.26.patch
  patches.rt/ftrace-trace-sched.patch
* Fri Oct 10 2008 mfasheh@suse.com
- supported.conf: mark kernel/fs/gfs2 unsupported
* Fri Oct 10 2008 gregkh@suse.de
- supported.conf: mark kernel/sound/pci/snd-cs5530 unsupported due
  to sb16 dependancy issues
* Fri Oct 10 2008 jeffm@suse.de
- patches.fixes/account-reserved-pages: Delete.
* Thu Oct  9 2008 jeffm@suse.de
- patches.suse/supported-flag-sysfs: Updated to build with
  CONFIG_MODULES=n.
* Thu Oct  9 2008 jeffm@suse.de
- Updated to 2.6.27-rc9, but still disabled:
  - patches.suse/silent-stack-overflow
  - patches.xen/xen3-silent-stack-overflow
* Thu Oct  9 2008 gregkh@suse.de
- supported.conf: thermal_sys, not thermal_sysfs.
* Thu Oct  9 2008 jeffm@suse.de
- patches.rt/hrtimers-stuck-in-waitqueue.patch: Updated against
  2.6.27-rc9.
* Thu Oct  9 2008 jdelvare@suse.de
- supported.conf: Fix the name of the thermal_sys module.
- config/x86_64/rt_timing: THERMAL_HWMON is a boolean.
* Thu Oct  9 2008 jeffm@suse.de
- patches.suse/netfilter-ipv4options: Updated to 2.6.27-rc9,
  enabled, and marked supported (bnc#131728 - FATE#182).
* Thu Oct  9 2008 jeffm@suse.de
- patches.fixes/serial8250_console_write-ier: Delete.
- patches.fixes/fix-serial-8250-UART_BUG_TXEN-test: Delete.
* Thu Oct  9 2008 gregkh@suse.de
- supported.conf: mark kernel/sound/pci/snd-als4000 unsupported due
  to dependancy on isa sb16 driver.
* Thu Oct  9 2008 jeffm@suse.de
- patches.fixes/dont-writeback-fd-bdev-inodes.patch: Delete.
- patches.arch/s390-ccwgroup-attribute-ignore-newline: Delete.
* Thu Oct  9 2008 gregkh@suse.de
- supported.conf: mark drivers/net/wan/hdlc_x25 unsupported due to
  symbol dependancy tree.
* Thu Oct  9 2008 jeffm@suse.de
- patches.suse/osync-error: make sure O_SYNC writes properly
  return -EIO (bnc#58622).
* Thu Oct  9 2008 bwalle@suse.de
- patches.arch/ppc-vmcoreinfo.diff:
  Add additional symbols to /sys/kernel/vmcoreinfo data for
  ppc(64).
* Thu Oct  9 2008 trenn@suse.de
- patches.xen/xen-x2APIC_build_fix.patch: Adopt Xen to x2APIC
  patchset (fate#303984 and fate#303948).
- Update config files.
  Disable interrupt remapping for Xen -> this is something for
  the hypervisor.
* Thu Oct  9 2008 jeffm@suse.de
- Update config files: THERMAL_HWMON=y in vanilla configs.
* Thu Oct  9 2008 jeffm@suse.de
- Update config files: THERMAL_HWMON=y; is boolean and enables
  functionality in the already modular THERMAL module.
* Thu Oct  9 2008 jeffm@suse.de
- patches.suse/supported-flag-sysfs: Export supported status
  via sysfs.
* Thu Oct  9 2008 carnold@novell.com
- Update config files.  Disabled the in kernel KVM modules in
  preference to using them as KMPs.  See also brogers@novell.com
* Thu Oct  9 2008 jeffm@suse.de
- Added a -iu|--ignore-unsupported-deps option to allow builds
  with supported.conf problems.
* Thu Oct  9 2008 jdelvare@suse.de
- config/i386/*, config/x86_64/*, config/ia64/*, supported.conf:
  Build hwmon and thermal as modules.
* Thu Oct  9 2008 gregkh@suse.de
- supported.conf: mark hdlc_ppp unsupported as syncppp is unsupported.
* Thu Oct  9 2008 gregkh@suse.de
- supported.conf: mark ubifs as unsupported as it relies on mtd/ubi/
* Thu Oct  9 2008 bwalle@suse.de
- patches.arch/ppc-dynamic-reconfiguration.diff:
  powerpc: Add support for dynamic reconfiguration memory in
  kexec/kdump kernels (bnc#431492).
* Thu Oct  9 2008 carnold@novell.com
- rpm/kernel-binary.spec.in: package kernel-xen has dependency to
  xen (bnc#431215).
* Thu Oct  9 2008 gregkh@suse.de
- supported.conf: mark TPM drivers a supported, as IBM and others
  rely on them.
* Thu Oct  9 2008 gregkh@suse.de
- supported.conf: fix a dependancy link with the isa sb driver with
  unsupported symbols
* Thu Oct  9 2008 gregkh@suse.de
- supported.conf: mark ieee80122 modules as supported, as other
  supported modules need them.
* Thu Oct  9 2008 gregkh@suse.de
- supported.conf: mark all of the mtd drivers as unsupported to fix
  the build errors (and to reflect our policy here.)
* Thu Oct  9 2008 bwalle@suse.de
- Set CONFIG_KDB_CONTINUE_CATASTROPHIC to 0 (bnc#429910).
* Thu Oct  9 2008 jdelvare@suse.de
- Don't build the tps65010 driver, it's only used on OMAP at the
  moment.
* Thu Oct  9 2008 mmarek@suse.cz
- rpm/built-in-where: make it work with a four-column
  Modules.symvers (bnc#433533)
* Thu Oct  9 2008 bwalle@suse.de
- Update KDB to v4.4-2.6.27-rc8.
* Thu Oct  9 2008 olh@suse.de
- disable legacy iseries (bnc#433685 - LTC48946)
* Thu Oct  9 2008 olh@suse.de
- enable battery_pmu on ppc32
* Thu Oct  9 2008 trenn@suse.de
- supported.conf:
  Marked these unsupported:
  cpufreq-nforce2
  e_powersaver
  gx-suspmod
  longhaul
  longrun
  p4-clockmod
  powernow-k6
  powernow-k7
  speedstep-ich
  speedstep-smi
  Even Via CPUs are exporting cpu freq steps via ACPI and work fine
  with acpi-cpufreq. No need to support the old, some are known
  broken, drivers.
* Thu Oct  9 2008 olh@suse.de
- add patches.suse/md-raid-metadata-PAGE_SIZE.patch
  ignore PAGE_SIZE in md metadata, for raid0 (bnc#429490)
* Thu Oct  9 2008 teheo@suse.de
- patches.xen/xen3-auto-common.diff: minor patch apply fix after
  libata-prefer-over-ide.
* Thu Oct  9 2008 teheo@suse.de
- patches.drivers/libata-prefer-over-ide: libata: prefer libata
  drivers over ide ones (bnc#433105).
* Wed Oct  8 2008 carnold@novell.com
- patches.xen/xen-op-packet: add support for new operation type
  BLKIF_OP_PACKET (fate#300964).
- patches.xen/xen-blkfront-cdrom: implement forwarding of CD-ROM
  specific commands (fate#300964).
* Wed Oct  8 2008 gregkh@suse.de
- supported.conf: major update.  Lots of new drivers added as this
  file hadn't been updated for a lot of kernel revisions.
  This should close out a lot of bugs about "unsupported" modules,
  like bnc#433541.
* Wed Oct  8 2008 gregkh@suse.de
- supported.conf: sorted the file correctly so we can start determining
  what we are not supporting easier.
* Wed Oct  8 2008 jeffm@suse.de
- Updated -rt for context against -rc9 and the x2APIC patches:
  - patches.rt/new-softirq-code.patch
  - patches.rt/preempt-irqs-core.patch
  - patches.rt/preempt-irqs-x86-64-ioapic-mask-quirk.patch
  - CONFIG_INTR_REMAP=n for now
  - patches.rt/preempt-softirqs-core.patch
  - patches.rt/rt-slab-new.patch
  - patches.rt/slab-irq-nopreempt-fix.patch
  - Update config files: NFS_SWAP=n
* Wed Oct  8 2008 trenn@suse.de
  x2APIC and interrupt remapping enablement.
  Xen needs further work to build again.
  Commit ids are from x86 tip git tree:
- patches.arch/x2APIC_fix_section_mismatch.patch: Fix several
  section mismatches (none).
- patches.arch/x2APIC_PATCH_01_0f4896665a02b465ddca59a560983b24ec28c64b:
  dmar: fix dmar_parse_dev() devices_cnt error condition check
  (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_01_of_41_e61d98d8dad0048619bb138b0ff996422ffae53b:
  x64, x2apic/intr-remap: Intel vt-d, IOMMU code reorganization
  (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_02_228324076234ca6a8cd34be89be78022773459f1:
  dmar: use list_for_each_entry_safe() in dmar_dev_scope_init()
  (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_02_of_41_c42d9f32443397aed2d37d37df161392e6a5862f:
  x64, x2apic/intr-remap: fix the need for sequential array
  allocation of iommus (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_03_3f1fdb3673bb5638fa94186dc391cbc4879590bc:
  dmar: initialize the return value in dmar_parse_dev() (fate
  [#303948] and fate #303984).
- patches.arch/x2APIC_PATCH_03_of_41_1886e8a90a580f3ad343f2065c84c1b9e1dac9ef:
  x64, x2apic/intr-remap: code re-structuring, to be used by both
  DMA and Interrupt remapping (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_04_f12c73e7fa7ebf9ad6defee2c4fb2664e743e970:
  dmar: fix using early fixmap mapping for DMAR table parsing
  (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_04_of_41_aaa9d1dd63bf89b62f4ea9f46de376ab1a3fbc6c:
  x64, x2apic/intr-remap: use CONFIG_DMAR for DMA-remapping
  specific code (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_05_7be42004065ce4df193aeef5befd26805267d0d9:
  x86, lguest: fix apic_ops build on UP (fate #303948 and fate
  [#303984]).
- patches.arch/x2APIC_PATCH_06_caf43bf7c6a55e89b6df5179df434d67e24aa32e:
  x86, xen: fix apic_ops build on UP (fate #303948 and fate
  [#303984]).
- patches.arch/x2APIC_PATCH_06_of_41_ad3ad3f6a2caebf56869b83b69e23eb9fa5e0ab6:
  x64, x2apic/intr-remap: parse ioapic scope under vt-d structures
  (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_07_511d9d34183662aada3890883e860b151d707e22:
  x86: apic_ops for lguest (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_07_of_41_cf1337f0447e5be8e66daa944f0ea3bcac2b6179:
  x64, x2apic/intr-remap: move IOMMU_WAIT_OP() macro to
  intel-iommu.h (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_08_of_41_fe962e90cb17a8426e144dee970e77ed789d98ee:
  x64, x2apic/intr-remap: Queued invalidation infrastructure
  (part of VT-d) (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_09_94a8c3c2437c8946f1b6c8e0b2c560a7db8ed3c6:
  x86: let 32bit use apic_ops too - fix (fate #303948 and fate
  [#303984]).
- patches.arch/x2APIC_PATCH_09_of_41_2ae21010694e56461a63bfc80e960090ce0a5ed9:
  x64, x2apic/intr-remap: Interrupt remapping infrastructure
  (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_10_of_41_b6fcb33ad6c05f152a672f7c96c1fab006527b80:
  x64, x2apic/intr-remap: routines managing Interrupt remapping
  table entries. (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_11_of_41_72b1e22dfcad1daca6906148fd956ffe404bb0bc:
  x64, x2apic/intr-remap: generic irq migration support from
  process context (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_12_of_41_d94d93ca5cc36cd78c532def62772c98fe8ba5d7:
  x64, x2apic/intr-remap: 8259 specific mask/unmask routines
  (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_13_of_41_4dc2f96cacd1e74c688f94348a3bfd0a980817d5:
  x64, x2apic/intr-remap: ioapic routines which deal with initial
  io-apic RTE setup (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_14_of_41_0c81c746f9bdbfaafe64322d540c8b7b59c27314:
  x64, x2apic/intr-remap: introduce read_apic_id() to genapic
  routines (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_15_of_41_2d7a66d02e11af9ab8e16c76d22767e622b4e3d7:
  x64, x2apic/intr-remap: Interrupt-remapping and x2apic support,
  fix (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_16_of_41_1b374e4d6f8b3eb2fcd034fcc24ea8ba1dfde7aa:
  x64, x2apic/intr-remap: basic apic ops support (fate #303948
  and fate #303984).
- patches.arch/x2APIC_PATCH_17_of_41_32e1d0a0651004f5fe47f85a2a5c725ad579a90c:
  x64, x2apic/intr-remap: cpuid bits for x2apic feature (fate
  [#303948] and fate #303984).
- patches.arch/x2APIC_PATCH_18_of_41_1cb11583a6c4ceda7426eb36f7bf0419da8dfbc2:
  x64, x2apic/intr-remap: disable DMA-remapping if
  Interrupt-remapping is detected (temporary quirk) (fate #303948
  and fate #303984).
- patches.arch/x2APIC_PATCH_19_of_41_13c88fb58d0112d47f7839f24a755715c6218822:
  x64, x2apic/intr-remap: x2apic ops for x2apic mode support
  (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_20_of_41_cff73a6ffaed726780b001937d2a42efde553922:
  x64, x2apic/intr-remap: introcude self IPI to genapic routines
  (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_21_of_41_12a67cf6851871ca8df42025c94f140c303d0f7f:
  x64, x2apic/intr-remap: x2apic cluster mode support (fate
  [#303948] and fate #303984).
- patches.arch/x2APIC_PATCH_22_of_41_5c520a6724e912a7e6153b7597192edad6752750:
  x64, x2apic/intr-remap: setup init_apic_ldr for UV (fate
  [#303948] and fate #303984).
- patches.arch/x2APIC_PATCH_23_of_41_89027d35aa5b8f45ce0f7fa0911db85b46563da0:
  x64, x2apic/intr-remap: IO-APIC support for interrupt-remapping
  (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_24_of_41_75c46fa61bc5b4ccd20a168ff325c58771248fcd:
  x64, x2apic/intr-remap: MSI and MSI-X support for interrupt
  remapping infrastructure (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_25_1_of_41_4c9961d56ec20c27ec5d02e49fd7427748312741:
  x86: make read_apic_id return final apicid (fate #303948 and
  fate #303984).
- patches.arch/x2APIC_PATCH_25_2_of_41_c535b6a1a685eb23f96e2c221777d6c1e05080d5:
  x86: let 32bit use apic_ops too (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_25_of_41_6e1cb38a2aef7680975e71f23de187859ee8b158:
  x64, x2apic/intr-remap: add x2apic support, including enabling
  interrupt-remapping (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_26_of_41_2d9579a124d746a3e0e0ba45e57d80800ee80807:
  x64, x2apic/intr-remap: support for x2apic physical mode support
  (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_27_of_41_9fa8c481b55e80edd8c637573f87853bb6b600f5:
  x64, x2apic/intr-remap: introduce CONFIG_INTR_REMAP (fate
  [#303948] and fate #303984).
- patches.arch/x2APIC_PATCH_28_1_of_41_f910a9dc7c865896815e2a95fe33363e9522f277:
  x86: make 64bit have get_apic_id (fate #303948 and fate
  [#303984]).
- patches.arch/x2APIC_PATCH_29_of_41_277d1f5846d84e16760131a93b7a67ebfa8eded4:
  x2apic: uninline uv_init_apic_ldr() (fate #303948 and fate
  [#303984]).
- patches.arch/x2APIC_PATCH_30_of_41_ad66dd340f561bdde2285992314d9e4fd9b6191e:
  x2apic: xen64 paravirt basic apic ops (fate #303948 and fate
  [#303984]).
- patches.arch/x2APIC_PATCH_34_of_41_1b9b89e7f163336ad84200b66a17284dbf26aced:
  x86: add apic probe for genapic 64bit, v2 (fate #303948 and
  fate #303984).
- patches.arch/x2APIC_PATCH_35_of_41_d25ae38b7e005af03843833bbd811ffe8c5f8cb4:
  x86: add apic probe for genapic 64bit - fix (fate #303948 and
  fate #303984).
- patches.arch/x2APIC_PATCH_36_of_41_276605dddb74cbf1b77696e32c4a947e42cec52d:
  x2apic: use x2apic id reported by cpuid during topology
  discovery (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_40_of_41_bbb65d2d365efe9951290e61678dcf81ec60add4:
  x86: use cpuid vector 0xb when available for detecting cpu
  topology (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_41_of_41_11c231a962c740b3216eb6565149ae5a7944cba7:
  x86: use x2apic id reported by cpuid during topology discovery,
  fix (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_42_of_41_77322deb4bc676a5ee645444e7ed1a89f854473d:
  x86: io-apic - interrupt remapping fix (fate #303948 and
  fate #303984).
- patches.arch/x2APIC_PATCH_43_of_41_2c72d93f6593f386f5760ca8e7ac7026948c31d7:
  x2apic: fix reserved APIC register accesses in
  print_local_APIC() (fate #303948 and fate #303984).
- patches.drivers/sgi-uv-led: SGI UV: Provide a LED driver and
  some System Activity Indicators (FATE#304268).
- patches.suse/kdb-x86: kdb-v4.4-2.6.27-rc5-x86-1 (FATE#303971).
- patches.xen/xen-x86-no-lapic: Disallow all accesses to the
  local APIC page (191115).
- patches.xen/xen3-auto-arch-x86.diff: xen3 arch-x86.
- patches.xen/xen3-patch-2.6.19: Linux 2.6.19.
- patches.xen/xen3-patch-2.6.26: 2.6.26.
- Update config files:
  Added CONFIG_INTR_REMAP to all x86_64 flavors
* Wed Oct  8 2008 gregkh@suse.de
- rpm/kernel-binary.spec.in: added Obsoletes: atl2-kmp as this
  driver is now included in the kernel package.
* Wed Oct  8 2008 jjolly@suse.de
- patches.arch/s390-01-04-fcpperf-4-v2.patch: Update for fcpperf-4
  patch to bring in sync with upstream version. (bnc#417243)
- patches.arch/s390-01-04-fcpperf-4.patch: Removed, replaced by
  updated patch
* Wed Oct  8 2008 sjayaraman@suse.de
- Remove stale swap-over-nfs patches.
- patches.suse/SoN-05-page_alloc-reserve.patch: Delete.
- patches.suse/SoN-06-reserve-slub.patch: Delete.
* Wed Oct  8 2008 agruen@suse.de
- No uml patches left, so remove the code referring to
  patches.uml.tar.bz2.
* Wed Oct  8 2008 ghaskins@suse.de
  Guarded by +RT
- patches.rt/fix-up-comment.patch: RT: Remove comment that is
  no longer true.
- patches.rt/check-for-migration-during-push.patch: RT: fix
  push_rt_task() to handle dequeue_pushable properly.
* Wed Oct  8 2008 agruen@suse.de
- Add DMAPI patches (supported by SGI).
- Update config files: enable DMAPI.
* Wed Oct  8 2008 sjayaraman@suse.de
- Doh, forgot to remove stale files from cvs
- Update config files NFS_SWAP=y.
* Wed Oct  8 2008 sjayaraman@suse.de
- Refreshed to -v19 of swap over nfs patchset.
  o netns, ipv6 fixes
  o patch ordering changes due to additional patches
- Adjust patches.xen/xen3-auto-common.diff to avoid conflict.
* Wed Oct  8 2008 bwalle@suse.de
- Enable CONFIG_MFD_SM501_GPIO also for RT.
* Wed Oct  8 2008 bwalle@suse.de
- Refresh patches.rt/mips-remove-duplicate-kconfig.patch.
* Wed Oct  8 2008 bwalle@suse.de
- Update to 2.6.27-rc9.
- Enable new configuration option CONFIG_MFD_SM501_GPIO.
- Drop following patches (mainline):
  o patches.suse/e1000e_debug_contention_on_NVM_SWFLAG
  o patches.suse/e1000e_do_not_ever_sleep_in_interrupt_context
  o patches.suse/e1000e_drop_stats_lock, e1000e_fix_lockdep_issues
  o patches.suse/e1000e_mmap_range_chk,
  o patches.suse/e1000e_reset_swflag_after_resetting_hardware
  o patches.suse/e1000e_update_versione1000e_write_protect_ichx_nvm
- Adjust/refresh following patches:
  o patches.arch/s390-01-03-cmm2-v2.patch
  o patches.drivers/e1000e_add_82574L.patch
  o patches.drivers/e1000e_add_ICH9_BM.patch
  o patches.drivers/e1000e_add_LOM_devices.patch
  o patches.suse/e1000e_allow_bad_checksum
  o patches.suse/e1000e_call_dump_eeprom
  o patches.suse/e1000e_ioremap_sanity_check
  o patches.suse/e1000e_use_set_memory_ro-rw_to_protect_flash_memory
* Wed Oct  8 2008 mmarek@suse.cz
- rpm/kernel-module-subpackage: switch KMPs to the new
  weak-modules2 script, which handles running depmod and mkinitrd
* Wed Oct  8 2008 hare@suse.de
- supported.conf: mark igb as supported.
* Wed Oct  8 2008 agruen@suse.de
- kernel-source-rt must not provide a kernel-source symbol: this
  would break dependencies.
* Wed Oct  8 2008 olh@suse.de
- update patches.suse/ppc-no-LDFLAGS_MODULE.patch
  use suggested patch from kernel.org bugzilla
* Wed Oct  8 2008 olh@suse.de
- add patches.arch/ppc-pseries_remove_lmb-PAGE_SHIFTT.patch
  fix oops in pseries_remove_lmb with 64k PAGE_SIZE (bnc#431380)
* Wed Oct  8 2008 gregkh@suse.de
- supported.conf: mark efivars.ko as supported
* Wed Oct  8 2008 gregkh@suse.de
- enable yealink driver (bnc#432841)
* Tue Oct  7 2008 oneukum@suse.de
- patches.fixes/ehci_sched.diff: fix hang in disable_periodic
  (bnc#403346).
* Tue Oct  7 2008 trenn@suse.de
- patches.fixes/fujisu_laptop_fix_section_mismatch.patch: Fix
  section mismatch in fujitsu_laptop driver (none).
* Tue Oct  7 2008 hare@suse.de
- patches.fixes/sd-needs-updating: Driver 'sd' needs updating
  (bnc#406656).
* Tue Oct  7 2008 agruen@suse.de
- rpm/post.sh: Catch mkinitrd error code indicating missing
  required modules. Only add a bootloader entry if an initrd
  could be created, but re-add the bootloader entry even if
  the initrd already existed before (bnc#431703).
* Tue Oct  7 2008 hare@suse.de
- patches.drivers/lpfc-8.2.8.4-update: Update lpfc to 8.2.8.4
  (bnc#420767).
- patches.drivers/qla4xxx-sles11-update: qla4xxx driver fixes
  for SLES11 (bnc#432976).
* Tue Oct  7 2008 olh@suse.de
- mark legacy iseries storage as supported
* Mon Oct  6 2008 jdelvare@suse.de
- supported.conf: Add the ad7414, adcxx and ibmaem hwmon drivers as
  unsupported.
* Mon Oct  6 2008 jdelvare@suse.de
- config/ia64/*: Don't built i2c-amd756-s4882 and i2c-nforce2-s4985
  on ia64, these are motherboard-specific drivers for x86_64
  motherboards.
- config/powerpc/*: Don't built i2c-isch on powerpc, it is a driver
  for x86 hardware.
- config/*: Don't built i2c-simtec on i386, x86_64 and ia64, there
  is no Simtec hardware based on these architectures.
* Sun Oct  5 2008 agruen@suse.de
- rpm/kernel-binary.spec.in: Fix the logic splitting up the symbols
  defined in vmlinux by subsystem. (Actually, per directory, under
  the assumption that there is enough of a correlation).
* Sun Oct  5 2008 greg@suse.de
- supported.conf: add ohci-hcd to base.  Fix up other USB drivers
  (USB network drivers had moved, others were missing)
* Sun Oct  5 2008 gregkh@suse.de
- patches.drivers/atl2-add-atl2-network-driver.patch: atl2:
  add atl2 network driver.
- Update config files (even the rt ones).
* Fri Oct  3 2008 jkosina@suse.de
- patches.suse/e1000e_debug_contention_on_NVM_SWFLAG: fix bogus
  WARN_ON() condition, as per upstream commit 95b866d5a
* Fri Oct  3 2008 olh@suse.de
- mark ibmvfc as supported (bnc#417555 - fate#304178 - LTC46935)
* Fri Oct  3 2008 olh@suse.de
- compile windfarm_pm121 into the kernel
* Fri Oct  3 2008 jeffm@suse.de
- doc/README.SUSE, scripts/tar-up_and_run_mbuild.sh,
  scripts/run_oldconfig.sh,
  scripts/sequence-patch.sh: Eliminated defconfig.$flavor
* Fri Oct  3 2008 olh@suse.de
- mark Cell drivers as supported
* Fri Oct  3 2008 tonyj@suse.de
- Update config files
  rt configs not updated for per-module-dynamic-debug-messages.patch
* Fri Oct  3 2008 gregkh@suse.de
- change patches.suse/supported-flag to show which modules are
  unsupported and externally supported in oops messages.  Also change
  the taint values as the documentation was totally wrong.
* Fri Oct  3 2008 tonyj@suse.de
- Reenable RT debug builds, compile tested only
- Update config files
- Fix tracer issues
  patches.rt/event-trace-hrtimer-trace.patch
  patches.rt/trace-events-handle-syscalls.patch
  patches.rt/trace-ktime-scalar.patch
  patches.rt/tracer-event-trace.patch
- patches.rt/kdb-disable-ist.patch: Disable stackfault and debug stacks for kdb
- patches.rt/kdb-rtmisc.patch: Misc KDB fixes for RT
- patches.rt/novfs-rtmisc.patch: Misc NOVFS fixes for RT
* Fri Oct  3 2008 gregkh@suse.de
- patches.drivers/driver-core-basic-infrastructure-for-per-module-dynamic-debug-messages.patch:
  driver core: basic infrastructure for per-module dynamic
  debug messages.
- refresh patches.trace/tracepoints.patch: Kernel Tracepoints.
- Update config files.
* Thu Oct  2 2008 agruen@suse.de
- Introduce kernel-source-rt and kernel-syms-rt packages, needed
  for building real-time KMPs.
* Thu Oct  2 2008 schwab@suse.de
- Don't clean <asm/nr-irqs.h>.
* Thu Oct  2 2008 jblunck@suse.de
- supported.conf: add qeth_l2 and qeth_l3 as supported modules
* Thu Oct  2 2008 jkosina@suse.de
- patches.suse/e1000e_write_protect_ichx_nvm: e1000e: update to
  the latest version of the patch as provided by Intel
* Thu Oct  2 2008 jbeulich@novell.com
- Update Xen patches to 2.6.27-rc8 and c/s 684.
- patches.xen/xen-e1000e_Export_set_memory_ro-rw: Replace by ...
- patches.xen/xen3-e1000e_Export_set_memory_ro-rw: this, and put
  in proper place in series.conf.
- patches.xen/xen-rwlocks-enable-interrupts: Replace by ...
- patches.xen/xen3-rwlocks-enable-interrupts: this, and put in
  proper place in series.conf.
* Wed Oct  1 2008 jeffm@suse.de
- scripts/sequence-patch.sh
- scripts/run_oldconfig.sh: x86 defconfigs go under arch/x86.
* Wed Oct  1 2008 olh@suse.de
- enable msi on ppc64 (bnc#430937)
* Wed Oct  1 2008 tiwai@suse.de
- rpm/kernel-source.spec.in: Remove /lib/modules from file list
  as it's already in filesystem
* Wed Oct  1 2008 tiwai@suse.de
- rpm/kernel-source.spec.in: Fixed missing endif
* Wed Oct  1 2008 tiwai@suse.de
- Update config files: make floppy module on i386, too
* Wed Oct  1 2008 tiwai@suse.de
- supported.conf: update sound drivers
* Wed Oct  1 2008 tonyj@suse.de
- update RT to 2.6.27-rc8
- patches.rt/preempt-realtime-fs-block.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-timer.patch: Linux-RT 2.6.27-RT.
* Wed Oct  1 2008 agruen@suse.de
- Update -rt config files.
* Tue Sep 30 2008 gregkh@suse.de
- update to 2.6.27-rc8
  - obsoletes these patches:
  - patches.arch/ia64-kdump_proc_iomem.diff
  - patches.drivers/qla2xxx-defer-risc-interrupt-enablement
  - patches.fixes/usb-hcd-interrupt-shared.patch
* Tue Sep 30 2008 jkosina@suse.de
- additional patches to track down and fix e1000e NVM corruption
- patches.suse/e1000e_ioremap_sanity_check: ioremap sanity check
  to catch mapping requests exceeding the BAR sizes (bnc#425480).
- patches.suse/e1000e_write_protect_ichx_nvm: e1000e: write
  protect ICHx NVM to prevent malicious write/erase (bnc#425480).
* Tue Sep 30 2008 hare@suse.de
- Update config files.
* Tue Sep 30 2008 hare@suse.de
- patches.drivers/mpt-fusion-4.00.43.00-update: Update MPT Fusion
  driver to v4.00.43.00 (bnc#425660).
- patches.kernel.org/gdth-section-conflict: Add missing annotations.
* Tue Sep 30 2008 sassmann@suse.de
- Update config files: Disabled everything unnecessary in
  ps3 config file
* Tue Sep 30 2008 olh@suse.de
- disable ninja32 and ns87415 pata drivers on ppc64
* Tue Sep 30 2008 sdietrich@suse.de
- config.conf: enable rt for i386/x86_64
- Update config files: Preliminary sync with default and debug configs.
- config/x86_64/rt_timing: Delete.
- patches.rt/2.6.21-rc6-lockless3-radix-tree-gang-slot-lookups.patch:
  Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT radix-tree: gang slot lookups.
- patches.rt/2.6.21-rc6-lockless5-lockless-probe.patch: Linux-RT
  2.6.27-RT
  Linux-RT 2.6.26-RT mm: lockless probe.
- patches.rt/2.6.21-rc6-lockless6-speculative-get-page.patch:
  Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT mm: speculative get page.
- patches.rt/2.6.21-rc6-lockless7-lockless-pagecache-lookups.patch:
  Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT mm: lockless pagecache lookups.
- patches.rt/2.6.21-rc6-lockless8-spinlock-tree_lock.patch:
  Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT mm: spinlock tree_lock.
- patches.rt/Add-dev-rmem-device-driver-for-real-time-JVM-testing.patch:
  Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/Allocate-RTSJ-memory-for-TCK-conformance-test.patch:
  Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/RT_utsname.patch: Linux-RT 2.6.27-RT.
- patches.rt/aacraid-compat-sem.patch: Linux-RT 2.6.27-RT.
- patches.rt/adapt-remove-extra-try-to-lock.patch: Linux-RT
  2.6.27-RT.
- patches.rt/adaptive-adjust-pi-wakeup.patch: Linux-RT 2.6.27-RT.
- patches.rt/adaptive-earlybreak-on-steal.patch: Linux-RT
  2.6.27-RT
  rtmutex: break out early on first run.
- patches.rt/adaptive-optimize-rt-lock-wakeup.patch: Linux-RT
  2.6.27-RT.
- patches.rt/adaptive-spinlock-lite-v2.patch: Linux-RT 2.6.27-RT
  adaptive spinlocks lite.
- patches.rt/adaptive-task-oncpu.patch: Linux-RT 2.6.27-RT.
- patches.rt/apic-dumpstack.patch: Linux-RT 2.6.27-RT.
- patches.rt/apic-level-smp-affinity.patch: Linux-RT 2.6.27-RT.
- patches.rt/arm-compile-fix.patch: Linux-RT 2.6.27-RT
  ARM: compile fix for event tracing.
- patches.rt/arm-fix-compile-error-trace-exit-idle.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/arm-futex-atomic-cmpxchg.patch: Linux-RT 2.6.27-RT.
- patches.rt/arm-latency-tracer-support.patch: Linux-RT 2.6.27-RT.
- patches.rt/arm-omap-02.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/arm-omap-05.patch: Linux-RT 2.6.27-RT.
- patches.rt/arm-preempt-config.patch: Linux-RT 2.6.27-RT.
- patches.rt/arm-trace-preempt-idle.patch: Linux-RT 2.6.27-RT.
- patches.rt/bh-state-lock.patch: Linux-RT 2.6.27-RT.
- patches.rt/bh-uptodate-lock.patch: Linux-RT 2.6.27-RT.
- patches.rt/bz235099-idle-load-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/cache_pci_find_capability.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT Cache calls to pci_find_capability.
- patches.rt/call_rcu_bh-rename-of-call_rcu.patch: Linux-RT
  2.6.27-RT
  just rename call_rcu_bh instead of making it a macro.
- patches.rt/cond_resched_softirq-WARN-fix.patch: Linux-RT
  2.6.27-RT
  WARNING: at kernel/sched.c:5071 2.6.23-rc1-rt7.
- patches.rt/cputimer-thread-rt-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/cputimer-thread-rt_A0.patch: Linux-RT 2.6.27-RT.
- patches.rt/cycles-to-ns-trace-fix.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/dev-queue-xmit-preempt-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/disable-irqpoll.patch: Linux-RT 2.6.27-RT.
- patches.rt/disable-ist-x86_64.patch: Linux-RT 2.6.27-RT.
- patches.rt/disable-lpptest-on-nonlinux.patch: Linux-RT
  2.6.27-RT.
- patches.rt/disable-run-softirq-from-hardirq-completely.patch:
  Linux-RT 2.6.27-RT
  Disable running softirqs from hardirqs completely!.
- patches.rt/dont-disable-preemption-without-IST.patch: Linux-RT
  2.6.27-RT.
- patches.rt/dont-let-rt-rw_semaphores-do-non_owner-locks.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/dont-unmask-io_apic.patch: Linux-RT 2.6.27-RT.
- patches.rt/drain-all-local-pages-via-sched.patch: Linux-RT
  2.6.27-RT.
- patches.rt/event-trace-hrtimer-trace.patch: Linux-RT 2.6.27-RT
  event-tracer: add clockevent trace.
- patches.rt/export-schedule-on-each-cpu.patch: Linux-RT
  2.6.27-RT.
- patches.rt/filemap-dont-bug-non-atomic.patch: Linux-RT
  2.6.27-RT.
- patches.rt/fix-a-previously-reverted-fix.patch: Linux-RT
  2.6.27-RT
  Fix a previously reverted "fix".
- patches.rt/fix-adaptive-hack.patch: Linux-RT 2.6.27-RT
  fix-adaptive-hack.patch.
- patches.rt/fix-bug-on-in-filemap.patch: Linux-RT 2.6.27-RT
  Change bug_on for atomic to pagefault_disabled..
- patches.rt/fix-circular-locking-deadlock.patch: Linux-RT
  2.6.27-RT.
- patches.rt/fix-compilation-for-non-RT-in-timer.patch: Linux-RT
  2.6.27-RT.
- patches.rt/fix-config-debug-rt-mutex-lock-underflow-warnings.patch:
  Linux-RT 2.6.27-RT
  Fix CONFIG_DEBUG_RT_MUTEX lock underflow warnings.
- patches.rt/fix-emac-locking-2.6.16.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/fix-emergency-reboot.patch: Linux-RT 2.6.27-RT
  call reboot notifier list when doing an emergency reboot.
- patches.rt/fix-migrating-softirq.patch: Linux-RT 2.6.27-RT.
- patches.rt/fix-softirq-checks-for-non-rt-preempt-hardirq.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/fix_vdso_gtod_vsyscall64_2.patch: Linux-RT 2.6.27-RT.
- patches.rt/floppy-resume-fix.patch: Linux-RT 2.6.27-RT
  floppy: suspend/resume fix.
- patches.rt/frace-use-tsc.patch: Linux-RT 2.6.27-RT.
- patches.rt/ftrace-compile-fixes.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT rt: remove call to stop tracer.
- patches.rt/ftrace-document-event-tracer.patch: Linux-RT
  2.6.27-RT.
- patches.rt/ftrace-document-update1.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT ftrace: document updates.
- patches.rt/ftrace-dont-trace-markers.patch: Linux-RT 2.6.27-RT
  ftrace: dont trace markers.
- patches.rt/ftrace-fix-get-kprobe-wreckage.patch: Linux-RT
  2.6.27-RT
  Linux-RT 2.6.26-RT ftrace-fix-missing-kprobe-include.pathc.
- patches.rt/ftrace-fix-header.patch: Linux-RT 2.6.27-RT.
- patches.rt/ftrace-function-record-nop.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT ftrace: define function trace nop.
- patches.rt/ftrace-hotplug-fix.patch: Linux-RT 2.6.27-RT
  ftrace: cpu hotplug fix.
- patches.rt/ftrace-m68knommu-add-FTRACE-support.patch: Linux-RT
  2.6.27-RT.
- patches.rt/ftrace-m68knommu-generic-stacktrace-function.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/ftrace-preempt-trace-check.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT ftrace: only trace preempt off with
  preempt tracer.
- patches.rt/ftrace-print-missing-cmdline.patch: Linux-RT
  2.6.27-RT
  ftrace: fix the command line printing.
- patches.rt/ftrace-record-comm-on-ctrl.patch: Linux-RT 2.6.27-RT
  ftrace: record comm on function ctrl change.
- patches.rt/ftrace-stop-trace-on-crash.patch: Linux-RT 2.6.27-RT
  fix-tracer-wreckage-wtf-is-this-code-all-features.patch.
- patches.rt/ftrace-trace-sched.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT ftrace: trace sched.c.
- patches.rt/ftrace-use-preempt-disable-not-irq-disable.patch:
  Linux-RT 2.6.27-RT
  ftrace: avoid lockdep recursion.
- patches.rt/ftrace-wakeup-rawspinlock.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT ftrace: user raw spin lock for wakeup
  function trace.
- patches.rt/generic-cmpxchg-use-raw-local-irq-variant.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/genhd-protect-percpu-var.patch: Linux-RT 2.6.27-RT.
- patches.rt/genirq-soft-resend.patch: Linux-RT 2.6.27-RT
  x86: activate HARDIRQS_SW_RESEND.
- patches.rt/git-ignore-script-lpp.patch: Linux-RT 2.6.27-RT.
- patches.rt/gtod-optimize.patch: Linux-RT 2.6.27-RT.
- patches.rt/hack-convert-i_alloc_sem-for-direct_io-craziness.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/hack-fix-rt-migration.patch: Linux-RT 2.6.27-RT.
- patches.rt/handle-pending-in-simple-irq.patch: Linux-RT
  2.6.27-RT
  handle IRQ_PENDING for simple irq handler.
- patches.rt/highmem-redo-mainline.patch: Linux-RT 2.6.27-RT.
- patches.rt/highmem-revert-mainline.patch: Linux-RT 2.6.27-RT.
- patches.rt/highmem_rewrite.patch: Linux-RT 2.6.27-RT
  mm: remove kmap_lock.
- patches.rt/hrtimer-no-printk.patch: Linux-RT 2.6.27-RT.
- patches.rt/hrtimers-overrun-api.patch: Linux-RT 2.6.27-RT.
- patches.rt/i386-mark-atomic-irq-ops-raw.patch: Linux-RT
  2.6.27-RT.
- patches.rt/i386-nmi-watchdog-show-regs.patch: Linux-RT
  2.6.27-RT.
- patches.rt/idle-fix.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/idle2-fix.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/ioapic-fix-too-fast-clocks.patch: Linux-RT 2.6.27-RT.
- patches.rt/irda-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/irq-mask-fix.patch: Linux-RT 2.6.27-RT
  genirq: fix simple and fasteoi irq handlers.
- patches.rt/jbd_assertions_smp_only.patch: Linux-RT 2.6.27-RT.
- patches.rt/kmap-atomic-i386-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/kmap-atomic-prepare.patch: Linux-RT 2.6.27-RT.
- patches.rt/kprobes-preempt-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/kstat-add-rt-stats.patch: Linux-RT 2.6.27-RT
  add rt stats to /proc/stat.
- patches.rt/kstat-fix-spurious-system-load-spikes-in-proc-loadavgrt.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/latency-measurement-drivers.patch: Linux-RT
  2.6.27-RT.
- patches.rt/latency-tracing-arm.patch: Linux-RT 2.6.27-RT.
- patches.rt/latency-tracing-ppc.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/loadavg_fixes_weird_loads.patch: Linux-RT 2.6.27-RT.
- patches.rt/local_irq_save_nort-in-swap.patch: Linux-RT
  2.6.27-RT.
- patches.rt/lock-init-plist-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/lock_list.patch: Linux-RT 2.6.27-RT
  lock_list - a fine grain locked double linked list.
- patches.rt/lock_page_ref.patch: Linux-RT 2.6.27-RT
  mm: lock_page_ref.
- patches.rt/lockdep-avoid-fork-waring.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT ftrace: fix if define to prove locking.
- patches.rt/lockdep-lock_set_subclass.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT lockdep: lock_set_subclass - reset a held
  lock's subclass.
- patches.rt/lockdep-more-entries.patch: Linux-RT 2.6.27-RT.
- patches.rt/lockdep-prettify.patch: Linux-RT 2.6.27-RT
  lockdep: prettify output.
- patches.rt/lockdep-rt-mutex.patch: Linux-RT 2.6.27-RT
  lockdep-rt: annotate PREEMPT_RT DEFINE_MUTEX.
- patches.rt/lockdep-rt-recursion-limit-fix.patch: Linux-RT
  2.6.27-RT.
- patches.rt/lockdep-show-held-locks.patch: Linux-RT 2.6.27-RT
  lockdep: show held locks when showing a stackdump.
- patches.rt/lockdep_lock_set_subclass_fix.patch: Linux-RT
  2.6.27-RT.
- patches.rt/lockstat-fix-contention-points.patch: Linux-RT
  2.6.27-RT
  Linux-RT 2.6.26-RT lockstat: fix contention points.
- patches.rt/lockstat-output.patch: Linux-RT 2.6.27-RT
  lockstat: warn about disabled lock debugging.
- patches.rt/lockstat-rt-hooks.patch: Linux-RT 2.6.27-RT.
- patches.rt/lockstat_bounce_rt.patch: Linux-RT 2.6.27-RT.
- patches.rt/loopback-revert.patch: Linux-RT 2.6.27-RT.
- patches.rt/m68knommu-make-cmpxchg-RT-safe.patch: Linux-RT
  2.6.27-RT.
- patches.rt/m68knommu_fixes_ontop_of_v2.6.26.patch: Linux-RT
  2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/mapping_nrpages-fix.patch: Linux-RT 2.6.27-RT
  mapping_nrpages-fix.patch.
- patches.rt/mapping_nrpages.patch: Linux-RT 2.6.27-RT
  mm/fs: abstract address_space::nrpages.
- patches.rt/mips-change-raw-spinlock-type.patch: Linux-RT
  2.6.27-RT
  Linux-RT 2.6.26-RT RT: change from raw_spinlock_t to
  __raw_spinlock_t.
- patches.rt/mips-remove-conlicting-rtc-lock-declaration.patch:
  Linux-RT 2.6.27-RT
  RT: remove conflicting rtc_lock declaration.
- patches.rt/mips-remove-duplicate-kconfig.patch: Linux-RT
  2.6.27-RT.
- patches.rt/mips-remove-finish-arch-switch.patch: Linux-RT
  2.6.27-RT
  RT: remove finish_arch_switch.
- patches.rt/mitigate-resched-flood.patch: Linux-RT 2.6.27-RT.
- patches.rt/mm-concurrent-pagecache-rt.patch: Linux-RT 2.6.27-RT
  mm: -rt bits for concurrent pagecache.
- patches.rt/mm-concurrent-pagecache.patch: Linux-RT 2.6.27-RT
  mm: concurrent pagecache write side.
- patches.rt/mm-fix-latency.patch: Linux-RT 2.6.27-RT
  reduce pagetable-freeing latencies.
- patches.rt/move-native-irq.patch: Linux-RT 2.6.27-RT.
- patches.rt/msi-suspend-resume-workaround.patch: Linux-RT
  2.6.27-RT.
- patches.rt/multi-reader-account.patch: Linux-RT 2.6.27-RT
  map tasks to reader locks held.
- patches.rt/multi-reader-limit.patch: Linux-RT 2.6.27-RT
  implement reader limit on read write locks.
- patches.rt/multi-reader-lock-account.patch: Linux-RT 2.6.27-RT
  map read/write locks back to their readers.
- patches.rt/multi-reader-pi.patch: Linux-RT 2.6.27-RT
  read lock Priority Inheritance implementation.
- patches.rt/native-sched-clock-booboo.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/neptune-no-at-keyboard.patch: Linux-RT 2.6.27-RT.
- patches.rt/net-core-preempt-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/netpoll-8139too-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/new-softirq-code.patch: Linux-RT 2.6.27-RT
  softirq preemption: optimization.
- patches.rt/nf_conntrack-fix-smp-processor-id.patch: Linux-RT
  2.6.27-RT.
- patches.rt/nf_conntrack-weird-crash-fix.patch: Linux-RT
  2.6.27-RT.
- patches.rt/nfs-stats-miss-preemption.patch: Linux-RT 2.6.27-RT
  nfs: fix missing preemption check.
- patches.rt/nmi-profiling.patch: Linux-RT 2.6.27-RT.
- patches.rt/nmi-show-regs-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/nmi-watchdog-disable.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT x86_64: do not enable the NMI watchdog
  by default.
- patches.rt/nmi-watchdog-fix-1.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/nmi-watchdog-fix-2.patch: Linux-RT 2.6.27-RT.
- patches.rt/nmi-watchdog-fix-3.patch: Linux-RT 2.6.27-RT.
- patches.rt/nmi-watchdog-fix-4.patch: Linux-RT 2.6.27-RT.
- patches.rt/no-warning-for-irqs-disabled-in-local-bh-enable.patch:
  Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT local_bh_enable() is safe for
  irqs_disabled().
- patches.rt/ntfs-local-irq-save-nort.patch: Linux-RT 2.6.27-RT.
- patches.rt/numa-slab-freeing.patch: Linux-RT 2.6.27-RT.
- patches.rt/only-run-softirqs-from-irq-thread-when-irq-affinity-is-set.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/pagefault-disable-cleanup.patch: Linux-RT 2.6.27-RT
  clean up the page fault disabling logic.
- patches.rt/panic-dont-stop-box.patch: Linux-RT 2.6.27-RT.
- patches.rt/paravirt-function-pointer-fix.patch: Linux-RT
  2.6.27-RT.
- patches.rt/pause-on-oops-head-tail.patch: Linux-RT 2.6.27-RT
  introduce pause_on_oops_head/tail boot options.
- patches.rt/percpu-locked-mm.patch: Linux-RT 2.6.27-RT.
- patches.rt/percpu-locked-netfilter.patch: Linux-RT 2.6.27-RT.
- patches.rt/percpu-locked-netfilter2.patch: Linux-RT 2.6.27-RT.
- patches.rt/percpu-locked-powerpc-fixups.patch: Linux-RT
  2.6.27-RT.
- patches.rt/percpu_list.patch: Linux-RT 2.6.27-RT
  percpu_list.
- patches.rt/plist-debug.patch: Linux-RT 2.6.27-RT.
- patches.rt/pmtmr-override.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT pmtmr: allow command line override of
  ioport.
- patches.rt/posix-cpu-timers-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/powerpc-count_active_rt_tasks-is-undefined-for-non-preempt-rt.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/powerpc-flush_tlb_pending-is-no-more.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/powerpc-ftrace-stop-on-oops.patch: Linux-RT 2.6.27-RT
  powerpc: ftrace stop on crash.
- patches.rt/powerpc-match-__rw_yield-function-declaration-to-prototype.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/ppc-chpr-set-rtc-lock.patch: Linux-RT 2.6.27-RT.
- patches.rt/ppc-gtod-notrace-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/ppc-hacks-to-allow-rt-to-run-kernbench.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/ppc-make-tlb-batch-64-only.patch: Linux-RT 2.6.27-RT.
- patches.rt/ppc-tlbflush-preempt.patch: Linux-RT 2.6.27-RT.
- patches.rt/ppc32-latency-compile-hack-fixes.patch: Linux-RT
  2.6.27-RT.
- patches.rt/ppc32_notrace_init_functions.patch: Linux-RT
  2.6.27-RT
  don't trace early init functions for ppc32.
- patches.rt/ppc64-fix-preempt-unsafe-paths-accessing-per_cpu-variables.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-Kconfig.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-arm-fix-oprofile.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-irqs-arm.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-direct-debug-keyboard.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-irqs-hrtimer.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-i386-idle-poll-loop-fix.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-i386-ioapic-mask-quirk.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-irqs-i386.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-m68knommu-make-timer-interrupt-non-threaded.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-mips.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-ppc-ack-irq-fixups.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-irqs-ppc-fix-b5.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-ppc-fix-b6.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-ppc-fix-more-fasteoi.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-irqs-ppc.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-x86-64-ioapic-mask-quirk.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-x86-64.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-acpi.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-arm-bagde4.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-arm-footbridge.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-arm-integrator.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-arm-ixp4xx.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-arm-pxa.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-arm-rawlock-in-mmu_context-h.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-arm-shark.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-arm.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-compile-fixes.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-console.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-core.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-debug-sysctl.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-fs-block.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-ftrace-disable-ftraced.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-ftrace.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-i386.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-ia64.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-ide.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-init-show-enabled-debugs.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-input.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-ipc.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-irqs.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-loopback.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-mellanox-driver-fix.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-mips.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-mm.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-mmdrop-delayed.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-net-drivers.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-net-softirq-fixups.patch: Linux-RT
  2.6.27-RT
  NOHZ: local_softirq_pending with tickless.
- patches.rt/preempt-realtime-net.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-powerpc-add-raw-relax-macros.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-powerpc-b2.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-powerpc-b3.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-powerpc-b4.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-powerpc-celleb-raw-spinlocks.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-powerpc-missing-raw-spinlocks.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-powerpc-tlb-batching.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-powerpc-update.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-powerpc.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-prevent-idle-boosting.patch:
  Linux-RT 2.6.27-RT
  Premmpt-RT: Preevent boosting of idle task.
- patches.rt/preempt-realtime-printk.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-profiling.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-rawlocks.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-rcu.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-sched-cpupri.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-sched-i386.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-sched.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-sound.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-supress-nohz-softirq-warning.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-supress-rtc-printk.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-timer.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-usb.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-warn-and-bug-on-fix.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-warn-and-bug-on.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-x86_64.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-rt-no-slub.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-trace.patch: Linux-RT 2.6.27-RT.
- patches.rt/print-might-sleep-hack.patch: Linux-RT 2.6.27-RT.
- patches.rt/printk-dont-bug-on-sched.patch: Linux-RT 2.6.27-RT.
- patches.rt/printk-in-atomic-hack-fix.patch: Linux-RT 2.6.27-RT
  fix printk in atomic hack.
- patches.rt/printk-in-atomic.patch: Linux-RT 2.6.27-RT.
- patches.rt/proportions-raw-locks.patch: Linux-RT 2.6.27-RT.
- patches.rt/qrcu.patch: Linux-RT 2.6.27-RT
  QRCU with lockless fastpath.
- patches.rt/quicklist-release-before-free-page-fix.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/quicklist-release-before-free-page.patch: Linux-RT
  2.6.27-RT.
- patches.rt/radix-concurrent-lockdep.patch: Linux-RT 2.6.27-RT.
- patches.rt/radix-percpu-hack-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/radix-tree-concurrent.patch: Linux-RT 2.6.27-RT
  radix-tree: concurrent write side support.
- patches.rt/radix-tree-lockdep-plus1.patch: Linux-RT 2.6.27-RT
  lockdep: add +1 to radix tree array.
- patches.rt/radix-tree-optimistic-hist.patch: Linux-RT 2.6.27-RT
  debug: optimistic lock histogram.
- patches.rt/radix-tree-optimistic.patch: Linux-RT 2.6.27-RT
  radix-tree: optimistic locking.
- patches.rt/raw-spinlocks-for-nmi-print.patch: Linux-RT
  2.6.27-RT.
- patches.rt/rcu-hrt-fixups.patch: Linux-RT 2.6.27-RT.
- patches.rt/rcu-new-7.patch: Linux-RT 2.6.27-RT.
- patches.rt/rcu-preempt-boost-default.patch: Linux-RT 2.6.27-RT.
- patches.rt/rcu-preempt-boost-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/rcu-preempt-boost-sdr.patch: Linux-RT 2.6.27-RT.
- patches.rt/rcu-preempt-fix-bad-dyntick-accounting.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/rcu-preempt-hotplug-hackaround.patch: Linux-RT
  2.6.27-RT.
- patches.rt/rcu-torture-preempt-update.patch: Linux-RT 2.6.27-RT.
- patches.rt/rcu-trace-fix-free.patch: Linux-RT 2.6.27-RT.
- patches.rt/rcupreempt-boost-early-init.patch: Linux-RT
  2.6.27-RT.
- patches.rt/realtime-preempt-warn-about-tracing.patch: Linux-RT
  2.6.27-RT.
- patches.rt/relay-fix.patch: Linux-RT 2.6.27-RT
  relay: fix timer madness.
- patches.rt/remove-check-pgt-cache-calls.patch: Linux-RT
  2.6.27-RT.
- patches.rt/replace-bugon-by-warn-on.patch: Linux-RT 2.6.27-RT.
- patches.rt/revert-preempt-bkl-revert.patch: Linux-RT 2.6.27-RT.
- patches.rt/root-domain-kfree-in-atomic.patch: Linux-RT
  2.6.27-RT.
- patches.rt/rt-apis.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-avoid-deadlock-in-swap.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-delayed-prio.patch: Linux-RT 2.6.27-RT
  rt: PI-workqueue: propagate prio for delayed work.
- patches.rt/rt-kmap-scale-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-list-mods.patch: Linux-RT 2.6.27-RT
  rt: list_splice2.
- patches.rt/rt-move-update-wall-time-back-to-do-timer.patch:
  Linux-RT 2.6.27-RT
  rt: move update_wall_time back to do timer.
- patches.rt/rt-mutex-arm.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-mutex-compat-semaphores.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-mutex-core.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-mutex-i386.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-mutex-irq-flags-checking.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/rt-mutex-mips.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-mutex-namespace.patch: Linux-RT 2.6.27-RT
  rt-mutex-namespace.patch.
- patches.rt/rt-mutex-ppc-fix-a5.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-mutex-ppc.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-mutex-preempt-debugging.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-mutex-trivial-route-cast-fix.patch: Linux-RT
  2.6.27-RT.
- patches.rt/rt-mutex-trivial-tcp-preempt-fix.patch: Linux-RT
  2.6.27-RT.
- patches.rt/rt-mutex-use-inline.patch: Linux-RT 2.6.27-RT
  rt-mutex-cleanup.patch.
- patches.rt/rt-mutex-x86-64.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-plist-mods.patch: Linux-RT 2.6.27-RT
  rt: plist_head_splice.
- patches.rt/rt-rwlock-conservative-locking.patch: Linux-RT
  2.6.27-RT
  rwlock: be more conservative in locking reader_lock_count.
- patches.rt/rt-s_files-kill-a-union.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-sched-groups.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-shorten-softirq-thread-names.patch: Linux-RT
  2.6.27-RT.
- patches.rt/rt-workqeue-prio.patch: Linux-RT 2.6.27-RT
  rt: PI-workqueue support.
- patches.rt/rt-workqueue-barrier.patch: Linux-RT 2.6.27-RT
  rt: PI-workqueue: fix barriers.
- patches.rt/rt-wq-barrier-fix.patch: Linux-RT 2.6.27-RT
  rt: PI-workqueue: wait_on_work() fixup.
- patches.rt/rt_mutex_setprio.patch: Linux-RT 2.6.27-RT
  rt: rename rt_mutex_setprio to task_setprio.
- patches.rt/rtmutex-debug-fix.patch: Linux-RT 2.6.27-RT
  rtmutex-debug-fix.patch.
- patches.rt/rtmutex-debug.h-cleanup.patch: Linux-RT 2.6.27-RT
  lock debugging: clean up rtmutex-debug.h.
- patches.rt/rtmutex-lateral-steal.patch: Linux-RT 2.6.27-RT.
- patches.rt/rtmutex-rearrange.patch: Linux-RT 2.6.27-RT.
- patches.rt/rtmutex-remove-xchg.patch: Linux-RT 2.6.27-RT
  rtmutex - remove double xchg.
- patches.rt/rtmutex-rwlock-cmpxchg-typecast.patch: Linux-RT
  2.6.27-RT.
- patches.rt/rwlock-fixes.patch: Linux-RT 2.6.27-RT
  rwlock: fix pi_list race conditions.
- patches.rt/rwlock-implement-downgrade-write.patch: Linux-RT
  2.6.27-RT
  rwlocks multi downgrade write.
- patches.rt/rwlock-pi-lock-reader.patch: Linux-RT 2.6.27-RT.
- patches.rt/rwlock-prio-fix.patch: Linux-RT 2.6.27-RT
  rwlock: reset prio on unlocks and wakeups.
- patches.rt/rwlock-protect-reader_lock_count.patch: Linux-RT
  2.6.27-RT.
- patches.rt/rwlock-slowunlock-mutex-fix.patch: Linux-RT
  2.6.27-RT.
- patches.rt/rwlock-slowunlock-mutex-fix2.patch: Linux-RT
  2.6.27-RT.
- patches.rt/rwlock-torture-no-rt.patch: Linux-RT 2.6.27-RT
  rwlock: fix torture test to handle non-rt.
- patches.rt/rwlock-torture.patch: Linux-RT 2.6.27-RT
  rwlock: rwlock torture test.
- patches.rt/rwlocks-default-nr-readers-nr-cpus.patch: Linux-RT
  2.6.27-RT.
- patches.rt/rwlocks-fix-no-preempt-rt.patch: Linux-RT 2.6.27-RT
  rwlock: fix non PREEMPT_RT case.
- patches.rt/rwlocks-multiple-readers.patch: Linux-RT 2.6.27-RT
  implement rwlocks management.
- patches.rt/rwsems-multiple-readers.patch: Linux-RT 2.6.27-RT
  add framework for multi readers on rwsems.
- patches.rt/s_files-pipe-fix.patch: Linux-RT 2.6.27-RT
  s_files: free_write_pipe() fix.
- patches.rt/s_files-schedule_on_each_cpu_wq.patch: Linux-RT
  2.6.27-RT.
- patches.rt/s_files.patch: Linux-RT 2.6.27-RT
  remove global files_lock.
- patches.rt/sched-clock-nmi.patch: Linux-RT 2.6.27-RT.
- patches.rt/sched-cpupri-hotplug-support.patch: Linux-RT
  2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/sched-cpupri-priocount.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/sched-enable-irqs-in-preempt-in-notifier-call.patch:
  Linux-RT 2.6.27-RT
  CFS: enable irqs in fire_sched_in_preempt_notifier.
- patches.rt/sched-fix-dequeued-race.patch: Linux-RT 2.6.27-RT
  sched-fix-dequeued-race.patch.
- patches.rt/sched-nr-migrate-lower-default-preempt-rt.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/sched-prioritize-non-migrating-rt-tasks.patch:
  Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/sched-rt-stats.patch: Linux-RT 2.6.27-RT.
- patches.rt/sched-use-a-2d-bitmap-search-prio-cpu.patch:
  Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/sched-wake_up_idle_cpu-rt.patch: Linux-RT 2.6.27-RT.
- patches.rt/sched_prio.patch: Linux-RT 2.6.27-RT.
- patches.rt/sched_rt-fixup.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/schedule-tail-balance-disable-irqs.patch: Linux-RT
  2.6.27-RT.
- patches.rt/schedule_on_each_cpu-enhance.patch: Linux-RT
  2.6.27-RT.
- patches.rt/select-error-leak-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/send-nmi-all-preempt-disable.patch: Linux-RT
  2.6.27-RT.
- patches.rt/seq-irqsave.patch: Linux-RT 2.6.27-RT.
- patches.rt/serial-locking-rt-cleanup.patch: Linux-RT 2.6.27-RT.
- patches.rt/serial-slow-machines.patch: Linux-RT 2.6.27-RT.
- patches.rt/slab-irq-nopreempt-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/smp-processor-id-fixups.patch: Linux-RT 2.6.27-RT.
- patches.rt/softirq-per-cpu-assumptions-fixes.patch: Linux-RT
  2.6.27-RT.
- patches.rt/softlockup-add-irq-regs-h.patch: Linux-RT 2.6.27-RT
  core: make asm/irq_regs.h available on every platform.
- patches.rt/spinlock-trylock-cleanup-sungem.patch: Linux-RT
  2.6.27-RT.
- patches.rt/sub-dont-disable-irqs.patch: Linux-RT 2.6.27-RT
  rt: dont disable irqs in usb.
- patches.rt/swap-spinlock-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/tasklet-busy-loop-hack.patch: Linux-RT 2.6.27-RT.
- patches.rt/tasklet-redesign.patch: Linux-RT 2.6.27-RT.
- patches.rt/timer-freq-tweaks.patch: Linux-RT 2.6.27-RT.
- patches.rt/timer-warning-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/trace-add-event-markers-arm.patch: Linux-RT
  2.6.27-RT.
- patches.rt/trace-do-not-wakeup-when-irqs-disabled.patch:
  Linux-RT 2.6.27-RT
  trace-do-not-wakeup-when-irqs-disabled.patch.
- patches.rt/trace-eip2ip.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT Re: 2.6.25.4-rt4.
- patches.rt/trace-events-handle-syscalls.patch: Linux-RT
  2.6.27-RT.
- patches.rt/trace-histograms.patch: Linux-RT 2.6.27-RT.
- patches.rt/trace-ktime-scalar.patch: Linux-RT 2.6.27-RT
  ftrace: print ktime values in readable form.
- patches.rt/trace_hist-divzero.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT trace_hist.c: divide-by-zero problem (2).
- patches.rt/trace_hist-latediv.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/tracer-add-event-markers.patch: Linux-RT 2.6.27-RT.
- patches.rt/tracer-event-trace.patch: Linux-RT 2.6.27-RT.
- patches.rt/use-edge-triggered-irq-handler-instead-of-simple-irq.patch:
  Linux-RT 2.6.27-RT
  [AT91: PATCH]: Use edge triggered interrupt handling for
  AT91-GPIO instead of simple_irq-handler.
- patches.rt/user-no-irq-disable.patch: Linux-RT 2.6.27-RT.
- patches.rt/vortex-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/warn-on-rt-scatterlist.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT remove warn on for scatterlist in preempt
  rt.
- patches.rt/watchdog_use_timer_and_hpet_on_x86_64.patch:
  Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/x86-64-tscless-vgettimeofday.patch: Linux-RT
  2.6.27-RT
  x86_64 GTOD: offer scalable vgettimeofday.
- patches.rt/x86_64-tsc-sync-irqflags-fix.patch: Linux-RT
  2.6.27-RT.
- patches.rt/26-rt1-chirag.patch: Linux-RT 2.6.27-RT
  This patch should solve some of the bug messages..
- patches.rt/add-generalized-pi-interface.patch: Linux-RT
  2.6.27-RT
  add generalized priority-inheritance interface.
- patches.rt/rtmutex-add_readers.patch: Linux-RT 2.6.27-RT
  RT: wrap the rt_rwlock "add reader" logic.
- patches.rt/rtmutex-defer-pi-until-sleepy.patch: Linux-RT
  2.6.27-RT
  rtmutex: pi-boost locks as late as possible.
- patches.rt/rtmutex-initialize-waiters.patch: Linux-RT 2.6.27-RT
  rtmutex: formally initialize the rt_mutex_waiters.
- patches.rt/rtmutex-use-runtime-init.patch: Linux-RT 2.6.27-RT
  rtmutex: use runtime init for rtmutexes.
- patches.rt/tie-pi-into-task.patch: Linux-RT 2.6.27-RT
  sched: add the basic PI infrastructure to the task_struct.
- patches.rt/rtmutex-convert-to-libpi.patch: Linux-RT 2.6.27-RT
  rtmutex: convert rtmutexes to fully use the PI library.
- patches.rt/ftrace-fix-elevated-preempt-count-in-wakeup-tracer.patch:
  Linux-RT 2.6.27-RT
  ftrace: fix elevated preempt_count in wakeup-tracer.
- patches.rt/seqlock-make-raw-seqlocks-spin-during-write.patch:
  Linux-RT 2.6.27-RT
  seqlock: make sure that raw_seqlock_t retries readers while
  writes are pending.
- patches.rt/event-tracer-syscall-i386.patch: Linux-RT 2.6.27-RT.
- patches.rt/event-tracer-syscall-x86_64.patch: Linux-RT
  2.6.27-RT.
- patches.rt/fix-acpi-build-weirdness.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/ftrace-upstream.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/gcc-warnings-shut-up.patch: Linux-RT 2.6.27-RT.
- patches.rt/nmi-profiling-base.patch: Linux-RT 2.6.27-RT
  nmi-driven profiling for /proc/profile.
- patches.rt/preempt-irqs-core.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-ppc-preempt-schedule-irq-entry-fix.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-timer.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-softirqs-core.patch: Linux-RT 2.6.27-RT.
- patches.rt/random-driver-latency-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-page_alloc.patch: Linux-RT 2.6.27-RT
  rt-friendly per-cpu pages.
- patches.rt/rt-slab-new.patch: Linux-RT 2.6.27-RT.
- patches.rt/bit-spinlocks-fix-compile.patch: Linux-RT 2.6.27-RT.
- patches.rt/compat_rwsem-fix-compile.patch: Linux-RT 2.6.27-RT.
- patches.rt/drivers_base_mutex.patch: Linux-RT 2.6.27-RT.
- patches.rt/fix-net-bug-fixes.patch: Linux-RT 2.6.27-RT.
- patches.rt/ftrace-ppc-define-mcount.patch: Linux-RT 2.6.27-RT.
- patches.rt/ftrace-report-failure.patch: Linux-RT 2.6.27-RT
  ftrace: warn on failure to disable mcount callers.
- patches.rt/ftrace-upstream-temp.patch: Linux-RT 2.6.27-RT.
- patches.rt/futex-fifo-warn-sysctl.patch: Linux-RT 2.6.27-RT.
- patches.rt/futex-trivial-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/hrtimers-stuck-in-waitqueue.patch: Linux-RT
  2.6.27-RT.
- patches.rt/lockdep-atomic-fixup.patch: Linux-RT 2.6.27-RT.
- patches.rt/namespace-lock-fixes.patch: Linux-RT 2.6.27-RT.
- patches.rt/nmi-prof-compile.patch: Linux-RT 2.6.27-RT.
- patches.rt/plist-fix-static-node-init.patch: Linux-RT 2.6.27-RT.
- patches.rt/powerpc-01-separate-the-irq-radix-tree-insertion.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/powerpc-02-make-the-irq-reverse-mapping-radix-tree-lockless.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/ppc-fix-prev-revert-fix-again.patch: Linux-RT
  2.6.27-RT.
- patches.rt/prof-sysctl-compile.patch: Linux-RT 2.6.27-RT.
- patches.rt/rcu-apply-rcu_process_callbacks-from-mainline.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/rcu-preempt-tracing-preempt-disable-fix.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/rt-wq-flush_work.patch: Linux-RT 2.6.27-RT.
- patches.rt/rtmutex-debug-magic.patch: Linux-RT 2.6.27-RT
  rtmutex: check integrity.
- patches.rt/sched-add-needs_post_schedule.patch: Linux-RT
  2.6.27-RT.
- patches.rt/sched-generic-hide-smp-warning.patch: Linux-RT
  2.6.27-RT
  suppress warning of smp_processor_id use..
- patches.rt/sched-make-double-lock-balance-fair.patch: Linux-RT
  2.6.27-RT.
- patches.rt/sched-only-push-if-pushable.patch: Linux-RT
  2.6.27-RT.
- patches.rt/sched-only-push-once-per-queue.patch: Linux-RT
  2.6.27-RT.
- patches.rt/sched-properly-account-irq-and-rt-load.patch:
  Linux-RT 2.6.27-RT
  sched: properly account IRQ and RT load in .
- patches.rt/sched-rt-runtime-lock-raw.patch: Linux-RT 2.6.27-RT.
- patches.rt/seqlock-01-make-sure-that-raw_seqlock-retries.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/seqlock-02-fix-elevated-preempt-count.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/seqlock-serialize-against-writers.patch: Linux-RT
  2.6.27-RT.
- patches.rt/seqlocks-handle-rwlock-and-spin.patch: Linux-RT
  2.6.27-RT
  seqlock - fix for both PREEMPT_RT and non PREEMPT_RT.
- patches.rt/shorten-posix-cpu-timers-name.patch: Linux-RT
  2.6.27-RT.
- patches.rt/sysctl-compile-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/tracepoint-backport.patch: Linux-RT 2.6.27-RT.
- patches.rt/x86-tlbstate-lock-raw.patch: Linux-RT 2.6.27-RT.
* Tue Sep 30 2008 olh@suse.de
- enable ipmi message handler on ppc64 (bnc#430705)
* Tue Sep 30 2008 olh@suse.de
- create flavor symlinks unconditionally
  they do not depend on presence of modules
* Mon Sep 29 2008 agruen@suse.de
- Update config files after Swap-over-NFS backout.
* Mon Sep 29 2008 agruen@suse.de
- kernel-vanilla and kernel-p3 are not split into main, -base, and
  - extra packages. Fix the bogus dependencies on those packages.
* Mon Sep 29 2008 jkosina@suse.de
- disabled the following Swap-over-NFS patches, as they cause panic
  in IPv6 code:
  - patches.suse/SoN-01-mm-gfp-to-alloc_flags.patch: mm:
    gfp_to_alloc_flags() (FATE#303834).
  - patches.suse/SoN-02-mm-setup_per_zone_pages_min.patch: mm:
    serialize access to min_free_kbytes (FATE#303834).
  - patches.suse/SoN-03-doc.patch: swap over network documentation
    (FATE#303834).
  - patches.suse/SoN-04-mm-gfp-to-alloc_flags-expose.patch: mm:
    expose gfp_to_alloc_flags() (FATE#303834).
  - patches.suse/SoN-05-page_alloc-reserve.patch: mm: tag reseve
    pages (FATE#303834).
  - patches.suse/SoN-06-reserve-slub.patch: mm: slb: add knowledge
    of reserve pages (FATE#303834).
  - patches.suse/SoN-07-mm-kmem_estimate_pages.patch: mm:
    kmem_alloc_estimate() (FATE#303834).
  - patches.suse/SoN-08-mm-PF_MEMALLOC-softirq.patch: mm: allow
    PF_MEMALLOC from softirq context (FATE#303834).
  - patches.suse/SoN-09-mm-page_alloc-emerg.patch: mm: emergency
    pool (FATE#303834).
  - patches.suse/SoN-10-global-ALLOC_NO_WATERMARKS.patch: mm:
    system wide ALLOC_NO_WATERMARK (FATE#303834).
  - patches.suse/SoN-11-mm-page_alloc-GFP_EMERGENCY.patch: mm:
    __GFP_MEMALLOC (FATE#303834).
  - patches.suse/SoN-12-mm-reserve.patch: mm: memory reserve
    management (FATE#303834).
  - patches.suse/SoN-13-mm-selinux-emergency.patch: selinux:
    tag avc cache alloc as non-critical (FATE#303834).
  - patches.suse/SoN-14-net-backlog.patch: net: wrap
    sk->sk_backlog_rcv() (FATE#303834).
  - patches.suse/SoN-15-net-ps_rx.patch: net: packet split receive
    api (FATE#303834).
  - patches.suse/SoN-16-net-sk_allocation.patch: net:
    sk_allocation() - concentrate socket related allocations
    (FATE#303834).
  - patches.suse/SoN-17-netvm-reserve.patch: netvm: network reserve
    infrastructure (FATE#303834).
  - patches.suse/SoN-18-netvm-reserve-inet.patch: netvm: INET
    reserves. (FATE#303834).
  - patches.suse/SoN-19-netvm-skbuff-reserve.patch: netvm: hook
    skb allocation to reserves (FATE#303834).
  - patches.suse/SoN-20-netvm-sk_filter.patch: netvm: filter
    emergency skbs. (FATE#303834).
  - patches.suse/SoN-21-netvm-tcp-deadlock.patch: netvm: prevent
    a stream specific deadlock (FATE#303834).
  - patches.suse/SoN-22-emergency-nf_queue.patch: netfilter:
    NF_QUEUE vs emergency skbs (FATE#303834).
  - patches.suse/SoN-23-netvm.patch: netvm: skb processing
    (FATE#303834).
  - patches.suse/SoN-24-mm-swapfile.patch: mm: add support for
    non block device backed swap files (FATE#303834).
  - patches.suse/SoN-25-mm-page_file_methods.patch: mm: methods
    for teaching filesystems about PG_swapcache pages (FATE#303834).
  - patches.suse/SoN-26-nfs-swapcache.patch: nfs: teach the NFS
    client how to treat PG_swapcache pages (FATE#303834).
  - patches.suse/SoN-27-nfs-swapper.patch: nfs: disable data cache
    revalidation for swapfiles (FATE#303834).
  - patches.suse/SoN-28-nfs-swap_ops.patch: nfs: enable swap on NFS
    (FATE#303834).
  - patches.suse/SoN-29-nfs-alloc-recursions.patch: nfs: fix various
    memory recursions possible with swap over NFS. (FATE#303834).
  - patches.xen/xen3-auto-common.diff: xen3 common.
* Mon Sep 29 2008 ptesarik@suse.cz
- patches.arch/x86-tracehook: x86 tracehook (FATE#304321).
  Provide the base infrastructure for utrace on x86.
* Mon Sep 29 2008 schwab@suse.de
- config/powerpc/vanilla: configure to 64bit.
* Mon Sep 29 2008 schwab@suse.de
- rpm/functions.sh: remove readlink emulation.
* Mon Sep 29 2008 hare@suse.de
- patches.drivers/lpfc-8.2.8.3-update: Update lpfc to 8.2.8.3
  (bnc#420767).
* Mon Sep 29 2008 rw@suse.de
- Update ia64 config files.  (bnc#429881)
* Mon Sep 29 2008 jjolly@suse.de
- patches.drivers/ehca-flush-cqe.patch: adds software flush CQE
  generation (bnc#430344)
* Mon Sep 29 2008 jkosina@suse.de
- patches.suse/e1000e_allow_bad_checksum: fix infinite loop bug in
  e1000_probe() in case the card has invalid EEPROM checksum
* Mon Sep 29 2008 agruen@suse.de
- Do not split kernels which have modules disabled (kernel-ps3)
  or which do not differentiate between supported and unsupported
  modules (kernel-vanilla).
* Mon Sep 29 2008 hare@suse.de
- patches.drivers/open-fcoe-dcb-support: Fix section annotation
  for ixgbe.
- patches.fixes/scsi-enhance-error-codes: Add missing hunk.
- patches.fixes/open-iscsi-git-update: Open-iSCSI updates
  (FATE#304283).
- patches.kernel.org/gdth-section-conflict: Fixup gdth
  section annotations.
* Mon Sep 29 2008 aj@suse.de
- Silence /etc/rpm/macros.kernel-source via rpmlintrc.
* Mon Sep 29 2008 jbeulich@novell.com
- Enable Solarflare driver link and resource driver patches.
- Update x86 config files.
* Mon Sep 29 2008 agruen@suse.de
- rpm/kernel-source.spc.in: Try to get rid of a hack that makes
  uname -r pretend in build environments that the kernel from
  the installed kernel-source package is the running kernel:
  packages assuming this are completely broken ans should really
  be fixed.
* Mon Sep 29 2008 agruen@suse.de
- rpm/kernel-source.spec.in: Prepare for the upcoming introduction
  of kernel-source-rt (and kernel-syms-rt) for producing KMPs for
  real-time kernels.
- rpm/install-configs: Remove; this script didn't improve things.
* Sun Sep 28 2008 aj@suse.de
- rpm/kernel-source.rpmlintrc: New file to silence warnings about
  zero size files
- rpm/kernel-source.spec.in: Install it.
- rpm/kernel-source.spec.in: Make /etc/rpm/macros.kernel-source
  a config file to silence rpmlint.
* Sun Sep 28 2008 jdelvare@suse.de
- supported.conf: Update the list of i2c bus drivers.
  - i2c-i810, i2c-prosavage and i2c-savage4 are gone.
  - i2c-isch and i2c-nforce2-s4985 are new, mark as supported.
* Sun Sep 28 2008 aj@suse.de
- rpm/kernel-source.spec.in: Do not package .gitignore files.
* Sun Sep 28 2008 agruen@suse.de
- Fix CONFIG_MODULES=n case.
- config.conf: Some cleanups.
* Sat Sep 27 2008 agruen@suse.de
- Split the binary kernel packages into three parts:
  + kernel-$flavor-base: very reduced hardware support, intended
  to be used in virtual machine images
  + kernel-$flavor: extends the base package; contains all kernel
  modules we can support
  + kernel-$flavor-extra: all other kernel modules which may be
  useful, but which we cannot support.
* Sat Sep 27 2008 agruen@suse.de
- Hardlink duplicate files automatically: It doesn't save much,
  but it keeps rpmlint from breaking the package build.
* Sat Sep 27 2008 agruen@suse.de
- Add consistency check: supported modules must not depend on
  unsupported ones ... and guess what, there was a large number of
  such modules. Fix this by adding all the dependent modules to
  supported.conf.
* Sat Sep 27 2008 knikanth@suse.de
- patches.suse/dm-barrier-single-device: Implement barrier
  support for single device DM devices (FATE#304489).
* Fri Sep 26 2008 jeffm@suse.de
- scripts/tar-up_and_run_mbuild.sh: Added -xen flavor to default
  mbuild spec list.
* Fri Sep 26 2008 jeffm@suse.de
- patches.xen/xen-e1000e_Export_set_memory_ro-rw: Export
  set_memory_ro() and set_memory_rw() calls for xen. (bnc#425480).
* Fri Sep 26 2008 kkeil@suse.de
- patches.suse/e1000e_mmap_range_chk:check ranges in pci_mmap
  * updated version with better reporting (bnc#425480)
* Fri Sep 26 2008 kkeil@suse.de
- patches to track down and fix the e1000e NVM corruption
  (bnc#425480)
- patches.suse/e1000e_allow_bad_checksum: e1000e: allow bad
  checksum
- patches.suse/e1000e_call_dump_eeprom: e1000e: dump eeprom to
  dmesg for ich8/9
- patches.suse/e1000e_debug_contention_on_NVM_SWFLAG: e1000e:
  debug contention on NVM SWFLAG
- patches.suse/e1000e_do_not_ever_sleep_in_interrupt_context:
  e1000e: do not ever sleep in interrupt context
- patches.suse/e1000e_drop_stats_lock: e1000e: drop stats lock
- patches.suse/e1000e_Export_set_memory_ro-rw: Export
  set_memory_ro() and set_memory_rw() calls
- patches.suse/e1000e_fix_lockdep_issues: e1000e: fix lockdep
  issues
- patches.suse/e1000e_mmap_range_chk: check ranges in pci_mmap
- patches.suse/e1000e_reset_swflag_after_resetting_hardware:
  e1000e: reset swflag after resetting hardware
- patches.suse/e1000e_update_version: update version
- patches.suse/e1000e_use_set_memory_ro-rw_to_protect_flash_memory:
  e1000e: Use set_memory_ro()/set_memory_rw() to protect flash
  memory
-   cleanup old not longer used patches
  * patches.drivers/e1000-7.6.5-napi-tail.patch
  * patches.drivers/e1000-7.6.9.2
  * patches.drivers/e1000-7.6.9.2-napi
* Fri Sep 26 2008 kkeil@suse.de
- Enable CONFIG_SGI_IOC4=m in x86_64 (bnc#430275)
* Fri Sep 26 2008 jeffm@suse.de
- patches.arch/acpi-export-hotplug_execute: acpi: export
  acpi_os_hotplug_execute.
* Fri Sep 26 2008 jeffm@suse.de
- patches.xen/xen-rwlocks-enable-interrupts: add missing
  __raw_{read,write}_lock_flags to xen's asm/spinlock.h.
* Fri Sep 26 2008 jeffm@suse.de
- patches.arch/acpi-bay-remove-from-makefile: acpi: remove bay.c
  from makefile.
* Fri Sep 26 2008 jeffm@suse.de
- rpm/kernel-binary.spec.in: Disabled sparse checking. Too many
  false positives.
* Fri Sep 26 2008 trenn@suse.de
  No functional change:
- patches.arch/acpi_thermal_passive_blacklist.patch: Avoid
  critical temp shutdowns on specific ThinkPad T4x(p) and R40
  (https://bugzilla.novell.com/show_bug.cgi?id=333043).
  Dock bug fixes (kacpid runs amok on Dells after suspend):
- patches.arch/acpi-dock-avoid-check-_STA-method.patch: avoid
  check _STA method (fate#304731,bnc#401740).
- patches.arch/acpi-dock-fix-eject-request-process.patch: fix
  eject request process (fate#304731,bnc#401740).
  More Dock improvements, unrelated to above fixes:
- patches.arch/acpi-bay-remove-useless-code.patch: remove useless
  code (fate#304731,bnc#401740).
- patches.arch/acpi-dock-Fix-duplicate-notification-handler-register.patch:
  Fix duplicate notification handler register
  (fate#304731,bnc#401740).
- patches.arch/acpi-dock-_LCK-support-for-dock.patch: add _LCK
  support for dock (fate#304731,bnc#401740).
- patches.arch/acpi-dock-fix-for-bay-in-a-dock-station.patch:
  fix for bay in a dock station (fate#304731,bnc#401740).
- patches.arch/acpi-dock-fix-hotplug-race.patch: fix hotplug race
  (fate#304731,bnc#401740).
- patches.arch/acpi-dock-introduce-.uevent-for-devices-in-dock.patch:
  introduce .uevent for devices in dock (fate#304731,bnc#401740).
- patches.arch/acpi-libata-hotplug-to-align-with-dock-driver.patch:
  libata hotplug to align with dock driver
  (fate#304731,bnc#401740).
- patches.arch/acpi-dock-makeing-dock-driver-supports-bay-and-battery-hotplug.patch:
  makeing dock driver supports bay and battery hotplug
  (fate#304731,bnc#401740).
- patches.arch/acpi-dock-add-type-sysfs-file-for-dock.patch:
  add 'type' sysfs file for dock (fate#304731,bnc#401740).
- patches.fixes/acpi_use_acpi_exception.patch: ACPI dock/bay:
  Use ACPI_EXCEPTION instead of printk(KERN_ERR.
* Fri Sep 26 2008 jeffm@suse.de
- Update config files: NFS_SWAP=y
* Fri Sep 26 2008 ptesarik@suse.cz
- patches.suse/rwlocks-enable-interrupts: Allow rwlocks to
  re-enable interrupts (bnc#387784).
- patches.arch/ia64-rwlocks-enable-interrupts: ia64: re-enable
  interrupts when waiting for a rwlock (bnc#387784).
* Fri Sep 26 2008 sjayaraman@suse.de
- Add Swap over NFS patchset.
- Adjust patches.xen/xen3-auto-common.diff to avoid conflict on skbuff.h
  as both xen and swap-over-nfs want to add some bits to the skbuff structure.
- patches.suse/SoN-01-mm-gfp-to-alloc_flags.patch: mm:
  gfp_to_alloc_flags() (FATE#303834).
- patches.suse/SoN-02-mm-setup_per_zone_pages_min.patch: mm:
  serialize access to min_free_kbytes (FATE#303834).
- patches.suse/SoN-03-doc.patch: swap over network documentation
  (FATE#303834).
- patches.suse/SoN-04-mm-gfp-to-alloc_flags-expose.patch: mm:
  expose gfp_to_alloc_flags() (FATE#303834).
- patches.suse/SoN-05-page_alloc-reserve.patch: mm: tag reseve
  pages (FATE#303834).
- patches.suse/SoN-06-reserve-slub.patch: mm: slb: add knowledge
  of reserve pages (FATE#303834).
- patches.suse/SoN-07-mm-kmem_estimate_pages.patch: mm:
  kmem_alloc_estimate() (FATE#303834).
- patches.suse/SoN-08-mm-PF_MEMALLOC-softirq.patch: mm: allow
  PF_MEMALLOC from softirq context (FATE#303834).
- patches.suse/SoN-09-mm-page_alloc-emerg.patch: mm: emergency
  pool (FATE#303834).
- patches.suse/SoN-10-global-ALLOC_NO_WATERMARKS.patch: mm:
  system wide ALLOC_NO_WATERMARK (FATE#303834).
- patches.suse/SoN-11-mm-page_alloc-GFP_EMERGENCY.patch: mm:
  __GFP_MEMALLOC (FATE#303834).
- patches.suse/SoN-12-mm-reserve.patch: mm: memory reserve
  management (FATE#303834).
- patches.suse/SoN-13-mm-selinux-emergency.patch: selinux:
  tag avc cache alloc as non-critical (FATE#303834).
- patches.suse/SoN-14-net-backlog.patch: net: wrap
  sk->sk_backlog_rcv() (FATE#303834).
- patches.suse/SoN-15-net-ps_rx.patch: net: packet split receive
  api (FATE#303834).
- patches.suse/SoN-16-net-sk_allocation.patch: net:
  sk_allocation() - concentrate socket related allocations
  (FATE#303834).
- patches.suse/SoN-17-netvm-reserve.patch: netvm: network reserve
  infrastructure (FATE#303834).
- patches.suse/SoN-18-netvm-reserve-inet.patch: netvm: INET
  reserves. (FATE#303834).
- patches.suse/SoN-19-netvm-skbuff-reserve.patch: netvm: hook
  skb allocation to reserves (FATE#303834).
- patches.suse/SoN-20-netvm-sk_filter.patch: netvm: filter
  emergency skbs. (FATE#303834).
- patches.suse/SoN-21-netvm-tcp-deadlock.patch: netvm: prevent
  a stream specific deadlock (FATE#303834).
- patches.suse/SoN-22-emergency-nf_queue.patch: netfilter:
  NF_QUEUE vs emergency skbs (FATE#303834).
- patches.suse/SoN-23-netvm.patch: netvm: skb processing
  (FATE#303834).
- patches.suse/SoN-24-mm-swapfile.patch: mm: add support for
  non block device backed swap files (FATE#303834).
- patches.suse/SoN-25-mm-page_file_methods.patch: mm: methods
  for teaching filesystems about PG_swapcache pages (FATE#303834).
- patches.suse/SoN-26-nfs-swapcache.patch: nfs: teach the NFS
  client how to treat PG_swapcache pages (FATE#303834).
- patches.suse/SoN-27-nfs-swapper.patch: nfs: disable data cache
  revalidation for swapfiles (FATE#303834).
- patches.suse/SoN-28-nfs-swap_ops.patch: nfs: enable swap on NFS
  (FATE#303834).
- patches.suse/SoN-29-nfs-alloc-recursions.patch: nfs: fix various
  memory recursions possible with swap over NFS. (FATE#303834).
- patches.xen/xen3-auto-common.diff: xen3 common.
* Fri Sep 26 2008 ptesarik@suse.cz
- split patches.arch/s390-01-01-self-ptrace-v3.patch to make it
  more obvious that the patch is not constrained to s390.
  The new series is:
    patches.suse/self-ptrace.patch: the generic pieces
    patches.arch/x86-self-ptrace.patch: implementation for x86
    patches.arch/s390-01-01-self-ptrace-v3.patch: dtto for s390
* Thu Sep 25 2008 jbeulich@novell.com
- Update Xen patches to 2.6.27-rc7 and c/s 676.
* Thu Sep 25 2008 olh@suse.de
- add patches.arch/ppc64-rpanote-relocate-firmware.patch
  update RPA note for firmware relocation (bnc#427960 - LTC48297)
* Wed Sep 24 2008 jblunck@suse.de
  This adds some tracepoint instrumentation taken from the LTTng patch
  series. Tracepoints are enabled for kernel-debug and kernel-trace only. I
  disabled ftrace for all flavors except kernel-debug and kernel-trace as well.
- Update config files.
- rpm/kernel-source.spec.in,kernel-binary.spec.in, config.conf: Add trace
  flavor
- patches.fixes/ia64-sparse-fixes.diff: ia64-kvm: fix sparse
  warnings.
- patches.xen/xen3-fixup-common: rediff
- patches.xen/xen3-auto-common.diff: rediff
- patches.xen/xen3-patch-2.6.21: rediff
- patches.xen/xen3-patch-2.6.26: rediff
- patches.trace/rcu-read-sched.patch
- patches.trace/markers-use-rcu-read-lock-sched.patch
- patches.trace/tracepoints.patch
- patches.trace/tracepoints-use-table-size-macro.patch
- patches.trace/tracepoints-documentation.patch
- patches.trace/tracepoints-tracepoint-synchronize-unregister.patch
- patches.trace/tracepoints-documentation-fix-teardown.patch
- patches.trace/tracepoints-samples.patch
- patches.trace/tracepoints-samples-fix-teardown.patch
- patches.trace/lttng-instrumentation-irq.patch
- patches.trace/lttng-instrumentation-scheduler.patch
- patches.trace/lttng-instrumentation-timer.patch
- patches.trace/lttng-instrumentation-kernel.patch
- patches.trace/lttng-instrumentation-filemap.patch
- patches.trace/lttng-instrumentation-swap.patch
- patches.trace/lttng-instrumentation-memory.patch
- patches.trace/lttng-instrumentation-page_alloc.patch
- patches.trace/lttng-instrumentation-hugetlb.patch
- patches.trace/lttng-instrumentation-net.patch
- patches.trace/lttng-instrumentation-ipv4.patch
- patches.trace/lttng-instrumentation-ipv6.patch
- patches.trace/lttng-instrumentation-socket.patch
- patches.trace/lttng-instrumentation-fs.patch
- patches.trace/lttng-instrumentation-ipc.patch
- patches.trace/ftrace-port-to-tracepoints.patch
- patches.trace/ftrace-framepointer.diff
* Tue Sep 23 2008 jjolly@suse.de
- patches.arch/s390-01-03-cmm2-v2.patch: kernel (new function):
  Collaborative Memory Management Stage II (bnc#417244)
- patches.xen/xen3-auto-common.diff: Modified patch to allow for
  the new patch
* Tue Sep 23 2008 jeffm@suse.de
- rpm/kernel-binary.spec.in: Enable sparse checking and section
  mismatch checking.
* Tue Sep 23 2008 jeffm@suse.de
- patches.kernel.org/arch-include-asm-fixes: kbuild: Properly
  handle arch/$arch/include/asm (bnc#427473).
* Mon Sep 22 2008 jeffm@suse.de
- patches.fixes/ext2-avoid-printk-flood-with-dir-corruption:
  ext2: Avoid printk floods in the face of directory corruption
  (bnc#427244 CVE-2008-3528).
- patches.fixes/ext3-avoid-printk-flood-with-dir-corruption:
  ext3: Avoid printk floods in the face of directory corruption
  (bnc#427244 CVE-2008-3528).
* Mon Sep 22 2008 jeffm@suse.de
- Update to 2.6.27-rc7.
  - Eliminated 2 patches.
  - patches.arch/s390-01-04-fcpperf-4.patch: Fixed up context.
* Mon Sep 22 2008 trenn@suse.de
  Workaround for ThinkPad brightness switching:
- patches.arch/acpi_video_thinkpad_exclude_IGD_devices.patch:
  Do not use video backlight switching for Lenovo ThinkPads.
  Commented out for now, possibly to be included later
- patches.drivers/cpufreq_add_cpu_number_paramater_1.patch:
  cpufreq: Add a cpu parameter to __cpufreq_driver_getavg()..
- patches.drivers/cpufreq_add_idle_microaccounting_6.patch:
  cpufreq,ondemand: Use get_cpu_idle_time_us() to get
  micro-accounted idle information.
- patches.drivers/cpufreq_change_load_calculation_2.patch:
  cpufreq, ondemand: Change the load calculation, optimizing
  for dependent cpus.
- patches.drivers/cpufreq_changes_to_get_cpu_idle_us_5.patch:
  export get_cpu_idle_time_us() .
- patches.drivers/cpufreq_get_cpu_idle_time_changes_3.patch:
  cpufreq,ondemand: Prepare changes for doing micro-accounting.
- patches.drivers/cpufreq_parameterize_down_differential_4.patch:
  cpufreq, ondemand: Use a parameter for down differential.
  Added CONFIG_PCIEASPM for rt, xen, powerpc and IA64 to be more
  consistent across different kernel flavors as suggested on the
  kernel list:
- Update config files.
* Mon Sep 22 2008 hare@suse.de
- patches.drivers/open-fcoe-libfc: Fix build error on IA64.
- patches.fixes/scsi-terminate-target-reset: Target reset hangs
  (bnc#427267).
- supported.conf: Update to include supported SCSI adapters.
* Fri Sep 19 2008 jbeulich@novell.com
- patches.suse/no-frame-pointer-select: Re-enable after removing FTRACE
  related change.
- Update x86 non-debug config files: Turn off FRAME_POINTER and FTRACE.
* Fri Sep 19 2008 nfbrown@suse.de
- patches.fixes/md-Allow-metadata_version-to-be-updated-for-externa.patch:
  md: Allow metadata_version to be updated for externally managed
  metadata. (FATE#304218).
- patches.fixes/md-Don-t-try-to-set-an-array-to-read-auto-if-it-i.patch:
  md: Don't try to set an array to 'read-auto' if it is already
  in that state. (FATE#304218).
* Thu Sep 18 2008 jbeulich@novell.com
- patches.suse/no-frame-pointer-select: Disable.
- Re-enable CONFIG_FRAME_POINTER in x86 config files.
* Thu Sep 18 2008 jbeulich@novell.com
- Update i386 and x86-64 config files (disable CONFIG_FRAME_POINTER in
  non-debug configs).
- patches.suse/stack-unwind: Add missing put_cpu()-s for x86-64.
- patches.suse/no-frame-pointer-select: Fix stack unwinder Kconfig
  (bnc#402518).
* Thu Sep 18 2008 hare@suse.de
- Update config files.
- patches.drivers/open-fcoe-driver: fcoe: Fibre Channel over
  Ethernet driver (FATE#303913).
- patches.drivers/open-fcoe-libfc: libfc: a modular software
  Fibre Channel implementation (FATE#303913).
- patches.drivers/open-fcoe-header-files: FC protocol definition
  header files (FATE#303913).
- patches.drivers/open-fcoe-dcb-support: FCoE: Add DCB support
  (FATE#303913).
- patches.drivers/ixgbe-fcoe-bugfixes: ixgbe: Bugfixes for FCoE.
- patches.fixes/vlan-gso-size-fix: vlan: device not reading gso
  max size of parent. (FATE#303913).
- patches.fixes/pkt_action-skbedit: pkt_action: add new action
  skbedit.
- patches.fixes/pkt_sched_multiq_support: pkt_sched: Add
  multiqueue scheduler support (FATE#303913).
- supported.conf: Update to include FCoE and device_handler
  modules
* Wed Sep 17 2008 jbeulich@novell.com
- supported.conf: adjust name of ide-cd (is now ide-cd_mod).
* Wed Sep 17 2008 hare@suse.de
- patches.drivers/qla2xxx-defer-risc-interrupt-enablement:
  qla2xxx: Defer enablement of RISC interrupts until ISP
  initialization completes (FATE#304113).
- patches.drivers/qla2xxx-8.02.01-k8-update: Update qla2xxx to
  8.02.01-k8 (FATE#304113).
* Wed Sep 17 2008 hare@suse.de
- patches.fixes/scsi-retry-hardware-error: make scsi_check_sense
  HARDWARE_ERROR return ADD_TO_MLQUEUE on retry (FATE#304042)
* Tue Sep 16 2008 olh@suse.de
- disable CONFIG_SPARSEMEM_VMEMMAP on ppc64 to allow memory remove
  (bnc#417537)
* Mon Sep 15 2008 jkosina@suse.de
- Update config files (build elousb driver as module)
- patches.drivers/elousb.patch: Elo USB touchscreen driver
  (FATE#304972).
* Mon Sep 15 2008 hare@suse.de
- patches.fixes/dm-mpath-abort-queue: Abort queued requests for
  multipath (FATE#304151).
* Mon Sep 15 2008 hare@suse.de
- Update config files: Disable CONFIG_OCFS2_COMPAT_JBD
* Mon Sep 15 2008 hare@suse.de
- patches.xen/xen-scsifront-block-timeout-update: Update XEN
  scsifront driver to request timeouts.
* Mon Sep 15 2008 sdietrich@suse.de
- Update config files: Enable GROUP_SCHED, FAIR_GROUP_SCHED,
  RT_GROUP_SCHED, CGROUP_SCHED
* Mon Sep 15 2008 hare@suse.de
- patches.drivers/block-timeout-handling: Fix typo.
* Fri Sep 12 2008 duwe@suse.de
- Add LED driver for SGI "UV" systems (FATE#304268)
* Fri Sep 12 2008 hare@suse.de
- patches.drivers/bdev-resize-added-flush_disk: Added
  flush_disk to factor out common buffer cache flushing code
  (FATE#302348,FATE#303786).
- patches.drivers/bdev-resize-adjust-block-device-size:
  Adjust block device size after an online resize of a
  disk. (FATE#302348,FATE#303786).
- patches.drivers/bdev-resize-call-flush_disk: Call flush_disk()
  after detecting an online resize. (FATE#302348,FATE#303786).
- patches.drivers/bdev-resize-check-for-device-resize:
  Check for device resize when rescanning partitions
  (FATE#302348,FATE#303786).
- patches.drivers/bdev-resize-sd-driver-calls: SCSI sd driver
  calls revalidate_disk wrapper (FATE#302348,FATE#303786).
- patches.drivers/bdev-resize-wrapper-for-revalidate_disk:
  Wrapper for lower-level revalidate_disk
  routines. (FATE#302348,FATE#303786).
- patches.drivers/block-timeout-handling: block: unify request
  timeout handling (FATE#304151,bnc#417544).
- patches.fixes/scsi-misc-git-update: SCSI misc fixes
  (FATE#303485,FATE#303484).
- patches.fixes/scsi-enhance-error-codes: Separate failfast into
  multiple bits (FATE#303485,FATE#303484).
- patches.suse/rq-based-block-layer: rediff.
- patches.suse/rq-based-multipath-functions: rediff.
- patches.suse/no-partition-scan: rediff.
* Fri Sep 12 2008 hare@suse.de
- patches.fixes/scsi-misc-git-update: SCSI misc fixes,
  required by the driver updates (FATE#303485,FATE#303484)
* Fri Sep 12 2008 hare@suse.de
- patches.drivers/lpfc-8.2.8.1-update: Update lpfc to 8.2.8.1
  (bnc#420767).
- patches.drivers/lpfc-8.2.8-update: Emulex lpfc driver update
  to 8.2.8 (FATE#303485,bnc#420767).
* Fri Sep 12 2008 bwalle@suse.de
- patches.arch/ia64-kdump_proc_iomem.diff:
  IA64: assign a distinguishable label to uncached memory in
  /proc/iomem (to fix MCA on kdump boot).
* Thu Sep 11 2008 jack@suse.cz
  Latest ext4 fixes from ext4 patch queue:
- patches.fixes/ext4-Add-inode-to-journal-handle-after-block-alloca.patch:
  ext4: Don't add the inode to journal handle until after the
  block is allocated (fate#303783).
- patches.fixes/ext4_add-missing-unlock-to-ext4-check-descriptors:
  ext4: add missing unlock in ext4_check_descriptors() on error
  path (fate#303783).
- patches.fixes/ext4-Add-percpu-dirty-block-accounting.patch:
  ext4: Add percpu dirty block accounting. (fate#303783).
- patches.fixes/ext4_create-proc-ext4-stats-file-more-carefully:
  ext4: fix #11321: create /proc/ext4/*/stats more carefully
  (fate#303783).
- patches.fixes/ext4_fix_longlong_checkpatch_issues: ext4:
  Fix long long checkpatch warnings (fate#303783).
- patches.fixes/ext4_fix_printk_checkpatch_issues: ext4:
  Add printk priority levels to clean up checkpatch warnings
  (fate#303783).
- patches.fixes/ext4_fix_whitespace_checkpatch_issues: ext4:
  Fix whitespace checkpatch warnings/errors (fate#303783).
- patches.fixes/ext4_i_disksize_lock_race_fix.patch: ext4:
  Properly update i_disksize. (fate#303783).
- patches.fixes/ext4_invalidate_pages_when_delalloc_alloc_fail.patch:
  ext4: invalidate pages if delalloc block allocation
  fails. (fate#303783).
- patches.fixes/ext4-Make-sure-all-the-block-allocation-paths-reser.patch:
  ext4: Make sure all the block allocation paths reserve blocks
  (fate#303783).
- patches.fixes/ext4_nonmballoc_reservation_ENOSPC_fix.patch:
  ext4: Fix ext4 nomballoc allocator for ENOSPC (fate#303783).
- patches.fixes/ext4-Retry-block-allocation-if-we-have-free-blocks.patch:
  ext4: Retry block allocation if we have free blocks left
  (fate#303783).
- patches.fixes/ext4-Retry-block-reservation.patch: ext4: Retry
  block reservation (fate#303783).
- patches.fixes/ext4-Signed-arithematic-fix.patch: ext4: Signed
  arithematic fix (fate#303783).
- patches.fixes/ext4-Switch-to-non-delalloc-mode-when-we-are-low-on.patch:
  ext4: Switch to non delalloc mode when we are low on free
  blocks count. (fate#303783).
- patches.fixes/ext4_truncate_block_allocated_on_a_failed_ext4_write_begin.patch:
  ext4: truncate block allocated on a failed ext4_write_begin
  (fate#303783).
- patches.fixes/ext4_update-flex-bg-counters-when-resizing:
  Update flex_bg free blocks and free inodes counters when
  resizing. (fate#303783).
- patches.fixes/percpu_counter_sum_cleanup.patch: percpu counter:
  clean up percpu_counter_sum_and_set() (fate#303783).
* Thu Sep 11 2008 bwalle@suse.de
- Enable KDB for i386 and x86_64 in "default" and "pae"
  configuration with CONFIG_KDB_OFF set to "y" (FATE#303971).
- Set CONFIG_KDB_CONTINUE_CATASTROPHIC=2 in all configurations
  that have KDB enabled.
* Thu Sep 11 2008 jslaby@suse.de
- Update config files.
  enable PID_NS and USER_NS
  (FATE#303785, FATE#304371)
* Thu Sep 11 2008 jeffm@suse.de
- Update config files.
  - Enabled CONFIG_XFRM_SUB_POLICY (FATE#303781)
* Thu Sep 11 2008 mfasheh@suse.com
- Added POSIX File Locks support for Ocfs2  (FATE#110294)
  - patches.suse/ocfs2-POSIX-file-locks-support.patch
* Thu Sep 11 2008 mfasheh@suse.com
- Added Ocfs2 JBD2 Support  (FATE#302877)
  - patches.suse/ocfs2-Limit-inode-allocation-to-32bits.patch
  - patches.suse/ocfs2-Add-the-inode64-mount-option.patch
  - patches.suse/ocfs2-Switch-over-to-JBD2.patch
* Thu Sep 11 2008 mfasheh@suse.com
- Added Ocfs2 Extended Attributes Support (FATE#302067)
  - patches.suse/ocfs2-Modify-ocfs2_num_free_extents-f.patch
  - patches.suse/ocfs2-Use-ocfs2_extent_list-instead-o.patch
  - patches.suse/ocfs2-Abstract-ocfs2_extent_tree-in-b.patch
  - patches.suse/ocfs2-Make-high-level-btree-extend-co.patch
  - patches.suse/ocfs2-Add-the-basic-xattr-disk-layout-in-ocf.patch
  - patches.suse/ocfs2-Add-helper-function-in-uptodate.patch
  - patches.suse/ocfs2-Add-extent-tree-operation-for-x.patch
  - patches.suse/ocfs2-reserve-inline-space-for-extend.patch
  - patches.suse/ocfs2-Add-extended-attribute-support.patch
  - patches.suse/ocfs2-Add-xattr-index-tree-operations.patch
  - patches.suse/ocfs2-Add-xattr-bucket-iteration-for.patch
  - patches.suse/ocfs2-Add-xattr-lookup-code-xattr-btr.patch
  - patches.suse/ocfs2-Optionally-limit-extent-size-in.patch
  - patches.suse/ocfs2-Enable-xattr-set-in-index-btree.patch
  - patches.suse/ocfs2-Delete-all-xattr-buckets-during.patch
  - patches.suse/ocfs2-Add-incompatible-flag-for-exten.patch
  - patches.suse/ocfs2-fix-printk-format-warnings.patch
  - patches.suse/ocfs2-Prefix-the-extent-tree-operations-structure.patch
  - patches.suse/ocfs2-Prefix-the-ocfs2_extent_tree-structure.patch
  - patches.suse/ocfs2-Make-ocfs2_extent_tree-get-put-instead-of-all.patch
  - patches.suse/ocfs2-Make-private-into-object-on-ocfs2_extent_.patch
  - patches.suse/ocfs2-Provide-the-get_root_el-method-to-ocfs2_ext.patch
  - patches.suse/ocfs2-Use-struct-ocfs2_extent_tree-in-ocfs2_num_fre.patch
  - patches.suse/ocfs2-Determine-an-extent-tree-s-max_leaf_clusters.patch
  - patches.suse/ocfs2-Create-specific-get_extent_tree-functions.patch
  - patches.suse/ocfs2-Add-an-insertion-check-to-ocfs2_extent_tree_o.patch
  - patches.suse/ocfs2-Make-ocfs2_extent_tree-the-first-class-repres.patch
  - patches.suse/ocfs2-Comment-struct-ocfs2_extent_tree_operations.patch
  - patches.suse/ocfs2-Change-ocfs2_get_-_extent_tree-to-ocfs2_ini.patch
  - patches.suse/ocfs2-bug-fix-for-journal-extend-in-xattr.patch
  - patches.suse/ocfs2-Resolve-deadlock-in-ocfs2_xattr_free_.patch
  - patches.suse/ocfs2-Add-xattr-mount-option-in-ocfs2_show_options.patch
* Thu Sep 11 2008 mfasheh@suse.com
- Add patches.fixes/jbd2-create-proc-entry-fix.patch
  jbd2: Create proc entry with bdevname+i_ino.
  (FATE#302877)
* Thu Sep 11 2008 mfasheh@suse.com
- Add patches.fixes/dlm-allow-multiple-lockspaces.patch
  dlm: allow multiple lockspace creates
  (FATE#110294)
* Thu Sep 11 2008 schwab@suse.de
- Update kdb patches.
* Thu Sep 11 2008 jslaby@suse.de
- Update config files.
  change CONFIG_NODES_SHIFT from 6 to 9
  (FATE#304261)
* Wed Sep 10 2008 trenn@suse.de
- Update config files.
  Added: CONFIG_PCIEASPM
* Wed Sep 10 2008 kkeil@suse.de
- patches.drivers/e1000e_add_82574L.patch: e1000e: add support
  for new 82574L part.
- patches.drivers/e1000e_add_ICH9_BM.patch: e1000e: add support
  for the 82567LM-4 device.
- patches.drivers/e1000e_add_LOM_devices.patch: e1000e: add
  support for 82567LM-3 and 82567LF-3 (ICH10D).
  (FATE#303916)
* Wed Sep 10 2008 hare@suse.de
- patches.suse/no-partition-scan: Implement 'no_partition_scan'
  commandline option (FATE#303697)
* Wed Sep 10 2008 jeffm@suse.de
- patches.kernel.org/ipmi-section-conflict.diff: ipmi: Fix
  section type conflicts.
- patches.kernel.org/psmouse-section-conflict.diff: psmouse:
  fix section type conflict.
- patches.kernel.org/carmine-section-mismatch: video: Fix section
  mismatch in carminefb.
- patches.kernel.org/md-section-conflict: md: Fix section
  conflicts.
- patches.kernel.org/setup_APIC_timer-section-mismatch: x86:
  Fix section conflict with kvm_setup_secondary_clock.
* Wed Sep 10 2008 trenn@suse.de
- patches.arch/thinkpad_fingers_off_backlight_igd.patch:
  Serve ThinkPad IGD devices backlight functionality through
  thinkpad_acpi (fate #302883).
- supported.conf: Add most important laptop drivers as supported:
    kernel/drivers/misc/asus_laptop
    kernel/drivers/misc/eeepc-laptop
    kernel/drivers/misc/msi-laptop
    kernel/drivers/misc/fujitsu-laptop
    kernel/drivers/acpi/wmi
    kernel/drivers/misc/hp-wmi
* Wed Sep 10 2008 jeffm@suse.de
- patches.suse/acpi-dsdt-initrd-v0.9a-2.6.25.patch: Fixed up
  some section conflicts.
* Wed Sep 10 2008 jeffm@suse.de
- Update to 2.6.27-rc6.
* Wed Sep 10 2008 jeffm@suse.de
- supported.conf: Added missing netfilter modules.
* Wed Sep 10 2008 jeffm@suse.de
- supported.conf: Updated netfilter module names.
* Wed Sep 10 2008 jeffm@suse.de
- patches.kernel.org/firmware-path: Updated header.
* Wed Sep 10 2008 jkosina@suse.de
- Update config files: support more than 4 serial ports
  (FATE#303314)
* Wed Sep 10 2008 olh@suse.de
- set CONFIG_CMM=y instead of =m to simplify virtual partition memory
  (bnc#417554)
* Tue Sep  9 2008 bphilips@suse.de
- rpm/kernel-binary.spec.in: add Recommends: kerneloops
* Tue Sep  9 2008 olh@suse.de
- Updated to 2.6.27-rc5-git10
* Mon Sep  8 2008 olh@suse.de
- Updated to 2.6.27-rc5-git9
* Fri Sep  5 2008 jjolly@suse.de
- patches.arch/s390-01-01-self-ptrace-v3.patch: system call
  notification with self_ptrace (bnc#417299)
- patches.arch/s390-01-02-dcss-64-v2.patch: dcssblk (new function):
  Add support for >2G DCSS and stacked contiguous DCSS support.
  (bnc#417246)
- patches.arch/s390-01-04-fcpperf-{1-4}.patch: (kernel):FCP -
  Performance Data colletion & analysis (bnc#417243)
* Fri Sep  5 2008 olh@suse.de
- add patches.fixes/usb-hcd-interrupt-shared.patch
  fix interrupt handling for shared irqs, for PS3 (bnc#409961)
* Fri Sep  5 2008 olh@suse.de
- Updated to 2.6.27-rc5-git7
* Thu Sep  4 2008 olh@suse.de
- build with CONFIG_POWER4_ONLY (bnc#417566)
  this disables support for POWER3 and RS64 cpus
* Thu Sep  4 2008 jkosina@suse.de
- switch from Reno to Cubic as default TCP congestion algorithm
  (bnc#422825)
* Thu Sep  4 2008 bwalle@suse.de
- Update KDB patches. Fix build on x86_64-debug.
* Wed Sep  3 2008 jeffm@suse.de
- mark crc-t10dif as supported
* Wed Sep  3 2008 olh@suse.de
- mark pata_pdc2027x as supported
* Wed Sep  3 2008 olh@suse.de
- mark spidernet as supported
* Wed Sep  3 2008 olh@suse.de
- mark ehea as supported
* Wed Sep  3 2008 trenn@suse.de
- supported.conf:
  Mark dock (libata depends on it), bay, acpi_memhotplug, hpilo
  as supported
  Remove or adjust supported laptop drivers that went from
  drivers/acpi to drivers/misc
* Wed Sep  3 2008 hare@suse.de
- supported.conf: Mark virtio modules as supported.
* Tue Sep  2 2008 jbeulich@novell.com
- Update Xen patches to 2.6.27-rc5 and c/s 651.
* Tue Sep  2 2008 jjolly@suse.de
- patches.arch/s390-01-01-self-ptrace-v2.patch: kernel
  (new function): System call notification with self_ptrace
  (bnc#417299,FATE#304021)
* Mon Sep  1 2008 agruen@suse.de
- File capabilities: replace our no_file_caps patch with what is
  supposed to end up in 2.6.28.
* Mon Sep  1 2008 bwalle@suse.de
- patches.arch/ia64-node_mem_map-node_start_pfn.diff:
  Fix memory map for ia64/discontmem for kdump.
* Mon Sep  1 2008 olh@suse.de
- Updated to 2.6.27-rc5-git2
* Fri Aug 29 2008 jeffm@suse.de
- Updated to 2.6.27-rc5.
  - Eliminated 2 patches.
  - KDB has an incompatible change on x86_64, so kernel-debug
    will fail there.
* Fri Aug 29 2008 olh@suse.de
- update message in post.sh to display also the rpm FLAVOR
* Thu Aug 28 2008 olh@suse.de
- update patches.suse/dm-raid45-2.6.25-rc2_20080221.patch
  rename rh_init to region_hash_init to avoid conflict
  with existing powerpc symbol on powerpc
* Thu Aug 28 2008 olh@suse.de
- disable musb, not useful, does not compile
* Tue Aug 26 2008 trenn@suse.de
  Vendor specific drivers vs generic video driver.
  Distinguish which ACPI driver should do backlight switching.
  This patch series is queued up for 2.6.28 in the ACPI branch:
- patches.arch/0000-ACPI-video-Ignore-devices-not-present.patch:
  ACPI: video: Ignore devices that aren't present in hardware.
- patches.arch/0001-Check-for-ACPI-backlight-support.patch: Check
  for ACPI backlight support otherwise use vendor ACPI drivers.
- patches.arch/0002-Acer-WMI-fingers-off-backlight-video.ko.patch:
  Acer-WMI: fingers off backlight if video.ko is serving this
  functionality.
- patches.arch/0003-Asus-acpi-fingers-off-backlight.patch:
  asus-acpi: fingers off backlight if video.ko is serving this
  functionality.
- patches.arch/0004-Compal-fingers-off-backlight.patch: compal:
  fingers off backlight if video.ko is serving this functionality.
- patches.arch/0005-eeepc-laptop-fingers-off.patch: eeepc-laptop:
  fingers off backlight if video.ko is serving this functionality.
- patches.arch/0006-fujitsu-laptop-fingers-off-backlight.patch:
  fujitsu-laptop: fingers off backlight if video.ko is serving
  this functionality.
- patches.arch/0007-msi-laptop-fingers-off-backlight.patch:
  msi-laptop: fingers off backlight if video.ko is serving this
  functionality.
- patches.arch/0008-sony-laptop-fingers-off-backlight.patch:
  sony-laptop: fingers off backlight if video.ko is serving
  this functionality.
- patches.arch/0009-thinkpad_acpi-fingers-off-backlight.patch:
  thinkpad_acpi: fingers off backlight if video.ko is serving
  this functionality.
  I had to refresh these. While one patch was broken,
  two lines were missing, "patch" from 11.0 still worked, while
  "patch" from 10.3 did not:
- patches.xen/add-console-use-vt: add console_use_vt.
- patches.xen/linux-2.6.19-rc1-kexec-move_segment_code-i386.patch:
  kexec: Move asm segment handling code to the assembly file
  (i386).
* Mon Aug 25 2008 jeffm@suse.de
- Disabled patches.kernel.org/ia64-asm-nr-irqs
* Mon Aug 25 2008 jeffm@suse.de
- patches.fixes/pseries-compile-fix: pseries: compile fix.
* Mon Aug 25 2008 jeffm@suse.de
- patches.kernel.org/musb-powerpc-conflict: musb: compile fix
  for powerpc.
* Mon Aug 25 2008 jeffm@suse.de
- patches.kernel.org/ia64-asm-nr-irqs: ia64: nr-irqs.h generation
  should place it in arch/../asm.
* Mon Aug 25 2008 jeffm@suse.de
- Update config files.
* Mon Aug 25 2008 jeffm@suse.de
- Updated to 2.6.27-rc4.
  - Refreshed context.
* Mon Aug 25 2008 trenn@suse.de
- patches.arch/x86-introduce-pci-noioapicquirk-kernel-cmdline.patch:
  x86, pci: introduce pci=noioapicquirk kernel cmdline option.
  Mysterious patch problem in include/asm-x86/pci.h
- patches.fixes/acpi-clear-wake-status.patch: Clear wak_sts
  register on resume.
* Mon Aug 25 2008 trenn@suse.de
- patches.suse/acpi_provide_non_windows_osi_boot_param.patch:
  Delete.
* Mon Aug 25 2008 jbeulich@novell.com
- Update Xen patches to 2.6.27-rc4.
- patches.xen/xen-x86_64-dump-user-pgt: dump the correct page
  tables for user mode faults.
- patches.xen/xen-x86_64-pgd-alloc-order: don't require order-1
  allocations for pgd-s.
- patches.xen/xen-x86_64-pgd-pin: make pinning of pgd pairs
  transparent to callers.
- patches.xen/xen-blktap-write-barriers: blktap: Write Barriers.
- patches.xen/xen-x86-pmd-handling: consolidate pmd/pud/pgd entry
  handling.
- patches.xen/xen-x86-bigmem: fix issues with the assignment of
  huge amounts of memory.
- patches.xen/xen-msix-restore: print at least a message if MSI-X
  restore failed.
- config.conf: Re-enable Xen.
- patches.xen/sfc-i2c: Delete.
- Update config files.
* Fri Aug 22 2008 jbeulich@novell.com
- patches.suse/stack-unwind: Adjust and re-enable.
- Update config files.
* Tue Aug 19 2008 jeffm@suse.de
- patches.kernel.org/ps3-lpm-include: Delete.
* Tue Aug 19 2008 jeffm@suse.de
- Removed unused patches.
* Tue Aug 19 2008 tiwai@suse.de
- Update config files: Use CONFIG_INPUT_PCSPKR=m (bnc#225221)
* Mon Aug 18 2008 schwab@suse.de
- Update config files.
* Mon Aug 18 2008 schwab@suse.de
- Update kdb patches.
* Fri Aug 15 2008 tiwai@suse.de
- patches.arch/ppc-ipic-suspend-without-83xx-fix: Fix build_error
  without CONFIG_PPC_83xx.
- Update config files.
* Fri Aug 15 2008 tiwai@suse.de
- Update config files: disable CONFIG_IPIC for ppc/default and
  vanilla again to fix build
* Fri Aug 15 2008 tiwai@suse.de
- rpm/kernel-binary.spec.in: fix build without firmware files
* Fri Aug 15 2008 jeffm@suse.de
- patches.kernel.org/no-include-asm: kbuild: correctly link
  include/asm in external builds.
* Fri Aug 15 2008 jeffm@suse.de
- patches.kernel.org/ath9k-workaround-gcc-ICE-again-on-powerpc:
  ath9k: work around gcc ICE again.
* Thu Aug 14 2008 jeffm@suse.de
- patches.suse/novfs-gregorian-day-fix: novfs: Fix GregorianDay
  conflict.
* Thu Aug 14 2008 jeffm@suse.de
- Enabled patches.kernel.org/firmware-path
* Thu Aug 14 2008 jeffm@suse.de
- patches.apparmor/add-security_path_permission: Fixed duplicate
  export of security_inode_permission.
* Thu Aug 14 2008 jeffm@suse.de
- patches.apparmor/add-security_path_permission: Add missing
  stub for security_path_permission when CONFIG_SECURITY_APPARMOR=n
* Thu Aug 14 2008 jeffm@suse.de
- patches.kernel.org/firmware-path: firmware: Allow
  release-specific firmware dir.
- rpm/kernel-binary.spec.in: Add firmware files.
* Thu Aug 14 2008 jeffm@suse.de
- patches.kernel.org/ia64-export-cpu_core_map: ia64: Export
  cpu_core_map for topology_core_siblings.
* Thu Aug 14 2008 jeffm@suse.de
- Updated to 2.6.27-rc3.
  - AppArmor mostly merged. There may be some hiccups.
  - Xen and RT temporarily disabled for merging.
  - 17 patches eliminated.
* Thu Aug 14 2008 ghaskins@suse.de
  Guarded by +RT
- patches.rt/seqlock-make-raw-seqlocks-spin-during-write.patch:
  seqlock: make sure that raw_seqlock_t retries readers while
  writes are pending.
- patches.rt/ftrace-fix-elevated-preempt-count-in-wakeup-tracer.patch:
  ftrace: fix elevated preempt_count in wakeup-tracer.
* Fri Aug  8 2008 hare@suse.de
- Update config files for RT kernel to activate SCSI
  device handler.
* Fri Aug  8 2008 jbeulich@novell.com
- patches.xen/xen3-fixup-common, patches.xen/xen3-fixup-kconfig,
  patches.xen/xen3-patch-2.6.24, patches.xen/xen3-patch-2.6.25: Fix
  a couple of bugs and inconsistencies.
* Fri Aug  8 2008 schwab@suse.de
- Fix reference to $RPM_BUILD_ROOT in makefiles.
* Fri Aug  8 2008 hare@suse.de
- patches.fixes/dm-mpath-hp-sw.patch: Delete.
- Update config files.
- patches.fixes/dm-2.6.27-update: Upstream device-mapper patches
  (FATE#302108).
- patches.fixes/scsi_dh-2.6.27-update: SCSI device handler update
  (FATE#302269,FATE#303696,FATE#303754,FATE#304125).
- patches.suse/rq-based-block-layer: rq-based multipathing:
  block layer changes (FATE#302108).
- patches.suse/rq-based-dm-interface: rq-based multipathing:
  device-mapper interface (FATE#302108).
- patches.suse/rq-based-multipath-functions: rq-based
  multipathing: request-based functions to multipath
  (FATE#302108).
* Thu Aug  7 2008 jbeulich@novell.com
- Update Xen patches to c/s 623.
- patches.xen/sfc-network-driver: Delete.
- patches.xen/xen-balloon-hvm-min: Delete.
- patches.xen/xen-netfront-flip-prod: Delete.
- patches.xen/xen-x86_64-init-cleanup: Delete.
- patches.xen/sfc-i2c: sfc: Use kernel I2C system and i2c-algo-bit
  driver (disabled).
- patches.xen/sfc-driverlink: Solarflare: Resource driver (disabled).
- Update Xen config files.
* Wed Aug  6 2008 olh@suse.de
- add patches.suse/ppc-no-LDFLAGS_MODULE.patch
  do not link external modules against arch/powerpc/lib/crtsavres.o
* Tue Aug  5 2008 jeffm@suse.de
- patches.fixes/reiserfs-commit-ids-unsigned-ints: reiserfs:
  audit transaction ids to always be unsigned ints (bnc#410847).
* Tue Aug  5 2008 jeffm@suse.de
- README.BRANCH: Took ownership of 11.1 tree.
* Tue Aug  5 2008 jeffm@suse.de
- README: Changed w3d links to wiki links.
* Tue Aug  5 2008 ghaskins@suse.de
  Fixed misnamed rt_trace to rt_timing
- config/x86_64/rt_trace: Delete.
- Update config files.
- config.conf:
* Tue Aug  5 2008 ghaskins@suse.de
  Added x86_64/rt_trace kernel flavor (based on ftrace)
- Update config files.
- config.conf:
* Tue Aug  5 2008 ghaskins@suse.de
  Guarded by +RT
- Fix rtmutex-tester build problem with rt_debug
- patches.rt/rtmutex-convert-to-libpi.patch: rtmutex: convert
  rtmutexes to fully use the PI library.
* Tue Aug  5 2008 ghaskins@suse.de
  Guarded by +RT
- Remove version.patch to stop build breakage
* Tue Aug  5 2008 jjohansen@suse.de
- update apparmor patches with fixes for
  - broken getcwd (bnc#413915)
  - ref counting bug in getcwd and d_namespace_path when used
    on disconnected paths (bnc#414607)
  - typeo in patches that keep selinux from compiling (bnc#414609)
  - incorporate smack patch into base apparmor patches, so
    that smack can be built (bnc#414610)
* Tue Aug  5 2008 jslaby@suse.de
- patches.fixes/ath5k-fix-memory-corruption.patch: Ath5k: fix
  memory corruption (bnc#414635).
- patches.fixes/ath5k-kill-tasklets-on-shutdown.patch: Ath5k:
  kill tasklets on shutdown (bnc#414638).
* Mon Aug  4 2008 gregkh@suse.de
- README.BRANCH: added file.
* Mon Aug  4 2008 olh@suse.de
- disable CONFIG_SECURITY_ROOTPLUG because /init in initrd will
  not run if USB is compiled in and a specific USB device is not
  present
* Mon Aug  4 2008 jslaby@suse.de
- patches.fixes/tpm-write-data-types.patch: tpm: Use correct
  data types for sizes in tpm_write() and tpm_read() (bnc#400211).
* Fri Aug  1 2008 ghaskins@suse.de
  PI rework v0.5 and a fix from upstream for 26-rt1
- patches.rt/26-rt1-chirag.patch: This patch should solve some
  of the bug messages..
- patches.rt/add-generalized-pi-interface.patch: add generalized
  priority-inheritance interface.
- patches.rt/tie-pi-into-task.patch: sched: add the basic PI
  infrastructure to the task_struct.
- patches.rt/rtmutex-initialize-waiters.patch: rtmutex: formally
  initialize the rt_mutex_waiters.
- patches.rt/rtmutex-add_readers.patch: RT: wrap the rt_rwlock
  "add reader" logic.
- patches.rt/rtmutex-use-runtime-init.patch: rtmutex: use runtime
  init for rtmutexes.
- patches.rt/rtmutex-convert-to-libpi.patch: rtmutex: convert
  rtmutexes to fully use the PI library.
- patches.rt/rtmutex-defer-pi-until-sleepy.patch: rtmutex:
  pi-boost locks as late as possible.
* Fri Aug  1 2008 schwab@suse.de
- Reenable EFI_RTC.
* Fri Aug  1 2008 trenn@suse.de
- Update config files.
  Unset on forgotten archs:
  CONFIG_X86_REROUTE_FOR_BROKEN_BOOT_IRQS
* Fri Aug  1 2008 trenn@suse.de
- patches.fixes/x86_hpet_amd_quirk.patch: Workaround a hpet BIOS
  bug which is common on latest AMD driven boards (bnc#387053).
* Fri Aug  1 2008 sassmann@suse.de
  Add boot interrupt patches from linux-2.6-tip
- patches.arch/x86-acpi-reroute-PCI-interrupt-to-legacy-boot-interrupt.patch
- patches.arch/x86-add-PCI-IDs-for-devices-that-need-boot-irq-quirk.patch
- patches.arch/x86-disable-AMD-ATI-boot-interrupt-generation.patch
- patches.arch/x86-disable-broadcomm-boot-interrupt-generation.patch
- patches.arch/x86-disable-intel-boot-interrupt-generation.patch
- patches.arch/x86-introduce-config-option-for-pci-reroute-quirks.patch
- patches.arch/x86-introduce-pci-ioapicreroute-kernel-cmdline.patch
- patches.arch/x86-introduce-pci-noioapicquirk-kernel-cmdline.patch
- Update config files.
  * reroute of boot interrupts is enabled for RT only!
* Thu Jul 31 2008 sdietrich@suse.de
  Update to 2.6.26-rt1:
- config.conf: Enable i386/x86_64 - RT / RT_debug
- Update config files:
  * Sync to default config.
  * Disable (broken):
  - Novell Netware Filesystem support (novfs) (EXPERIMENTAL) (NOVFS)
  - ISP 1760 HCD support (USB_ISP1760_HCD)
  - KDB
  - QLogic InfiniPath Driver (INFINIBAND_IPATH)
  Remove obsolete patches:
- patches.rt/arm-cmpxchg-support-armv6.patch: Delete.
- patches.rt/arm-cmpxchg.patch: Delete.
- patches.rt/arm-fix-atomic-cmpxchg.patch: Delete.
- patches.rt/arm-leds-timer.patch: Delete.
- patches.rt/arm-omap-03.patch: Delete.
- patches.rt/arm-omap-04.patch: Delete.
- patches.rt/disable-sched-rt-groups.patch: Delete.
- patches.rt/drivers-edac-add-support-for-HS21XM-SMI-remediation:
  Delete.
- patches.rt/drivers-edac-add-support-for-HS21_LS21-SMI-remediation:
  Delete.
- patches.rt/drivers-edac-add-sysfs_notify-calls.patch: Delete.
- patches.rt/drivers-edac-i5000-turn-off-unsupported-check:
  Delete.
- patches.rt/drivers-edac-new-amd64.patch: Delete.
- patches.rt/drivers-edac-new-k8-rev-f.patch: Delete.
- patches.rt/drivers-edac-prevent-potential-printk-storm: Delete.
- patches.rt/drivers-edac-test_device.patch: Delete.
- patches.rt/ep93xx-clockevents-fix.patch: Delete.
- patches.rt/ep93xx-clockevents.patch: Delete.
- patches.rt/ep93xx-timer-accuracy.patch: Delete.
- patches.rt/fix-alternate_node_alloc.patch: Delete.
- patches.rt/fix-irq-flags-size.patch: Delete.
- patches.rt/foo.patch: Delete.
- patches.rt/ftrace-add-nr_syscalls.patch: Delete.
- patches.rt/ftrace-alloc-pages.patch: Delete.
- patches.rt/ftrace-cpu-clock-update.patch: Delete.
- patches.rt/ftrace-debug-use-preempt-disable-notrace.patch:
  Delete.
- patches.rt/ftrace-direct-calls.patch: Delete.
- patches.rt/ftrace-disable-daemon.patch: Delete.
- patches.rt/ftrace-dont-use-raw-irq-save.patch: Delete.
- patches.rt/ftrace-eventtrace-fixup.patch: Delete.
- patches.rt/ftrace-filter-functions.patch: Delete.
- patches.rt/ftrace-fix-ip.patch: Delete.
- patches.rt/ftrace-flip-fix.patch: Delete.
- patches.rt/ftrace-handle-time-outside-of-lockdep.patch: Delete.
- patches.rt/ftrace-irqsoff-smp-processor-id-fix.patch: Delete.
- patches.rt/ftrace-lockdep-notrace-annotations.patch: Delete.
- patches.rt/ftrace-max-update-fixes.patch: Delete.
- patches.rt/ftrace-move-memory-management-to-generic.patch:
  Delete.
- patches.rt/ftrace-nop-calls.patch: Delete.
- patches.rt/ftrace-peterz-cpu_clock.patch: Delete.
- patches.rt/ftrace-remove-max-printks.patch: Delete.
- patches.rt/ftrace-safe-traversal-hlist.patch: Delete.
- patches.rt/ftrace-stop-function-trace-fix.patch: Delete.
- patches.rt/ftrace-unlock-mutex-in-output.patch: Delete.
- patches.rt/ftrace-update-cnt-stat-fix.patch: Delete.
- patches.rt/ftracer-build-fix.patch: Delete.
- patches.rt/futex-performance-hack-sysctl-fix.patch: Delete.
- patches.rt/futex-performance-hack.patch: Delete.
- patches.rt/git-ignore-module-markers.patch: Delete.
- patches.rt/irq-flags-unsigned-long.patch: Delete.
- patches.rt/kernel-bug-after-entering-something-from-login.patch:
  Delete.
- patches.rt/kthread-cpus-allowed-init.patch: Delete.
- patches.rt/kvm-lapic-migrate-latency-fix.patch: Delete.
- patches.rt/kvm-make-less-noise.patch: Delete.
- patches.rt/kvm-preempt-rt-resched-delayed.patch: Delete.
- patches.rt/latency-tracing-prctl-api-hack.patch: Delete.
- patches.rt/netfilter-more-debugging.patch: Delete.
- patches.rt/page-alloc-use-real-time-pcp-locking-for-page-draining.patch:
  Delete.
- patches.rt/pcounter-percpu-protect.patch: Delete.
- patches.rt/percpu-locked-powerpc-fixups-a6.patch: Delete.
- patches.rt/powerpc-rearrange-thread-flags-to-work-with-andi-instruction.patch:
  Delete.
- patches.rt/ppc-add-mcount.patch: Delete.
- patches.rt/ppc-add-ppc32-mcount.patch: Delete.
- patches.rt/ppc-mark-notrace-mainline.patch: Delete.
- patches.rt/ppc-mcount-dummy-functions.patch: Delete.
- patches.rt/ppc-rename-xmon-mcount.patch: Delete.
- patches.rt/ppc-select-mcount.patch: Delete.
- patches.rt/preempt-irqs-ppc-celleb-beatic-eoi.patch: Delete.
- patches.rt/preempt-irqs-softirq-in-hardirq.patch: Delete.
- patches.rt/preempt-realtime-powerpc-a7.patch: Delete.
- patches.rt/preempt-realtime-ppc-more-resched-fixups.patch:
  Delete.
- patches.rt/preempt-realtime-ppc-need-resched-delayed.patch:
  Delete.
- patches.rt/preempt-realtime-sh.patch: Delete.
- patches.rt/preempt-realtime-supress-cpulock-warning.patch:
  Delete.
- patches.rt/rcu-preempt-trace-markers-1.patch: Delete.
- patches.rt/rcu-preempt-trace-markers-2.patch: Delete.
- patches.rt/rcu-various-fixups.patch: Delete.
- patches.rt/rt-mutex-arm-fix.patch: Delete.
- patches.rt/rt-mutex-delayed-resched.patch: Delete.
- patches.rt/rt-mutex-drop-generic-TIF_NEED_RESCHED_DELAYED.patch:
  Delete.
- patches.rt/rt-time-starvation-fix.patch: Delete.
- patches.rt/rtmutex-adaptive-locks.patch: Delete.
- patches.rt/rtmutex-adaptive-timeout.patch: Delete.
- patches.rt/rtmutex-lateral-steal-sysctl.patch: Delete.
- patches.rt/sched-fix-rt-task-wakeup.patch: Delete.
- patches.rt/sched-fix-sched-fair-wakeup.patch: Delete.
- patches.rt/sched-rt-push-only-new.patch: Delete.
- patches.rt/schedule_on_each_cpu-enhance-rt.patch: Delete.
- patches.rt/tasklet-fix-preemption-race.patch: Delete.
- patches.rt/tasklet-more-fixes.patch: Delete.
- patches.rt/time-gcc-linker-error.patch: Delete.
- patches.rt/tracer-use-sched-clock.patch: Delete.
- patches.rt/write-try-lock-irqsave.patch: Delete.
- patches.rt/x86-delay-enable-preempt-tglx.patch: Delete.
  Introduce 2.6.26-RT1:
- patches.rt/2.6.21-rc6-lockless3-radix-tree-gang-slot-lookups.patch:
  Linux-RT 2.6.26-RT
  radix-tree: gang slot lookups.
- patches.rt/2.6.21-rc6-lockless5-lockless-probe.patch: Linux-RT
  2.6.26-RT
  mm: lockless probe.
- patches.rt/2.6.21-rc6-lockless6-speculative-get-page.patch:
  Linux-RT 2.6.26-RT
  mm: speculative get page.
- patches.rt/2.6.21-rc6-lockless7-lockless-pagecache-lookups.patch:
  Linux-RT 2.6.26-RT
  mm: lockless pagecache lookups.
- patches.rt/2.6.21-rc6-lockless8-spinlock-tree_lock.patch:
  Linux-RT 2.6.26-RT
  mm: spinlock tree_lock.
- patches.rt/Add-dev-rmem-device-driver-for-real-time-JVM-testing.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/Allocate-RTSJ-memory-for-TCK-conformance-test.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/RT_utsname.patch: Linux-RT 2.6.26-RT.
- patches.rt/aacraid-compat-sem.patch: Linux-RT 2.6.26-RT.
- patches.rt/adapt-remove-extra-try-to-lock.patch: Linux-RT
  2.6.26-RT.
- patches.rt/adaptive-adjust-pi-wakeup.patch: Linux-RT 2.6.26-RT.
- patches.rt/adaptive-earlybreak-on-steal.patch: Linux-RT
  2.6.26-RT
  rtmutex: break out early on first run.
- patches.rt/adaptive-optimize-rt-lock-wakeup.patch: Linux-RT
  2.6.26-RT.
- patches.rt/adaptive-spinlock-lite-v2.patch: Linux-RT 2.6.26-RT
  adaptive spinlocks lite.
- patches.rt/adaptive-task-oncpu.patch: Linux-RT 2.6.26-RT.
- patches.rt/apic-dumpstack.patch: Linux-RT 2.6.26-RT.
- patches.rt/apic-level-smp-affinity.patch: Linux-RT 2.6.26-RT.
- patches.rt/arm-compile-fix.patch: Linux-RT 2.6.26-RT
  ARM: compile fix for event tracing.
- patches.rt/arm-fix-compile-error-trace-exit-idle.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/arm-futex-atomic-cmpxchg.patch: Linux-RT 2.6.26-RT.
- patches.rt/arm-latency-tracer-support.patch: Linux-RT 2.6.26-RT.
- patches.rt/arm-omap-02.patch: Linux-RT 2.6.26-RT.
- patches.rt/arm-omap-05.patch: Linux-RT 2.6.26-RT.
- patches.rt/arm-preempt-config.patch: Linux-RT 2.6.26-RT.
- patches.rt/arm-trace-preempt-idle.patch: Linux-RT 2.6.26-RT.
- patches.rt/bh-state-lock.patch: Linux-RT 2.6.26-RT.
- patches.rt/bh-uptodate-lock.patch: Linux-RT 2.6.26-RT.
- patches.rt/cache_pci_find_capability.patch: Linux-RT 2.6.26-RT
  Cache calls to pci_find_capability.
- patches.rt/call_rcu_bh-rename-of-call_rcu.patch: Linux-RT
  2.6.26-RT
  just rename call_rcu_bh instead of making it a macro.
- patches.rt/cond_resched_softirq-WARN-fix.patch: Linux-RT
  2.6.26-RT
  WARNING: at kernel/sched.c:5071 2.6.23-rc1-rt7.
- patches.rt/cputimer-thread-rt-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/cputimer-thread-rt_A0.patch: Linux-RT 2.6.26-RT.
- patches.rt/cycles-to-ns-trace-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/dev-queue-xmit-preempt-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/disable-irqpoll.patch: Linux-RT 2.6.26-RT.
- patches.rt/disable-ist-x86_64.patch: Linux-RT 2.6.26-RT.
- patches.rt/disable-lpptest-on-nonlinux.patch: Linux-RT
  2.6.26-RT.
- patches.rt/disable-run-softirq-from-hardirq-completely.patch:
  Linux-RT 2.6.26-RT
  Disable running softirqs from hardirqs completely!.
- patches.rt/dont-disable-preemption-without-IST.patch: Linux-RT
  2.6.26-RT.
- patches.rt/dont-let-rt-rw_semaphores-do-non_owner-locks.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/dont-unmask-io_apic.patch: Linux-RT 2.6.26-RT.
- patches.rt/drain-all-local-pages-via-sched.patch: Linux-RT
  2.6.26-RT.
- patches.rt/event-tracer-syscall-i386.patch: Linux-RT 2.6.26-RT.
- patches.rt/event-tracer-syscall-x86_64.patch: Linux-RT
  2.6.26-RT.
- patches.rt/export-schedule-on-each-cpu.patch: Linux-RT
  2.6.26-RT.
- patches.rt/filemap-dont-bug-non-atomic.patch: Linux-RT
  2.6.26-RT.
- patches.rt/fix-acpi-build-weirdness.patch: Linux-RT 2.6.26-RT.
- patches.rt/fix-bug-on-in-filemap.patch: Linux-RT 2.6.26-RT
  Change bug_on for atomic to pagefault_disabled..
- patches.rt/fix-circular-locking-deadlock.patch: Linux-RT
  2.6.26-RT.
- patches.rt/fix-compilation-for-non-RT-in-timer.patch: Linux-RT
  2.6.26-RT.
- patches.rt/fix-emac-locking-2.6.16.patch: Linux-RT 2.6.26-RT.
- patches.rt/fix-emergency-reboot.patch: Linux-RT 2.6.26-RT
  call reboot notifier list when doing an emergency reboot.
- patches.rt/fix-migrating-softirq.patch: Linux-RT 2.6.26-RT.
- patches.rt/fix-softirq-checks-for-non-rt-preempt-hardirq.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/fix_vdso_gtod_vsyscall64_2.patch: Linux-RT 2.6.26-RT.
- patches.rt/floppy-resume-fix.patch: Linux-RT 2.6.26-RT
  floppy: suspend/resume fix.
- patches.rt/ftrace-compile-fixes.patch: Linux-RT 2.6.26-RT
  rt: remove call to stop tracer.
- patches.rt/ftrace-dont-trace-markers.patch: Linux-RT 2.6.26-RT
  ftrace: dont trace markers.
- patches.rt/ftrace-fix-header.patch: Linux-RT 2.6.26-RT.
- patches.rt/ftrace-function-record-nop.patch: Linux-RT 2.6.26-RT
  ftrace: define function trace nop.
- patches.rt/ftrace-print-missing-cmdline.patch: Linux-RT
  2.6.26-RT
  ftrace: fix the command line printing.
- patches.rt/ftrace-record-comm-on-ctrl.patch: Linux-RT 2.6.26-RT
  ftrace: record comm on function ctrl change.
- patches.rt/ftrace-trace-sched.patch: Linux-RT 2.6.26-RT
  ftrace: trace sched.c.
- patches.rt/ftrace-upstream.patch: Linux-RT 2.6.26-RT.
- patches.rt/ftrace-use-preempt-disable-not-irq-disable.patch:
  Linux-RT 2.6.26-RT
  ftrace: avoid lockdep recursion.
- patches.rt/gcc-warnings-shut-up.patch: Linux-RT 2.6.26-RT.
- patches.rt/genhd-protect-percpu-var.patch: Linux-RT 2.6.26-RT.
- patches.rt/genirq-soft-resend.patch: Linux-RT 2.6.26-RT
  x86: activate HARDIRQS_SW_RESEND.
- patches.rt/git-ignore-script-lpp.patch: Linux-RT 2.6.26-RT.
- patches.rt/gtod-optimize.patch: Linux-RT 2.6.26-RT.
- patches.rt/hack-convert-i_alloc_sem-for-direct_io-craziness.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/hack-fix-rt-migration.patch: Linux-RT 2.6.26-RT.
- patches.rt/handle-pending-in-simple-irq.patch: Linux-RT
  2.6.26-RT
  handle IRQ_PENDING for simple irq handler.
- patches.rt/highmem-redo-mainline.patch: Linux-RT 2.6.26-RT.
- patches.rt/highmem-revert-mainline.patch: Linux-RT 2.6.26-RT.
- patches.rt/highmem_rewrite.patch: Linux-RT 2.6.26-RT
  mm: remove kmap_lock.
- patches.rt/hrtimer-no-printk.patch: Linux-RT 2.6.26-RT.
- patches.rt/hrtimers-overrun-api.patch: Linux-RT 2.6.26-RT.
- patches.rt/i386-mark-atomic-irq-ops-raw.patch: Linux-RT
  2.6.26-RT.
- patches.rt/i386-nmi-watchdog-show-regs.patch: Linux-RT
  2.6.26-RT.
- patches.rt/ioapic-fix-too-fast-clocks.patch: Linux-RT 2.6.26-RT.
- patches.rt/irda-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/irq-mask-fix.patch: Linux-RT 2.6.26-RT
  genirq: fix simple and fasteoi irq handlers.
- patches.rt/jbd_assertions_smp_only.patch: Linux-RT 2.6.26-RT.
- patches.rt/kmap-atomic-i386-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/kmap-atomic-prepare.patch: Linux-RT 2.6.26-RT.
- patches.rt/kprobes-preempt-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/kstat-add-rt-stats.patch: Linux-RT 2.6.26-RT
  add rt stats to /proc/stat.
- patches.rt/kstat-fix-spurious-system-load-spikes-in-proc-loadavgrt.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/latency-measurement-drivers.patch: Linux-RT
  2.6.26-RT.
- patches.rt/latency-tracing-arm.patch: Linux-RT 2.6.26-RT.
- patches.rt/latency-tracing-ppc.patch: Linux-RT 2.6.26-RT.
- patches.rt/loadavg_fixes_weird_loads.patch: Linux-RT 2.6.26-RT.
- patches.rt/local_irq_save_nort-in-swap.patch: Linux-RT
  2.6.26-RT.
- patches.rt/lock-init-plist-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/lock_list.patch: Linux-RT 2.6.26-RT
  lock_list - a fine grain locked double linked list.
- patches.rt/lock_page_ref.patch: Linux-RT 2.6.26-RT
  mm: lock_page_ref.
- patches.rt/lockdep-avoid-fork-waring.patch: Linux-RT 2.6.26-RT
  ftrace: fix if define to prove locking.
- patches.rt/lockdep-lock_set_subclass.patch: Linux-RT 2.6.26-RT
  lockdep: lock_set_subclass - reset a held lock's subclass.
- patches.rt/lockdep-more-entries.patch: Linux-RT 2.6.26-RT.
- patches.rt/lockdep-prettify.patch: Linux-RT 2.6.26-RT
  lockdep: prettify output.
- patches.rt/lockdep-rt-mutex.patch: Linux-RT 2.6.26-RT
  lockdep-rt: annotate PREEMPT_RT DEFINE_MUTEX.
- patches.rt/lockdep-rt-recursion-limit-fix.patch: Linux-RT
  2.6.26-RT.
- patches.rt/lockdep-show-held-locks.patch: Linux-RT 2.6.26-RT
  lockdep: show held locks when showing a stackdump.
- patches.rt/lockdep_lock_set_subclass_fix.patch: Linux-RT
  2.6.26-RT.
- patches.rt/lockstat-fix-contention-points.patch: Linux-RT
  2.6.26-RT
  lockstat: fix contention points.
- patches.rt/lockstat-output.patch: Linux-RT 2.6.26-RT
  lockstat: warn about disabled lock debugging.
- patches.rt/lockstat-rt-hooks.patch: Linux-RT 2.6.26-RT.
- patches.rt/lockstat_bounce_rt.patch: Linux-RT 2.6.26-RT.
- patches.rt/loopback-revert.patch: Linux-RT 2.6.26-RT.
- patches.rt/mapping_nrpages.patch: Linux-RT 2.6.26-RT
  mm/fs: abstract address_space::nrpages.
- patches.rt/mips-change-raw-spinlock-type.patch: Linux-RT
  2.6.26-RT
  RT: change from raw_spinlock_t to __raw_spinlock_t.
- patches.rt/mips-remove-conlicting-rtc-lock-declaration.patch:
  Linux-RT 2.6.26-RT
  RT: remove conflicting rtc_lock declaration.
- patches.rt/mips-remove-duplicate-kconfig.patch: Linux-RT
  2.6.26-RT.
- patches.rt/mips-remove-finish-arch-switch.patch: Linux-RT
  2.6.26-RT
  RT: remove finish_arch_switch.
- patches.rt/mitigate-resched-flood.patch: Linux-RT 2.6.26-RT.
- patches.rt/mm-concurrent-pagecache-rt.patch: Linux-RT 2.6.26-RT
  mm: -rt bits for concurrent pagecache.
- patches.rt/mm-concurrent-pagecache.patch: Linux-RT 2.6.26-RT
  mm: concurrent pagecache write side.
- patches.rt/mm-fix-latency.patch: Linux-RT 2.6.26-RT
  reduce pagetable-freeing latencies.
- patches.rt/move-native-irq.patch: Linux-RT 2.6.26-RT.
- patches.rt/msi-suspend-resume-workaround.patch: Linux-RT
  2.6.26-RT.
- patches.rt/multi-reader-account.patch: Linux-RT 2.6.26-RT
  map tasks to reader locks held.
- patches.rt/multi-reader-limit.patch: Linux-RT 2.6.26-RT
  implement reader limit on read write locks.
- patches.rt/multi-reader-lock-account.patch: Linux-RT 2.6.26-RT
  map read/write locks back to their readers.
- patches.rt/multi-reader-pi.patch: Linux-RT 2.6.26-RT
  read lock Priority Inheritance implementation.
- patches.rt/native-sched-clock-booboo.patch: Linux-RT 2.6.26-RT.
- patches.rt/neptune-no-at-keyboard.patch: Linux-RT 2.6.26-RT.
- patches.rt/net-core-preempt-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/netpoll-8139too-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/new-softirq-code.patch: Linux-RT 2.6.26-RT
  softirq preemption: optimization.
- patches.rt/nf_conntrack-fix-smp-processor-id.patch: Linux-RT
  2.6.26-RT.
- patches.rt/nf_conntrack-weird-crash-fix.patch: Linux-RT
  2.6.26-RT.
- patches.rt/nmi-profiling-base.patch: Linux-RT 2.6.26-RT
  nmi-driven profiling for /proc/profile.
- patches.rt/nmi-profiling.patch: Linux-RT 2.6.26-RT.
- patches.rt/nmi-show-regs-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/nmi-watchdog-disable.patch: Linux-RT 2.6.26-RT
  x86_64: do not enable the NMI watchdog by default.
- patches.rt/nmi-watchdog-fix-1.patch: Linux-RT 2.6.26-RT.
- patches.rt/nmi-watchdog-fix-2.patch: Linux-RT 2.6.26-RT.
- patches.rt/nmi-watchdog-fix-3.patch: Linux-RT 2.6.26-RT.
- patches.rt/nmi-watchdog-fix-4.patch: Linux-RT 2.6.26-RT.
- patches.rt/no-warning-for-irqs-disabled-in-local-bh-enable.patch:
  Linux-RT 2.6.26-RT
  local_bh_enable() is safe for irqs_disabled().
- patches.rt/ntfs-local-irq-save-nort.patch: Linux-RT 2.6.26-RT.
- patches.rt/numa-slab-freeing.patch: Linux-RT 2.6.26-RT.
- patches.rt/only-run-softirqs-from-irq-thread-when-irq-affinity-is-set.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/pagefault-disable-cleanup.patch: Linux-RT 2.6.26-RT
  clean up the page fault disabling logic.
- patches.rt/panic-dont-stop-box.patch: Linux-RT 2.6.26-RT.
- patches.rt/paravirt-function-pointer-fix.patch: Linux-RT
  2.6.26-RT.
- patches.rt/pause-on-oops-head-tail.patch: Linux-RT 2.6.26-RT
  introduce pause_on_oops_head/tail boot options.
- patches.rt/percpu-locked-mm.patch: Linux-RT 2.6.26-RT.
- patches.rt/percpu-locked-netfilter.patch: Linux-RT 2.6.26-RT.
- patches.rt/percpu-locked-netfilter2.patch: Linux-RT 2.6.26-RT.
- patches.rt/percpu-locked-powerpc-fixups.patch: Linux-RT
  2.6.26-RT.
- patches.rt/percpu_list.patch: Linux-RT 2.6.26-RT
  percpu_list.
- patches.rt/plist-debug.patch: Linux-RT 2.6.26-RT.
- patches.rt/posix-cpu-timers-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/powerpc-count_active_rt_tasks-is-undefined-for-non-preempt-rt.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/powerpc-flush_tlb_pending-is-no-more.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/powerpc-match-__rw_yield-function-declaration-to-prototype.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/ppc-chpr-set-rtc-lock.patch: Linux-RT 2.6.26-RT.
- patches.rt/ppc-gtod-notrace-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/ppc-hacks-to-allow-rt-to-run-kernbench.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/ppc-make-tlb-batch-64-only.patch: Linux-RT 2.6.26-RT.
- patches.rt/ppc-tlbflush-preempt.patch: Linux-RT 2.6.26-RT.
- patches.rt/ppc32-latency-compile-hack-fixes.patch: Linux-RT
  2.6.26-RT.
- patches.rt/ppc32_notrace_init_functions.patch: Linux-RT
  2.6.26-RT
  don't trace early init functions for ppc32.
- patches.rt/preempt-irqs-Kconfig.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-irqs-arm-fix-oprofile.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-irqs-arm.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-irqs-core.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-irqs-direct-debug-keyboard.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-irqs-hrtimer.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-irqs-i386-idle-poll-loop-fix.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/preempt-irqs-i386-ioapic-mask-quirk.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-irqs-i386.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-irqs-mips.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-irqs-ppc-ack-irq-fixups.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-irqs-ppc-fix-b5.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-irqs-ppc-fix-b6.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-irqs-ppc-fix-more-fasteoi.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-irqs-ppc-preempt-schedule-irq-entry-fix.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/preempt-irqs-ppc.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-irqs-timer.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-irqs-x86-64-ioapic-mask-quirk.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/preempt-irqs-x86-64.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-acpi.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-arm-bagde4.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-realtime-arm-footbridge.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-realtime-arm-integrator.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-realtime-arm-ixp4xx.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-realtime-arm-pxa.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-arm-rawlock-in-mmu_context-h.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-arm-shark.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-arm.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-compile-fixes.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-realtime-console.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-core.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-debug-sysctl.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-realtime-fs-block.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-ftrace-disable-ftraced.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-ftrace.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-i386.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-ia64.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-ide.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-init-show-enabled-debugs.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-input.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-ipc.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-irqs.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-loopback.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-mellanox-driver-fix.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-mips.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-mm.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-mmdrop-delayed.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-realtime-net-drivers.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-realtime-net-softirq-fixups.patch: Linux-RT
  2.6.26-RT
  NOHZ: local_softirq_pending with tickless.
- patches.rt/preempt-realtime-net.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-powerpc-add-raw-relax-macros.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-powerpc-b2.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-realtime-powerpc-b3.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-realtime-powerpc-b4.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-realtime-powerpc-celleb-raw-spinlocks.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-powerpc-missing-raw-spinlocks.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-powerpc-tlb-batching.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-powerpc-update.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-realtime-powerpc.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-prevent-idle-boosting.patch:
  Linux-RT 2.6.26-RT
  Premmpt-RT: Preevent boosting of idle task.
- patches.rt/preempt-realtime-printk.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-profiling.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-rawlocks.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-rcu.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-sched-cpupri.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-realtime-sched-i386.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-realtime-sched.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-sound.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-supress-nohz-softirq-warning.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-supress-rtc-printk.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-realtime-timer.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-usb.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-warn-and-bug-on-fix.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-warn-and-bug-on.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-rt-no-slub.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-softirqs-core.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-trace.patch: Linux-RT 2.6.26-RT.
- patches.rt/print-might-sleep-hack.patch: Linux-RT 2.6.26-RT.
- patches.rt/printk-dont-bug-on-sched.patch: Linux-RT 2.6.26-RT.
- patches.rt/printk-in-atomic-hack-fix.patch: Linux-RT 2.6.26-RT
  fix printk in atomic hack.
- patches.rt/printk-in-atomic.patch: Linux-RT 2.6.26-RT.
- patches.rt/proportions-raw-locks.patch: Linux-RT 2.6.26-RT.
- patches.rt/qrcu.patch: Linux-RT 2.6.26-RT
  QRCU with lockless fastpath.
- patches.rt/quicklist-release-before-free-page-fix.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/quicklist-release-before-free-page.patch: Linux-RT
  2.6.26-RT.
- patches.rt/radix-concurrent-lockdep.patch: Linux-RT 2.6.26-RT.
- patches.rt/radix-percpu-hack-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/radix-tree-concurrent.patch: Linux-RT 2.6.26-RT
  radix-tree: concurrent write side support.
- patches.rt/radix-tree-optimistic-hist.patch: Linux-RT 2.6.26-RT
  debug: optimistic lock histogram.
- patches.rt/radix-tree-optimistic.patch: Linux-RT 2.6.26-RT
  radix-tree: optimistic locking.
- patches.rt/random-driver-latency-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/rcu-hrt-fixups.patch: Linux-RT 2.6.26-RT.
- patches.rt/rcu-new-7.patch: Linux-RT 2.6.26-RT.
- patches.rt/rcu-preempt-boost-default.patch: Linux-RT 2.6.26-RT.
- patches.rt/rcu-preempt-boost-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/rcu-preempt-boost-sdr.patch: Linux-RT 2.6.26-RT.
- patches.rt/rcu-preempt-fix-bad-dyntick-accounting.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/rcu-preempt-hotplug-hackaround.patch: Linux-RT
  2.6.26-RT.
- patches.rt/rcu-torture-preempt-update.patch: Linux-RT 2.6.26-RT.
- patches.rt/rcu-trace-fix-free.patch: Linux-RT 2.6.26-RT.
- patches.rt/rcupreempt-boost-early-init.patch: Linux-RT
  2.6.26-RT.
- patches.rt/realtime-preempt-warn-about-tracing.patch: Linux-RT
  2.6.26-RT.
- patches.rt/relay-fix.patch: Linux-RT 2.6.26-RT
  relay: fix timer madness.
- patches.rt/remove-check-pgt-cache-calls.patch: Linux-RT
  2.6.26-RT.
- patches.rt/replace-bugon-by-warn-on.patch: Linux-RT 2.6.26-RT.
- patches.rt/root-domain-kfree-in-atomic.patch: Linux-RT
  2.6.26-RT.
- patches.rt/rt-apis.patch: Linux-RT 2.6.26-RT.
- patches.rt/rt-avoid-deadlock-in-swap.patch: Linux-RT 2.6.26-RT.
- patches.rt/rt-delayed-prio.patch: Linux-RT 2.6.26-RT
  rt: PI-workqueue: propagate prio for delayed work.
- patches.rt/rt-kmap-scale-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/rt-list-mods.patch: Linux-RT 2.6.26-RT
  rt: list_splice2.
- patches.rt/rt-move-update-wall-time-back-to-do-timer.patch:
  Linux-RT 2.6.26-RT
  rt: move update_wall_time back to do timer.
- patches.rt/rt-mutex-arm.patch: Linux-RT 2.6.26-RT.
- patches.rt/rt-mutex-compat-semaphores.patch: Linux-RT 2.6.26-RT.
- patches.rt/rt-mutex-core.patch: Linux-RT 2.6.26-RT.
- patches.rt/rt-mutex-i386.patch: Linux-RT 2.6.26-RT.
- patches.rt/rt-mutex-irq-flags-checking.patch: Linux-RT
  2.6.26-RT.
- patches.rt/rt-mutex-mips.patch: Linux-RT 2.6.26-RT.
- patches.rt/rt-mutex-ppc-fix-a5.patch: Linux-RT 2.6.26-RT.
- patches.rt/rt-mutex-ppc.patch: Linux-RT 2.6.26-RT.
- patches.rt/rt-mutex-preempt-debugging.patch: Linux-RT 2.6.26-RT.
- patches.rt/rt-mutex-trivial-route-cast-fix.patch: Linux-RT
  2.6.26-RT.
- patches.rt/rt-mutex-trivial-tcp-preempt-fix.patch: Linux-RT
  2.6.26-RT.
- patches.rt/rt-mutex-x86-64.patch: Linux-RT 2.6.26-RT.
- patches.rt/rt-page_alloc.patch: Linux-RT 2.6.26-RT
  rt-friendly per-cpu pages.
- patches.rt/rt-plist-mods.patch: Linux-RT 2.6.26-RT
  rt: plist_head_splice.
- patches.rt/rt-s_files-kill-a-union.patch: Linux-RT 2.6.26-RT.
- patches.rt/rt-sched-groups.patch: Linux-RT 2.6.26-RT.
- patches.rt/rt-shorten-softirq-thread-names.patch: Linux-RT
  2.6.26-RT.
- patches.rt/rt-slab-new.patch: Linux-RT 2.6.26-RT.
- patches.rt/rt-workqeue-prio.patch: Linux-RT 2.6.26-RT
  rt: PI-workqueue support.
- patches.rt/rt-workqueue-barrier.patch: Linux-RT 2.6.26-RT
  rt: PI-workqueue: fix barriers.
- patches.rt/rt-wq-barrier-fix.patch: Linux-RT 2.6.26-RT
  rt: PI-workqueue: wait_on_work() fixup.
- patches.rt/rt_mutex_setprio.patch: Linux-RT 2.6.26-RT
  rt: rename rt_mutex_setprio to task_setprio.
- patches.rt/rtmutex-debug.h-cleanup.patch: Linux-RT 2.6.26-RT
  lock debugging: clean up rtmutex-debug.h.
- patches.rt/rtmutex-lateral-steal.patch: Linux-RT 2.6.26-RT.
- patches.rt/rtmutex-rearrange.patch: Linux-RT 2.6.26-RT.
- patches.rt/rtmutex-remove-xchg.patch: Linux-RT 2.6.26-RT
  rtmutex - remove double xchg.
- patches.rt/rtmutex-rwlock-cmpxchg-typecast.patch: Linux-RT
  2.6.26-RT.
- patches.rt/rwlock-implement-downgrade-write.patch: Linux-RT
  2.6.26-RT
  rwlocks multi downgrade write.
- patches.rt/rwlocks-default-nr-readers-nr-cpus.patch: Linux-RT
  2.6.26-RT.
- patches.rt/rwlocks-fix-no-preempt-rt.patch: Linux-RT 2.6.26-RT
  rwlock: fix non PREEMPT_RT case.
- patches.rt/rwlocks-multiple-readers.patch: Linux-RT 2.6.26-RT
  implement rwlocks management.
- patches.rt/rwsems-multiple-readers.patch: Linux-RT 2.6.26-RT
  add framework for multi readers on rwsems.
- patches.rt/s_files-pipe-fix.patch: Linux-RT 2.6.26-RT
  s_files: free_write_pipe() fix.
- patches.rt/s_files-schedule_on_each_cpu_wq.patch: Linux-RT
  2.6.26-RT.
- patches.rt/s_files.patch: Linux-RT 2.6.26-RT
  remove global files_lock.
- patches.rt/sched-clock-nmi.patch: Linux-RT 2.6.26-RT.
- patches.rt/sched-enable-irqs-in-preempt-in-notifier-call.patch:
  Linux-RT 2.6.26-RT
  CFS: enable irqs in fire_sched_in_preempt_notifier.
- patches.rt/sched-nr-migrate-lower-default-preempt-rt.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/sched-prioritize-non-migrating-rt-tasks.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/sched-rt-stats.patch: Linux-RT 2.6.26-RT.
- patches.rt/sched-use-a-2d-bitmap-search-prio-cpu.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/sched-wake_up_idle_cpu-rt.patch: Linux-RT 2.6.26-RT.
- patches.rt/sched_prio.patch: Linux-RT 2.6.26-RT.
- patches.rt/sched_rt-fixup.patch: Linux-RT 2.6.26-RT.
- patches.rt/schedule-tail-balance-disable-irqs.patch: Linux-RT
  2.6.26-RT.
- patches.rt/schedule_on_each_cpu-enhance.patch: Linux-RT
  2.6.26-RT.
- patches.rt/select-error-leak-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/send-nmi-all-preempt-disable.patch: Linux-RT
  2.6.26-RT.
- patches.rt/seq-irqsave.patch: Linux-RT 2.6.26-RT.
- patches.rt/serial-locking-rt-cleanup.patch: Linux-RT 2.6.26-RT.
- patches.rt/serial-slow-machines.patch: Linux-RT 2.6.26-RT.
- patches.rt/slab-irq-nopreempt-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/smp-processor-id-fixups.patch: Linux-RT 2.6.26-RT.
- patches.rt/softirq-per-cpu-assumptions-fixes.patch: Linux-RT
  2.6.26-RT.
- patches.rt/softlockup-add-irq-regs-h.patch: Linux-RT 2.6.26-RT
  core: make asm/irq_regs.h available on every platform.
- patches.rt/spinlock-trylock-cleanup-sungem.patch: Linux-RT
  2.6.26-RT.
- patches.rt/swap-spinlock-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/tasklet-busy-loop-hack.patch: Linux-RT 2.6.26-RT.
- patches.rt/tasklet-redesign.patch: Linux-RT 2.6.26-RT.
- patches.rt/timer-freq-tweaks.patch: Linux-RT 2.6.26-RT.
- patches.rt/timer-warning-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/trace-add-event-markers-arm.patch: Linux-RT
  2.6.26-RT.
- patches.rt/trace-events-handle-syscalls.patch: Linux-RT
  2.6.26-RT.
- patches.rt/trace-histograms.patch: Linux-RT 2.6.26-RT.
- patches.rt/trace_hist-divzero.patch: Linux-RT 2.6.26-RT
  trace_hist.c: divide-by-zero problem (2).
- patches.rt/trace_hist-latediv.patch: Linux-RT 2.6.26-RT.
- patches.rt/tracer-add-event-markers.patch: Linux-RT 2.6.26-RT.
- patches.rt/tracer-event-trace.patch: Linux-RT 2.6.26-RT.
- patches.rt/use-edge-triggered-irq-handler-instead-of-simple-irq.patch:
  Linux-RT 2.6.26-RT
  [AT91: PATCH]: Use edge triggered interrupt handling for
  AT91-GPIO instead of simple_irq-handler.
- patches.rt/user-no-irq-disable.patch: Linux-RT 2.6.26-RT.
- patches.rt/version.patch: Linux-RT 2.6.26-RT
  add -rt extra-version.
- patches.rt/vortex-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/watchdog_use_timer_and_hpet_on_x86_64.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/x86-64-tscless-vgettimeofday.patch: Linux-RT
  2.6.26-RT
  x86_64 GTOD: offer scalable vgettimeofday.
- patches.rt/x86_64-tsc-sync-irqflags-fix.patch: Linux-RT
  2.6.26-RT.
- patches.rt/event-trace-hrtimer-trace.patch: Linux-RT 2.6.26-RT
  event-tracer: add clockevent trace.
- patches.rt/ftrace-hotplug-fix.patch: Linux-RT 2.6.26-RT
  ftrace: cpu hotplug fix.
- patches.rt/ftrace-wakeup-rawspinlock.patch: Linux-RT 2.6.26-RT
  ftrace: user raw spin lock for wakeup function trace.
- patches.rt/preempt-realtime-x86_64.patch: Linux-RT 2.6.26-RT.
- patches.rt/radix-tree-lockdep-plus1.patch: Linux-RT 2.6.26-RT
  lockdep: add +1 to radix tree array.
- patches.rt/rwlock-fixes.patch: Linux-RT 2.6.26-RT
  rwlock: fix pi_list race conditions.
- patches.rt/rwlock-prio-fix.patch: Linux-RT 2.6.26-RT
  rwlock: reset prio on unlocks and wakeups.
- patches.rt/rwlock-torture.patch: Linux-RT 2.6.26-RT
  rwlock: rwlock torture test.
- patches.rt/sched-cpupri-hotplug-support.patch: Linux-RT
  2.6.26-RT.
- patches.rt/sched-cpupri-priocount.patch: Linux-RT 2.6.26-RT.
- patches.rt/trace-eip2ip.patch: Linux-RT 2.6.26-RT
  Re: 2.6.25.4-rt4.
- patches.rt/bz235099-idle-load-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/fix-adaptive-hack.patch: Linux-RT 2.6.26-RT
  fix-adaptive-hack.patch.
- patches.rt/fix-a-previously-reverted-fix.patch: Linux-RT
  2.6.26-RT
  Fix a previously reverted "fix".
- patches.rt/fix-config-debug-rt-mutex-lock-underflow-warnings.patch:
  Linux-RT 2.6.26-RT
  Fix CONFIG_DEBUG_RT_MUTEX lock underflow warnings.
- patches.rt/frace-use-tsc.patch: Linux-RT 2.6.26-RT.
- patches.rt/ftrace-document-event-tracer.patch: Linux-RT
  2.6.26-RT.
- patches.rt/ftrace-document-update1.patch: Linux-RT 2.6.26-RT
  ftrace: document updates.
- patches.rt/ftrace-fix-get-kprobe-wreckage.patch: Linux-RT
  2.6.26-RT
  ftrace-fix-missing-kprobe-include.pathc.
- patches.rt/ftrace-m68knommu-add-FTRACE-support.patch: Linux-RT
  2.6.26-RT.
- patches.rt/ftrace-m68knommu-generic-stacktrace-function.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/ftrace-preempt-trace-check.patch: Linux-RT 2.6.26-RT
  ftrace: only trace preempt off with preempt tracer.
- patches.rt/ftrace-stop-trace-on-crash.patch: Linux-RT 2.6.26-RT
  fix-tracer-wreckage-wtf-is-this-code-all-features.patch.
- patches.rt/generic-cmpxchg-use-raw-local-irq-variant.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/idle2-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/idle-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/m68knommu_fixes_ontop_of_v2.6.26.patch: Linux-RT
  2.6.26-RT.
- patches.rt/m68knommu-make-cmpxchg-RT-safe.patch: Linux-RT
  2.6.26-RT.
- patches.rt/mapping_nrpages-fix.patch: Linux-RT 2.6.26-RT
  mapping_nrpages-fix.patch.
- patches.rt/nfs-stats-miss-preemption.patch: Linux-RT 2.6.26-RT
  nfs: fix missing preemption check.
- patches.rt/pmtmr-override.patch: Linux-RT 2.6.26-RT
  pmtmr: allow command line override of ioport.
- patches.rt/powerpc-ftrace-stop-on-oops.patch: Linux-RT 2.6.26-RT
  powerpc: ftrace stop on crash.
- patches.rt/ppc64-fix-preempt-unsafe-paths-accessing-per_cpu-variables.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/preempt-irqs-m68knommu-make-timer-interrupt-non-threaded.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-mm.patch~: Linux-RT 2.6.26-RT.
- patches.rt/raw-spinlocks-for-nmi-print.patch: Linux-RT
  2.6.26-RT.
- patches.rt/revert-preempt-bkl-revert.patch: Linux-RT 2.6.26-RT.
- patches.rt/rtmutex-debug-fix.patch: Linux-RT 2.6.26-RT
  rtmutex-debug-fix.patch.
- patches.rt/rt-mutex-namespace.patch: Linux-RT 2.6.26-RT
  rt-mutex-namespace.patch.
- patches.rt/rt-mutex-use-inline.patch: Linux-RT 2.6.26-RT
  rt-mutex-cleanup.patch.
- patches.rt/rt-rwlock-conservative-locking.patch: Linux-RT
  2.6.26-RT
  rwlock: be more conservative in locking reader_lock_count.
- patches.rt/rwlock-pi-lock-reader.patch: Linux-RT 2.6.26-RT.
- patches.rt/rwlock-protect-reader_lock_count.patch: Linux-RT
  2.6.26-RT.
- patches.rt/rwlock-slowunlock-mutex-fix2.patch: Linux-RT
  2.6.26-RT.
- patches.rt/rwlock-slowunlock-mutex-fix.patch: Linux-RT
  2.6.26-RT.
- patches.rt/rwlock-torture-no-rt.patch: Linux-RT 2.6.26-RT
  rwlock: fix torture test to handle non-rt.
- patches.rt/sched-fix-dequeued-race.patch: Linux-RT 2.6.26-RT
  sched-fix-dequeued-race.patch.
- patches.rt/serial-locking-rt-cleanup.patch~: Linux-RT 2.6.26-RT.
- patches.rt/sub-dont-disable-irqs.patch: Linux-RT 2.6.26-RT
  rt: dont disable irqs in usb.
- patches.rt/trace-do-not-wakeup-when-irqs-disabled.patch:
  Linux-RT 2.6.26-RT
  trace-do-not-wakeup-when-irqs-disabled.patch.
- patches.rt/trace-ktime-scalar.patch: Linux-RT 2.6.26-RT
  ftrace: print ktime values in readable form.
- patches.rt/warn-on-rt-scatterlist.patch: Linux-RT 2.6.26-RT
  remove warn on for scatterlist in preempt rt.
* Tue Jul 29 2008 trenn@suse.de
- patches.arch/acpi_thermal_passive_blacklist.patch: Avoid
  critical temp shutdowns on specific ThinkPad T4x(p) and R40
  (https://bugzilla.novell.com/show_bug.cgi?id=333043).
- patches.fixes/acpi_use_acpi_exception.patch: ACPI dock/bay:
  Use ACPI_EXCEPTION instead of printk(KERN_ERR.
- patches.suse/acpi_provide_non_windows_osi_boot_param.patch:
  ACPI: Provide a spec conform OSI interface to the BIOS.
* Tue Jul 29 2008 bphilips@suse.de
- rpm/kernel-binary.spec.in: uvcvideo merged.  Add Obsoletes.
* Fri Jul 25 2008 mszeredi@suse.cz
- supported.conf: Mark fuse as supported.
* Thu Jul 24 2008 gregkh@suse.de
- Enable CONFIG_MARKERS
* Thu Jul 24 2008 gregkh@suse.de
- Enable CONFIG_SECURITY_SELINUX
* Thu Jul 24 2008 agruen@suse.de
- Fix for using relative paths in /usr/src/linux-obj/$arch/
  $flavor/Makefile (bnc#409982).
* Fri Jul 18 2008 hare@suse.de
- Update config files for S/390.
* Thu Jul 17 2008 bwalle@suse.de
- patches.fixes/show-OSRELEASE-in-VMCOREINFO.diff:
  kdump: Report actual value of VMCOREINFO_OSRELEASE in VMCOREINFO
* Thu Jul 17 2008 jeffm@suse.de
- rpm/kernel-module-subpackage: Removed Supplements handling
  entirely. Use preamble instead.
* Thu Jul 17 2008 jbeulich@novell.com
- patches.xen/xen3-patch-2.6.26: Fix 32-bit build.
* Thu Jul 17 2008 jbeulich@novell.com
- Update Xen patches for 2.6.26.
- patches.xen/540-blkif-nr-segments-check.patch: Delete.
- patches.xen/560-x86_64-no-irq-affinity-break-msg.patch: Delete.
- patches.xen/xen3-patch-2.6.25.1: Delete.
- Update i386 and x86-64 config files.
- config.conf: Re-enable Xen configs.
* Thu Jul 17 2008 jbeulich@novell.com
- patches.fixes/seccomp-disable-tsc-option: Also handle x86-64 (191123).
- Update x86-64 config files.
- patches.suse/raw_device_max_minors_param.diff: Fix uninitialized
  return value.
- patches.apparmor/remove_suid.diff: Also handle fuse.
- supported.conf: Add e1000e, rtc-core, rtc-lib, and rtc-cmos.
* Mon Jul 14 2008 jeffm@suse.de
- patches.kernel.org/fsl-diu-fb-compile-fix: Delete.
* Mon Jul 14 2008 olh@suse.de
- disable unused fsl-diu-fb driver
* Mon Jul 14 2008 jeffm@suse.de
- Updated to 2.6.26-final.
* Mon Jul 14 2008 bwalle@suse.de
- patches.fixes/move-crashkernel-reservation.diff:
  x86: Move crashkernel reservation before dma32_reserve_bootmem().
* Mon Jul 14 2008 rgoldwyn@suse.de
- Enable patches.suse/convert-novfs-to-open-soure-coding-standards.patch
  Fix oops in novfs_daemon_lib_ioctl
* Fri Jul 11 2008 jeffm@suse.de
- Updated squashfs to v3.3. (bnc#373285)
* Thu Jul 10 2008 jeffm@suse.de
- Update config files: Enable raw devices on s390.
* Thu Jul 10 2008 jack@suse.cz
- patches.suse/raw_device_max_minors_param.diff: Allow setting
  of number of raw devices as a module parameter (FATE 302178).
* Thu Jul 10 2008 jeffm@suse.de
- patches.kernel.org/fsl-diu-fb-compile-fix: fsl-diu-fb:
  compile fix.
* Wed Jul  9 2008 jeffm@suse.de
- patches.suse/kdb-common: Removed obsolete file_lock_operations
  printing.
* Wed Jul  9 2008 jeffm@suse.de
- patches.fixes/reiserfs-discard-xattr-prealloc: Upstreamed with
  - git5.
* Wed Jul  9 2008 jeffm@suse.de
- patches.fixes/reiserfs-discard-xattr-prealloc: reiserfs:
  discard prealloc in reiserfs_delete_inode (bnc#389656).
* Wed Jul  9 2008 jeffm@suse.de
- Updated to 2.6.26-rc9-git5.
  - Eliminated 2 patches.
* Wed Jul  9 2008 jbohac@suse.cz
- Update config files.
- patches.suse/netfilter-ip_conntrack_slp.patch: connection
  tracking helper for SLP (fate#301134).
* Wed Jul  9 2008 olh@suse.de
- enable PHYP-assisted OS dump (fate#304131)
* Mon Jul  7 2008 trenn@suse.de
- patches.fixes/acpi_thermal_passive_cleanup.patch: Delete.
* Wed Jul  2 2008 jkosina@suse.de
- patches.fixes/input-add-gericom-bellagio-to-nomux.patch: Input:
  add Gericom Bellagio to nomux blacklist (bnc#404892).
* Wed Jul  2 2008 jkosina@suse.de
- patches.fixes/input-add-acer-aspire-1360-to-nomux.patch: Input:
  add Acer Aspire 1360 to nomux blacklist (bnc#216857).
* Wed Jul  2 2008 jeffm@suse.de
- patches.apparmor/__d_path-keep-connected.diff
  patches.apparmor/mount-consistent-__d_path.diff
  patches.suse/kdb-ia64: Edited to apply with --fuzz=0
- Added --fuzz=0 (-F0) to sequence-patch.sh and spec files
* Fri Jun 27 2008 bwalle@suse.de
- rpm/kernel-binary.spec.in: don't generate the makedumpfile.config
  any more, the new kernel, kexec-tools and makedumpfile is able to
  extract that information from the running kernel and pass it
  as ELF NOTE (in /proc/vmcore)
* Thu Jun 26 2008 olh@suse.de
- add patches.arch/ppc-ibmebus-modalias.patch
  autoload ehea and ehca (bnc#394602 - LTC44938)
* Thu Jun 26 2008 sdietrich@suse.de
- RT:  Update config files - enable CONFIG_CGROUPS
* Thu Jun 26 2008 sdietrich@suse.de
- Update config files - enable CPUSETs support:
  CONFIG_CGROUPS, CONFIG_CGROUP_NS, CONFIG_CGROUP_DEVICE,
  CONFIG_CPUSET, CONFIG_CGROUP_CPUACCT,
  CONFIG_RESOURCE_COUNTERS, CONFIG_MM_OWNER,
  CONFIG_CGROUP_MEM_RES_CTLR, CONFIG_PROC_PID_CPUSET
- debug only: CONFIG_CGROUP_DEBUG
* Thu Jun 26 2008 jeffm@suse.de
- Updated to 2.6.26-rc8
  - Eliminated 1 patch.
* Wed Jun 25 2008 jeffm@suse.de
- rpm/kernel-module-subpackage: Added Supplements tag copying and added
    coreutils and grep to Requires
- rpm/macros.kernel-source: Added kernel-syms to BuildRequires
* Wed Jun 25 2008 olh@suse.de
- enable 64K pages in config ppc64 (fate#304100)
- enable up to 1024 cpus in config ppc64 (fate#304180)
- enable up to 4 cpus in config kdump
- enable powermanagement in config ppc64
- enable cell be cpufreq
* Wed Jun 25 2008 jdelvare@suse.de
- supported.conf: Update the list of i2c bus drivers.
  - i2c-isa is gone.
  - i2c-i810, i2c-prosavage and i2c-savage4 are deprecated and will
    be removed soon, mark as unsupported.
  - i2c-voodoo3 has very limited usefulness, mark as unsupported.
  - i2c-powermac is new, mark as supported.
- supported.conf: Update the list of i2c chip drivers.
  - ds1337, ds1374, rtc8564 and x1205 are gone (RTC drivers, moved
    to drivers/rtc).
  - pca9539, pcf8574 and pcf8575 are deprecated (new GPIO drivers
    exist in drivers/gpio), mark as unsupported.
  - ds1682, max6875 and tsl2550 are new, mark as supported.
* Wed Jun 25 2008 jdelvare@suse.de
- supported.conf: Add two new hwmon drivers (dme1737 and thmc50,
  both unsupported.)
- supported.conf: Mark hwmon and hwmon-vid as supported. These are
  simple, software-only utility modules, it makes little sense
  to taint the kernel just because they are loaded.
* Mon Jun 23 2008 tiwai@suse.de
- disable CONFIG_SND_PCSP as it conflicts with input pcspkr and
  disturbs the order of sound devices
* Mon Jun 23 2008 agruen@suse.de
- genksyms: add support for checking against a reference ABI.
* Wed Jun 18 2008 jeffm@suse.de
- Updated to 2.6.26-rc6-git5.
  - Eliminated 2 patches.
* Fri Jun 13 2008 jeffm@suse.de
- Removed kABI reference symbols
- Restored make-symsets check for ignoring/tolerating kABI changes.
* Fri Jun 13 2008 jeffm@suse.de
- Update config files (vanilla).
* Fri Jun 13 2008 jeffm@suse.de
- Update config files.
* Fri Jun 13 2008 jeffm@suse.de
- Updated to 2.6.26-rc6-git1.
  - Eliminated 2 patches.
* Thu Jun 12 2008 sdietrich@suse.de
- config.conf: Suppress RT until forward-port is complete
* Thu Jun 12 2008 jeffm@suse.de
- patches.drivers/libata-ata_piix-macbook-fix: Delete.
* Thu Jun 12 2008 olh@suse.de
- update ps3 config, disable unused drivers
- disable patches.arch/ppc-efika-slowdown.patch
* Thu Jun 12 2008 jeffm@suse.de
- Updated to 2.6.26-rc5-git5.
  - Eliminated 91 patches.
  - Disabled OCFS2 userspace heartbeat.
  - Disabled Xen.
* Thu Jun 12 2008 sdietrich@suse.de
  Build fix: drop patches merged into 2.6.25.5
- patches.rt/x86-fix-tsc-cyc2ns-crap.patch: Delete.
- patches.rt/x86-prepare-to-fix-32bit-sched-clock-crap.patch:
  Delete.
- patches.rt/x86-fix-32bit-sched-clock-crap.patch: Delete.
  Update to 2.6.25-RT6:
- Update config files: enable (M) CONFIG_RWLOCK_TORTURE_TEST
  Resolve conflicts:
- patches.rt/preempt-realtime-x86_64.patch: Linux-RT 2.6.25.4-RT.
  Add:
- patches.rt/trace-eip2ip.patch: Re: 2.6.25.4-rt4 Compile Fix.
- patches.rt/rwlock-prio-fix.patch: rwlock: reset prio on unlocks
  and wakeups.
- patches.rt/rwlock-fixes.patch: rwlock: fix pi_list race
  conditions.
- patches.rt/event-trace-hrtimer-trace.patch: event-tracer:
  add clockevent trace.
- patches.rt/rwlock-torture.patch: rwlock: rwlock torture test.
- patches.rt/ftrace-wakeup-rawspinlock.patch: ftrace: user raw
  spin lock for wakeup function trace.
- patches.rt/radix-tree-lockdep-plus1.patch: lockdep: add +1 to
  radix tree array.
- patches.rt/sched-cpupri-hotplug-support.patch: sched: fix
  cpupri hotplug support.
- patches.rt/sched-cpupri-priocount.patch: sched: fix cpupri
  priocount.
- patches.rt/ftrace-hotplug-fix.patch: ftrace: cpu hotplug fix.
* Wed Jun 11 2008 agruen@suse.de
- rpm/make-symsets: update to the latest version which will ignore
  symset changes if the symset includes a symbol marked to be
  ignored.
* Wed Jun 11 2008 agruen@suse.de
- rpm/kernel-binary.spec.in: only generate symsets for kernels
  with CONFIG_MODULES=y.
- rpm/macros.kernel-source: remove the ps3 specific check: we
  really want to check whether the kernel mas modules enabled,
  which is covered by the symsets check already now.
* Wed Jun 11 2008 gregkh@suse.de
- patches.drivers/usb-don-t-use-reset-resume-if-drivers-don-t-support-it.patch:
  USB: don't use reset-resume if drivers don't support it.
* Wed Jun 11 2008 gregkh@suse.de
- comment out
  patches.suse/convert-novfs-to-open-soure-coding-standards.patch in the
  series file as it is reported to fail some regression tests.
* Wed Jun 11 2008 gregkh@suse.de
- patches.suse/convert-novfs-to-open-soure-coding-standards.patch:
  Convert novfs to open soure coding standards.
* Mon Jun  9 2008 gregkh@suse.de
- patches.fixes/mptbase-vmware-fix: Delete as it's not needed anymore
* Mon Jun  9 2008 gregkh@suse.de
- refresh patches to apply cleanly
* Mon Jun  9 2008 gregkh@suse.de
- Update to 2.6.25.6
  - loads of bugfixes
  - remove the following patches that were already included in this release:
  - patches.arch/cpufreq_fix_acpi_driver_on_BIOS_changes.patch
  - patches.drivers/libata-force-hardreset-if-link-pm
  - patches.fixes/input-hid-apple-numlock-emulation.patch
  - patches.arch/check-for-acpi-resource-conflicts-in-i2c-bus-drivers.patch
* Mon Jun  9 2008 gregkh@suse.de
- patches.drivers/usb-sierra-option.patch: USB: update sierra
  and option device ids (bnc#374637).
* Mon Jun  9 2008 teheo@suse.de
- patches.drivers/libata-ahci-mcp65-workarounds: ahci: workarounds
  for mcp65 (bnc#398573).
* Mon Jun  9 2008 jkosina@suse.de
- patches.fixes/input-i8042-add-ctr-resume-timeout.patch: Input:
  add retry logic to resume with respect to CTR (bnc#351119).
* Sat Jun  7 2008 gregkh@suse.de
- Update to 2.6.25.5.
  - fixes CVE-2008-1673
* Fri Jun  6 2008 tiwai@suse.de
- add missing patches.rt/ftrace-add-nr_syscalls.patch for fixing
  i386-rt_debug
* Thu Jun  5 2008 jbeulich@novell.com
- patches.xen/xen3-patch-2.6.22,
  patches.xen/xen3-patch-2.6.23,
  patches.xen/xen3-patch-2.6.24,
  patches.xen/xen3-patch-2.6.25: netfront (bnc#394575) and page table
  handling (bnc#396858) fixes.
- patches.xen/540-blkif-nr-segments-check.patch: Avoid theoretical
  TOCTTOU bug in block backend nr_segments checking.
- patches.xen/560-x86_64-no-irq-affinity-break-msg.patch: x86_64:
  Remove warning message about 'Breaking affinity for irq'.
- patches.xen/xen-netfront-flip-prod: fix updating of req_prod_pvt
  in the receive ring for the flipping case.
* Wed Jun  4 2008 jblunck@suse.de
- patches.drivers/libata-acpi-fix-hotplug: Don't call ata_port_freeze()
  in ata_acpi_detach_device().
* Wed Jun  4 2008 schwab@suse.de
- Don't clean asm-offsets.h.
* Wed Jun  4 2008 jjohanse@suse.de
- patches.apparmor/apparmor-module_interface.diff: AppArmor:
  Update patch to properly set profile name_table size (bnc#396993)
* Wed Jun  4 2008 jkosina@suse.de
- patches.fixes/input-add-amilo-pro-v-to-nomux.patch: Add
  Fujitsu-Siemens Amilo Pro 2010 and 2030 to nomux list
  (bnc#345699 bnc#389169)
* Tue Jun  3 2008 tiwai@suse.de
- patches.drivers/alsa-hda-realtek-auto-resume-fix: hda - Fix
  resume of auto-config mode with Realtek codecs (bnc#385473).
* Tue Jun  3 2008 bphilips@suse.de
  Backport: e1000e for montevina systems
- patches.drivers/e1000e-backport-0001-remove-no-longer-used-e1000e_read_nvm_spi.patch:
  e1000e: remove no longer used e1000e_read_nvm_spi.
- patches.drivers/e1000e-backport-0002-remove-irq_sem.patch:
  e1000e: remove irq_sem.
- patches.drivers/e1000e-backport-0003-rename-mc_addr_list_update.patch:
  e1000e: rename mc_addr_list_update.
- patches.drivers/e1000e-backport-0004-reorganize-PHY-and-flow-control-interface.patch:
  e1000e: reorganize PHY and flow control interface.
- patches.drivers/e1000e-backport-0005-Make-arrays-out-of-these-Rx-Tx-registers.patch:
  e1000e: Make arrays out of these Rx/Tx registers.
- patches.drivers/e1000e-backport-0006-rename-a-few-functions.patch:
  e1000e: rename a few functions.
- patches.drivers/e1000e-backport-0007-cleanup-several-stats-issues.patch:
  e1000e: cleanup several stats issues.
- patches.drivers/e1000e-backport-0008-Fix-HW-Error-on-es2lan-ARP-capture-issue-by.patch:
  e1000e: Fix HW Error on es2lan, ARP capture issue by BMC.
- patches.drivers/e1000e-backport-0009-Add-support-for-BM-PHYs-on-ICH9.patch:
  e1000e: Add support for BM PHYs on ICH9.
* Mon Jun  2 2008 tiwai@suse.de
- patches.drivers/alsa-hda-vt1708-pcm-noise-fix: Delete.
- patches.drivers/alsa-hda-backport-2.6.26-rc4: Backport ALSA
  HDA-Intel patches from 2.6.26-rc4 (bnc#390473).
* Mon Jun  2 2008 tiwai@suse.de
- patches.drivers/alsa-asus-a9t-fix: ac97 - Fix ASUS A9T laptop
  output (bnc#363987).
* Mon Jun  2 2008 jeffm@suse.de
- patches.fixes/reiserfs-prealloc-fix: reiserfs: Use list_del_init
  in use_preallocated_list_if_available (bnc#378095).
* Mon Jun  2 2008 tiwai@suse.de
- patches.drivers/alsa-hp2133-mic-fix: hda - Fix mic input on
  HP2133 (bnc#388540).
* Mon Jun  2 2008 tiwai@suse.de
- patches.drivers/alsa-emu10k1-audigy2-digital-fix: emu10k1 - Fix
  inverted Analog/Digital mixer switch on Audigy2 (bnc#396204).
* Sat May 31 2008 sdietrich@suse.de
  RT: Update to 2.5.25.4-rt4 (refreshed patches suppressed)
- Update config files.
  Added:
- patches.rt/adapt-remove-extra-try-to-lock.patch
- patches.rt/adaptive-adjust-pi-wakeup.patch
- patches.rt/adaptive-earlybreak-on-steal.patch
- patches.rt/adaptive-optimize-rt-lock-wakeup.patch
- patches.rt/adaptive-task-oncpu.patch
- patches.rt/arm-fix-compile-error-trace-exit-idle.patch
- patches.rt/arm-omap-02.patch
- patches.rt/arm-omap-03.patch
- patches.rt/arm-omap-04.patch
- patches.rt/arm-omap-05.patch
- patches.rt/fix_vdso_gtod_vsyscall64_2.patch
- patches.rt/ftrace-compile-fixes.patch
- patches.rt/ftrace-disable-daemon.patch
- patches.rt/ftrace-dont-trace-markers.patch
- patches.rt/ftrace-fix-header.patch
- patches.rt/ftrace-function-record-nop.patch
- patches.rt/ftrace-print-missing-cmdline.patch
- patches.rt/ftrace-record-comm-on-ctrl.patch
- patches.rt/ftrace-safe-traversal-hlist.patch
- patches.rt/ftrace-trace-sched.patch
- patches.rt/ftrace-update-cnt-stat-fix.patch
- patches.rt/git-ignore-module-markers.patch
- patches.rt/git-ignore-script-lpp.patch
- patches.rt/lockdep-avoid-fork-waring.patch
- patches.rt/lockstat-fix-contention-points.patch
- patches.rt/lockstat-output.patch
- patches.rt/nmi-show-regs-fix.patch
- patches.rt/preempt-realtime-ftrace-disable-ftraced.patch
- patches.rt/realtime-preempt-warn-about-tracing.patch
- patches.rt/rtmutex-rwlock-cmpxchg-typecast.patch
- patches.rt/rwlock-implement-downgrade-write.patch
- patches.rt/rwlocks-fix-no-preempt-rt.patch
- patches.rt/sched-fix-rt-task-wakeup.patch
- patches.rt/sched-fix-sched-fair-wakeup.patch
- patches.rt/sched-nr-migrate-lower-default-preempt-rt.patch
- patches.rt/sched-prioritize-non-migrating-rt-tasks.patch
- patches.rt/sched-wake_up_idle_cpu-rt.patch
- patches.rt/trace_hist-divzero.patch
- patches.rt/trace_hist-latediv.patch
- patches.rt/x86-delay-enable-preempt-tglx.patch
  Removed:
- patches.rt/rtmutex-optimize-wakeup.patch
- patches.rt/rtmutex-adjust-pi_lock-usage-in-wakeup.patch
- patches.rt/rtmutex-remove-extra-try.patch
- patches.rt/ftrace-remove-print-of-max.patch
* Thu May 29 2008 sdietrich@suse.de
  RT: Update IBM EDAC and PRTM
- Update config files.
- patches.rt/drivers-edac-add-support-for-HS21XM-SMI-remediation:
  Add support for HS21XM SMI Remediation to the 2.6.22-based
  SLERT kernel.
- patches.rt/drivers-edac-add-support-for-HS21_LS21-SMI-remediation:
  Add support for HS21/LS21 SMI Remediation to the 2.6.22-based
  SLERT kernel.
- patches.rt/drivers-edac-i5000-turn-off-unsupported-check:
  Turn off unsupported EDAC check on the i5000 controller.
- patches.rt/drivers-edac-prevent-potential-printk-storm:
  Prevent potential EDAC printk storm.
- patches.rt/drivers-edac-test_device.patch:
  edac-2.6.23-to-2.6.22.patch back-port.
- patches.rt/drivers-edac-new-k8-rev-f.patch:
  edac-2.6.23-to-2.6.22.patch back-port.
- patches.rt/drivers-edac-add-sysfs_notify-calls.patch:
  edac-2.6.23-to-2.6.22.patch back-port.
- patches.rt/drivers-edac-new-amd64.patch:
  drivers-edac-new-amd64.patch (revision 108).
  Obsolete:
- patches.rt/add-support-for-HS21_LS21-SMI-remediation: Delete.
- patches.rt/add-support-for-HS21XM-SMI-remediation: Delete.
- patches.rt/prevent-potential-EDAC-printk-storm: Delete.
* Thu May 29 2008 teheo@suse.de
- patches.drivers/libata-ata_piix-macbook-fix: ata_piix: fix
  macbook ich8m problems (bnc#395407).
* Thu May 29 2008 agruen@suse.de
- Obsolete some KMPs which have been integrated into mainline
  meanwhile (bnc#357799).
* Thu May 29 2008 jbeulich@novell.com
- supported.conf: Mark 8250_pnp as supported.
* Wed May 28 2008 teheo@suse.de
- patches.drivers/libata-acpi-fix-hotplug: libata: Handle bay
  devices in dock stations (bnc#390822 bnc#395082).
* Wed May 28 2008 jkosina@suse.de
- patches.fixes/input-add-i8042-nopnp-for-D845PESV.patch: Input:
  Add i8042.nopnp for Intel D845PESV (bnc#386952).
* Mon May 26 2008 sdietrich@suse.de
  RT: Update to 2.6.25.4-rt3 - add RWSEM / RWLOCK patches:
- patches.rt/rt-mutex-core.patch: Linux-RT 2.6.25.4-RT3.
- patches.rt/multi-reader-account.patch: map tasks to reader
  locks held.
- patches.rt/multi-reader-limit.patch: implement reader limit
  on read write locks.
- patches.rt/multi-reader-lock-account.patch: map read/write
  locks back to their readers.
- patches.rt/multi-reader-pi.patch: read lock Priority Inheritance
  implementation.
- patches.rt/native-sched-clock-booboo.patch: Re: 2.6.25.4-rt2
  (native_sched_clock() booboo).
- patches.rt/rwlocks-default-nr-readers-nr-cpus.patch:
- patches.rt/rwlocks-multiple-readers.patch: implement rwlocks
  management.
- patches.rt/rwsems-multiple-readers.patch: add framework for
  multi readers on rwsems.
* Mon May 26 2008 olh@suse.de
- add patches.arch/ppc-efika-slowdown.patch
  slow down hot code paths to avoid hangs during install (bnc#374309)
* Sun May 25 2008 tiwai@suse.de
- Update config files: forgot to update vanilla kernel configs
* Sat May 24 2008 tiwai@suse.de
- Update config files: disable group scheduler for normal kernels
  for openSUSE 11.0, too (this should be enabled again later for
  11.1 once after the bugs get fixed...)
* Fri May 23 2008 tiwai@suse.de
- patches.drivers/alsa-hda-dma-pos-fix: hda - Fix DMA position
  inaccuracy (bnc#362775, bnc#364421).
- patches.drivers/alsa-hda-vt1708-pcm-noise-fix: hda - Fix noise
  on VT1708 codec (bnc#390473).
* Fri May 23 2008 sdietrich@suse.de
  RT: Update config files: Disable Group Scheduler
* Thu May 22 2008 teheo@suse.de
- patches.drivers/libata-pmp-simg3726-nosrst: libata: SRST can't
  be trusted on PMP sil3726 (bnc#393456).
* Thu May 22 2008 sdietrich@suse.de
  RT: update config files: Disable SYSFS_DEPRECATED
* Thu May 22 2008 teheo@suse.de
- patches.drivers/libata-pmp-detection-fixes: libata: fix a
  number of PMP detection problems (bnc#393456).  series.conf not
  updated.  Fix it.
* Thu May 22 2008 teheo@suse.de
- patches.drivers/libata-pmp-detection-fixes: libata: fix a
  number of PMP detection problems (bnc#393456).
* Thu May 22 2008 sdietrich@suse.de
  RT: build fix
- suppress adaptive locking patches that are not upstream.
- Update config files.
* Wed May 21 2008 jblunck@suse.de
- patches.fixes/acpi-bay-cleanup-and-exit.patch: bay: Exit if
  notify handler cannot be installed (bnc#390822).
* Wed May 21 2008 jbeulich@novell.com
- patches.xen/xen3-patch-2.6.25: Fix DomU boot issue.
* Wed May 21 2008 oneukum@suse.de
- patches.drivers/ehci_fix_remote_wakeup_regression.diff: EHCI:
  fix remote-wakeup regression. (bnc#373128)
* Tue May 20 2008 jblunck@suse.de
- doc/novell-kmp/novell-example-1.1.tar.bz2,
  doc/novell-kmp/novell-example.spec: Fix example spec and Kbuild
  because EXTRA_CFLAGS isn't taken from the environment anymore.
* Tue May 20 2008 sdietrich@suse.de
- Update config files: SLERT compatibility: SYSFS_DEPRECATED
* Tue May 20 2008 sdietrich@suse.de
  RT: Update to 2.5.25.4-rt2 (refreshed patches suppressed)
  Add:
- patches.rt/rtmutex-adaptive-locks.patch: adaptive real-time
  lock support.
- patches.rt/x86-fix-32bit-sched-clock-crap.patch: x86: disable TSC
  for sched_clock() when calibration failed
- patches.rt/x86-fix-tsc-cyc2ns-crap.patch: x86: fix setup of cyc2ns
  in tsc_64.c.
- patches.rt/x86-prepare-to-fix-32bit-sched-clock-crap.patch:
  x86: distangle user disabled TSC from unstable
- patches.rt/adaptive-spinlock-lite-v2.patch: adaptive spinlocks
  lite.
- patches.rt/rtmutex-remove-xchg.patch: rtmutex - remove double
  xchg.
  Update:
- patches.rt/rtmutex-rearrange.patch: rearrange
  rt_spin_lock_slowlock sleeping code.
  Resolve Conflicts:
- patches.rt/rtmutex-lateral-steal.patch: allow rt-mutex
  lock-stealing to include lateral priority.
- Update config files.
* Mon May 19 2008 sdietrich@suse.de
  RT: Adaptive locking patches:
- patches.rt/rtmutex-lateral-steal.patch: allow rt-mutex
  lock-stealing to include lateral priority.
- patches.rt/rtmutex-lateral-steal-sysctl.patch: sysctl for
  runtime-control of lateral mutex stealing.
- patches.rt/rtmutex-rearrange.patch: rearrange
  rt_spin_lock_slowlock sleeping code.
- patches.rt/rtmutex-adaptive-locks.patch: adaptive real-time
  lock support.
- patches.rt/rtmutex-adaptive-timeout.patch: add a timeout
  mechanism to adaptive-locking.
- patches.rt/rtmutex-optimize-wakeup.patch: optimize rt lock
  wakeup.
- patches.rt/rtmutex-adjust-pi_lock-usage-in-wakeup.patch:
  adjust pi_lock usage in wakeup.
- patches.rt/rtmutex-remove-extra-try.patch: remove the extra
  call to try_to_take_lock.
- Update config files:
  CONFIG_RTLOCK_LATERAL_STEAL=y
  CONFIG_ADAPTIVE_RTLOCK=y
  CONFIG_IBM_RTL (disable temporarily to address build error)
* Mon May 19 2008 tiwai@suse.de
- Update config files (missing for rt*).
* Mon May 19 2008 tiwai@suse.de
- patches.drivers/alsa-hda-backport-2.6.25-rc3: Backport ALSA
  HDA-Intel patches from 2.6.25-rc3 (bnc#390473, bnc#386422,
  bnc#385473).
- patches.drivers/alsa-intel8x0-8ch: intel8x0 - Add support of
  8 channel sound.
- patches.drivers/alsa-mixer-oss-map-fix: Add more fallbacks to
  OSS PHONEOUT mixer map.
- patches.drivers/alsa-usb-audio-disconnect-oops-fix: Fix Oops
  with usb-audio reconnection.
- patches.drivers/alsa-hda-intel-new-ati-id: Delete.
- patches.drivers/alsa-hda-intel-new-nvidia-id: Delete.
- patches.drivers/alsa-hda-intel-use-PCI_DEVICE: Delete.
- patches.drivers/alsa-dell-xps-m1330-hp-fix: Delete.
- Update config files.
* Mon May 19 2008 jbeulich@novell.com
- Update Xen patches to c/s 524 and 2.6.25.4.
- patches.xen/xen-balloon-hvm-min: don't allow ballooning down
  a HVM domain below a reasonable limit (172482).
- patches.xen/xen-swiotlb-heuristics: adjust Xen's swiotlb
  default size setting.
* Mon May 19 2008 jbeulich@novell.com
- patches.arch/acpi_thinkpad_introduce_acpi_root_table_boot_param.patch:
  Add missing list terminator for acpi_rsdt_dmi_table[] and move to
  __initdata.
* Mon May 19 2008 sdietrich@suse.de
  RT: SMI latency fixes from IBM.
- patches.rt/add-support-for-HS21_LS21-SMI-remediation: [PATCH
  1/3] Add support for HS21/LS21 SMI Remediation.
- patches.rt/add-support-for-HS21XM-SMI-remediation: [PATCH 2/3]
  Add support for HS21XM SMI Remediation .
- patches.rt/prevent-potential-EDAC-printk-storm: [PATCH 3/3]
  Prevent potential EDAC printk storm.
- RT: Update config files.
* Mon May 19 2008 agruen@suse.de
- patches.suse/nfs4acl-ext3.diff: Fix compilation error when
  CONFIG_EXT3_FS_NFS4ACL is off.
* Mon May 19 2008 sdietrich@suse.de
- RT: Update config files.
* Mon May 19 2008 trenn@suse.de
- patches.suse/acpi-dsdt-initrd-v0.9a-2.6.25.patch: ACPI:
  initramfs DSDT override support.
  - > Did not make it into 2.6.25 again...
- Update config files.
* Sun May 18 2008 agruen@suse.de
- Update the nfs4acl patches (and split them out more explicitly).
  Export all new symbols als GPL only.
- patches.apparmor/parent-permission.diff: Rediff.
* Sun May 18 2008 sdietrich@suse.de
- RT: Update config files.
* Sun May 18 2008 sdietrich@suse.de
  RT: update to 2.6.25.4-rt1 patch queue.
* Sun May 18 2008 sdietrich@suse.de
  RT cleanup: Remove unused/obsolete RT patches.
* Sun May 18 2008 sdietrich@suse.de
- Update config files: update RT debug configs.
- config.conf: enable DEBUG flavors.
* Sat May 17 2008 sdietrich@suse.de
  Linux-RT 2.6.25-RT:
- Updated RT patch queue (not individually enumerated here)
- Update config files: RT
- config.conf: RT
* Fri May 16 2008 gregkh@suse.de
- Update config files.
- patches.drivers/usb-add-option-hso-driver.patch: USB: add
  option hso driver.
* Fri May 16 2008 gregkh@suse.de
- refresh patches due to fuzz
* Fri May 16 2008 gregkh@suse.de
- patches.fixes/bluetooth-wake-up-properly-after-ide-timeout-expires.patch:
  bluetooth: wake up properly after ide timeout expires
  (bnc#390839).
* Fri May 16 2008 olh@suse.de
- update patches.fixes/tg3-flowctrl.patch
  do not compare flow control settings in parallel detect mode
* Fri May 16 2008 trenn@suse.de
- patches.arch/acpi_thinkpad_introduce_acpi_root_table_boot_param.patch:
  Introduce acpi_root_table=rsdt boot param and dmi list to
  force rsdt (http://bugzilla.kernel.org/show_bug.cgi?id=8246).
- patches.arch/acpi_thinkpad_introduce_acpica_rsdt_global_variable.patch:
  ACPICA: Add acpi_gbl_force_rsdt variable
  (http://bugzilla.kernel.org/show_bug.cgi?id=8246).
- patches.arch/acpi_thinkpad_remove_R40e_c-state_blacklist.patch:
  Remove R40e c-state blacklist
  (http://bugzilla.kernel.org/show_bug.cgi?id=8246).
- patches.arch/cpufreq_fix_acpi_driver_on_BIOS_changes.patch:
  CPUFREQ: Check against freq changes from the BIOS.
* Fri May 16 2008 jblunck@suse.de
- patches.fixes/vfs-2.6.git-9bc300eae0400efdfae3fec3352896e10468a78f.patch:
  return to old errno choice for fix mkdir -p with ro-bind mounts
* Fri May 16 2008 jblunck@suse.de
- rpm/kernel-{binary,source}.spec.in: use localversion and set
  KBUILD_BUILD_VERSION (used for Kernel:Vanilla)
* Thu May 15 2008 gregkh@suse.de
- Update to final version of 2.6.25.4
* Thu May 15 2008 jblunck@suse.de
- rpm/macros.kernel-source: Let KMPs fail when flavors_to_build is empty
- rpm/kernel-{dummy,source,syms,binary}.spec.in, scripts/tar-up.sh:
  fix release number changes introduced by bnc#271712 for OBS (bnc#378933)
* Thu May 15 2008 olh@suse.de
- add patches.fixes/tg3-flowctrl.patch
  revert 'Fix supporting flowctrl code' to fix JS21 (bnc#390314)
* Wed May 14 2008 oneukum@suse.de
- patches.drivers/appletouch_persist.diff: reset_resume and
  autosuspend for appletouch touchpads (bnc#388399).
* Wed May 14 2008 oneukum@suse.de
- patches.drivers/appletouch_persist.diff: reset_resume and
  autosuspend for appletouch touchpads (bnc#388399).
* Wed May 14 2008 teheo@suse.de
- patches.drivers/libata-force-hardreset-if-link-pm: libata:
  force hardreset if link is in powersave mode (bnc#381795).
- patches.drivers/libata-ahci-sb600-no-msi: ahci: SB600 ahci
  can't do MSI, blacklist that capability (bnc#384559).
* Tue May 13 2008 gregkh@suse.de
- Update config files for vanilla targets
* Tue May 13 2008 gregkh@suse.de
- Update to 2.6.25.4-rc1
  - lots of bug fixes
* Tue May 13 2008 sdietrich@suse.de
  Cleanup RT:
- patches.rt/*: Delete.
* Mon May 12 2008 jkosina@suse.de
- patches.fixes/input-hid-apple-numlock-emulation.patch:
  HID: split Numlock emulation quirk from
  HID_QUIRK_APPLE_HAS_FN. (bnc#381764).
* Sat May 10 2008 gregkh@suse.de
- Update to 2.6.25.3
  - fixes 2 security issues (one networking, one sparc, no CVE
    numbers issued just yet)
* Fri May  9 2008 jeffm@suse.de
- patches.apparmor/fsetattr-restore-ia_file: vfs: restore ia_file
  for compatibility with external modules. (bnc#381259)
* Fri May  9 2008 hare@suse.de
- patches.drivers/open-iscsi-git-update: Delete.
- patches.fixes/open-iscsi-nop-fixes: NOP timeout fixes.
* Thu May  8 2008 gregkh@suse.de
- patches.kernel.org/v4l-dvb-patch-for-various-dibcom-based-devices.patch:
  V4L/DVB (7473): PATCH for various Dibcom based devices
  (bnc#381632).
* Thu May  8 2008 gregkh@suse.de
- comment out vmware patch as it should no longer be needed
* Thu May  8 2008 gregkh@suse.de
- rediff patches to apply cleanly.
* Thu May  8 2008 gregkh@suse.de
- Update to 2.6.25.3-rc1
  - potential fix for increased power consumption and other bugs
* Thu May  8 2008 sassmann@suse.de
- Update config file ppc64.
- patches.arch/ppc-ps3-ps3vram-mtd.patch: ps3vram driver that
  allows you to access the extra ~240MB of DDR video.
* Wed May  7 2008 gregkh@suse.de
- patches.kernel.org/patch-2.6.25.1-2: Linux 2.6.25.2.
  - fixes CVE-2008-1669
* Tue May  6 2008 schwab@suse.de
- suse-ppc32-mol-semaphore: fix mol for 2.6.26-rc1.
* Mon May  5 2008 jack@suse.cz
  Bring UDF to state in 2.6.26-rc1 to support UDF 2.50.
- patches.suse/udf-10-simple-cleanup-of-truncate.c.patch: udf:
  simple cleanup of truncate.c (fate#303336).
- patches.suse/udf-11-truncate-create-function-for-updating-of-Alloc.patch:
  udf: truncate: create function for updating of Allocation Ext
  Descriptor (fate#303336).
- patches.suse/udf-12-replace-all-adds-to-little-endians-variables-wi.patch:
  udf: replace all adds to little endians variables with
  le*_add_cpu (fate#303336).
- patches.suse/udf-13-simplify-__udf_read_inode.patch: udf:
  simplify __udf_read_inode (fate#303336).
- patches.suse/udf-14-replace-udf_-_offset-macros-with-functions.patch:
  udf: replace udf_*_offset macros with functions (fate#303336).
- patches.suse/udf-15-convert-udf_count_free_bitmap-to-use-bitmap_wei.patch:
  udf: convert udf_count_free_bitmap to use bitmap_weight
  (fate#303336).
- patches.suse/udf-16-udf_get_block-inode_bmap-remove-unneeded-che.patch:
  udf: udf_get_block, inode_bmap - remove unneeded checks
  (fate#303336).
- patches.suse/udf-17-create-function-for-conversion-from-timestamp-t.patch:
  udf: create function for conversion from timestamp to timespec
  (fate#303336).
- patches.suse/udf-18-convert-udf_stamp_to_time-to-return-struct-time.patch:
  udf: convert udf_stamp_to_time to return struct timespec
  (fate#303336).
- patches.suse/udf-19-convert-udf_stamp_to_time-and-udf_time_to_stamp.patch:
  udf: convert udf_stamp_to_time and udf_time_to_stamp to use
  timestamps (fate#303336).
- patches.suse/udf-1-kill-udf_set_blocksize.patch: udf: kill
  udf_set_blocksize (fate#303336).
- patches.suse/udf-20-remove-unneeded-kernel_timestamp-type.patch:
  udf: remove unneeded kernel_timestamp type (fate#303336).
- patches.suse/udf-21-super.c-reorganization.patch: udf: super.c
  reorganization (fate#303336).
- patches.suse/udf-22-Mark-udf_process_sequence-as-noinline.patch:
  udf: Mark udf_process_sequence() as noinline (fate#303336).
- patches.suse/udf-23-Remove-checking-of-existence-of-filename-in-udf.patch:
  udf: Remove checking of existence of filename in udf_add_entry()
  (fate#303336).
- patches.suse/udf-24-Remove-declarations-of-arrays-of-size-UDF_NAME_.patch:
  udf: Remove declarations of arrays of size UDF_NAME_LEN (256
  bytes) (fate#303336).
- patches.suse/udf-25-fix-anchor-point-detection.patch: udf:
  fix anchor point detection (fate#303336).
- patches.suse/udf-26-Cleanup-volume-descriptor-sequence-processing.patch:
  udf: Cleanup volume descriptor sequence processing
  (fate#303336).
- patches.suse/udf-27-Improve-error-recovery-on-mount.patch:
  udf: Improve error recovery on mount (fate#303336).
- patches.suse/udf-28-Move-filling-of-partition-descriptor-info-into.patch:
  udf: Move filling of partition descriptor info into a separate
  function (fate#303336).
- patches.suse/udf-29-Move-processing-of-virtual-partitions.patch:
  udf: Move processing of virtual partitions (fate#303336).
- patches.suse/udf-2-kill-useless-file-header-comments-for-vfs-metho.patch:
  udf: kill useless file header comments for vfs method
  implementations (fate#303336).
- patches.suse/udf-30-Cleanup-anchor-block-detection.patch: udf:
  Cleanup anchor block detection. (fate#303336).
- patches.suse/udf-31-Improve-anchor-block-detection.patch: udf:
  Improve anchor block detection (fate#303336).
- patches.suse/udf-32-Silence-warning-about-accesses-beyond-end-of-de.patch:
  udf: Silence warning about accesses beyond end of device
  (fate#303336).
- patches.suse/udf-33-Fix-detection-of-VAT-version.patch: udf:
  Fix detection of VAT version (fate#303336).
- patches.suse/udf-34-Allow-loading-of-VAT-inode.patch: udf:
  Allow loading of VAT inode (fate#303336).
- patches.suse/udf-35-Handle-VAT-packed-inside-inode-properly.patch:
  udf: Handle VAT packed inside inode properly (fate#303336).
- patches.suse/udf-36-Mount-filesystem-read-only-if-it-has-pseudoover.patch:
  udf: Mount filesystem read-only if it has pseudooverwrite
  partition (fate#303336).
- patches.suse/udf-37-Fix-handling-of-multisession-media.patch:
  udf: Fix handling of multisession media (fate#303336).
- patches.suse/udf-38-Add-read-only-support-for-2.50-UDF-media.patch:
  udf: Add read-only support for 2.50 UDF media (fate#303336).
- patches.suse/udf-39-Fix-bug-in-VAT-mapping-code.patch: udf:
  Fix bug in VAT mapping code (fate#303336).
- patches.suse/udf-3-move-headers-out-include-linux.patch: udf:
  move headers out include/linux/ (fate#303336).
- patches.suse/udf-40-Fix-compilation-warnings-when-UDF-debug-is-on.patch:
  udf: Fix compilation warnings when UDF debug is on
  (fate#303336).
- patches.suse/udf-41-use-crc_itu_t-from-lib-instead-of-udf_crc.patch:
  udf: use crc_itu_t from lib instead of udf_crc (fate#303336).
- patches.suse/udf-42-fs-udf-partition.c-udf_get_pblock-mustn-t-be.patch:
  udf: fs/udf/partition.c:udf_get_pblock() mustn't be inline
  (fate#303336).
- patches.suse/udf-4-Use-DIV_ROUND_UP.patch: fs/udf: Use
  DIV_ROUND_UP (fate#303336).
- patches.suse/udf-5--udf_error-static.patch: make udf_error()
  static (fate#303336).
- patches.suse/udf-6-udf_CS0toUTF8-cleanup.patch: udf:
  udf_CS0toUTF8 cleanup (fate#303336).
- patches.suse/udf-7-fix-udf_build_ustr.patch: udf: fix
  udf_build_ustr (fate#303336).
- patches.suse/udf-8-udf_CS0toNLS-cleanup.patch: udf: udf_CS0toNLS
  cleanup (fate#303336).
- patches.suse/udf-9-constify-crc.patch: udf: constify crc
  (fate#303336).
* Fri May  2 2008 teheo@suse.de
- patches.drivers/libata-sata_inic162x-update-to-0.4:
  sata_inic162x: update to 0.4 (bnc#385599).
* Fri May  2 2008 gregkh@suse.de
- update to 2.6.25.1:
  - fixes CVE-2008-1375 and CVE-2008-1675
  - lots of other minor bugfixes
* Thu May  1 2008 agruen@suse.de
- Provide "kernel(flavor:symset) = version" instead of
  "kernel(symset) = version". This disambiguates the case where
  several kernel flavors end up with the same modver checksums
  (bnc#190163, bnc#355628).
* Thu May  1 2008 teheo@suse.de
- patches.drivers/libata-ata_piix-verify-sidpr: ata_piix: verify
  SIDPR access before enabling it (bnc#385535).
* Wed Apr 30 2008 gregkh@suse.de
- novfs: fixes needed due to apparmor vfs core changes
  (extended attributes probably do not work now...)
* Wed Apr 30 2008 gregkh@suse.de
- patches.suse/novfs-add-the-novell-filesystem-client-kernel-module.patch:
  novfs: Add the Novell filesystem client kernel module.
- Update config files.
* Wed Apr 30 2008 jeffm@suse.de
- patches.suse/reiserfs-simplify-xattr-internal-file-lookups-opens.diff:
  removed fs.h changes, they weren't used.
* Mon Apr 28 2008 gregkh@suse.de
- Update config files.
  hopefully the build system is happy now
* Mon Apr 28 2008 gregkh@suse.de
- rpm/config-subst: add #!/bin/sh at start of script to keep future
  build issues (like bnc#382214) from causing problems.
* Mon Apr 28 2008 sdietrich@suse.de
  Cleanup:
  Remove obsolete patches: ARM-ep93xx-timer, latency-tracing,
  RCU, KVM, mcount, PPC-gtod
- patches.rt/ep93xx-timer-accuracy.patch: Delete.
- patches.rt/ep93xx-clockevents.patch: Delete.
- patches.rt/ep93xx-clockevents-fix.patch: Delete.
- patches.rt/kvm-fix-preemption-bug.patch: Delete.
- patches.rt/kvm-lapic-migrate-latency-fix.patch: Delete.
- patches.rt/kvm-make-less-noise.patch: Delete.
- patches.rt/kvm-preempt-rt-resched-delayed.patch: Delete.
- patches.rt/sched-use-a-2d-bitmap-search-prio-cpu.patch: Delete.
- patches.rt/remove-unused-var-warning.patch: Delete.
- patches.rt/latency-tracing.patch: Delete.
- patches.rt/latency-tracing-remove-trace-array.patch: Delete.
- patches.rt/latency-tracer-disable-across-trace-cmdline.patch:
  Delete.
- patches.rt/latency-tracing-i386-paravirt-fastcall.patch: Delete.
- patches.rt/latency-tracing-i386.patch: Delete.
- patches.rt/latency-tracing-x86_64.patch: Delete.
- patches.rt/latency-tracing-ppc.patch: Delete.
- patches.rt/latency-tracer-printk-fix.patch: Delete.
- patches.rt/latency-tracing-exclude-printk.patch: Delete.
- patches.rt/latency-tracing-prctl-api-hack.patch: Delete.
- patches.rt/latency-tracing-raw-spinlock-hack.patch: Delete.
- patches.rt/latency-tracer-one-off-fix.patch: Delete.
- patches.rt/smaller-trace.patch: Delete.
- patches.rt/trace-name-plus.patch: Delete.
- patches.rt/trace-with-caller-addr.patch: Delete.
- patches.rt/trace-sti-mwait.patch: Delete.
- patches.rt/latency-tracer-optimize-a-bit.patch: Delete.
- patches.rt/idle-stop-critical-timing.patch: Delete.
- patches.rt/latency-tracer-variable-threshold.patch: Delete.
- patches.rt/reset-latency-histogram.patch: Delete.
- patches.rt/undo-latency-tracing-raw-spinlock-hack.patch: Delete.
- patches.rt/random-driver-latency-fix.patch: Delete.
- patches.rt/latency-tracing-use-now.patch: Delete.
- patches.rt/preempt_max_latency-in-all-modes.patch: Delete.
- patches.rt/latency-hist-add-resetting-for-all-timing-options.patch:
  Delete.
- patches.rt/latency-trace-sysctl-config-fix.patch: Delete.
- patches.rt/latency-trace-convert-back-to-ms.patch: Delete.
- patches.rt/latency-trace-fix.patch: Delete.
- patches.rt/trace-cpuidle.patch: Delete.
- patches.rt/lockdep-show-held-locks.patch: Delete.
- patches.rt/lockdep-lock_set_subclass.patch: Delete.
- patches.rt/lockdep-prettify.patch: Delete.
- patches.rt/lockdep-more-entries.patch: Delete.
- patches.rt/latency-tracer-arch-low-address.patch: Delete.
- patches.rt/latency-tracer-dont-panic-on-failed-bootmem-alloc.patch:
  Delete.
- patches.rt/mcount-add-x86_64-notrace-annotations.patch: Delete.
- patches.rt/mcount-add-x86-vdso-notrace-annotations.patch:
  Delete.
- patches.rt/mcount-nmi-notrace-annotations.patch: Delete.
- patches.rt/mcount-add-time-notrace-annotations.patch: Delete.
- patches.rt/mcount-lockdep-notrace-annotations.patch: Delete.
- patches.rt/mcount-preemptcount-notrace-annotations.patch:
  Delete.
- patches.rt/mcount-fault-notrace-annotations.patch: Delete.
- patches.rt/mcount-irqs-notrace-annotations.patch: Delete.
- patches.rt/mcount-rcu-notrace-annotations.patch: Delete.
- patches.rt/latency-measurement-drivers-fix.patch: Delete.
- patches.rt/latency-measurement-drivers.patch: Delete.
- patches.rt/redo-regparm-option.patch: Delete.
- patches.rt/nmi-profiling-base.patch: Delete.
- patches.rt/ppc-gtod-notrace-fix.patch: Delete.
- patches.rt/ppc-gtod-support.patch: Delete.
- patches.rt/ppc-gtod-support-fix.patch: Delete.
- patches.rt/ppc-a-2.patch: Delete.
- patches.rt/ppc-fix-clocksource-timebase-shift.patch: Delete.
- patches.rt/ppc-remove-broken-vsyscall.patch: Delete.
- patches.rt/ppc-read-persistent-clock.patch: Delete.
- patches.rt/ppc-clockevents.patch: Delete.
- patches.rt/ppc-clockevents-fix.patch: Delete.
- patches.rt/ppc-highres-dyntick.patch: Delete.
- patches.rt/inet-hash-bits-ipv6-fix.patch: Delete.
- patches.rt/inet_hash_bits.patch: Delete.
- patches.rt/rcu-1.patch: Delete.
- patches.rt/rcu-2.patch: Delete.
- patches.rt/rcu-3.patch: Delete.
- patches.rt/rcu-4.patch: Delete.
- patches.rt/rcu-preempt-fix-nmi-watchdog.patch: Delete.
- patches.rt/rcu-preempt-fix-rcu-torture.patch: Delete.
- patches.rt/dynticks-rcu-rt-fixlet.patch: Delete.
- patches.rt/rcu-tasklet-softirq.patch: Delete.
- patches.rt/rcu-classic-fixup.patch: Delete.
- patches.rt/rcu-warn-underflow.patch: Delete.
* Mon Apr 28 2008 sdietrich@suse.de
  Cleanup:
  Remove obsolete Adaptive-locking patches
- patches.rt/rtmutex-adaptive-locks.patch: Delete.
- patches.rt/rtmutex-adaptive-mutexes.patch: Delete.
- patches.rt/rtmutex-adaptive-timeout.patch: Delete.
- patches.rt/rtmutex-adjust-pi_lock-usage-in-wakeup.patch: Delete.
- patches.rt/rtmutex-lateral-steal.patch: Delete.
- patches.rt/rtmutex-lateral-steal-sysctl.patch: Delete.
- patches.rt/rtmutex-optimize-wakeup.patch: Delete.
- patches.rt/rtmutex-rearrange.patch: Delete.
- patches.rt/rtmutex-remove-extra-try.patch: Delete.
- patches.rt/x86-ticket-lock.patch: Delete.
* Mon Apr 28 2008 sdietrich@suse.de
  Cleanup:
  Remove ARM and MIPS RT patches
- patches.rt/arm-cmpxchg-support-armv6.patch: Delete.
- patches.rt/arm-cmpxchg.patch: Delete.
- patches.rt/arm-compile-fix.patch: Delete.
- patches.rt/arm-fix-atomic-cmpxchg.patch: Delete.
- patches.rt/arm-futex-atomic-cmpxchg.patch: Delete.
- patches.rt/arm-latency-tracer-support.patch: Delete.
- patches.rt/arm-leds-timer.patch: Delete.
- patches.rt/arm-preempt-config.patch: Delete.
- patches.rt/arm-trace-preempt-idle.patch: Delete.
- patches.rt/latency-tracing-arm.patch: Delete.
- patches.rt/preempt-irqs-arm-fix-oprofile.patch: Delete.
- patches.rt/preempt-irqs-arm.patch: Delete.
- patches.rt/preempt-realtime-arm-bagde4.patch: Delete.
- patches.rt/preempt-realtime-arm-footbridge.patch: Delete.
- patches.rt/preempt-realtime-arm-integrator.patch: Delete.
- patches.rt/preempt-realtime-arm-ixp4xx.patch: Delete.
- patches.rt/preempt-realtime-arm-pxa.patch: Delete.
- patches.rt/preempt-realtime-arm-rawlock-in-mmu_context-h.patch:
  Delete.
- patches.rt/preempt-realtime-arm-shark.patch: Delete.
- patches.rt/preempt-realtime-arm.patch: Delete.
- patches.rt/preempt-irqs-mips.patch: Delete.
- patches.rt/preempt-realtime-mips.patch: Delete.
- patches.rt/rt-mutex-arm-fix.patch: Delete.
- patches.rt/rt-mutex-arm.patch: Delete.
- patches.rt/rt-mutex-mips.patch: Delete.
- patches.rt/mips-change-raw-spinlock-type.patch: Delete.
- patches.rt/mips-remove-conlicting-rtc-lock-declaration.patch:
  Delete.
- patches.rt/mips-remove-duplicate-kconfig.patch: Delete.
- patches.rt/mips-remove-finish-arch-switch.patch: Delete.
* Fri Apr 25 2008 carnold@novell.com
- rpm/kernel-binary.spec.in: kernel-xen does not obsolete/provide
  kernel-xenpae (bnc#382309)
* Fri Apr 25 2008 olh@suse.de
- update patches.arch/ppc-efika-mpc52xx-ac97.patch
  create /builtin/sound/cell-index, content == 1
* Thu Apr 24 2008 olh@suse.de
- update patches.arch/ppc-efika-modalias.patch
  add newline to devspec files
* Thu Apr 24 2008 olh@suse.de
- update patches.arch/ppc-efika-modalias.patch
  add devspec file for mac-io, it was created as a side effect
  in of/platform.c (bnc#374693)
* Thu Apr 24 2008 olh@suse.de
- use bzip2 instead of lzma as rpm compression method for vanilla
* Thu Apr 24 2008 olh@suse.de
- relax Conflicts for kernel-vanilla
  no version check for lvm, udev and apparmor
* Wed Apr 23 2008 olh@suse.de
- readd patches.arch/ppc-pegasos-console-autodetection.patch
  force speed 115200, device-tree has no current-speed property
* Wed Apr 23 2008 tiwai@suse.de
- patches.drivers/alsa-hda-intel-new-ati-id,
  patches.drivers/alsa-hda-intel-use-PCI_DEVICE,
  patches.drivers/alsa-hda-intel-new-nvidia-id: Add missing PCI
  ids for new ATI/Nvidia devices (bnc#370775)
- patches.drivers/alsa-dell-xps-m1330-hp-fix: Fix Dell XPS M1330
  outputs
* Tue Apr 22 2008 jack@suse.cz
- patches.fixes/quota_reiserfs_tail_fix.diff: reiserfs: Unpack
  tails on quota files (375179).
* Tue Apr 22 2008 olh@suse.de
- update patches.arch/ppc-efika-mpc52xx-ac97.patch
  fixes for 2.6.25
* Sat Apr 19 2008 schwab@suse.de
- Add compat handler for PTRACE_GETSIGINFO.
* Sat Apr 19 2008 aj@suse.de
- Conflict with apparmor-parser < 2.3 (not <=) in kernel-binary
  spec files.
* Sat Apr 19 2008 jeffm@suse.de
- Re-synced reiserfs patch set due to broken local repo.
* Sat Apr 19 2008 jeffm@suse.de
- Updated reiserfs patch set
  - Eliminated xattr interaction with AppArmor
  - Eliminated xattr deadlock under load between journal lock and
    xattr dir i_mutex
  - Properly annotated xattr i_mutex locking for lockdep
  - Code cleanup
* Fri Apr 18 2008 jjohanse@suse.de
- Update fsetattr.diff to EXPORT_SYMBOL_GPL(fnotify_change)
* Fri Apr 18 2008 jjohanse@suse.de
- patches.apparmor/__d_path-keep-connected.diff: Fix __d_path
  to allow for old and new behavior bnc#380763.
* Thu Apr 17 2008 gregkh@suse.de
- refresh patches to apply without fuzz
* Thu Apr 17 2008 gregkh@suse.de
- Update to 2.6.25-final
* Wed Apr 16 2008 jjohanse@suse.de
- Update to AppArmor 2.3 patch series
* Wed Apr 16 2008 jeffm@suse.de
- patches.suse/reiserfs-kill-xattr-readdir.diff: Fixed accidental
  passing of -ENODATA to userspace during chown, and messages during
  chown and delete.
* Tue Apr 15 2008 jbeulich@novell.com
- Update Xen patches to 2.6.25-rc9 and c/s 517.
* Sat Apr 12 2008 gregkh@suse.de
- refresh patches to clean up fuzz
* Sat Apr 12 2008 gregkh@suse.de
- Update config files.
* Sat Apr 12 2008 gregkh@suse.de
- updat to 2.6.25-rc9
* Thu Apr 10 2008 gregkh@suse.de
- update to 2.6.25-rc8-git8
* Tue Apr  8 2008 gregkh@suse.de
- update to 2.6.25-rc8-git7
* Mon Apr  7 2008 gregkh@suse.de
- patches.kernel.org/pvrusb2-fix-broken-build-due-to-patch-order-dependency.patch:
  pvrusb2: fix broken build due to patch order dependency.
* Mon Apr  7 2008 gregkh@suse.de
- update to 2.6.25-rc8-git5
* Sun Apr  6 2008 jeffm@suse.de
- patches.suse/reiserfs-kill-xattr-readdir.diff: Removed struct
  file use entirely.
* Sun Apr  6 2008 jeffm@suse.de
- patches.suse/reiserfs-kill-xattr-readdir.diff: Eliminated use
  of vfsmount-less dentry_open().
* Thu Apr  3 2008 teheo@suse.de
- patches.drivers/libata-pata_ali-disable-ATAPI_DMA: pata_ali:
  disable ATAPI DMA (332588).
* Wed Apr  2 2008 gregkh@suse.de
- Update to 2.6.25-rc8
* Tue Apr  1 2008 jblunck@suse.de
- rpm/kernel-source.spec.in,kernel-binary.spec.in: Cleanup Requires
* Mon Mar 31 2008 jdelvare@suse.de
- supported.conf: Add new hwmon drivers, all unsupported.
* Thu Mar 27 2008 jeffm@suse.de
- Fixed up the rest of the reiserfs patch queue.
* Thu Mar 27 2008 jeffm@suse.de
- Updated reiserfs xattr patches.
* Thu Mar 27 2008 gregkh@suse.de
- fix merge error in patches.suse/supported-flag caused by me...
* Thu Mar 27 2008 gregkh@suse.de
- update to 2.6.25-rc7-git2
* Thu Mar 27 2008 gregkh@suse.de
- update to 2.6.25-rc7
  - note that reiserfs xattr patches are now disabled due to merge
    issues...
* Sun Mar 23 2008 teheo@suse.de
- patches.drivers/libata-improve-hpa-error-handling: libata:
  improve HPA error handling (365534).
* Thu Mar 20 2008 gregkh@suse.de
- fix up some EXPORT_SYMBOL() markings to be EXPORT_SYMBOL_GPL() as the
  code is not upstream and we aren't allowed to add non-GPL exports to
  our kernel tree.
* Thu Mar 20 2008 gregkh@suse.de
- update to 2.6.25-rc6-git5
- refresh patches to apply cleanly
* Thu Mar 20 2008 gregkh@suse.de
- update to 2.6.25-rc6-git4
- refresh patches to apply cleanly
* Thu Mar 20 2008 agruen@suse.de
- scripts/tar-up.sh: Rename --kbuild option to --source-timestamp.
  For generating the source timestamp, use HEAD as the branch
  name.
- rpm/get_release_number.sh.in: Don't try to synchronize release
  numbers with kernel-dummy if the release number has been
  specified explicitly (tar-up with --release-string, --timestamp,
  or --source-timestamp).
* Thu Mar 20 2008 olh@suse.de
- remove patches.kernel.org/powerpc-needs-uboot
  not needed without mpc51xx support
* Thu Mar 20 2008 olh@suse.de
- disable gianfar network driver and unused freescale drivers
* Wed Mar 19 2008 gregkh@suse.de
- patch refreshes due to version update
* Wed Mar 19 2008 gregkh@suse.de
- Update to 2.6.25-rc6-git3
- Update config files.
* Wed Mar 19 2008 gregkh@suse.de
- Update to 2.6.25-rc6
  - which deleted the following patches:
  - patches.fixes/hibernation-snapshot-numa-workaround.patch
  - patches.fixes/acpi-fix-double-log-level.patch
  - patches.fixes/acpi_fix_mem_corruption.patch
  - patches.kernel.org/patch-2.6.25-rc5
  - patches.kernel.org/patch-2.6.25-rc5-git3
- Update config files.
- delete patches.arch/x86-nvidia-timer-quirk as it is not being used.
* Wed Mar 19 2008 olh@suse.de
- remove patches.arch/ppc-efika-ipic.patch
  disable mpc51xx support instead
* Tue Mar 18 2008 jeffm@suse.de
- rpm/kernel-binary.spec.in: Changed to just match %%ix86
* Tue Mar 18 2008 olh@suse.de
- add patches.arch/ppc-efika-ipic.patch
  fix a crash in init_ipic_sysfs on efika
* Mon Mar 17 2008 agruen@suse.de
- post.sh: Fix a syntax error when creating the initrd.
* Mon Mar 17 2008 jbeulich@novell.com
- patches.xen/xen-quicklist.patch: Delete.
- Update i386 Xen config file.
- patches.xen/xen3-patch-2.6.25-rc5-rc6: 2.6.25-rc6.
- patches.xen/xen3-auto-xen-kconfig.diff,
  patches.xen/xen3-fixup-kconfig,
  patches.xen/xen3-patch-2.6.19,
  patches.xen/xen3-patch-2.6.20,
  patches.xen/xen3-patch-2.6.21,
  patches.xen/xen3-patch-2.6.22,
  patches.xen/xen3-patch-2.6.23,
  patches.xen/xen3-patch-2.6.24,
  patches.xen/xen3-patch-2.6.25-rc5,
  patches.xen/xen-x86-no-lapic,
  patches.xen/xen-x86-panic-no-reboot: Various adjustments.
* Sun Mar 16 2008 jeffm@suse.de
- rpm/kernel-binary.spec.in: Added an RPM conflict for 32-bit
  kernels and 64-bit glibc to avoid installing a 32-bit kernel
  with 64-bit userspace. (364433, et al)
* Fri Mar 14 2008 jeffm@suse.de
- scripts/tar-up.sh: Added --kbuild option to autogenerate
  release number based on branch and timestamp.
* Fri Mar 14 2008 jeffm@suse.de
- patches.apparmor/export-security_inode_permission-for-aufs:
  LSM: Export security_inode_permission for aufs (356902).
* Fri Mar 14 2008 agruen@suse.de
- Boot loader: do the same during initial installation as when
  updating a kernel package (FATE 302660).
* Thu Mar 13 2008 gregkh@suse.de
- Update to 2.6.25-rc5-git3
* Thu Mar 13 2008 olh@suse.de
- disable unuses pata platform and ibm newemac driver on powerpc
* Thu Mar 13 2008 olh@suse.de
- add patches.xen/xen-quicklist.patch
  fix kernel-xen compile, readd CONFIG_QUICKLIST for xen
* Wed Mar 12 2008 gregkh@suse.de
- remove alpha configs as they are no longer used
* Wed Mar 12 2008 gregkh@suse.de
- Enabled CONFIG_UNUSED_SYMBOLS for now.  It will be disabled
  after the next openSUSE alpha release.  It is being enabled
  for now to let some kmp packages still work while their
  maintainers are working to update them with the 2.6.25
  kernel changes.
* Wed Mar 12 2008 gregkh@suse.de
- refresh patches to apply cleanly
* Wed Mar 12 2008 gregkh@suse.de
- update to 2.6.25-rc5-git2
* Wed Mar 12 2008 sassmann@suse.de
- patches.arch/ppc-ps3-rename-wireless-interface.patch:
  rename ps3 wireless interface from eth? to wlan? for better
  handling in udev
* Wed Mar 12 2008 jbeulich@novell.com
- Update Xen patches to 2.6.25-rc5 and c/s 471.
- patches.xen/xen3-aslr-i386-and-x86_64-randomize-brk.patch:
  Delete.
- patches.xen/xen3-aslr-pie-executable-randomization.patch:
  Delete.
- patches.xen/xen3-early-firewire.diff: Delete.
- Update x86 config files.
- config.conf: Re-enable Xen configs.
* Tue Mar 11 2008 gregkh@suse.de
- add usb persist for storage devices across suspend to ram.  This is going to
  be in 2.6.26, just missed the .25 merge window.
* Tue Mar 11 2008 gregkh@suse.de
- Update to 2.6.26-rc5-git1
- Update config files.
* Tue Mar 11 2008 gregkh@suse.de
- update to 2.6.25-rc5
* Mon Mar 10 2008 agruen@suse.de
- scripts/tar-up.sh: Don't lose the EXTRAVERSION when overriding
  the release number with --release-string or --timestamp.
* Sun Mar  9 2008 jeffm@suse.de
- patches.fixes/hibernation-snapshot-numa-workaround.patch:
  swsusp: workaround for crash on NUMA (kernel.org#9966).
* Sat Mar  8 2008 agruen@suse.de
- Encode the EXTRAVERSION part of kernel release numbers in the
  RPM release instead of in the version. This resolves the problem
  that kernel releases like 2.6.25-rc4 would result in a package
  with a higher version than 2.6.25 according to RPM's versioning
  scheme (bug 271712).
* Fri Mar  7 2008 schwab@suse.de
- Update kdb patches.
* Thu Mar  6 2008 trenn@suse.de
- patches.fixes/acpi_fix_mem_corruption.patch: ACPI: Fix mem
  corruption (350017).
- patches.fixes/acpi_thermal_passive_cleanup.patch: Warn user
  about a BIOS bug in asus boards (350017).
* Thu Mar  6 2008 gregkh@suse.de
- Update s390 config files.
* Thu Mar  6 2008 gregkh@suse.de
- update to 2.6.24-rc5-git1
* Wed Mar  5 2008 gregkh@suse.de
- enable CONFIG_GROUP_SCHED
* Wed Mar  5 2008 gregkh@suse.de
- enable CONFIG_HIGH_RES_TIMERS on i386
* Wed Mar  5 2008 gregkh@suse.de
- enable CONFIG_USB_PERSIST for vanilla config files
* Wed Mar  5 2008 gregkh@suse.de
- refresh patches to apply cleanly with no fuzz
- enable CONFIG_USB_PERSIST so that users can enable this if they want
* Wed Mar  5 2008 gregkh@suse.de
- update the vanilla config files for CONFIG_DEBUG_RODATA
* Wed Mar  5 2008 gregkh@suse.de
- enable CONFIG_DEBUG_RODATA (Not really a debug option, something
  we need in all of our kernels.)
* Wed Mar  5 2008 gregkh@suse.de
- Update vanilla config files.
* Wed Mar  5 2008 jbeulich@novell.com
- patches.fixes/parport-mutex,
  patches.suse/stack-unwind: Fix merge mistakes.
- Update i386 config files.
* Wed Mar  5 2008 gregkh@suse.de
- Update tree to 2.6.25-rc4
* Wed Mar  5 2008 fseidel@suse.de
- add patches.fixes/fat_detect_media_wo_parttable.patch and
  patches.fixes/fat_valid_media.patch:
  detect FAT formated medias without partition table correctly
  (bnc 364365)
* Tue Mar  4 2008 olh@suse.de
- add patches.kernel.org/s390-defkeymap.patch
  Build fix for drivers/s390/char/defkeymap.c
* Tue Mar  4 2008 olh@suse.de
- enable ext2/3 acl support in ps3 kernel
* Tue Mar  4 2008 olh@suse.de
- Update to 2.6.25-rc3-git5
* Tue Mar  4 2008 olh@suse.de
- use suffix -ps3 for PS3 kernel, it is only used in otheros.bld
* Mon Mar  3 2008 lmb@suse.de
- rpm/kernel-binary.spec.in: Require udev >= 118.
* Mon Mar  3 2008 ak@suse.de
- patches.arch/x86-nvidia-timer-quirk: Delete.
  PCI device ID list still not complete and let's have the same
  crap as mainline for now. It would be better to fix the PCI
  ID lists (#302327)
* Sun Mar  2 2008 olh@suse.de
- add patches.fixes/ibmvstgt-fixes.patch
  fix oops in ibmvstgt init function
* Fri Feb 29 2008 olh@suse.de
- add patches.arch/ppc-pci-bogus-resources.patch
  fix bogus test for unassigned resources
* Thu Feb 28 2008 olh@suse.de
- disable CONFIG_CRYPTO_DEV_HIFN_795X on ppc32 due to __divdi3 usage
- update patches.kernel.org/powerpc-needs-uboot
  disable mkimage call in arch/powerpc/boot/wrapper
* Thu Feb 28 2008 olh@suse.de
- update patches.kernel.org/fixed-phy-select
  add dependency on libphy=y
* Wed Feb 27 2008 jdelvare@suse.de
- patches.fixes/acpi-fix-double-log-level.patch: ACPI: Fix a
  duplicate log level.
* Wed Feb 27 2008 trenn@suse.de
- patches.fixes/acpi_force-fan-active.patch: Delete.
* Tue Feb 26 2008 sdietrich@suse.de
- remove obsolete adaptive-locks patches
  patches.rt/rtmutex-adaptive-locks.patch: Delete.
  patches.rt/rtmutex-adjust-pi_lock-usage-in-wakeup.patch: Delete.
  patches.rt/rtmutex-optimize-wakeup.patch: Delete.
  patches.rt/rtmutex-rearrange.patch: Delete.
  patches.rt/rtmutex-remove-extra-try.patch: Delete.
  patches.rt/rtmutex-adaptive-mutexes.patch: Delete.
  patches.rt/rtmutex-adaptive-timeout.patch: Delete.
  patches.rt/rtmutex-lateral-steal.patch: Delete.
  patches.rt/rtmutex-lateral-steal-sysctl.patch: Delete.
* Tue Feb 26 2008 sassmann@suse.de
- remove patches included upstream
  patches.arch/ppc-ps3-gelic-cleanup.patch
  patches.arch/ppc-ps3-gelic-endianness.patch
  patches.arch/ppc-ps3-gelic-ethernet-linkstatus.patch
  patches.arch/ppc-ps3-gelic-fix-fallback.diff
  patches.arch/ppc-ps3-gelic-multiple-interface.patch
  patches.arch/ppc-ps3-gelic-remove-duplicate-ethtool-handlers.patch
  patches.arch/ppc-ps3-gelic-wireless-v2.patch
* Tue Feb 26 2008 jeffm@suse.de
- Update config files: Disabled CONFIG_INPUT_YEALINK per an old
  request from AJ.
* Tue Feb 26 2008 jeffm@suse.de
- Update to 2.6.25-rc3.
* Sun Feb 24 2008 sdietrich@suse.de
- patches.rt/0001-sched-count-of-queued-RT-tasks.patch: Delete.
- patches.rt/0002-sched-track-highest-prio-task-queued.patch:
  Delete.
- patches.rt/0003-sched-add-RT-task-pushing.patch: Delete.
- patches.rt/0004-sched-add-rt-overload-tracking.patch: Delete.
- patches.rt/0005-sched-pull-RT-tasks-from-overloaded-runqueues.patch:
  Delete.
- patches.rt/0006-sched-push-RT-tasks-from-overloaded-CPUs.patch:
  Delete.
- patches.rt/0007-sched-disable-standard-balancer-for-RT-tasks.patch:
  Delete.
- patches.rt/0008-sched-add-RT-balance-cpu-weight.patch: Delete.
- patches.rt/0009-sched-clean-up-this_rq-use-in-kernel-sched_rt.c.patch:
  Delete.
- patches.rt/0010-sched-de-SCHED_OTHER-ize-the-RT-path.patch:
  Delete.
- patches.rt/0011-sched-break-out-search-for-RT-tasks.patch:
  Delete.
- patches.rt/0012-sched-RT-balancing-include-current-CPU.patch:
  Delete.
- patches.rt/0013-sched-pre-route-RT-tasks-on-wakeup.patch:
  Delete.
- patches.rt/0014-sched-optimize-RT-affinity.patch: Delete.
- patches.rt/0015-sched-wake-balance-fixes.patch: Delete.
- patches.rt/0016-sched-RT-balance-avoid-overloading.patch:
  Delete.
- patches.rt/0017-sched-break-out-early-if-RT-task-cannot-be-migrated.patch:
  Delete.
- patches.rt/0018-sched-RT-balance-optimize.patch: Delete.
- patches.rt/0019-sched-RT-balance-optimize-cpu-search.patch:
  Delete.
- patches.rt/0020-sched-RT-balance-on-new-task.patch: Delete.
- patches.rt/0021-sched-clean-up-pick_next_highest_task_rt.patch:
  Delete.
- patches.rt/0022-sched-clean-up-find_lock_lowest_rq.patch:
  Delete.
- patches.rt/0023-sched-clean-up-overlong-line-in-kernel-sched_debug.patch:
  Delete.
- patches.rt/0024-sched-clean-up-kernel-sched_rt.c.patch: Delete.
- patches.rt/0025-sched-remove-rt_overload.patch: Delete.
- patches.rt/0026-sched-remove-leftover-debugging.patch: Delete.
- patches.rt/0027-sched-clean-up-pull_rt_task.patch: Delete.
- patches.rt/0028-sched-clean-up-schedule_balance_rt.patch:
  Delete.
- patches.rt/0029-sched-add-sched-domain-roots.patch: Delete.
- patches.rt/0030-sched-update-root-domain-spans-upon-departure.patch:
  Delete.
- patches.rt/0031-Subject-SCHED-Only-balance-our-RT-tasks-within-ou.patch:
  Delete.
- patches.rt/0032-sched-fix-sched_rt.c-join-leave_domain.patch:
  Delete.
- patches.rt/0033-sched-remove-unused-JIFFIES_TO_NS-macro.patch:
  Delete.
- patches.rt/0034-sched-style-cleanup-2.patch: Delete.
- patches.rt/0035-sched-add-credits-for-RT-balancing-improvements.patch:
  Delete.
- patches.rt/0036-sched-reactivate-fork-balancing.patch: Delete.
- patches.rt/0037-sched-whitespace-cleanups-in-topology.h.patch:
  Delete.
- patches.rt/0038-sched-no-need-for-affine-wakeup-balancing-in.patch:
  Delete.
- patches.rt/0039-sched-get-rid-of-new_cpu-in-try_to_wake_up.patch:
  Delete.
- patches.rt/0040-sched-remove-do_div-from-__sched_slice.patch:
  Delete.
- patches.rt/0041-sched-RT-balance-replace-hooks-with-pre-post-sched.patch:
  Delete.
- patches.rt/0042-sched-RT-balance-add-new-methods-to-sched_class.patch:
  Delete.
- patches.rt/0043-sched-RT-balance-only-adjust-overload-state-when-c.patch:
  Delete.
- patches.rt/0044-sched-remove-some-old-cpuset-logic.patch:
  Delete.
- Remove scheduler patches already upstream in 2.6.25-rc1
* Sat Feb 23 2008 jeffm@suse.de
- patches.kernel.org/libertas-section-conflict: libertas: fix
  section conflict.
* Sat Feb 23 2008 jeffm@suse.de
- Enabled patches.kernel.org/ps3-lpm-include
* Sat Feb 23 2008 jeffm@suse.de
- patches.kernel.org/spu_profiler-include: powerpc: spu_profiler
  build fix.
* Sat Feb 23 2008 jeffm@suse.de
- patches.kernel.org/ps3-lpm-include: ps3: lpm build fix.
* Sat Feb 23 2008 jeffm@suse.de
- patches.kernel.org/fixed-phy-select: powerpc: FSL_SOC requires
  FIXED_PHY.
- patches.kernel.org/lguest-fixups: lguest: Fix asm-offsets_32
  with correct config option.
* Sat Feb 23 2008 jeffm@suse.de
- Build fixes for ia64 and i386.
* Sat Feb 23 2008 jeffm@suse.de
- Update to 2.6.25-rc2-git6.
  - Removed:
  - patches.arch/ppc-pegasos-pata_via-fixup.patch: Delete.
  - patches.arch/ppc-pegasos-console-autodetection.patch: Delete.
  - patches.arch/ppc-ps3-make-dev_id-and-bus_id-u64.diff: Delete.
  - patches.arch/acpi_autoload_bay.patch: Delete.
  - patches.arch/small-acpica-extension-to-be-able-to-store-the-name-of.patch:
    Delete.
  - patches.arch/export-acpi_check_resource_conflict.patch: Delete.
  - patches.drivers/early-firewire.diff: Delete.
  - patches.drivers/scsi-throttle-SG_DXFER_TO_FROM_DEV-warning-better:
    Delete.
  - patches.drivers/libata-implement-force-parameter: Delete.
  - patches.drivers/igb-1.0.8-k2: Delete.
  - patches.drivers/always-announce-new-usb-devices.patch: Delete.
  - patches.drivers/nozomi.patch: Delete.
  - patches.drivers/libata-quirk_amd_ide_mode: Delete.
  - patches.fixes/acpi_autoload_baydock.patch: Delete.
  - patches.fixes/bluetooth_hci_dev_put.patch: Delete.
  - patches.fixes/bluetooth_hci_conn_childs.patch: Delete.
  - patches.fixes/mac80211-fix-hw-scan1.patch: Delete.
  - patches.fixes/mac80211-fix-hw-scan2.patch: Delete.
  - patches.fixes/libiscsi-missing-semicolon.diff: Delete.
  - patches.fixes/pci-quirk-enable-smbus-on-hp-xw4100.patch: Delete.
  - patches.kernel.org/patch-2.6.24.1: Delete.
  - patches.suse/acpi_dsdt_ssdt_initrd_initramfs.patch: Delete.
  - patches.suse/squashfs.patch.fixup: Delete.
  - patches.suse/aslr-pie-executable-randomization.patch: Delete.
  - patches.suse/aslr-i386-and-x86_64-randomize-brk.patch: Delete.
  - Xen and RT currently disabled.
  - SquashFS may not work.
* Fri Feb 22 2008 jeffm@suse.de
- scripts/embargo-filter: fixed and renabled check
* Fri Feb 22 2008 sdietrich@suse.de
- embargoed-patches: eliminate embargoed patches abuse.
* Fri Feb 22 2008 jeffm@suse.de
- scripts/embargo-filter: Disable check for non-existant patches.
* Fri Feb 22 2008 schwab@suse.de
- Update kdb patches.
* Fri Feb 22 2008 jbeulich@novell.com
- config/i386/xenpae: Rename to config/i386/xen.
- config.conf: Delete i386/xenpae.
* Thu Feb 21 2008 sdietrich@suse.de
- Update config files: update RT options for adaptive RT locks
* Thu Feb 21 2008 sdietrich@suse.de
- patches.rt/rtmutex-adaptive-mutexes.patch: cleanup.
- patches.rt/rtmutex-adaptive-timeout.patch: cleanup.
- patches.rt/rtmutex-lateral-steal-sysctl.patch: sysctl for
  runtime-control of lateral mutex stealing.
* Thu Feb 21 2008 jbeulich@novell.com
- Update Xen patches to c/s 425.
- patches.xen/sfc-network-driver: Solarflare: Standard network driver
  (disabled until status clarified).
- patches.xen/sfc-resource-driver: Solarflare: Resource driver
  (disabled until status clarified).
- Update Xen config files.
* Wed Feb 20 2008 ghaskins@suse.de
- adaptive-locking v20
* Wed Feb 20 2008 ghaskins@suse.de
- adaptive-locking v19
* Wed Feb 20 2008 jeffm@suse.de
- Update config files for dmraid45.
* Wed Feb 20 2008 bwalle@suse.de
- rpm/kernel-binary.spec.in: add PAGESIZE detection for
  makedumpfile.config from the .config file also for PPC64
* Wed Feb 20 2008 fseidel@suse.de
- patches.fixes/bluetooth_hci_dev_put.patch,
  patches.fixes/bluetooth_hci_conn_childs.patch,
  patches.fixes/bluetooth_hci_unregister_sysfs.patch:
  fix kernel crash after removing bluetooth adapter (bnc 359546)
* Tue Feb 19 2008 jeffm@suse.de
- patches.suse/dm-raid45-2.6.24-20080602a.patch: DMRAID45 module.
* Fri Feb 15 2008 sdietrich@suse.de
- Update to latest patch set:
- patches.rt/rearrange_rtspinlock_sleep:
  [PATCH 02/10] rearrange rtspinlock sleep
- patches.rt/optimize_rtspinlock_wakeup:
  [PATCH 03/10] optimize rtspinlock wakeup
- patches.rt/adaptive_RT_spinlock_support:
  [PATCH 04/10] Adaptive RT spinlock support
- patches.rt/add_timeout_mechanism: [PATCH 05/10]
  add a loop counter based timeoutmechanism
- patches.rt/adaptive_mutexes: [PATCH 06/10] adaptive mutexes
- patches.rt/adjust_pi_lock_usage_in_wakeup:
  [PATCH 07/10] Adjust pi_lock usage in wakeup
- patches.rt/optimize_printk_fastpath: [PATCH 08/10]
  optimize the !printk fastpath throughthe lock acquisition
- patches.rt/remove_extra_call_try_to_take_lock:
  [PATCH 09/10] remove the extra call to try_to_take_lock
- patches.rt/lateral_lock_steal: [PATCH 10/10] allow
  rt-mutex lock-stealing toinclude lateral priority
* Fri Feb 15 2008 sdietrich@suse.de
- embargoed-patches: (embargo development RT throughput patches)
- Update config files (RT config options)
- patches.rt/optimize_rtspinlock_wakeup: optimize rtspinlock
  wakeup.
- patches.rt/adaptive_RT_spinlock_support: Adaptive RT spinlock
  support.
- patches.rt/add_timeout_mechanism: add
  a loop counter based timeout mechanism
- patches.rt/adaptive_mutexes: adaptive mutexes
- patches.rt/adjust_pi_lock_usage_in_wakeup:
  Adjust pi_lock usage in wakeup
- patches.rt/optimize_printk_fastpath: optimize
  the !printk fastpath through the lockacquisition
- patches.rt/remove_extra_call_try_to_take_lock:
  remove the extra call to try_to_take_lock
- patches.rt/lateral_lock_steal: allow rt-mutex
  lock-stealing to include lateralpriority
- patches.rt/rearrange_rtspinlock_sleep: cleanup rtspinlock sleep
* Thu Feb 14 2008 jeffm@suse.de
- Removed unused OCFS2 patches.
* Thu Feb 14 2008 jeffm@suse.de
- Removed old commented out ocfs2 patchset.
* Thu Feb 14 2008 teheo@suse.de
- patches.drivers/libata-quirk_amd_ide_mode: PCI: modify SATA
  IDE mode quirk (345124).
* Wed Feb 13 2008 jeffm@suse.de
- patches.suse/ocfs2-03-split-disk-heartbeat-out.diff: Fixed
  section conflict.
* Wed Feb 13 2008 jeffm@suse.de
- Update config files.
* Wed Feb 13 2008 jeffm@suse.de
- Merged and re-enabled OCFS2 userspace clustering
* Wed Feb 13 2008 jdelvare@suse.de
- config/*: Don't build i2c algorithm drivers that we do not use.
- supported.conf: Drop i2c-elektor and i2c-algo-pcf, we don't ship
  them.
* Tue Feb 12 2008 teheo@suse.de
  Build fix for section mismatch check.
- patches.drivers/libata-implement-force-parameter: libata:
  implement libata.force module parameter (337610).
* Mon Feb 11 2008 teheo@suse.de
- patches.drivers/libata-force-cable-type: Delete.
- patches.drivers/libata-implement-force-parameter: libata:
  implement libata.force module parameter (337610).
* Fri Feb  8 2008 gregkh@suse.de
- Update to 2.6.24.1
  - fixes CVE-2008-0007, CVE-2008-0009, CVE-2008-0010
  - lots of USB device ids updated
  - lots of other bugfixes
  - removed patches.fixes/bootstrap-memoryless-node.patch as it is now
    contained within.
* Fri Feb  8 2008 gregkh@suse.de
- Move ipv6-no-autoconf to xen directory as it is a Xen bugfix
* Fri Feb  8 2008 bwalle@suse.de
- patches.arch/ppc-fix-prpmc2800: remove patch since it's not needed
  with current binutils any more
* Fri Feb  8 2008 bwalle@suse.de
- patches.drivers/igb-2007-12-11: Delete.
- patches.drivers/igb-1.0.8-k2: Update to latest version which is
  also upstream now in the 2.6.25 tree.
* Fri Feb  8 2008 gregkh@suse.de
- Remove NO_BRP_NOEXECSTACK from the .spec files as it is obsolete
  and doesn't do anything anymore.
* Fri Feb  8 2008 jbeulich@novell.com
- patches.xen/xen3-auto-common.diff,
  patches.xen/xen3-patch-2.6.23: fix merge mistake.
* Fri Feb  8 2008 jbenc@suse.cz
- Update config files: disabled CONFIG_BCM43XX.
* Wed Feb  6 2008 jeffm@suse.de
- patches.apparmor/vfs-mkdir.diff: Added missing case in
  kernel/cgroup.c
* Wed Feb  6 2008 fseidel@suse.de
- updated patches.drivers/nozomi.patch: mainline info
* Wed Feb  6 2008 sdietrich@suse.de
- Update config files: RT@1KHz, sched groups & cpusets enabled.
* Wed Feb  6 2008 olh@suse.de
- enable bnx2 on ppc64 (bnc 359114 - LTC42106)
* Wed Feb  6 2008 gregkh@suse.de
- remove unused lockd patches:
  - patches.suse/lockd-switchable-statd
  - patches.suse/lockd-kernel-statd
  - patches.suse/lockd-suse-config
  - patches.suse/lockd-max-hosts-dynamic
* Wed Feb  6 2008 oneukum@suse.de
- patches.suse/usb_printer_no_auto.diff: Delete.
  Obsoleted by mainline change
* Tue Feb  5 2008 gregkh@suse.de
- Enable CONFIG_TASK_IO_ACCOUNTING (bnc 356547) for RT kernels
* Tue Feb  5 2008 gregkh@suse.de
- Enable CONFIG_TASK_IO_ACCOUNTING (bnc 356547)
* Thu Jan 31 2008 sdietrich@suse.de
- patches.rt/megasas_IRQF_NODELAY.patch: Convert megaraid sas
  IRQ to non-threaded IRQ.
- patches.rt/version.patch: Delete (unused).
* Thu Jan 31 2008 jbenc@suse.cz
- patches.fixes/mac80211-fix-hw-scan1.patch,
  patches.fixes/mac80211-fix-hw-scan2.patch: mac80211: hardware
  scan rework (bnc#307050).
* Thu Jan 31 2008 sdietrich@suse.de
- Remove a legacy tweak carried over from the 10.3 Kernel,
  enable the affinity load-balancing sysctl.
* Wed Jan 30 2008 sdietrich@suse.de
- patches.rt/x86-ticket-lock.patch: FIFO ticket lock spinlocks
  for x86 (RT).
- patches.rt/rt-mutex-i386.patch: Resolve conflicts.
* Tue Jan 29 2008 olh@suse.de
- really skip kernel-ps3 in suse_kernel_module_package rpm macro
* Tue Jan 29 2008 jbeulich@novell.com
- Update Xen patches to 2.6.24 final and c/s 399.
- patches.xen/xen3-seccomp-disable-tsc-option: [PATCH seccomp:
  make tsc disabling optional (191123).
* Sat Jan 26 2008 sdietrich@suse.de
- Linux-RT 2.6.24-rt1 (many patches in patches.rt refreshed).
- patches.rt/series: Delete (unused).
* Sat Jan 26 2008 olh@suse.de
- update patches.arch/ppc-efika-modalias.patch
  use struct device_attribute to fix oops on boot
* Sat Jan 26 2008 jeffm@suse.de
- scripts/sequence-patch.sh: Updated to include $EXTRA_SYMBOLS in
  $PATCH_DIR (e.g.: --symbol=RT creates linux-2.6.24-RT)
* Fri Jan 25 2008 jeffm@suse.de
- patches.rt/rcu-new-1.patch: Updated context against 2.6.24.
* Fri Jan 25 2008 olh@suse.de
- add patches.fixes/bootstrap-memoryless-node.patch
  slab: fix bootstrap on memoryless node
* Fri Jan 25 2008 gregkh@suse.de
- refresh allmost all patches to apply cleanly and have a proper
  diffstat (except for the xen patches, they were left alone...)
* Fri Jan 25 2008 gregkh@suse.de
- Update to 2.6.24
* Thu Jan 24 2008 olh@suse.de
- always skip kernel-ps3 in suse_kernel_module_package rpm macro
* Thu Jan 24 2008 sdietrich@suse.de
- Update config files: set SYSFS_DEPRECATED for reverse
  compatibility with SLERT
* Tue Jan 22 2008 olh@suse.de
- update patches.arch/ppc-efika-modalias.patch
  simplify patch
* Tue Jan 22 2008 agruen@suse.de
- patches.rpmify/cloneconfig.diff: Adjust to upstream i386 + x86_64
  merge (347712).
* Tue Jan 22 2008 sassmann@suse.de
- add defconfig for ps3 kernel
- add entry for ps3 defconfig in config.conf
- add support for kernels without loadable modules to rpm/kernel-binary.spec.in
- include ps3 target in scripts/tar-up_and_run_mbuild.sh
* Mon Jan 21 2008 sdietrich@suse.de
- Update config files (RT)
* Mon Jan 21 2008 sdietrich@suse.de
- Linux-RT 2.6.24-rc8-rt1
* Mon Jan 21 2008 olh@suse.de
- add patches.arch/ppc-pegasos-pata_via-fixup.patch
  call chrp_pci_fixup_vt8231_ata() later to allow pata_via usage
* Mon Jan 21 2008 aj@suse.de
- Remove unused config/s390/rt.
* Sat Jan 19 2008 jeffm@suse.de
- patches.rt/irq-flags-unsigned-long.patch: Delete.
* Sat Jan 19 2008 jeffm@suse.de
- Update to 2.6.24-rc8-git2.
* Fri Jan 18 2008 jeffm@suse.de
- Enabled 2.6.24-rc8-git1.
* Fri Jan 18 2008 jbenc@suse.cz
- patches.fixes/rt2x00-remove-duplicate-id.patch: Delete. The patch
  is not correct, there exist two cards with different chipsets but
  the same USB ID.
* Fri Jan 18 2008 jbenc@suse.cz
- patches.fixes/rt2x00-remove-duplicate-id.patch: rt2x00: remove
  duplicate USB ID (350956).
* Fri Jan 18 2008 olh@suse.de
- sync powerpc vanilla with default .config to enable libata
* Fri Jan 18 2008 olh@suse.de
- add patches.arch/ppc-pegasos-mv643xx_eth-modalias.patch
  provide module alias platform:mv643xx_eth
* Thu Jan 17 2008 jeffm@suse.de
- Update to 2.6.24-rc8-git1.
* Wed Jan 16 2008 jeffm@suse.de
- Update to 2.6.24-rc8.
* Sun Jan 13 2008 jeffm@suse.de
- Update to 2.6.24-rc7-git5.
* Fri Jan 11 2008 jeffm@suse.de
- Update to 2.6.24-rc7-git3.
* Fri Jan 11 2008 jbeulich@novell.com
- Update Xen patches to c/s 372 and 2.6.24-rc7.
- patches.xen/xen3-aux-at_vector_size.patch: Delete.
- Update Xen config files.
* Thu Jan 10 2008 olh@suse.de
- update patches.arch/ppc-efika-ethernet-phy.patch
  move Forth code to fixup_device_tree_efika
* Wed Jan  9 2008 schwab@suse.de
- Fix debug package build.
* Wed Jan  9 2008 oneukum@suse.de
- Update config files. CONFIG_USB_SUSPEND default
* Wed Jan  9 2008 schwab@suse.de
- Update kdb patches.
* Wed Jan  9 2008 jbeulich@novell.com
- patches.suse/stack-unwind: Another try...
* Wed Jan  9 2008 jeffm@suse.de
- Update config files: Enabled CONFIG_SCSI_SAS_ATA. (346990)
* Wed Jan  9 2008 jbeulich@novell.com
- patches.suse/stack-unwind: Fix CONFIG_FRAME_POINTER build.
* Wed Jan  9 2008 jbeulich@novell.com
- patches.suse/stack-unwind: DWARF2 EH-frame based stack
  unwinding.
- patches.xen/xen3-stack-unwind: DWARF2 EH-frame based stack
  unwinding.
- Update config files.
* Tue Jan  8 2008 jeffm@suse.de
- patches.fixes/seccomp-disable-tsc-option: Fixed so it only applies
  to i386, and updated config files.
* Tue Jan  8 2008 jeffm@suse.de
- patches.fixes/seccomp-disable-tsc-option: [PATCH] seccomp:
  make tsc disabling optional (191123).
* Tue Jan  8 2008 olh@suse.de
- add patches.arch/ppc-efika-ethernet-phy.patch
  drop patches.arch/ppc-efika-bestcomm-ethernet.patch
  provide phy-handle property for fec_mpc52xx (347234)
* Tue Jan  8 2008 teheo@suse.de
- patches.drivers/libata-force-cable-type: libata: implement
  libata.force_cbl parameter (337610).
* Mon Jan  7 2008 jeffm@suse.de
- Update to 2.6.24-rc7.
* Mon Jan  7 2008 teheo@suse.de
- patches.drivers/libata-sata_nv-disable-ADMA: sata_nv: disable
  ADMA by default (346508).
* Mon Jan  7 2008 teheo@suse.de
  Bug 347708.  port_info for vmw was being assigned to the wrong index.
- patches.drivers/libata-ata_piix-vmw-ign-DMA-err: ata_piix:
  ignore ATA_DMA_ERR on vmware ich4 (258256).
* Mon Jan  7 2008 teheo@suse.de
  As the rest of kernel has caught up now, this one is no longer
  necessary.
- patches.drivers/libata-fix-up-build-after-upstream-update.patch:
  Delete.
* Mon Jan  7 2008 teheo@suse.de
- patches.drivers/libata-fix-up-build-after-upstream-update.patch:
  Delete.
- patches.drivers/libata-ata_piix-vmw-ign-DMA-err: ata_piix:
  ignore ATA_DMA_ERR on vmware ich4 (258256).
* Fri Jan  4 2008 jeffm@suse.de
- Update config files for -vanilla.
* Fri Jan  4 2008 jeffm@suse.de
- patches.rt/timer-freq-tweaks.patch: Adjusted context.
* Fri Jan  4 2008 jeffm@suse.de
- Update config files.
* Fri Jan  4 2008 jeffm@suse.de
- Update to 2.6.24-rc6-git11.
* Wed Jan  2 2008 jblunck@suse.de
- rpm/kernel-binary.spec.in: Copy debug sources to a proper location.
* Tue Jan  1 2008 jeffm@suse.de
- Update to 2.6.24-rc6-git7.
* Tue Jan  1 2008 jeffm@suse.de
- scripts/run_oldconfig.sh: Removed RT symbol from EXTRA_SYMBOLS.
  We add it manually when building the patch list. This allows
  the script to work with the RT kernel without having to remove
  all the other configs from config.conf first.
